@@ -34,9 +34,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 //  Suported extensions
 //
+//  DESCRIPTION:
+//  Extensions in IFRIT must be associated with power-of-two ids, so that they can be ORed together.
+//
 #define IEXTENSION_NONE		0
 #define IEXTENSION_HART		1
 #define IEXTENSION_MV		2
+#define IEXTENSION_GADGET	4
 
 //
 //  Supported shells
