@@ -35,22 +35,22 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ianimatorscript.h"
 #include "icontrolmodule.h"
-#include "icrosssectionviewobject.h"
+#include "icrosssectionviewsubject.h"
 #include "idata.h"
 #include "idataexplorer.h"
 #include "idatareader.h"
 #include "iedition.h"
-#include "imarkerviewobject.h"
-#include "iobject.h"
 #include "iparticlegroup.h"
-#include "iparticlesviewobject.h"
+#include "iparticlesviewsubject.h"
 #include "ipicker.h"
 #include "irendertool.h"
-#include "isurfaceviewobject.h"
-#include "itensorfieldviewobject.h"
-#include "ivectorfieldviewobject.h"
+#include "isurfaceviewsubject.h"
+#include "itensorfieldviewsubject.h"
+#include "ivectorfieldviewsubject.h"
 #include "iviewmodule.h"
-#include "ivolumeviewobject.h"
+#include "iviewobject.h"
+#include "iviewobjectfamily.h"
+#include "ivolumeviewsubject.h"
 
 #if IEXTENSION_INCLUDED(IEXTENSION_HART)
 #include "hobjects.h"
@@ -79,123 +79,79 @@ iAnimatorScript* iExtensionFactory::CreateAnimatorScript(iAnimator *m)
 }
 
 
-iControlModule* iExtensionFactory::CreateControlModule(iShell *s)
+iViewObject* iExtensionFactory::CreateViewObject(iViewObjectParent *parent)
 {
-#if IEXTENSION_INCLUDED(IEXTENSION_HART)
-	return new hControlModule(s);
-#else
-	return new iControlModule(s);
-#endif
-}
-
-
-iObject* iExtensionFactory::CreateObject(const iObjectType &type, iViewModule *vm)
-{
-	iObject *obj = 0;
+	iViewModule *vm(parent->GetViewModule());
+	const iObjectType &type(parent->GetObjectType());
+	
+	//
+	//  Particles are special - they are not single-type
+	//
+	iViewObject *obj = new iViewObject(parent,false,!type.IsMatch(iParticlesViewSubject::Type()));
+	if(obj == 0) return 0;
 
 	//
-	//  Other objects
+	//  View objects
 	//
-	if(type.IsMatch(iDataExplorer::Type()))
+	if(type.IsMatch(iCrossSectionViewSubject::Type()))
 	{
+		obj->AddSubject(new iCrossSectionViewSubject(vm,iData::UniformScalars(),"Cross Section"));
 #if IEXTENSION_INCLUDED(IEXTENSION_HART)
-		obj = new hDataExplorer(vm,iDataType::UniformScalars()+iDataType::UniformVectors()+iDataType::UniformTensors()+iDataType::BasicParticles()+hDataType::HARTVariables()+hDataType::HARTParticles()+hDataType::HARTParticles(1)+hDataType::HARTParticles(2));
-#else
-		obj = new iDataExplorer(vm,iDataType::UniformScalars()+iDataType::UniformVectors()+iDataType::UniformTensors()+iDataType::BasicParticles());
+		obj->AddSubject(new hCrossSectionViewSubject(vm,iData::HARTVariables(),"Cross Section"));
 #endif
 	}
 
-	if(type.IsMatch(iDataReader::Type()))
+	if(type.IsMatch(iParticlesViewSubject::Type()))
 	{
+		obj->AddSubject(new iParticlesViewSubject(vm,iData::BasicParticles(),"Particles"));
 #if IEXTENSION_INCLUDED(IEXTENSION_HART)
-		obj = new hDataReader(vm);
-#else
-		obj = new iDataReader(vm);
+		obj->AddSubject(new iParticlesViewSubject(vm,iData::HARTParticles(0),"HART Particles"));
+		obj->AddSubject(new iParticlesViewSubject(vm,iData::HARTParticles(1),"HART Stellar Particles"));
+		obj->AddSubject(new iParticlesViewSubject(vm,iData::HARTParticles(2),"HART Black Hole Particles"));
 #endif
 	}
 
-	if(type.IsMatch(iPicker::Type()))
+	if(type.IsMatch(iSurfaceViewSubject::Type()))
 	{
+		obj->AddSubject(new iSurfaceViewSubject(vm,iData::UniformScalars(),"Surface"));
 #if IEXTENSION_INCLUDED(IEXTENSION_HART)
-		obj = new hPicker(vm);
-#else
-		obj = new iPicker(vm);
+		obj->AddSubject(new hSurfaceViewSubject(vm,iData::HARTVariables(),"Surface"));
 #endif
 	}
 
-	//
-	//  Visual objects
-	//
-	if(type.IsMatch(iCrossSectionViewObject::Type()))
+	if(type.IsMatch(iTensorFieldViewSubject::Type()))
 	{
+		obj->AddSubject(new iTensorFieldViewSubject(vm,iData::UniformTensors(),"Tensor Field"));
 #if IEXTENSION_INCLUDED(IEXTENSION_HART)
-		obj = new hCrossSectionViewObject(vm,iDataType::UniformScalars()+hDataType::HARTVariables());
-#else
-		obj = new iCrossSectionViewObject(vm,iDataType::UniformScalars());
+		obj->AddSubject(new hTensorFieldViewSubject(vm,iData::HARTVariables(2),"Tensor Field"));
 #endif
 	}
 
-	if(type.IsMatch(iParticleGroup::Type()))
+	if(type.IsMatch(iVectorFieldViewSubject::Type()))
 	{
+		obj->AddSubject(new iVectorFieldViewSubject(vm,iData::UniformVectors(),"Vector Field"));
 #if IEXTENSION_INCLUDED(IEXTENSION_HART)
-		obj = new hParticleGroup(vm,iDataType::BasicParticles()+hDataType::HARTParticles());
-#else
-		obj = new iParticleGroup(vm,iDataType::BasicParticles());
+		obj->AddSubject(new hVectorFieldViewSubject(vm,iData::HARTVariables(1),"Vector Field"));
 #endif
 	}
 
-	if(type.IsMatch(iParticlesViewObject::Type()))
+	if(type.IsMatch(iVolumeViewSubject::Type()))
 	{
+		obj->AddSubject(new iVolumeViewSubject(vm,iData::UniformScalars(),"Volume"));
 #if IEXTENSION_INCLUDED(IEXTENSION_HART)
-		obj = new hParticlesViewObject(vm,iDataType::BasicParticles()+hDataType::HARTParticles());
-#else
-		obj = new iParticlesViewObject(vm,iDataType::BasicParticles());
-#endif
-	}
-
-	if(type.IsMatch(iSurfaceViewObject::Type()))
-	{
-#if IEXTENSION_INCLUDED(IEXTENSION_HART)
-		obj = new hSurfaceViewObject(vm,iDataType::UniformScalars()+hDataType::HARTVariables());
-#else
-		obj = new iSurfaceViewObject(vm,iDataType::UniformScalars());
-#endif
-	}
-
-	if(type.IsMatch(iTensorFieldViewObject::Type()))
-	{
-#if IEXTENSION_INCLUDED(IEXTENSION_HART)
-		obj = new hTensorFieldViewObject(vm,iDataType::UniformTensors()+hDataType::HARTVariables(2));
-#else
-		obj = new iTensorFieldViewObject(vm,iDataType::UniformTensors());
-#endif
-	}
-
-	if(type.IsMatch(iVectorFieldViewObject::Type()))
-	{
-#if IEXTENSION_INCLUDED(IEXTENSION_HART)
-		obj = new hVectorFieldViewObject(vm,iDataType::UniformVectors()+hDataType::HARTVariables(1));
-#else
-		obj = new iVectorFieldViewObject(vm,iDataType::UniformVectors());
-#endif
-	}
-
-	if(type.IsMatch(iVolumeViewObject::Type()))
-	{
-#if IEXTENSION_INCLUDED(IEXTENSION_HART)
-		obj = new hVolumeViewObject(vm,iDataType::UniformScalars()+hDataType::HARTVariables());
-#else
-		obj = new iVolumeViewObject(vm,iDataType::UniformScalars());
+		obj->AddSubject(new hVolumeViewSubject(vm,iData::HARTVariables(),"Volume"));
 #endif
 	}
 
 #if IEXTENSION_INCLUDED(IEXTENSION_HART)
-	if(type.IsMatch(hMeshViewObject::Type()))
+	if(type.IsMatch(hMeshViewSubject::Type()))
 	{
-		obj = new hMeshViewObject(vm,hDataType::HARTVariables());
+		obj->AddSubject(new hMeshViewSubject(vm,iData::HARTVariables(),"HART Adaptive Mesh"));
 	}
 #endif
 
+	obj->Verify();
+
 	iEdition::ApplySettings(obj,type);
 
 	return obj;
@@ -212,19 +168,35 @@ iRenderTool* iExtensionFactory::CreateRenderTool(iViewModule *vm)
 }
 
 
-iViewModule* iExtensionFactory::CreateViewModule(iControlModule *cm)
+void iExtensionFactory::InstallExtensions(iControlModule *cm)
 {
-	iViewModule *vm;
-
 #if IEXTENSION_INCLUDED(IEXTENSION_HART)
-	vm = new hViewModule(cm);
-#else
-	vm = new iViewModule(cm);
+	cm->InstallExtension(new hControlModuleExtension(cm,"HART"));
 #endif
+}
 
-	iEdition::ApplySettings(vm,iViewModule::Type());
 
-	return vm;
+void iExtensionFactory::InstallExtensions(iDataReader *dr)
+{
+#if IEXTENSION_INCLUDED(IEXTENSION_HART)
+	dr->InstallExtension(new hDataReaderExtension(dr,"HART"));
+#endif
+}
+
+
+void iExtensionFactory::InstallExtensions(iPicker *picker)
+{
+#if IEXTENSION_INCLUDED(IEXTENSION_HART)
+	picker->InstallExtension(new hPickerExtension(picker,"HART"));
+#endif
+}
+
+
+void iExtensionFactory::InstallExtensions(iViewModule *vm)
+{
+#if IEXTENSION_INCLUDED(IEXTENSION_HART)
+	vm->InstallExtension(new hViewModuleExtension(vm,"HART"));
+#endif
 }
 
 #endif
