@@ -42,8 +42,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #ifdef IVTK_4
 
-class vtkProcessObject;
-typedef vtkProcessObject vtkFilter;
+class vtkSource;
+typedef vtkSource vtkFilter;
 #define IVTK_QUAD_ORDER 0
 
 #else
