@@ -97,8 +97,9 @@ class iActor: public vtkLODActor
 	
 public:
 	
+	vtkTypeMacro(iActor,vtkLODActor);
+
 	static iActor* New(bool scaled = false);
-	virtual int IsA(const char *type);
 
 	virtual void ReleaseGraphicsResources(vtkWindow *win);
 	virtual void Render(vtkRenderer *ren, vtkMapper *m);
@@ -120,7 +121,6 @@ public:
 	void SetScalarRange(float min, float max);
 
 	void SyncWithLimits(iDataLimits *l, int v, float scale = 1.0f);
-	void SetPalette(const iPalette *p);
 	inline iLookupTable* GetLookupTable() const { return mLookupTable; }
 
 	void AddMapperObserver(unsigned long event, vtkCommand *obs);
