@@ -33,7 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ianimatorscript.h"
 #include "icontrolmodule.h"
-#include "icrosssectionviewobject.h"
+#include "icrosssectionviewsubject.h"
 #include "idatareader.h"
 #include "ierror.h"
 #include "ierrorstatus.h"
@@ -43,6 +43,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ishellfactory.h"
 #include "isystem.h"
 #include "iviewmodule.h"
+#include "iviewobject.h"
 #include "iviewobjectfamily.h"
 #include "iwriter.h"
 
@@ -70,7 +71,7 @@ using namespace iParameter;
 #define REN this->GetViewModule()->GetRenderer()
 #define DATAREADER this->GetViewModule()->GetReader()
 #define CAM this->GetViewModule()->GetRenderer()->GetActiveCamera()
-#define XSECTION this->GetViewModule()->GetCrossSectionFamily()->GetCurrentMember()
+#define XSECTION this->GetViewModule()->GetCrossSectionViewSubject()
 
 #define RAN_U (2.0*vtkMath::Random()-1.0)
 #define RAN_N (1.4142*tan(2.0*RAN_U/3.1415926))
@@ -174,10 +175,10 @@ iAnimator::iAnimator(iViewModule *vm) : iViewModuleComponent(vm), mBlenderBase(0
 
 	mDoingTitlePage = false;
 
-	mAnimatorScript = iAnimatorScript::New(this); IERROR_ASSERT_NULL_POINTER(mAnimatorScript);
-	mAnimatorObserver = iAnimatorEventObserver::New(this->GetViewModule()); IERROR_ASSERT_NULL_POINTER(mAnimatorObserver);
+	mAnimatorScript = iAnimatorScript::New(this); IERROR_ASSERT(mAnimatorScript);
+	mAnimatorObserver = iAnimatorEventObserver::New(this->GetViewModule()); IERROR_ASSERT(mAnimatorObserver);
 
-	mCameraPath = iCameraPath::New(this->GetViewModule()); IERROR_ASSERT_NULL_POINTER(mCameraPath);
+	mCameraPath = iCameraPath::New(this->GetViewModule()); IERROR_ASSERT(mCameraPath);
 }
 
 
@@ -751,7 +752,7 @@ bool iAnimator::RenderImages(bool dumpImage)
 			//
 			while(mBlenderBase.Size() < mState.nBlendedFrames)
 			{
-				iStereoImageArray *ptmparr = new iStereoImageArray; IERROR_ASSERT_NULL_POINTER(ptmparr);
+				iStereoImageArray *ptmparr = new iStereoImageArray; IERROR_ASSERT(ptmparr);
 				ptmparr->Copy(images);
 				mBlenderBase.Add(ptmparr);
 			}
@@ -761,13 +762,13 @@ bool iAnimator::RenderImages(bool dumpImage)
 			}
 
 			delete mBlenderBase[0];
-			for(k=0; k<mBlenderBase.Last(); k++) mBlenderBase[k]->Copy(*mBlenderBase[k+1]);
-			mBlenderBase[mBlenderBase.Last()]->Copy(images);
+			for(k=0; k<mBlenderBase.MaxIndex(); k++) mBlenderBase[k]->Copy(*mBlenderBase[k+1]);
+			mBlenderBase.Last()->Copy(images);
 
 			//
 			//  Make sure that all the arrays are of the same size
 			//
-			for(k=0; k<mBlenderBase.Last(); k++)
+			for(k=0; k<mBlenderBase.MaxIndex(); k++)
 			{
 				while(mBlenderBase[k]->Size() > images.Size()) mBlenderBase[k]->RemoveLast();
 				while(mBlenderBase[k]->Size() < images.Size()) mBlenderBase[k]->Add(images[mBlenderBase[k]->Size()]);
@@ -1179,9 +1180,9 @@ void iAnimator::PackStateBody(iString &s) const
 	int i, n = mCameraPath->GetNumberOfHandles();
 	double x[3];
 
-	float *x1 = new float[n]; IERROR_ASSERT_NULL_POINTER(x1);
-	float *x2 = new float[n]; IERROR_ASSERT_NULL_POINTER(x2);
-	float *x3 = new float[n]; IERROR_ASSERT_NULL_POINTER(x3);
+	float *x1 = new float[n]; IERROR_ASSERT(x1);
+	float *x2 = new float[n]; IERROR_ASSERT(x2);
+	float *x3 = new float[n]; IERROR_ASSERT(x3);
 
 	for(i=0; i<n; i++)
 	{
@@ -1254,9 +1255,9 @@ void iAnimator::UnPackStateBody(const iString &s)
 	int n = mCameraPath->GetNumberOfHandles();
 	double x[3];
 
-	float *xc = new float[n]; IERROR_ASSERT_NULL_POINTER(xc);
-	float *yc = new float[n]; IERROR_ASSERT_NULL_POINTER(yc);
-	float *zc = new float[n]; IERROR_ASSERT_NULL_POINTER(zc);
+	float *xc = new float[n]; IERROR_ASSERT(xc);
+	float *yc = new float[n]; IERROR_ASSERT(yc);
+	float *zc = new float[n]; IERROR_ASSERT(zc);
 
 	if(this->UnPackValue(s,KeyCameraPathX(),xc,n) && this->UnPackValue(s,KeyCameraPathY(),yc,n) && this->UnPackValue(s,KeyCameraPathZ(),zc,n))
 	{
@@ -1289,16 +1290,11 @@ void iAnimator::UnPackStateBody(const iString &s)
 	//
 	//  Action keys
 	//
-#ifdef I_CHECK1
-	bool saveReportMissingKeys = iObject::ReportMissingKeys;
-	iObject::ReportMissingKeys = false; //action keys are not part of the states
-#endif
+	iObject::ReportMissingKeys(false); //action keys are not part of the states
 
 	if(this->UnPackValue(s,KeyCameraPathDemo(),b) && b) this->PlayCameraPathDemo();
 
-#ifdef I_CHECK1
-	iObject::ReportMissingKeys = saveReportMissingKeys;
-#endif
+	iObject::ReportMissingKeys(true);
 }
 
 
