@@ -33,7 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icamera.h"
 #include "icontrolmodule.h"
 #include "icontrolscript.h"
-#include "icrosssectionviewobject.h"
+#include "icrosssectionviewsubject.h"
 #include "idata.h"
 #include "idatalimits.h"
 #include "idatareader.h"
@@ -41,18 +41,20 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierrorstatus.h"
 #include "iextensionfactory.h"
 #include "ifile.h"
-#include "imarkerviewobject.h"
+#include "imarker.h"
+#include "imarkerfamily.h"
 #include "iparticlegroup.h"
-#include "iparticlesviewobject.h"
+#include "iparticlesviewsubject.h"
 #include "irendertool.h"
 #include "ishell.h"
 #include "ishellfactory.h"
-#include "isurfaceviewobject.h"
-#include "itensorfieldviewobject.h"
-#include "ivectorfieldviewobject.h"
+#include "isurfaceviewsubject.h"
+#include "itensorfieldviewsubject.h"
+#include "ivectorfieldviewsubject.h"
 #include "iviewmodule.h"
+#include "iviewobject.h"
 #include "iviewobjectfamily.h"
-#include "ivolumeviewobject.h"
+#include "ivolumeviewsubject.h"
 
 #include <vtkCamera.h>
 #include <vtkMath.h>
@@ -62,7 +64,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //  Templates (needed for some compilers)
 //
 #include "iarraytemplate.h"
-#include "iviewobjectfamilytemplate.h"
+#include "iviewfamilytemplate.h"
 
 //
 //  macros
@@ -81,14 +83,17 @@ iValue* iAnimatorScript::valRS = 0;
 iValue* iAnimatorScript::valRP = 0;
 iValue* iAnimatorScript::valVA3 = 0;
 
-#define curScript		iPointerCast<iAnimatorScript,iScript>(me)
-#define curAnimator		iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()
-#define curVisual		iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()
-#define curControl		iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetControlModule()
-#define curReader		iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetReader()
-#define curRenderer		iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetRenderer()
-#define curCamera		iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetRenderer()->GetActiveCamera()
-#define curLimits(t)	iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetReader()->GetLimits(t)
+#define curScript			iPointerCast<iAnimatorScript,iScript>(me)
+#define curAnimator			iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()
+#define curVisual			iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()
+#define curControl			iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetControlModule()
+#define curReader			iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetReader()
+#define curRenderer			iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetRenderer()
+#define curCamera			iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetRenderer()->GetActiveCamera()
+#define curLimits(t)		iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetReader()->GetLimits(t)
+#define curObject(name)		iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->Get##name##ViewSubject()
+#define numObject(name,n)	iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->Get##name##ViewSubject(n)
+#define curObjectFamily(name)	iPointerCast<iAnimatorScript,iScript>(me)->GetAnimator()->GetViewModule()->GetViewObjectFamily(_ObjectType##name)
 
 
 iAnimatorScript* iAnimatorScript::New(iAnimator *m)
@@ -366,7 +371,7 @@ void iAnimatorScript::MultiRender(iScript *me, iValue *v0, iValue::Assignment vt
 	}
 
 	int n = ((iValue_VA *)v0)->GetSize();
-	int *v = new int[n]; IERROR_ASSERT_NULL_POINTER(v);
+	int *v = new int[n]; IERROR_ASSERT(v);
 	if(v == 0)
 	{
 		me->GetErrorStatus()->Set("Unable to allocate memory."); 
@@ -569,7 +574,7 @@ void iAnimatorScript::ScalarFieldLowerLimit(iScript *me, iValue *n0, iValue *v0,
 	n--;
 
 	const iDataType &t = iDataType::ReSpecifyType(curReader->GetFileSetDataType(),"ScalarField");
-	if(t==iDataType::Null() || !curReader->IsThereData(t)) 
+	if(t==iData::None() || !curReader->IsThereData(t)) 
 	{
 		me->GetErrorStatus()->Set("There are no scalar field data in the set.");
 		return;
@@ -590,7 +595,7 @@ void iAnimatorScript::ScalarFieldUpperLimit(iScript *me, iValue *n0, iValue *v0,
 	n--;
 
 	const iDataType &t = iDataType::ReSpecifyType(curReader->GetFileSetDataType(),"ScalarField");
-	if(t==iDataType::Null() || !curReader->IsThereData(t)) 
+	if(t==iData::None() || !curReader->IsThereData(t)) 
 	{
 		me->GetErrorStatus()->Set("There are no scalar field data in the set.");
 		return;
@@ -612,7 +617,7 @@ void iAnimatorScript::ParticleSetLowerLimit(iScript *me, iValue *n0, iValue *v0,
 	n--;
 
 	const iDataType &t = iDataType::ReSpecifyType(curReader->GetFileSetDataType(),"ParticleSet");
-	if(t==iDataType::Null() || !curReader->IsThereData(t)) 
+	if(t==iData::None() || !curReader->IsThereData(t)) 
 	{
 		me->GetErrorStatus()->Set("There are no particle set data in the set.");
 		return;
@@ -634,7 +639,7 @@ void iAnimatorScript::ParticleSetUpperLimit(iScript *me, iValue *n0, iValue *v0,
 	n--;
 
 	const iDataType &t = iDataType::ReSpecifyType(curReader->GetFileSetDataType(),"ParticleSet");
-	if(t==iDataType::Null() || !curReader->IsThereData(t)) 
+	if(t==iData::None() || !curReader->IsThereData(t)) 
 	{
 		me->GetErrorStatus()->Set("There are no particle set data in the set.");
 		return;
@@ -653,7 +658,7 @@ void iAnimatorScript::VectorFieldUpperLimit(iScript *me, iValue *v0, iValue::Ass
 	float v;
 
 	const iDataType &t = iDataType::ReSpecifyType(curReader->GetFileSetDataType(),"VectorField");
-	if(t==iDataType::Null() || !curReader->IsThereData(t)) 
+	if(t==iData::None() || !curReader->IsThereData(t)) 
 	{
 		me->GetErrorStatus()->Set("There are no vector field data in the set.");
 		return;
@@ -668,7 +673,7 @@ void iAnimatorScript::TensorFieldUpperLimit(iScript *me, iValue *v0, iValue::Ass
 	float v;
 
 	const iDataType &t = iDataType::ReSpecifyType(curReader->GetFileSetDataType(),"TensorField");
-	if(t==iDataType::Null() || !curReader->IsThereData(t)) 
+	if(t==iData::None() || !curReader->IsThereData(t)) 
 	{
 		me->GetErrorStatus()->Set("There are no tensor field data in the set.");
 		return;
@@ -820,15 +825,15 @@ void iAnimatorScript::LogoPosition(iScript *me, iValue* v0, iValue::Assignment)
 }
 
 //
-// Manupulation of iViewObjects
+// Manupulation of iViewSubjects
 //
 void iAnimatorScript::SurfaceVar(iScript *me, iValue *n0, iValue *v0, iValue::Assignment vtkNotUsed(rel))
 {
 	int n;
 	int v;
-	iSurfaceViewObject *s;
+	iSurfaceViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curVisual->GetSurfaceFamily()->GetCurrentMember(); else s = curVisual->GetSurfaceFamily()->GetMember(n-1);
+	if(n <= 0) s = curObject(Surface); else s = numObject(Surface,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
@@ -840,9 +845,9 @@ void iAnimatorScript::SurfaceLevel(iScript *me, iValue *n0, iValue *v0, iValue::
 {
 	int n;
 	float v;
-	iSurfaceViewObject *s;
+	iSurfaceViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curVisual->GetSurfaceFamily()->GetCurrentMember(); else s = curVisual->GetSurfaceFamily()->GetMember(n-1);
+	if(n <= 0) s = curObject(Surface); else s = numObject(Surface,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,s->GetIsoSurfaceLevel());
@@ -854,9 +859,9 @@ void iAnimatorScript::SurfaceOpacity(iScript *me, iValue *n0, iValue *v0, iValue
 {
 	int n;
 	float v;
-	iSurfaceViewObject *s;
+	iSurfaceViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curVisual->GetSurfaceFamily()->GetCurrentMember(); else s = curVisual->GetSurfaceFamily()->GetMember(n-1);
+	if(n <= 0) s = curObject(Surface); else s = numObject(Surface,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,s->GetOpacity(0));
@@ -869,9 +874,9 @@ void iAnimatorScript::CrossSectionVar(iScript *me, iValue *n0, iValue *v0, iValu
 {
 	int n;
 	int v;
-	iCrossSectionViewObject *s;
+	iCrossSectionViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curVisual->GetCrossSectionFamily()->GetCurrentMember(); else s = curVisual->GetCrossSectionFamily()->GetMember(n-1);
+	if(n <= 0) s = curObject(CrossSection); else s = numObject(CrossSection,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
@@ -883,9 +888,9 @@ void iAnimatorScript::CrossSectionDir(iScript *me, iValue *n0, iValue *v0, iValu
 {
 	int n;
 	int v;
-	iCrossSectionViewObject *s;
+	iCrossSectionViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curVisual->GetCrossSectionFamily()->GetCurrentMember(); else s = curVisual->GetCrossSectionFamily()->GetMember(n-1);
+	if(n <= 0) s = curObject(CrossSection); else s = numObject(CrossSection,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
@@ -897,9 +902,9 @@ void iAnimatorScript::CrossSectionPos(iScript *me, iValue *n0, iValue *v0, iValu
 {
 	int n;
 	double v;
-	iCrossSectionViewObject *s;
+	iCrossSectionViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curVisual->GetCrossSectionFamily()->GetCurrentMember(); else s = curVisual->GetCrossSectionFamily()->GetMember(n-1);
+	if(n <= 0) s = curObject(CrossSection); else s = numObject(CrossSection,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,(double)s->GetPos());
@@ -911,9 +916,9 @@ void iAnimatorScript::VolumeVar(iScript *me, iValue *n0, iValue *v0, iValue::Ass
 {
 	int n;
 	int v;
-	iVolumeViewObject *s;
+	iVolumeViewSubject *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curVisual->GetVolumeFamily()->GetCurrentMember(); else s = curVisual->GetVolumeFamily()->GetMember(n-1);
+	if(n <= 0) s = curObject(Volume); else s = numObject(Volume,n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
@@ -927,7 +932,7 @@ void iAnimatorScript::ParticlesOpacity(iScript *me, iValue *n0, iValue *v0, iVal
 	float v;
 	iParticleGroup *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curVisual->GetParticlesFamily()->GetCurrentMember()->GetCurrentGroup(); else s = curVisual->GetParticlesFamily()->GetCurrentMember()->GetGroup(n-1);
+	if(n <= 0) s = curVisual->GetParticlesViewSubject()->GetCurrentGroup(); else s = curVisual->GetParticlesViewSubject()->GetGroup(n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,s->GetOpacity(0));
@@ -942,15 +947,15 @@ void iAnimatorScript::ParticlesDownsampleFactor(iScript *me, iValue *v0, iValue:
 	if(v < 1) return;
 	curReader->SetParticlesDownsampleFactor(v);
 	me->GetErrorStatus()->Monitor(curReader,"Data reader: ");
-	curReader->ReloadData(iDataType::BasicParticles());
+	curReader->ReloadData(iData::BasicParticles());
 }
 
 void iAnimatorScript::MarkerPosition(iScript *me, iValue *n0, iValue *v0, iValue::Assignment rel)
 {
 	int n;
-	iMarkerViewObject *s;
+	iMarker *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curVisual->GetMarkerFamily()->GetCurrentMember(); else s = curVisual->GetMarkerFamily()->GetMember(n-1);
+	if(n <= 0) s = curVisual->GetMarker(); else s = curVisual->GetMarker(n-1);
 	if(s != 0)
 	{
 		double v[3];
@@ -966,9 +971,9 @@ void iAnimatorScript::MarkerSize(iScript *me, iValue *n0, iValue *v0, iValue::As
 {
 	int n;
 	double v;
-	iMarkerViewObject *s;
+	iMarker *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curVisual->GetMarkerFamily()->GetCurrentMember(); else s = curVisual->GetMarkerFamily()->GetMember(n-1);
+	if(n <= 0) s = curVisual->GetMarker(); else s = curVisual->GetMarker(n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,(double)s->GetSize());
@@ -980,9 +985,9 @@ void iAnimatorScript::MarkerOpacity(iScript *me, iValue *n0, iValue *v0, iValue:
 {
 	int n;
 	float v;
-	iMarkerViewObject *s;
+	iMarker *s;
 	IBASESCRIPT_UPDATE_VALUE_ABS(n0,n);
-	if(n <= 0) s = curVisual->GetMarkerFamily()->GetCurrentMember(); else s = curVisual->GetMarkerFamily()->GetMember(n-1);
+	if(n <= 0) s = curVisual->GetMarker(); else s = curVisual->GetMarker(n-1);
 	if(s != 0)
 	{
 		IBASESCRIPT_UPDATE_VALUE_REL(v0,rel,v,s->GetOpacity(0));
@@ -1032,25 +1037,25 @@ void iAnimatorScript::LoadFileByType(iScript *me, iValue* v0, int key, const iDa
 
 void iAnimatorScript::LoadUniformScalarsFile(iScript *me, iValue* v0, iValue::Assignment vtkNotUsed(rel))
 {
-	LoadFileByType(me,v0,_EnvironmentScalarFieldData,iDataType::UniformScalars());
+	LoadFileByType(me,v0,_EnvironmentScalarFieldData,iData::UniformScalars());
 }
 
 
 void iAnimatorScript::LoadBasicParticlesFile(iScript *me, iValue* v0, iValue::Assignment vtkNotUsed(rel))
 {
-	LoadFileByType(me,v0,_EnvironmentParticleSetData,iDataType::BasicParticles());
+	LoadFileByType(me,v0,_EnvironmentParticleSetData,iData::BasicParticles());
 }
 
 
 void iAnimatorScript::LoadUniformVectorsFile(iScript *me, iValue* v0, iValue::Assignment vtkNotUsed(rel))
 {
-	LoadFileByType(me,v0,_EnvironmentVectorFieldData,iDataType::UniformVectors());
+	LoadFileByType(me,v0,_EnvironmentVectorFieldData,iData::UniformVectors());
 }
 
 
 void iAnimatorScript::LoadUniformTensorsFile(iScript *me, iValue* v0, iValue::Assignment vtkNotUsed(rel))
 {
-	LoadFileByType(me,v0,_EnvironmentTensorFieldData,iDataType::UniformTensors());
+	LoadFileByType(me,v0,_EnvironmentTensorFieldData,iData::UniformTensors());
 }
 
 
@@ -1061,7 +1066,7 @@ void iAnimatorScript::ShowSurface(iScript *me, iValue* v0, iValue::Assignment vt
 {
 	bool v;
     IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
-	curVisual->GetSurfaceFamily()->Show(v); 
+	curObjectFamily(Surface)->Show(v); 
 }
 
 
@@ -1069,7 +1074,7 @@ void iAnimatorScript::ShowCrossSection(iScript *me, iValue* v0, iValue::Assignme
 {
 	bool v;
     IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
-	curVisual->GetCrossSectionFamily()->Show(v); 
+	curObjectFamily(CrossSection)->Show(v); 
 }
 
 
@@ -1077,7 +1082,7 @@ void iAnimatorScript::ShowVolume(iScript *me, iValue* v0, iValue::Assignment vtk
 {
 	bool v;
     IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
-	curVisual->GetVolumeFamily()->Show(v); 
+	curObjectFamily(Volume)->Show(v); 
 }
 
 
@@ -1085,7 +1090,7 @@ void iAnimatorScript::ShowParticles(iScript *me, iValue* v0, iValue::Assignment
 {
 	bool v;
     IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
-	curVisual->GetParticlesFamily()->Show(v); 
+	curObjectFamily(Particles)->Show(v); 
 }
 
 
@@ -1093,7 +1098,7 @@ void iAnimatorScript::ShowVectorField(iScript *me, iValue* v0, iValue::Assignmen
 {
 	bool v;
     IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
-	curVisual->GetVectorFieldFamily()->Show(v); 
+	curObjectFamily(VectorField)->Show(v); 
 }
 
 
@@ -1101,6 +1106,6 @@ void iAnimatorScript::ShowTensorField(iScript *me, iValue* v0, iValue::Assignmen
 {
 	bool v;
     IBASESCRIPT_UPDATE_VALUE_ABS(v0,v);
-	curVisual->GetTensorFieldFamily()->Show(v); 
+	curObjectFamily(TensorField)->Show(v); 
 }
 
