@@ -36,14 +36,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 class iAppendPolyDataFilter : public iGenericPolyDataToPolyDataFilter<vtkAppendPolyData>
 {
-	
-public:
 
-	static iAppendPolyDataFilter* New();
-	
+	IGENERICFILTER_DECLARE(iAppendPolyDataFilter);
+
 protected:
-	
-	virtual void ProduceOutput(vtkPolyData *input, vtkPolyData *output);
+
+	virtual void ProduceOutput();
 };
 
 #endif // IAPPENDPOLYDATAFILTER_H
