@@ -42,18 +42,18 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 // iBoundedSphereSource class
 //
-iBoundedSphereSource* iBoundedSphereSource::New(iViewObject *vo)
+iBoundedSphereSource* iBoundedSphereSource::New(iViewSubject *vo)
 {
 	return new iBoundedSphereSource(vo);
 }
 
 
-iBoundedSphereSource::iBoundedSphereSource(iViewObject *vo) : iBoundedPolyDataSource(vo,false,true)
+iBoundedSphereSource::iBoundedSphereSource(iViewSubject *vo) : iBoundedPolyDataSource(vo,false,true)
 {
-	mAppend = vtkAppendPolyData::New(); IERROR_ASSERT_NULL_POINTER(mAppend);
+	mAppend = vtkAppendPolyData::New(); IERROR_ASSERT(mAppend);
 	for(int i=0; i<8; i++)
 	{
-		mSource[i] = vtkSphereSource::New(); IERROR_ASSERT_NULL_POINTER(mSource[i]);
+		mSource[i] = vtkSphereSource::New(); IERROR_ASSERT(mSource[i]);
 	}
 	mAppend->UserManagedInputsOn();
 	mAppend->SetInputByNumber(0,mSource[0]->GetOutput());
