@@ -71,7 +71,7 @@ iCameraPath::iCameraPath(iViewModule *vm) : iViewModuleComponent(vm), mNumInterv
 {
 	mIsFocalPath = mIsFocalPathToPoint = false;
 
-	mCamPathWidget = new iSplineWidget; IERROR_ASSERT_NULL_POINTER(mCamPathWidget);
+	mCamPathWidget = new iSplineWidget; IERROR_ASSERT(mCamPathWidget);
 	mCamPathWidget->SetNumberOfHandles(3);
 	mCamPathWidget->SetResolution(mNumIntervalsPerSegment*2);
 	mCamPathWidget->SetInteractor(this->GetViewModule()->GetInteractor());
@@ -81,7 +81,7 @@ iCameraPath::iCameraPath(iViewModule *vm) : iViewModuleComponent(vm), mNumInterv
 	mCamPathWidget->SetHandlePosition(1,0.0,0.0,1.0);
 	mCamPathWidget->SetHandlePosition(0,1.0,0.0,1.0);
 
-	mFocPathWidget = new iSplineWidget; IERROR_ASSERT_NULL_POINTER(mFocPathWidget);
+	mFocPathWidget = new iSplineWidget; IERROR_ASSERT(mFocPathWidget);
 	mFocPathWidget->SetNumberOfHandles(3);
 	mFocPathWidget->SetResolution(mNumIntervalsPerSegment*2);
 	mFocPathWidget->SetInteractor(this->GetViewModule()->GetInteractor());
@@ -98,11 +98,11 @@ iCameraPath::iCameraPath(iViewModule *vm) : iViewModuleComponent(vm), mNumInterv
 	mFocPathWidget->AddObserver(vtkCommand::EnableEvent,this);
 	mFocPathWidget->AddObserver(vtkCommand::DisableEvent,this);
 
-	mCamPathData = vtkPolyData::New(); IERROR_ASSERT_NULL_POINTER(mCamPathData);
-	mFocPathData = vtkPolyData::New(); IERROR_ASSERT_NULL_POINTER(mFocPathData);
+	mCamPathData = vtkPolyData::New(); IERROR_ASSERT(mCamPathData);
+	mFocPathData = vtkPolyData::New(); IERROR_ASSERT(mFocPathData);
 		
-	mCamPathHeadActor = iActor::New(true); IERROR_ASSERT_NULL_POINTER(mCamPathHeadActor);
-	mCamPathHeadSource = vtkConeSource::New(); IERROR_ASSERT_NULL_POINTER(mCamPathHeadSource);
+	mCamPathHeadActor = iActor::New(true); IERROR_ASSERT(mCamPathHeadActor);
+	mCamPathHeadSource = vtkConeSource::New(); IERROR_ASSERT(mCamPathHeadSource);
 	mCamPathHeadSource->SetResolution(12);
 	mCamPathHeadSource->SetRadius(0.1);
 	mCamPathHeadSource->SetHeight(0.15);
@@ -110,8 +110,8 @@ iCameraPath::iCameraPath(iViewModule *vm) : iViewModuleComponent(vm), mNumInterv
 	mCamPathHeadActor->GetProperty()->SetColor(0.0,0.68,1.0);
 	mCamPathHeadActor->PickableOff();
 
-	mFocPathBandActor = iActor::New(); IERROR_ASSERT_NULL_POINTER(mFocPathBandActor);
-	mFocPathBandSource = vtkPolyData::New(); IERROR_ASSERT_NULL_POINTER(mFocPathBandSource);
+	mFocPathBandActor = iActor::New(); IERROR_ASSERT(mFocPathBandActor);
+	mFocPathBandSource = vtkPolyData::New(); IERROR_ASSERT(mFocPathBandSource);
 	mFocPathBandActor->SetInput(mFocPathBandSource);
 	mFocPathBandActor->GetProperty()->SetColor(0.4,0.5,0.6);
 	mFocPathBandActor->PickableOff();
@@ -351,8 +351,8 @@ void iCameraPath::Execute(vtkObject *caller, unsigned long eventId, void *vtkNot
 					nstep = cp->GetNumberOfPoints()/n;
 				}
 
-				vtkPoints *newPoints = vtkPoints::New(VTK_FLOAT); IERROR_ASSERT_NULL_POINTER(newPoints);
-				vtkCellArray *newLines = vtkCellArray::New(); IERROR_ASSERT_NULL_POINTER(newLines);
+				vtkPoints *newPoints = vtkPoints::New(VTK_FLOAT); IERROR_ASSERT(newPoints);
+				vtkCellArray *newLines = vtkCellArray::New(); IERROR_ASSERT(newLines);
 				newPoints->SetNumberOfPoints(2*n);
 				newLines->Allocate(3*n);
 
