@@ -44,6 +44,7 @@ public:
 	inline int Blue() const { return mBlue; }
 
 	inline void GetRGB(char rgb[3]) const { rgb[0] = (char)mRed; rgb[1] = (char)mGreen; rgb[2] = (char)mBlue; }
+	inline void GetRGB(unsigned char rgb[3]) const { rgb[0] = (unsigned char)mRed; rgb[1] = (unsigned char)mGreen; rgb[2] = (unsigned char)mBlue; }
 
 	double* ToVTK() const { return (double *)mVTK; }
 
@@ -58,7 +59,7 @@ private:
 	void Update();
 
 	int mRed, mGreen, mBlue;
-	double mVTK[3];
+	double mVTK[4];
 };
 
 
@@ -67,6 +68,7 @@ inline void iColor::Update()
 	mVTK[0] = mRed/255.0;
 	mVTK[1] = mGreen/255.0;
 	mVTK[2] = mBlue/255.0;
+	mVTK[3] = 1.0;
 }
 
 inline iColor::iColor()
