@@ -58,11 +58,9 @@ using namespace iParameter;
 IOBJECT_DEFINE_TYPE(iColorBars,ColorBars,cb,iObjectType::_Helper);
 
 IOBJECT_DEFINE_KEY(iColorBars,Automatic,a,Bool,1);
-IOBJECT_DEFINE_KEY(iColorBars,BarLeft,bl,Int,4);
-IOBJECT_DEFINE_KEY(iColorBars,BarRight,br,Int,4);
+IOBJECT_DEFINE_KEY(iColorBars,BarLeft,bl,Int,3);
+IOBJECT_DEFINE_KEY(iColorBars,BarRight,br,Int,3);
 IOBJECT_DEFINE_KEY(iColorBars,Color,c,Color,1);
-IOBJECT_DEFINE_KEY(iColorBars,FontSize,fs,Int,1);
-IOBJECT_DEFINE_KEY(iColorBars,FontType,ft,Int,1);
 IOBJECT_DEFINE_KEY(iColorBars,SideOffset,so,Float,1);
 
 
@@ -85,11 +83,14 @@ public:
 		int j;
 		for(j=0; j<2; j++)
 		{
-			Base[j] = iTextActor::New(parent); IERROR_ASSERT_NULL_POINTER(Base[j]);
-			Power[j] = iTextActor::New(parent); IERROR_ASSERT_NULL_POINTER(Power[j]);
+			Base[j] = iTextActor::New(parent); IERROR_ASSERT(Base[j]);
+			Power[j] = iTextActor::New(parent); IERROR_ASSERT(Power[j]);
 			Base[j]->SetBold(true);
 			Power[j]->SetBold(true);
+			Power[j]->SetHJustification(_TextJustLeft);
 		}
+		Base[0]->SetHJustification(_TextJustLeft);
+		Base[1]->SetHJustification(_TextJustRight);
 	}
 
 	~iColorBarsLabel()
@@ -118,7 +119,6 @@ iColorBars::iColorBars(iViewModule *vm) : iOverlayBase(vm->GetRenderTool()), iVi
 	int i;
 
 	mAutomatic = true;
-	mFontSize = 14;
 	mFontType = _TextTypeBitmap;
 	mStarted = false;
 	mScale = 1.0;
@@ -136,10 +136,11 @@ iColorBars::iColorBars(iViewModule *vm) : iOverlayBase(vm->GetRenderTool()), iVi
 	mManualBars[0].Priority = -2;
 	mManualBars[1].Priority = -1;
 	mManualBars[0].DataTypeId = mManualBars[1].DataTypeId = 1;
+	mManualBars[0].Count = mManualBars[1].Count = 1;
 
 	for(i=0; i<2; i++)
 	{
-		mBarActor[i] = vtkScalarBarActor::New(); IERROR_ASSERT_NULL_POINTER(mBarActor[i]);
+		mBarActor[i] = vtkScalarBarActor::New(); IERROR_ASSERT(mBarActor[i]);
 		mBarActor[i]->GetPositionCoordinate()->SetCoordinateSystemToNormalizedViewport();
 		mBarActor[i]->SetOrientationToVertical();
 		mBarActor[i]->SetMaximumNumberOfColors(256);
@@ -152,7 +153,7 @@ iColorBars::iColorBars(iViewModule *vm) : iOverlayBase(vm->GetRenderTool()), iVi
 
 	for(i=0; i<2; i++)
 	{
-		mTitleActor[i] = iTextActor::New(this->GetRenderTool()); IERROR_ASSERT_NULL_POINTER(mTitleActor[i]);
+		mTitleActor[i] = iTextActor::New(this->GetRenderTool()); IERROR_ASSERT(mTitleActor[i]);
 		mTitleActor[i]->Rotate(90.0);
 		mTitleActor[i]->SetVJustification(_TextJustCenter);
 		mTitleActor[i]->SetBold(true);
@@ -163,13 +164,13 @@ iColorBars::iColorBars(iViewModule *vm) : iOverlayBase(vm->GetRenderTool()), iVi
 	iColorBarsLabel *l;
 	for(i=0; i<10; i++)
 	{
-		l = new iColorBarsLabel(this->GetRenderTool()); IERROR_ASSERT_NULL_POINTER(l);
+		l = new iColorBarsLabel(this->GetRenderTool()); IERROR_ASSERT(l);
 		mLabels.Add(l);
 	}
 
 	this->SetSideOffset(0.08);
 	this->SetColor(iColor());
-	this->SetFontSize(mFontSize);
+	this->SetFontScale(mFontScale);
 	this->SetFontType(mFontType);
 }
 
@@ -195,7 +196,7 @@ void iColorBars::SetSideOffset(float v)
 	{
 		mXOff[1] = v; 
 		mXOff[0] = 1.0 - mWidth - mXOff[1]; 
-		mTextOff[0] = mXOff[0] + mWidth + 0.01; mTextOff[1] = mXOff[1] - 0.01;
+		mTextOff[0] = mXOff[0] + mWidth + 0.0; mTextOff[1] = mXOff[1] - 0.01;
 		mTitleOff[0] = mXOff[0] - 0.3*mWidth; mTitleOff[1] = mXOff[1] + mWidth;
 		mTitleActor[0]->SetPosition(mTitleOff[0],0.5);
 		mTitleActor[1]->SetPosition(mTitleOff[1],0.5);
@@ -224,19 +225,19 @@ void iColorBars::SetColor(iColor c)
 }
 
 	
-void iColorBars::SetFontSize(int s)
+void iColorBars::SetFontScale(int s)
 {
 	int i, j;
 	for(i=0; i<2; i++)
 	{
-		mTitleActor[i]->SetFontSize(round(1.25*s));
+		mTitleActor[i]->SetFontScale(s+1);
 		for(j=0; j<mLabels.Size(); j++)
 		{
-			mLabels[j]->Base[i]->SetFontSize(s);
-			mLabels[j]->Power[i]->SetFontSize(s);
+			mLabels[j]->Base[i]->SetFontScale(s);
+			mLabels[j]->Power[i]->SetFontScale(s);
 		}
 	}
-	mFontSize = mLabels[0]->Base[0]->GetFontSize();
+	mFontScale = mLabels[0]->Base[0]->GetFontScale();
 	this->ClearCache();
 }
 
@@ -253,7 +254,7 @@ void iColorBars::SetFontType(int s)
 			mLabels[j]->Power[i]->SetFontType(s);
 		}
 	}
-	mFontSize = mLabels[0]->Base[0]->GetFontType();
+	mFontType = mLabels[0]->Base[0]->GetFontType();
 	this->ClearCache();
 }
 
@@ -277,10 +278,10 @@ void iColorBars::ReleaseGraphicsResources(vtkWindow *win)
 
 int iColorBars::RenderOverlay(vtkViewport* viewport)
 {
-	vtkCamera *cam = iPointerCast<vtkRenderer,vtkViewport>(viewport)->GetActiveCamera();
-	if(!mStarted || cam==0) return 0;
+	if(!mStarted) return 0;
 
-	for(int i=0; i<2; i++)  if(this->Queue()[i].Count > 0) 
+	int i;
+	for(i=0; i<this->Queue().Size(); i++)  if(this->Queue()[i].Count>0 && this->Queue()[i].Palette!=0) 
 	{
 		mBarActor[i]->RenderOverlay(viewport);
 		mTitleActor[i]->RenderOverlay(viewport);
@@ -301,9 +302,6 @@ int iColorBars::RenderOpaqueGeometry(vtkViewport* viewport)
 	int i, j;
 	float w1 = 0.0, h1 = 0.0, w2 = 0.0, h2 = 0.0;
 
-	vtkCamera *cam = iPointerCast<vtkRenderer,vtkViewport>(viewport)->GetActiveCamera();
-	if(cam == 0) return 0;
-
 	if(!mStarted) mStarted = true;
 
 	if(this->GetRenderingMagnification() == 1)
@@ -315,7 +313,7 @@ int iColorBars::RenderOpaqueGeometry(vtkViewport* viewport)
 			mBarActor[i]->SetHeight(mHeight);
 		}
 
-		for(i=0; i<2; i++) if(this->Queue()[i].Count > 0) 
+		for(i=0; i<this->Queue().Size(); i++) if(this->Queue()[i].Count>0 && this->Queue()[i].Palette!=0) 
 		{
 			int nstep;
 
@@ -421,7 +419,7 @@ int iColorBars::RenderOpaqueGeometry(vtkViewport* viewport)
 				} 
 				else 
 				{
-					mLabels[j]->Base[i]->SetPosition(xpos-w1-w2,ypos-0.5*h1);
+					mLabels[j]->Base[i]->SetPosition(xpos-w2,ypos-0.5*h1);
 					mLabels[j]->Power[i]->SetPosition(xpos-w2,ypos+0.5*h1);
 				}
 			}
@@ -434,7 +432,7 @@ int iColorBars::RenderOpaqueGeometry(vtkViewport* viewport)
 
 			mTitleActor[i]->SetText(lim->GetName(this->Queue()[i].Var).ToCharPointer());
 			
-			mBarActor[i]->SetLookupTable(this->GetViewModule()->GetControlModule()->GetPalette(this->Queue()[i].Palette)->GetLookupTable());
+			mBarActor[i]->SetLookupTable(this->GetViewModule()->GetControlModule()->GetPalette(iMath::Abs(this->Queue()[i].Palette)-1)->GetLookupTable(this->Queue()[i].Palette < 0));
 		}
 	}
 	else
@@ -449,14 +447,14 @@ int iColorBars::RenderOpaqueGeometry(vtkViewport* viewport)
 		//  Shift positions if under magnification - 
 		//
 		int winij[2];
-		this->ComputePositionShiftsUnderMagnification(cam,winij,viewport);
+		this->ComputePositionShiftsUnderMagnification(winij);
 		
 		for(i=0; i<2; i++) mBarActor[i]->SetPosition(mag*mXOff[i]-winij[0],mag*mYOff-winij[1]);
 	}
 	//
 	//  Render everything
 	//
-	for(i=0; i<2; i++) if(this->Queue()[i].Count > 0) 
+	for(i=0; i<this->Queue().Size(); i++) if(this->Queue()[i].Count>0 && this->Queue()[i].Palette!=0) 
 	{
 		mBarActor[i]->RenderOpaqueGeometry(viewport);
 		mTitleActor[i]->RenderOpaqueGeometry(viewport);
@@ -526,32 +524,29 @@ void iColorBars::SetAutomatic(bool automatic)
 }
 
 
-void iColorBars::SetBar(int bar, int v, int id, int p, bool s)
+void iColorBars::SetBar(int bar, int v, int id, int p)
 {
 	if(bar>=0 && bar<2)
 	{
 		mManualBars[bar].Var = v;
 		mManualBars[bar].Palette = p;
 		mManualBars[bar].DataTypeId = id;
-		if(s) mManualBars[bar].Count = 1; else mManualBars[bar].Count = 0;
 		this->ClearCache();
 	}
 }
 
 
-void iColorBars::GetBar(int bar, int &v, int &id, int &p, bool &s) const
+void iColorBars::GetBar(int bar, int &v, int &id, int &p) const
 {
 	if(bar<0 || bar>1)
 	{
 		v = id = p = 0;
-		s = false;
 	}
 	else
 	{
 		v = mManualBars[bar].Var;
 		p = mManualBars[bar].Palette;
 		id = mManualBars[bar].DataTypeId;
-		s = (mManualBars[bar].Count>0);
 	}
 }
 
@@ -560,33 +555,26 @@ void iColorBars::GetBar(int bar, int &v, int &id, int &p, bool &s) const
 //
 void iColorBars::PackStateBody(iString &s) const
 {
-	this->PackValue(s,KeyFontType(),mFontType);
-	this->PackValue(s,KeyFontSize(),mFontSize);
 	this->PackValue(s,KeyColor(),mColor);
 	this->PackValue(s,KeySideOffset(),this->GetSideOffset());
 	this->PackValue(s,KeyAutomatic(),this->GetAutomatic());
 
-	bool b;
-	int iv[4];
-	this->GetBar(0,iv[0],iv[1],iv[2],b);
+	int iv[3];
+	this->GetBar(0,iv[0],iv[1],iv[2]);
 	iv[0]++;  //  vars start with 1
 	iv[2]++;
-	iv[3] = (int)b;
-	this->PackValue(s,KeyBarRight(),iv,4);
-	this->GetBar(1,iv[0],iv[1],iv[2],b);
+	this->PackValue(s,KeyBarRight(),iv,3);
+	this->GetBar(1,iv[0],iv[1],iv[2]);
 	iv[0]++;
 	iv[2]++;
-	iv[3] = (int)b;
-	this->PackValue(s,KeyBarLeft(),iv,4);
+	this->PackValue(s,KeyBarLeft(),iv,3);
 }
 
 
 void iColorBars::UnPackStateBody(const iString &s)
 {
-	int i, iv[4]; bool b, a; float f; iColor c;
+	int iv[3]; bool a; float f; iColor c;
 
-	if(this->UnPackValue(s,KeyFontType(),i)) this->SetFontType(i);
-	if(this->UnPackValue(s,KeyFontSize(),i)) this->SetFontSize(i);
 	if(this->UnPackValue(s,KeyColor(),c)) this->SetColor(c);
 	if(this->UnPackValue(s,KeySideOffset(),f)) this->SetSideOffset(f);
 
@@ -594,16 +582,14 @@ void iColorBars::UnPackStateBody(const iString &s)
 	this->UnPackValue(s,KeyAutomatic(),a);
 	this->SetAutomatic(false);
 
-	this->GetBar(0,iv[0],iv[1],iv[2],b);
+	this->GetBar(0,iv[0],iv[1],iv[2]);
 	iv[0]++;  //  vars start with 1
 	iv[2]++;
-	iv[3] = (int)b;
-	if(this->UnPackValue(s,KeyBarRight(),iv,4)) this->SetBar(0,iv[0]-1,iv[1],iv[2]-1,(iv[3]!=0));
-	this->GetBar(1,iv[0],iv[1],iv[2],b);
+	if(this->UnPackValue(s,KeyBarRight(),iv,3)) this->SetBar(0,iv[0]-1,iv[1],iv[2]-1);
+	this->GetBar(1,iv[0],iv[1],iv[2]);
 	iv[0]++;  //  vars start with 1
 	iv[2]++;
-	iv[3] = (int)b;
-	if(this->UnPackValue(s,KeyBarLeft(),iv,4)) this->SetBar(1,iv[0]-1,iv[1],iv[2]-1,(iv[3]!=0));
+	if(this->UnPackValue(s,KeyBarLeft(),iv,3)) this->SetBar(1,iv[0]-1,iv[1],iv[2]-1);
 
 	this->SetAutomatic(a);
 }
