@@ -53,17 +53,11 @@ class iColorBars: public vtkActor2D, public iObject, protected iOverlayBase, pro
 	
 public:
 	
+	IOBJECT_DECLARE_SELF(iColorBars,iObject);
+
 	static iColorBars* New(iViewModule *vm);
 	static const iObjectType& Type();
 	
-	IOBJECT_DECLARE_GETSET1(FontType,int);
-	//virtual void SetFontType(int t);
-	//inline int GetFontType() const { return mFontType; }
-
-	IOBJECT_DECLARE_GETSET1(FontSize,int);
-	//virtual void SetFontSize(int t);
-	//inline int GetFontSize() const { return mFontSize; }
-
 	IOBJECT_DECLARE_GETSET1(Color,iColor);
 	//virtual void SetColor(iColor c);
 	//inline iColor GetColor() const { return mColor; }
@@ -76,11 +70,16 @@ public:
 	//virtual void SetAutomatic(bool);
 	//inline bool GetAutomatic() const { return mAutomatic; }
 
-	virtual void SetBar(int bar, int v, int id, int p, bool s); 
-	virtual void GetBar(int bar, int &v, int &id, int &p, bool &s) const; 
+	virtual void SetBar(int bar, int v, int id, int p); 
+	virtual void GetBar(int bar, int &v, int &id, int &p) const; 
 	static const iObjectKey& KeyBarLeft();
 	static const iObjectKey& KeyBarRight();
 
+	virtual void SetFontScale(int s);
+
+	virtual void SetFontType(int t);
+	inline int GetFontType() const { return mFontType; }
+
 	virtual int RenderOverlay(vtkViewport*);
 	virtual int RenderOpaqueGeometry(vtkViewport*);
 	virtual int RenderTranslucentGeometry(vtkViewport *){ return 0; }
@@ -112,7 +111,7 @@ private:
 
 	iOrderedArray<QueueItem>& Queue();
 
-	int mFontSize, mFontType;
+	int mFontType;
 
 	bool mStarted, mAutomatic;
 	float mScale;
