@@ -58,16 +58,19 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 namespace iControlScript_Private
 {
-
 	template<class T>
 	T* QueryKeyData(T, const iObjectKey *tmp, iControlScript *me, int d)
 	{
 		T* data = new T[d];
 		if(data != 0) 
 		{
-			me->GetControlModule()->QueryValue(*tmp,data,d);
+			if(me->GetControlModule()->QueryValue(*tmp,data,d)) return data; else
+			{
+				delete [] data;
+				return 0;
+			}
 		}
-		return data;
+		else return 0;
 	}
 
 	template<class T>
@@ -78,7 +81,7 @@ namespace iControlScript_Private
 
 		if(data == 0) 
 		{
-			me->GetErrorStatus()->Set("Not enough memory.");
+			me->GetErrorStatus()->Set("The value of this property is not currently available.");
 			return 0;
 		}
 
@@ -133,7 +136,6 @@ namespace iControlScript_Private
 		}
 		return val;
 	}
-
 };
 
 
@@ -423,7 +425,7 @@ void iControlScript::ExecBody(iScript *me, iValue *v0, int mode)
 }
 
 //
-//  Show/hide a ViewObject
+//  Show/hide a ViewSubject
 //
 void iControlScript::Show(iScript *me, iValue *v0, iValue::Assignment)
 {
