@@ -79,31 +79,44 @@ IOBJECT_DEFINE_KEY(iDataReader,ScalarFieldCalculatorOutputVariable,scv,OffsetInt
 IOBJECT_DEFINE_KEY(iDataReader,ScaledDimension,sd,Int,1);
 IOBJECT_DEFINE_KEY(iDataReader,VoxelLocation,vl,Int,1);
 
-IOBJECT_DEFINE_KEY(iDataReader,RecordLength,-rl,Int,1);  // hidden
-
 
 //
 //  Main class
 //
 iDataReader* iDataReader::New(iViewModule* vm)
 {
-	return iPointerCast<iDataReader,iObject>(iExtensionFactory::CreateObject(Type(),vm));
+	int i;
+
+	iDataReader *tmp = new iDataReader(vm); IERROR_ASSERT(tmp);
+	iExtensionFactory::InstallExtensions(tmp);
+
+	iDataSubject *s;
+	for(i=0; i<tmp->mExtensions.Size(); i++)
+	{
+		while((s = iDataReaderExtension::RequiredCast(tmp->mExtensions[i])->AddNewSubject()) != 0)
+		{
+			tmp->mSubjects.Add(s);
+		}
+	}
+
+	iEdition::ApplySettings(tmp,iDataReader::Type());
+
+	return tmp;
 }
 
 
 iDataReader::iDataReader(iViewModule *vm) : iViewModuleComponent(vm), mSetSubjects(0), mSubjects(0), mVisitedFilesList(VisitedFile())
 {
-	mRecordLength = 4; 
-	mTwoCopies = false;
+	mTwoCopies = mInExtensionUpdate = false;
 
 	mCellToPointMode = 2;
 	mVoxelLocation = 0;
 	mBoundaryConditions = _BoundaryConditionsWall;
 
-    mUniformVectorsSubject = new iUniformVectorsDataSubject(this); IERROR_ASSERT_NULL_POINTER(mUniformVectorsSubject);
-    mUniformScalarsSubject = new iUniformScalarsDataSubject(this,mUniformVectorsSubject); IERROR_ASSERT_NULL_POINTER(mUniformScalarsSubject);
-    mUniformTensorsSubject = new iUniformTensorsDataSubject(this); IERROR_ASSERT_NULL_POINTER(mUniformTensorsSubject);
-    mBasicParticlesSubject = new iBasicParticlesDataSubject(this); IERROR_ASSERT_NULL_POINTER(mBasicParticlesSubject);
+    mUniformVectorsSubject = new iUniformVectorsDataSubject(this); IERROR_ASSERT(mUniformVectorsSubject);
+    mUniformScalarsSubject = new iUniformScalarsDataSubject(this,mUniformVectorsSubject); IERROR_ASSERT(mUniformScalarsSubject);
+    mUniformTensorsSubject = new iUniformTensorsDataSubject(this); IERROR_ASSERT(mUniformTensorsSubject);
+    mBasicParticlesSubject = new iBasicParticlesDataSubject(this); IERROR_ASSERT(mBasicParticlesSubject);
 
 	iEdition::ApplySettings(mUniformScalarsSubject,mUniformScalarsSubject->RealType());
 	iEdition::ApplySettings(mUniformVectorsSubject,mUniformVectorsSubject->RealType());
@@ -116,7 +129,6 @@ iDataReader::iDataReader(iViewModule *vm) : iViewModuleComponent(vm), mSetSubjec
 	mSubjects.Add(mBasicParticlesSubject);
 
 	mCurrentRecord = -1;
-	mLastRecord = round(pow10(float(mRecordLength))) - 1;
 	mPeriodicityLeader = 0;
 
 	mDataShift[0] = mDataShift[1] = mDataShift[2] = 0.0f;
@@ -125,7 +137,7 @@ iDataReader::iDataReader(iViewModule *vm) : iViewModuleComponent(vm), mSetSubjec
 
 //	mLastFileName = mLastAttemptedFileName = "";
 
-	mDirectory = new iDirectory; IERROR_ASSERT_NULL_POINTER(mDirectory);
+	mDirectory = new iDirectory; IERROR_ASSERT(mDirectory);
 }
 
 
@@ -187,7 +199,7 @@ void iDataReader::ReloadData(const iDataType &type)
 		if(mSubjects[i]->IsUsingData(type) && mSubjects[i]->IsThereData() && mSubjects[i]->OwnsData())
 		{
 			this->GetErrorStatus()->Monitor(mSubjects[i]);
-			mSubjects[i]->ReadFile(mSubjects[i]->GetLastFileName(),mSubjects[i]->GetFileRoot(),mSubjects[i]->GetFileSuffix(),mSubjects[i]->GetRecord());
+			mSubjects[i]->ReadFile(mSubjects[i]->GetLastFileName());
 			if(mSubjects[i]->GetObserver()->IsAborted()) this->GetErrorStatus()->SetAbort();
 
 			if(this->GetErrorStatus()->NoError()) mSubjects[i]->Finalize();
@@ -279,26 +291,20 @@ iDataSubject* iDataReader::GetSubject(const iDataType &type) const
 }
 
 
-iString iDataReader::GetRecordAsString(int rec) const
+bool iDataReader::IsSetLeader(const iDataSubject *subject) const
 {
-	const iString format = "%0" + iString::FromNumber(mRecordLength) + "d";
-	return iString::FromNumber(rec,format.ToCharPointer());
+	return (mSetSubjects.Size()>0 && mSetSubjects[0]==subject);
 }
 
 
 void iDataReader::LoadFile(const iDataType &type, const iString &fname, bool dryrun, bool savename)
 {
 	int i, newrec;
-	iString root, record, suffix, name;
+//	iString root, suffix, name;
 
 	this->GetErrorStatus()->Clear();
 	this->ClearCache();
 	mLastAttemptedFileName = fname;
-
-	//
-	//  Analyze the file name
-	//
-	newrec = this->DissectFileName(fname,root,record,suffix);
 	
 	//
 	//  Ask subjects to read the data
@@ -314,8 +320,11 @@ void iDataReader::LoadFile(const iDataType &type, const iString &fname, bool dry
 			}
 			else
 			{
+				iString root, suffix;
+				newrec = mSubjects[i]->DissectFileName(fname,root,suffix);
+
 				this->GetErrorStatus()->Monitor(mSubjects[i]);
-				mSubjects[i]->ReadFile(fname,root,suffix,newrec);
+				mSubjects[i]->ReadFile(fname);
 				if(this->GetErrorStatus()->NoError())
 				{
 					subject = mSubjects[i];
@@ -353,7 +362,7 @@ void iDataReader::LoadFile(const iDataType &type, const iString &fname, bool dry
 			//
 			//  Re-establish the set if we are not loading a new one
 			//
-			if(mSetSubjects[0] != subject)
+			if(!this->IsSetLeader(subject))
 			{
 				this->BreakSet();
 				mSetSubjects.Add(subject);
@@ -374,12 +383,12 @@ void iDataReader::LoadFile(const iDataType &type, const iString &fname, bool dry
 	//
 	//  Do we have a set? If yes, load the rest of it too
 	//
-	if(subject == mSetSubjects[0])
+	if(this->IsSetLeader(subject))
 	{
 		//
 		//Is the filename consistent?
 		//
-		if(root!=mSetSubjects[0]->GetFileRoot() || suffix!=mSetSubjects[0]->GetFileSuffix())
+		if(!mSetSubjects[0]->IsSeriesFileName(fname))
 		{
 			this->BreakSet();
 		}
@@ -391,8 +400,7 @@ void iDataReader::LoadFile(const iDataType &type, const iString &fname, bool dry
 			for(i=1; this->GetErrorStatus()->NoError() && i<mSetSubjects.Size(); i++) // start at 1 since the leader has been loaded already
 			{
 				this->GetErrorStatus()->Monitor(mSetSubjects[i]);
-				name = mSetSubjects[i]->GetFileRoot() + record + "." + mSetSubjects[i]->GetFileSuffix();
-				mSetSubjects[i]->ReadFile(name,mSetSubjects[i]->GetFileRoot(),mSetSubjects[i]->GetFileSuffix(),newrec);
+				mSetSubjects[i]->ReadFile(mSetSubjects[i]->GetFileName(newrec));
 				if(this->GetErrorStatus()->IsError() && !mTwoCopies) mSetSubjects[i]->EraseData(); // mark data as absent if we keep only one copy
 			}
 		}
@@ -405,7 +413,7 @@ void iDataReader::LoadFile(const iDataType &type, const iString &fname, bool dry
 	//
 	subject->Finalize();
 	if(subject->GetObserver()->IsAborted()) { subject->EraseData(); this->GetErrorStatus()->SetAbort(); }
-	if(subject == mSetSubjects[0])
+	if(this->IsSetLeader(subject))
 	{
 		for(i=1; this->GetErrorStatus()->NoError() && i<mSetSubjects.Size(); i++) // the leader has been loaded already
 		{
@@ -419,9 +427,9 @@ void iDataReader::LoadFile(const iDataType &type, const iString &fname, bool dry
 	//
 	subject->ShiftData(mDataShift);
 	if(subject->GetObserver()->IsAborted()) { subject->EraseData(); this->GetErrorStatus()->SetAbort(); }
-	if(subject == mSetSubjects[0])
+	if(this->IsSetLeader(subject))
 	{
-		for(i=0; this->GetErrorStatus()->NoError() && i<mSetSubjects.Size(); i++) if(mSetSubjects[i] != mSetSubjects[0]) // the leader has been loaded already
+		for(i=1; this->GetErrorStatus()->NoError() && i<mSetSubjects.Size(); i++) // the leader has been loaded already
 		{
 			mSetSubjects[i]->ShiftData(mDataShift);
 			if(mSetSubjects[i]->GetObserver()->IsAborted()) { mSetSubjects[i]->EraseData(); this->GetErrorStatus()->SetAbort(); }
@@ -429,30 +437,21 @@ void iDataReader::LoadFile(const iDataType &type, const iString &fname, bool dry
 	}
 
 	this->GetViewModule()->GetParallelManager()->StopCounters();
-	this->GetViewModule()->UpdateLabel();
-	this->GetViewModule()->UpdatePerformance();
-}
+	this->GetViewModule()->UpdateAfterFileLoad();
 
+	//
+	//  Ask extensions do to their share of work, but guard against loops if they call this function
+	//
+	if(mInExtensionUpdate) return;
+	mInExtensionUpdate = true;
 
-int iDataReader::DissectFileName(const iString &fname, iString &root, iString &record, iString &suffix) const
-{
-	bool ok;
-	int rec;
-
-	suffix = fname.Section(".",-1);
-	root = fname.Part(0,fname.Length()-suffix.Length()-1);
-	record = root.Part(-mRecordLength);
-	rec = record.ToInt(ok);
-	if(!ok || record!=this->GetRecordAsString(rec) || rec<0) 
+	for(i=0; i<mExtensions.Size(); i++) 
 	{
-		record.Clear();
-		return -1;
-	}
-	else
-	{
-		root = root.Part(0,root.Length()-mRecordLength);
-		return rec;
+		iDataReaderExtension *ext = iDataReaderExtension::RequiredCast(mExtensions[i]);
+		if(ext->IsUsingData(type)) ext->AfterLoadFile(type,fname,dryrun);
 	}
+
+	mInExtensionUpdate = false;
 }
 
 
@@ -470,13 +469,13 @@ void iDataReader::LoadRecord(int rec, int skip, bool dryrun, bool savename)
 
 	this->GetErrorStatus()->Clear();
 	this->ClearCache();
-	if(mSetSubjects[0] == 0)
+	if(mSetSubjects.Size() == 0)
 	{
 		this->GetErrorStatus()->Set("File set has not been established.");
 		return;
 	}
 
-	iString fname = mSetSubjects[0]->GetFileRoot() + this->GetRecordAsString(rec) + "." + mSetSubjects[0]->GetFileSuffix();
+	iString fname = mSetSubjects[0]->GetFileName(rec);
 	if(!iFile::IsLoadable(fname))
 	{
 		this->GetErrorStatus()->Set("File is not accessible.");
@@ -491,11 +490,16 @@ void iDataReader::LoadRecord(int rec, int skip, bool dryrun, bool savename)
 			return;
 		}
 	
-		fname = mDirectory->GetFile(fname,skip);
+		while(skip>0 && !fname.IsEmpty())
+		{
+			fname = mDirectory->GetFile(fname,1);
+			if(this->IsAnotherSetLeader(fname)) skip--;
+		}
+
 		//
-		//  Is this filename from the same set?
+		//  Is this filename from the same series?
 		//
-		if(!this->IsSetMember(fname))
+		if(!this->IsAnotherSetLeader(fname))
 		{
 			this->GetErrorStatus()->Set("File does not exist.",10);
 			return;
@@ -517,7 +521,7 @@ const iDataType& iDataReader::GetFileSetDataType(int member) const
 {
 	if(member<0 || member>=mSetSubjects.Size())
 	{
-		return iDataType::Null();
+		return iData::None();
 	}
 	else
 	{
@@ -530,7 +534,7 @@ const iString& iDataReader::GetLastFileSetName() const
 {
 	static const iString none;
 
-	if(mSetSubjects[0] == 0) return none; else return mSetSubjects[0]->GetLastFileName();
+	if(mSetSubjects.Size() == 0) return none; else return mSetSubjects[0]->GetLastFileName();
 }
 
 
@@ -538,16 +542,28 @@ const iString iDataReader::GetFileSetName(int rec) const
 {
 	static const iString none;
 	
-	if(mSetSubjects[0]!=0 && rec>=0) return mSetSubjects[0]->GetFileRoot() + this->GetRecordAsString(rec) + "." + mSetSubjects[0]->GetFileSuffix(); else return none;
+	if(mSetSubjects.Size()>0 && rec>=0) return mSetSubjects[0]->GetFileName(rec); else return none;
 }
 
 
-bool iDataReader::IsSetMember(const iString &fname) const
+bool iDataReader::IsCurrentSetMember(const iString &fname) const
 {
-	iString root, record, suffix;
-	int newrec = this->DissectFileName(fname,root,record,suffix);
-	
-	return (mSetSubjects[0]!=0 && newrec>=0 && root==mSetSubjects[0]->GetFileRoot() && suffix==mSetSubjects[0]->GetFileSuffix()); 
+	int i;
+	for(i=0; i<mSetSubjects.Size(); i++)
+	{
+		if(mSetSubjects[i]->GetLastFileName() == fname) return true;
+	}
+	return false;
+}
+
+
+bool iDataReader::IsAnotherSetLeader(const iString &fname) const
+{
+	if(mSetSubjects.Size() > 0)
+	{
+		return mSetSubjects[0]->IsSeriesFileName(fname);
+	}
+	else return false;
 }
 
 
@@ -589,7 +605,7 @@ float iDataReader::GetMemorySize() const
 }
 
 
-void iDataReader::PackStateBody(iString &s) const
+void iDataReader::ExtendableObjectPackStateBody(iString &s) const
 {
 	this->PackValue(s,KeyParticlesOrderInFileIsAttribute(),this->GetParticlesOrderInFileIsAttribute());
 	this->PackValue(s,KeyCellToPointMode(),mCellToPointMode);
@@ -610,15 +626,10 @@ void iDataReader::PackStateBody(iString &s) const
 	//
 	this->PackValue(s,KeyErrorMessage(),this->GetErrorStatus()->GetErrorMessage());
 	this->PackValue(s,KeyIsSet(),this->IsSet());
-
-	//
-	//  Hidden keys
-	//
-	this->PackValue(s,KeyRecordLength(),mRecordLength);
 }
 
 
-void iDataReader::UnPackStateBody(const iString &s)
+void iDataReader::ExtendableObjectUnPackStateBody(const iString &s)
 {
 	int i; bool b; double ds[3]; iString s1;
 
@@ -645,34 +656,20 @@ void iDataReader::UnPackStateBody(const iString &s)
 	//
 	//  Special "action" keys
 	//
-#ifdef I_CHECK1
-	bool saveReportMissingKeys = iObject::ReportMissingKeys;
-	iObject::ReportMissingKeys = false; //action keys are not part of the states
-#endif
+	iObject::ReportMissingKeys(false); //action keys are not part of the states
 
 	if(this->UnPackValue(s,KeyEraseData(),i)) if(i>=0 && i<mSubjects.Size()) this->EraseData(mSubjects[i]->GetDataType()); 
 
 	iString ws[2];
 	if(this->UnPackValue(s,KeyLoadData(),ws,2))
 	{
-		this->LoadFileByStringKey(iDataType::UniformScalars(),_EnvironmentScalarFieldData,ws);
-		this->LoadFileByStringKey(iDataType::UniformVectors(),_EnvironmentVectorFieldData,ws);
-		this->LoadFileByStringKey(iDataType::UniformTensors(),_EnvironmentTensorFieldData,ws);
-		this->LoadFileByStringKey(iDataType::BasicParticles(),_EnvironmentParticleSetData,ws);
+		this->LoadFileByStringKey(iData::UniformScalars(),_EnvironmentScalarFieldData,ws);
+		this->LoadFileByStringKey(iData::UniformVectors(),_EnvironmentVectorFieldData,ws);
+		this->LoadFileByStringKey(iData::UniformTensors(),_EnvironmentTensorFieldData,ws);
+		this->LoadFileByStringKey(iData::BasicParticles(),_EnvironmentParticleSetData,ws);
 	}
 
-#ifdef I_CHECK1
-	iObject::ReportMissingKeys = saveReportMissingKeys;
-#endif
-
-	//
-	//  Hidden keys
-	//
-	if(this->UnPackValue(s,KeyRecordLength(),i))
-	{
-		mRecordLength = i;
-		this->ClearCache();
-	}
+	iObject::ReportMissingKeys(true);
 }
 
 
@@ -695,17 +692,20 @@ void iDataReader::PackCompleteState(iString &s) const
 
 void iDataReader::UnPackCompleteState(const iString &s)
 {
-	int i; iString s1;
+	int i, j, n;
+	iString s1, name;
 
 	this->UnPackState(s);
 
 	//
 	//  UnPack all subjects for state restoring
 	//
-	for(i=0; i<mSubjects.Size(); i++)
+	n = s.Contains(iObjectKey::SpecialSeparator());
+	for(j=0; j<n; j++)
 	{
-		s1 = s.Section(iObjectKey::SpecialSeparator(),i+1,i+1);
-		if(mSubjects[i]->GetDataType().GetName() == s1.Section(iObjectKey::Delimiter(),0,0))
+		s1 = s.Section(iObjectKey::SpecialSeparator(),j+1,j+1);
+		name = s1.Section(iObjectKey::Delimiter(),0,0);
+		for(i=0; i<mSubjects.Size(); i++) if(mSubjects[i]->GetDataType().IsOfType(name))
 		{
 			mSubjects[i]->UnPackCompleteState(s1);
 		}
@@ -715,7 +715,7 @@ void iDataReader::UnPackCompleteState(const iString &s)
 
 void iDataReader::LoadFileByStringKey(const iDataType &type, int envkey, iString ws[2])
 {
-	if(type.IsA(ws[0])) 
+	if(type.IsOfType(ws[0])) 
 	{
 		if(ws[1][0] == '+') ws[1] = this->GetViewModule()->GetControlModule()->GetFileName(envkey,ws[1].Part(1));
 		this->LoadFile(type,ws[1]);
@@ -753,7 +753,7 @@ iProgressEventObserver* iDataReader::GetProgressEventObserver(const iDataType &t
 
 const iDataType& iDataReader::GetDataType(int i) const
 {
-	if(i>=0 && i<mSubjects.Size()) return mSubjects[i]->GetDataType(); else return iDataType::Null();
+	if(i>=0 && i<mSubjects.Size()) return mSubjects[i]->GetDataType(); else return iData::None();
 }
 
 
@@ -766,7 +766,10 @@ vtkDataSet* iDataReader::GetOutput(const iDataType &type) const
 
 	for(i=0; i<mSubjects.Size(); i++)
 	{
-		if(mSubjects[i]->IsUsingData(type)) return mSubjects[i]->GetData();
+		if(mSubjects[i]->IsUsingData(type))
+		{
+			return mSubjects[i]->GetData();
+		}
 	}
 
 	return 0;
@@ -886,10 +889,10 @@ void iDataReader::SetScaledDimension(int v)
 {
 	int i;
 
-	iGridDataSubject *ds;
+	iUniformGridDataSubject *ds;
 	for(i=0; i<mSubjects.Size(); i++)
 	{
-		ds = dynamic_cast<iGridDataSubject*>(mSubjects[i]);
+		ds = dynamic_cast<iUniformGridDataSubject*>(mSubjects[i]);
 		if(ds != 0)
 		{
 			ds->SetScaledDimension(v);
@@ -905,10 +908,10 @@ void iDataReader::SetVoxelLocation(int v)
 {
 	int i;
 
-	iGridDataSubject *ds;
+	iUniformGridDataSubject *ds;
 	for(i=0; i<mSubjects.Size(); i++)
 	{
-		ds = dynamic_cast<iGridDataSubject*>(mSubjects[i]);
+		ds = dynamic_cast<iUniformGridDataSubject*>(mSubjects[i]);
 		if(ds != 0)
 		{
 			ds->SetVoxelLocation(v);
@@ -924,10 +927,10 @@ void iDataReader::SetCellToPointMode(int m)
 { 
 	int i;
 
-	iGridDataSubject *ds;
+	iUniformGridDataSubject *ds;
 	for(i=0; i<mSubjects.Size(); i++)
 	{
-		ds = dynamic_cast<iGridDataSubject*>(mSubjects[i]);
+		ds = dynamic_cast<iUniformGridDataSubject*>(mSubjects[i]);
 		if(ds != 0)
 		{
 			ds->SetCellToPointMode(m);
@@ -937,3 +940,23 @@ void iDataReader::SetCellToPointMode(int m)
 	this->ClearCache();
 }
 
+
+//
+//  Extension
+//
+IOBJECTEXTENSION_DEFINE_ABSTRACT(iDataReader);
+
+
+void iDataReaderExtension::Define()
+{
+	mNextSubjectToCreate = 0;
+}
+
+
+iDataSubject* iDataReaderExtension::AddNewSubject()
+{
+	iDataSubject *s = this->CreateSubject(mNextSubjectToCreate);
+	if(s != 0) mNextSubjectToCreate++;
+	return s;
+}
+
