@@ -32,6 +32,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ibuffer.h"
 #include "icontrolmodule.h"
 #include "idata.h"
+#include "idataconsumer.h"
 #include "idatalimits.h"
 #include "idatareader.h"
 #include "ierror.h"
@@ -144,7 +145,7 @@ namespace iDataSubject_Private
 			}
 		default:
 			{
-				IERROR_REPORT_FATAL_ERROR("IFrIT was not ported to that platform.");
+				IERROR_FINISH("IFrIT was not ported to that platform.");
 			}
 		}
 	}
@@ -167,7 +168,7 @@ namespace iDataSubject_Private
 			}
 		default:
 			{
-				IERROR_REPORT_FATAL_ERROR("IFrIT was not ported to that platform.");
+				IERROR_FINISH("IFrIT was not ported to that platform.");
 			}
 		}
 	}
@@ -315,6 +316,7 @@ IOBJECT_DEFINE_KEY(iDataSubject,Stretch,s,Int,0);
 IOBJECT_DEFINE_KEY(iDataSubject,UpperLimit,up,Float,0);
 
 IOBJECT_DEFINE_KEY(iDataSubject,ResizeLimits,-rl,Int,1); // hidden key
+IOBJECT_DEFINE_KEY(iDataSubject,RecordLength,-l,Int,1);  // hidden key
 
 
 bool iDataSubject::IsTypeMatch(const iString &prefix)
@@ -340,20 +342,21 @@ iString iDataSubject::GetDataSubjectName(const iString &prefix)
 
 iDataSubject::iDataSubject(iDataReader *r, const iDataType &type) : iViewModuleComponent(r->GetViewModule()), mDataType(type)
 {
+	mRecordLength = 4; 
 	mFortranHeaderFooterLength = -1;
 
 	mReader = r;
 	mLimits = 0;
 
-	if(mDataType == iDataType::Null())
+	if(mDataType == iData::None())
 	{
-		IERROR_REPORT_FATAL_ERROR("DataSubject cannot have Null DataType.");
+		IERROR_FINISH("DataSubject cannot have Null DataType.");
 	}
 
 	mInternalData = mExternalData = 0;  // must be set by a child
 
 	// mFileRoot = mFileSuffix = mLastFileName = "";
-	mUpdated = false;
+	mUpdated = true;
 	mIsBigEndian = true;
 	mTwoCopies = false;
 	mOwnsData = type.IsPrimary();
@@ -369,7 +372,7 @@ iDataSubject::iDataSubject(iDataReader *r, const iDataType &type) : iViewModuleC
 	//  Event observers are driven directly (otherwise we would have to create at least 16 new events, which is
 	//  cumbersome), so adding with AddObserver is not necessarily
 	//
-	mObserver = dynamic_cast<iProgressEventObserver *>(iShellFactory::CreateEventObserver("Progress",mReader->GetViewModule())); IERROR_ASSERT_NULL_POINTER(mObserver);
+	mObserver = dynamic_cast<iProgressEventObserver *>(iShellFactory::CreateEventObserver("Progress",mReader->GetViewModule())); IERROR_ASSERT(mObserver);
 }
 
 
@@ -426,7 +429,7 @@ iDataLimits* iDataSubject::GetLimits() const
 {
 	if(mLimits == 0)
 	{
-		mLimits = this->CreateLimits(); IERROR_ASSERT_NULL_POINTER(mLimits);
+		mLimits = this->CreateLimits(); IERROR_ASSERT(mLimits);
 	}
 	
 	return mLimits;
@@ -439,7 +442,7 @@ void iDataSubject::ResetLimits()
 }
 
 
-void iDataSubject::ReadFile(const iString &fname, const iString &root, const iString &suffix, int record)
+void iDataSubject::ReadFile(const iString &fname)
 {
 	this->GetErrorStatus()->Clear();
 	mOverflow = false;
@@ -451,6 +454,9 @@ void iDataSubject::ReadFile(const iString &fname, const iString &root, const iSt
 		return;
 	}
 
+	iString root, suffix;
+	int record = this->DissectFileName(fname,root,suffix);
+
 	this->GetLimits()->BlockNotifications(true);
 	this->ReadFileBody(suffix,fname);
 	this->GetLimits()->BlockNotifications(false);
@@ -505,7 +511,7 @@ void iDataSubject::NotifyDependencies()
 	//
 	//  Default implementation, but can be changed in a child
 	//
-	this->GetLimits()->NotifyDependencies(0);
+	this->GetLimits()->NotifyDependencies(-1);
 }
 
 
@@ -529,7 +535,6 @@ void iDataSubject::EraseData()
 		if(mInternalData != 0) mInternalData->Initialize();
 		if(mExternalData != 0) mExternalData->Initialize();
 	}
-	mUpdated = false;
 	mRecord = -1;
 	mShift[0] = mShift[1] = mShift[2] = 0.0f;
 
@@ -549,7 +554,7 @@ void iDataSubject::DetachData()
 void iDataSubject::Reset()
 {
 	if(mExternalData != 0) mExternalData->Modified();
-	this->GetViewModule()->NotifyDataConsumers(mDataType,0,0);
+	this->GetViewModule()->NotifyDataConsumers(this->Request());
 }
 
 
@@ -657,7 +662,6 @@ bool iDataSubject::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const Re
 }
 
 
-
 bool iDataSubject::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const ReadingBuffer &b2, const ReadingBuffer &b3, float updateStart, float updateDuration, bool autoswap)
 {
 	long lrec1, lrec2;
@@ -681,6 +685,28 @@ bool iDataSubject::ReadFortranRecord(iFile& F, const ReadingBuffer &b1, const Re
 	return true;
 }
 
+	
+bool iDataSubject::ReadFortranRecord(iFile& F, int nbufs, const ReadingBuffer *b, float updateStart, float updateDuration, bool autoswap) // read any number of buffers
+{
+	long lrec1, lrec2;
+
+	if(b==0 || nbufs<=0 || !this->ReadFortranHeaderFooter(F,lrec1)) return false;
+
+	int i;
+	long len = 0L;
+	for(i=0; i<nbufs; i++)
+	{
+		len += b[i].Length*b[i].Size;
+		if(!ReadBlockToBuffer(F,b[i],updateStart+i*updateDuration,updateDuration,autoswap && mIsBigEndian!=iSystem::IsBigEndianMachine(),mObserver)) return false;
+		if(mObserver->IsAborted()) return true;
+	}
+
+	if(!this->ReadFortranHeaderFooter(F,lrec2)) return false;
+	if(lrec1!=lrec2 || lrec1!=len) return false;
+
+	return true;
+}
+
 
 bool iDataSubject::ReadFortranHeaderFooter(iFile& F, long &lrec)
 {
@@ -703,7 +729,7 @@ bool iDataSubject::ReadFortranHeaderFooter(iFile& F, long &lrec)
 	}
 	else
 	{
-		IERROR_REPORT_ERROR("Invalid Fortran header/footer length.");
+		IERROR_REPORT("Invalid Fortran header/footer length.");
 	}
 
 	return ret;
@@ -717,7 +743,9 @@ void iDataSubject::PackCompleteState(iString &s) const
 	//  Save the currently loaded Vars
 	//
 	limits->BackupVars();
+	limits->BlockNotifications(true);
 	limits->AssignVars();
+	limits->BlockNotifications(false);
 	//
 	//  Pack state without caching
 	//
@@ -738,7 +766,9 @@ void iDataSubject::UnPackCompleteState(const iString &s)
 	//  Save the currently loaded Vars
 	//
 	limits->BackupVars();
+	limits->BlockNotifications(true);
 	limits->AssignVars();
+	limits->BlockNotifications(false);
 	//
 	//  Unpack state and clear the cache
 	//
@@ -792,6 +822,11 @@ void iDataSubject::PackStateBody(iString &s) const
 		this->PackValue(s,KeyName(),stmp,n);
 	}
 
+	//
+	//  Hidden key
+	//
+	this->PackValue(s,KeyRecordLength(),mRecordLength);
+
 	this->DataSubjectPackStateBody(s);
 }
 
@@ -866,14 +901,25 @@ void iDataSubject::UnPackStateBody(const iString &s)
 		}
 	}
 
+	//
+	//  Hidden key
+	//
+	iObject::ReportMissingKeys(false);
+	if(this->UnPackValue(s,KeyRecordLength(),i))
+	{
+		mRecordLength = i;
+		this->ClearCache();
+	}
+	iObject::ReportMissingKeys(true);
+
 	this->DataSubjectUnPackStateBody(s);
 
 	limits->BlockNotifications(false);
-	limits->NotifyDependencies(0);
+	limits->NotifyDependencies(-1);
 }
 
 
-bool iDataSubject::DetectFileStructureFromFirstRecord(iFile &F, long len)
+bool iDataSubject::DetectFortranFileStructure(iFile &F, long len)
 {
 	//
 	//  Try int-sized records
@@ -898,6 +944,61 @@ bool iDataSubject::DetectFileStructureFromFirstRecord(iFile &F, long len)
 }
 
 
+const iDataSyncRequest& iDataSubject::Request(int var) const
+{
+	return iDataConsumer::Request(this->GetDataType(),var);
+}
+
+
+iString iDataSubject::GetRecordAsString(int rec) const
+{
+	const iString format = "%0" + iString::FromNumber(mRecordLength) + "d";
+	return iString::FromNumber(rec,format.ToCharPointer());
+}
+
+
+int iDataSubject::DissectFileName(const iString &fname, iString &root, iString &suffix) const
+{
+	bool ok;
+	int rec;
+
+	suffix = fname.Section(".",-1);
+	root = fname.Part(0,fname.Length()-suffix.Length()-1);
+	iString record = root.Part(-mRecordLength);
+	rec = record.ToInt(ok);
+	if(!ok || record!=this->GetRecordAsString(rec) || rec<0) 
+	{
+		return -1;
+	}
+	else
+	{
+		root = root.Part(0,root.Length()-mRecordLength);
+		return rec;
+	}
+}
+
+
+const iString iDataSubject::GetFileName(int rec) const
+{
+	if(mFileSuffix.IsEmpty())
+	{
+		return mFileRoot + this->GetRecordAsString(rec);
+	}
+	else
+	{
+		return mFileRoot + this->GetRecordAsString(rec) + "." + mFileSuffix;
+	}
+}
+
+
+bool iDataSubject::IsSeriesFileName(const iString &fname) const
+{
+	iString root, suffix;
+	int	rec = this->DissectFileName(fname,root,suffix);
+	return (rec>=0 && root==mFileRoot && suffix==mFileSuffix);
+}
+
+
 //
 //  Overloads
 //
@@ -914,3 +1015,102 @@ IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(float);
 IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(double);
 //IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(unsigned int);
 //IDATASUBJECT_DEFINE_READ_BLOCK_FUNCTIONS(unsigned long);
+
+
+//
+//  Secondary subject (for data subjects that do not own their data)
+//
+iSecondaryDataSubject::iSecondaryDataSubject(iPrimaryDataSubject *parent, const iDataType &type) : iDataSubject(parent->GetReader(),type)
+{
+	int i;
+
+	mParent = parent; IERROR_ASSERT(parent);
+	mOwnsData = false;
+
+	mBoundaryConditions = parent->GetBoundaryConditions();
+	for(i=0; i<3; i++) mPeriodic[i] = parent->IsDirectionPeriodic(i);
+	mAdjustableLimits = parent->GetAdjustableLimits();
+
+	mParent->RegisterDependentSubject(this);
+}
+
+
+iSecondaryDataSubject::~iSecondaryDataSubject()
+{
+	this->ResetLimits();  // a copy, not an independent object
+	if(mParent != 0) mParent->UnRegisterDependentSubject(this);
+}
+
+
+void iSecondaryDataSubject::DataSubjectPackStateBody(iString &) const
+{
+}
+
+void iSecondaryDataSubject::DataSubjectUnPackStateBody(const iString &)
+{
+}
+
+
+void iSecondaryDataSubject::ReadFileBody(const iString &, const iString &)
+{
+}
+
+
+void iSecondaryDataSubject::ShiftDataBody(int, double)
+{
+}
+
+
+void iSecondaryDataSubject::FinalizeBody()
+{
+}
+
+
+iProbeFilter* iSecondaryDataSubject::CreateProbeFilter(iViewSubject *vo) const
+{
+	if(mParent != 0) return mParent->CreateProbeFilter(vo); else return 0;
+}
+
+
+iHistogramMaker* iSecondaryDataSubject::CreateHistogramMaker() const
+{
+	if(mParent != 0) return mParent->CreateHistogramMaker(); else return 0;
+}
+
+
+//
+//  Primary subject (for data subjects that control secondary subject)
+//
+iPrimaryDataSubject::iPrimaryDataSubject(iDataReader *r, const iDataType &type) : iDataSubject(r,type), mDependentSubjects(0)
+{
+}
+
+
+iPrimaryDataSubject::~iPrimaryDataSubject()
+{
+	int i;
+
+	for(i=0; i<mDependentSubjects.Size(); i++) mDependentSubjects[i]->mParent = 0;
+}
+
+
+void iPrimaryDataSubject::NotifyDependencies()
+{
+	int i;
+
+	this->iDataSubject::NotifyDependencies();
+	for(i=0; i<mDependentSubjects.Size(); i++) mDependentSubjects[i]->NotifyDependencies();
+}
+
+
+void iPrimaryDataSubject::RegisterDependentSubject(iSecondaryDataSubject *subject)
+{
+	if(subject != 0) mDependentSubjects.AddUnique(subject);
+}
+
+
+void iPrimaryDataSubject::UnRegisterDependentSubject(iSecondaryDataSubject *subject)
+{
+	if(subject != 0) mDependentSubjects.Remove(subject);
+}
+
