@@ -36,16 +36,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iconsole.h"
 
 
-#define IERROR_ASSERT_NULL_POINTER(_p_) { if((_p_) == 0) iConsole::Instance()->DisplayFatalErrorMessage("Null pointer.",__FILE__,__LINE__); }
-#define IERROR_REPORT_OUT_OF_BOUNDS     { iConsole::Instance()->DisplayFatalErrorMessage("Array out of bounds.",__FILE__,__LINE__); }
-#define IERROR_REPORT_FATAL_ERROR(m)    { iConsole::Instance()->DisplayFatalErrorMessage(m,__FILE__,__LINE__); }
-#define IERROR_REPORT_ERROR(m)          { iConsole::Instance()->DisplayErrorMessage(m,__FILE__,__LINE__); }
+#define IERROR_ASSERT(_p_)		{ if((_p_) == 0) iConsole::Instance()->DisplayFatalErrorMessage("Null pointer.",__FILE__,__LINE__); }
+#define IERROR_FINISH(_m_)		{ iConsole::Instance()->DisplayFatalErrorMessage(_m_,__FILE__,__LINE__); }
+#define IERROR_REPORT(_m_)		{ iConsole::Instance()->DisplayErrorMessage(_m_,__FILE__,__LINE__); }
 #ifdef I_CHECK1
-#define IERROR_REPORT_BUG               { iConsole::Instance()->DisplayErrorMessage("Bug detected.",__FILE__,__LINE__); }
+#define IERROR_REPORT_BUG		{ iConsole::Instance()->DisplayErrorMessage("Bug detected.",__FILE__,__LINE__); }
 #endif
 #ifdef I_DEBUG
-#define IERROR_BREAKPOINT               { iConsole::Instance()->BreakPoint(__FILE__,__LINE__); }
+#define IERROR_BREAKPOINT		{ iConsole::Instance()->BreakPoint(__FILE__,__LINE__); }
 #endif
+
 //
 //  error-reporting dynamic_cast - make it a global function to reduce de-referencing
 //
@@ -54,7 +54,20 @@ inline O* iPointerCast(I* p)
 {
 	if(p == 0) return 0;
 	O* tmp = dynamic_cast<O*>(p);
-	if(tmp == 0) iConsole::Instance()->DisplayFatalErrorMessage("Invalid cast",__FILE__,__LINE__);
+	if(tmp == 0) iConsole::Instance()->DisplayFatalErrorMessage("Invalid cast.",__FILE__,__LINE__);
+	return tmp;
+}
+
+//
+//  RequiredCast for VTK Objects
+//
+class vtkObject;
+template<class O>
+inline O* iRequiredCast(vtkObject *p)
+{
+	if(p == 0) return 0;
+	O* tmp = O::SafeDownCast(p);
+	if(tmp == 0) iConsole::Instance()->DisplayFatalErrorMessage("Invalid cast.",__FILE__,__LINE__);
 	return tmp;
 }
 
