@@ -132,7 +132,7 @@ int iExpressionParser::Parse()
 
 int iExpressionParser::DisambiguateOperators()
 {
-	unsigned char* tempStack = new unsigned char[mByteCode.Size()]; IERROR_ASSERT_NULL_POINTER(tempStack);
+	unsigned char* tempStack = new unsigned char[mByteCode.Size()]; IERROR_ASSERT(tempStack);
 	int i;
 	int tempStackPtr = -1;
 	
@@ -672,7 +672,7 @@ void iExpressionParser::RemoveSpaces()
 	int i, n = 0;
 
 	mFunction.ReduceWhiteSpace();
-	char *p = new char[mFunction.Length()+1]; IERROR_ASSERT_NULL_POINTER(p);
+	char *p = new char[mFunction.Length()+1]; IERROR_ASSERT(p);
 
 	for(i=0; i<mFunction.Length(); i++) if(mFunction[i] != ' ')
 	{
