@@ -33,69 +33,115 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define IGENERICFILTER_H
 
 
-#include <vtkPolyDataSource.h>
-#include <vtkPolyDataToPolyDataFilter.h>
-#include <vtkStructuredPointsToPolyDataFilter.h>
-#include <vtkStructuredPointsToStructuredPointsFilter.h>
+#include "iviewsubjectcomponent.h"
 
 
 #include "ivtk.h"
 
-class iGridData;
-class iPolyData;
 
 class vtkDataObject;
 class vtkDataSetAttributes;
 class vtkFloatArray;
+class vtkInformation;
+class vtkInformationVector;
+class vtkPolyData;
 
 
 template<class Source, class OutputType>
-class iGenericSource : public Source
+class iGenericSource : public Source, public iViewSubjectComponent
 {
 
+#ifndef IVTK_4
+protected:
+	virtual int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *);
+
+	void SaveRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
+
+	vtkInformation *mSavedRequest;
+	vtkInformationVector **mSavedInputVector;
+	vtkInformationVector *mSavedOutputVector;
+	int mReturnCode;
+#endif
+
+public:
+
+	virtual float GetMemorySize();
+	virtual int GetNumberOfOutputs();  
+
 protected:
 
-	iGenericSource(){}
+	iGenericSource(iViewSubject *vo, bool usesLimits);
 	virtual ~iGenericSource(){}
 
 	virtual void ExecuteData(vtkDataObject *output);
+	void ExecuteParent();
 
-	virtual void ProduceOutput(OutputType *output) = 0; // called to recompute the output
+	virtual void SyncWithData(const iDataSyncRequest &r);
+
+	virtual void ProduceOutput() = 0; // called to recompute the output
+
+	const bool mUsesLimits;
+
+private:
+
+	int mExecuteMethod;
 };
 
 
 template<class Filter, class InputType, class OutputType>
-class iGenericFilter : public Filter
+class iGenericFilter : public Filter, public iViewSubjectComponent
 {
 
 #ifdef IVTK_4
-public:
+protected:
 	virtual void ExecuteInformation();
 #else
 protected:
-	virtual int ProcessRequest(vtkInformation*, vtkInformationVector**, vtkInformationVector*);
+	virtual int ProcessRequest(vtkInformation *, vtkInformationVector **, vtkInformationVector *);
+	virtual int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *);
+
+	void SaveRequest(vtkInformation *request, vtkInformationVector **inInfo, vtkInformationVector *outInfo);
+
+	vtkInformation *mSavedRequest;
+	vtkInformationVector **mSavedInputVector;
+	vtkInformationVector *mSavedOutputVector;
+	int mReturnCode;
 #endif
 
+public:
+
+	virtual float GetMemorySize();
+	virtual int GetNumberOfOutputs();  
+
 protected:
 
-	iGenericFilter(int numInputs = 1);
+	iGenericFilter(iViewSubject *vo, int numInputs, bool ownsOutput, bool usesLimits);
 	virtual ~iGenericFilter(){}
 
 	virtual void ExecuteData(vtkDataObject *output);
+	void ExecuteParent();
 
-	virtual void InitExecution(InputType *input, OutputType *output);  //  called if recomputing is needed
-	virtual void ProduceOutput(InputType *input, OutputType *output) = 0; // called to recompute the output
-	virtual void VerifyResults(InputType *input, OutputType *output);  //  called on every pipeline pass after Compute
+	virtual void SyncWithData(const iDataSyncRequest &r);
+
+	virtual void InitExecution();		// called if recomputing is needed
+	virtual void ProduceOutput() = 0;	// called to recompute the output
+	virtual void VerifyResults();		// called on every pipeline pass after ProduceOutput
 
 	//
 	//  Helper members for transforming scalars
 	//
-	bool ScalarsInit(vtkDataSetAttributes *data, vtkIdType nSizeOut = 0, int nDimOut = 0);
+	bool ScalarsInit(vtkDataSetAttributes *data, long nSizeOut = 0, int nDimOut = 0);
 	void ScalarsDone(vtkDataSetAttributes *data);
 
+	const bool mOwnsOutput, mUsesLimits;
+
 	vtkFloatArray *wScalarArrIn, *wScalarArrOut;
 	float *wScalarPtrIn, *wScalarPtrOut;
 	int wScalarDimIn, wScalarDimOut;
+
+private:
+
+	int mExecuteMethod;
 };
 
 
@@ -105,16 +151,20 @@ class iGenericPolyDataToPolyDataFilter : public iGenericFilter<Filter,vtkPolyDat
 
 protected:
 	
-	iGenericPolyDataToPolyDataFilter(int numInputs = 1) : iGenericFilter<Filter,vtkPolyData,vtkPolyData>(numInputs){}
+	iGenericPolyDataToPolyDataFilter(iViewSubject *vo, int numInputs, bool ownsOutput, bool usesLimits) : iGenericFilter<Filter,vtkPolyData,vtkPolyData>(vo,numInputs,ownsOutput,usesLimits){}
 
-	virtual void VerifyResults(vtkPolyData *input, vtkPolyData *output);
+	virtual void VerifyResults();
 };
 
 
-typedef iGenericSource<vtkPolyDataSource,vtkPolyData> iAbstractPolyDataSource;
-typedef iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter> iAbstractPolyDataToPolyDataFilter;
-typedef iGenericFilter<vtkStructuredPointsToPolyDataFilter,vtkImageData,vtkPolyData> iAbstractGridDataToPolyDataFilter;
-typedef iGenericFilter<vtkStructuredPointsToStructuredPointsFilter,vtkImageData,vtkStructuredPoints> iAbstractGridDataToGridDataFilter;
+//
+//  Useful macro
+//
+#define IGENERICFILTER_DECLARE(_name_) \
+	public: \
+		static _name_* New(iViewSubject *vo) { return new _name_(vo); } \
+	protected: \
+		_name_(iViewSubject *vo);
 
 #endif // IGENERICFILTER_H
  
