@@ -69,13 +69,13 @@ iImageComposerBackgroundWindow::iImageComposerBackgroundWindow(int tx, int ty, i
 
 int iImageComposerBackgroundWindow::GetWidth() const
 {
-	if(mViewModule != 0) return mViewModule->GetThisImageWidth(); else if(!mWallpaperImage.IsEmpty()) return mWallpaperImage.Width(); else return 0;
+	if(this->GetViewModule() != 0) return this->GetViewModule()->GetThisImageWidth(); else if(!mWallpaperImage.IsEmpty()) return mWallpaperImage.Width(); else return 0;
 }
 
 
 int iImageComposerBackgroundWindow::GetHeight() const
 {
-	if(mViewModule != 0) return mViewModule->GetThisImageHeight(); else if(!mWallpaperImage.IsEmpty()) return mWallpaperImage.Height(); else return 0;
+	if(this->GetViewModule() != 0) return this->GetViewModule()->GetThisImageHeight(); else if(!mWallpaperImage.IsEmpty()) return mWallpaperImage.Height(); else return 0;
 }
 
 
@@ -111,13 +111,13 @@ iImageComposerForegroundWindow::iImageComposerForegroundWindow(iViewModule *vm,
 
 int iImageComposerForegroundWindow::GetWidth() const
 {
-	if(mViewModule != 0) return mViewModule->GetThisImageWidth(); else return 0;
+	if(this->GetViewModule() != 0) return this->GetViewModule()->GetThisImageWidth(); else return 0;
 }
 
 
 int iImageComposerForegroundWindow::GetHeight() const
 {
-	if(mViewModule != 0) return mViewModule->GetThisImageHeight(); else return 0;
+	if(this->GetViewModule() != 0) return this->GetViewModule()->GetThisImageHeight(); else return 0;
 }
 
 
@@ -247,7 +247,7 @@ iImageComposer::iImageComposer(iControlModule *cm, iShell *s) : iControlModuleCo
 	mFullWidth = mTileWidth = 640;
 	mFullHeight = mTileHeight = 480;
 
-	mBackgroundWindow = new iImageComposerBackgroundWindow*[1]; IERROR_ASSERT_NULL_POINTER(mBackgroundWindow);
+	mBackgroundWindow = new iImageComposerBackgroundWindow*[1]; IERROR_ASSERT(mBackgroundWindow);
 	mBackgroundWindow[0] = iImageComposerBackgroundWindow::New(0,0,this);
 }
 
@@ -287,7 +287,7 @@ void iImageComposer::SetNumTiles(int nx, int ny)
 	mNumTilesX = nx; 
 	mNumTilesY = ny; 
 
-	iImageComposerBackgroundWindow **tmp = new iImageComposerBackgroundWindow*[nx*ny]; IERROR_ASSERT_NULL_POINTER(tmp);
+	iImageComposerBackgroundWindow **tmp = new iImageComposerBackgroundWindow*[nx*ny]; IERROR_ASSERT(tmp);
 	
 	for(j=0; j<ny && j<oldNumTilesY; j++)
 	{
@@ -348,21 +348,22 @@ void iImageComposer::AddForegroundWindow(iViewModule *v)
 
 void iImageComposer::RemoveForegroundWindow(int n)
 {
-	if(n<0 || n>mForegroundWindow.Last()) return;
+	if(n<0 || n>=mForegroundWindow.Size()) return;
 
-	mForegroundWindow.Remove(n)->Delete();
+	mForegroundWindow[n]->Delete();
+	mForegroundWindow.Remove(n);
 	this->ClearCache();
 }
 
 
 void iImageComposer::MoveToBack(int n)
 {
-	if(n<0 || n>=mForegroundWindow.Last()) return;
+	if(n<0 || n>=mForegroundWindow.MaxIndex()) return;
 
 	int i;
 	iImageComposerForegroundWindow *tmp = mForegroundWindow[n];
-	for(i=n; i<mForegroundWindow.Last(); i++) mForegroundWindow[i] = mForegroundWindow[i+1];
-	mForegroundWindow[mForegroundWindow.Last()] = tmp;
+	for(i=n; i<mForegroundWindow.MaxIndex(); i++) mForegroundWindow[i] = mForegroundWindow[i+1];
+	mForegroundWindow.Last() = tmp;
 	this->ClearCache();
 }
 
@@ -511,11 +512,11 @@ void iImageComposer::PackStateBody(iString &s) const
 	this->PackValue(s,KeyNumTiles(),iv,2);
 	this->PackValue(s,KeyNumForegroundWindows(),mForegroundWindow.Size());
 
-	int *itmp = new int[mNumTilesX*mNumTilesY]; IERROR_ASSERT_NULL_POINTER(itmp);
+	int *itmp = new int[mNumTilesX*mNumTilesY]; IERROR_ASSERT(itmp);
 	for(i=0; i<mNumTilesX*mNumTilesY; i++) itmp[i] = (mBackgroundWindow[i]->GetViewModule() != 0) ? mBackgroundWindow[i]->GetViewModule()->GetWindowNumber() : -1;
 	this->PackValue(s,KeyBackgroundWindowViewModule(),itmp,mNumTilesX*mNumTilesY);
 
-	iString *stmp = new iString[mNumTilesX*mNumTilesY]; IERROR_ASSERT_NULL_POINTER(stmp);
+	iString *stmp = new iString[mNumTilesX*mNumTilesY]; IERROR_ASSERT(stmp);
 	for(i=0; i<mNumTilesX*mNumTilesY; i++) stmp[i] = mBackgroundWindow[i]->GetWallpaperFile();
 	this->PackValue(s,KeyBackgroundWindowWallpaperFile(),stmp,mNumTilesX*mNumTilesY);
 	delete [] stmp;
@@ -530,7 +531,7 @@ void iImageComposer::PackStateBody(iString &s) const
 	if(n > mNumTilesX*mNumTilesY)
 	{
 		delete [] itmp;
-		itmp = new int[n]; IERROR_ASSERT_NULL_POINTER(itmp);
+		itmp = new int[n]; IERROR_ASSERT(itmp);
 	}
 
 	if(mForegroundWindow.Size() == 0) itmp[0] = 0;
@@ -545,12 +546,12 @@ void iImageComposer::PackStateBody(iString &s) const
 	for(i=0; i<mForegroundWindow.Size(); i++) itmp[i] = mForegroundWindow[i]->GetBorderWidth();
 	this->PackValue(s,KeyForegroundWindowBorderWidth(),itmp,n);
 
-	iColor *ctmp = new iColor[n]; IERROR_ASSERT_NULL_POINTER(ctmp);
+	iColor *ctmp = new iColor[n]; IERROR_ASSERT(ctmp);
 	for(i=0; i<mForegroundWindow.Size(); i++) ctmp[i] = mForegroundWindow[i]->GetBorderColor();
 	this->PackValue(s,KeyForegroundWindowBorderColor(),ctmp,n);
 	delete [] ctmp;
 
-	float *ftmp = new float[n]; IERROR_ASSERT_NULL_POINTER(ftmp);
+	float *ftmp = new float[n]; IERROR_ASSERT(ftmp);
 	if(mForegroundWindow.Size() == 0) ftmp[0] = 1.0;
 	for(i=0; i<mForegroundWindow.Size(); i++) ftmp[i] = mForegroundWindow[i]->GetScale();
 	this->PackValue(s,KeyForegroundWindowScale(),ftmp,n);
@@ -580,7 +581,7 @@ void iImageComposer::UnPackStateBody(const iString &s)
 		while(i > mForegroundWindow.Size()) this->AddForegroundWindow(this->GetControlModule()->GetViewModule());
 	}
 
-	int *itmp = new int[mNumTilesX*mNumTilesY]; IERROR_ASSERT_NULL_POINTER(itmp);
+	int *itmp = new int[mNumTilesX*mNumTilesY]; IERROR_ASSERT(itmp);
 	for(i=0; i<mNumTilesX*mNumTilesY; i++) itmp[i] = (mBackgroundWindow[i]->GetViewModule() != 0) ? mBackgroundWindow[i]->GetViewModule()->GetWindowNumber() : -1;
 	if(this->UnPackValue(s,KeyBackgroundWindowViewModule(),itmp,mNumTilesX*mNumTilesY)) 
 	{
@@ -591,7 +592,7 @@ void iImageComposer::UnPackStateBody(const iString &s)
 		}
 	}
 
-	iString *stmp = new iString[mNumTilesX*mNumTilesY]; IERROR_ASSERT_NULL_POINTER(stmp);
+	iString *stmp = new iString[mNumTilesX*mNumTilesY]; IERROR_ASSERT(stmp);
 	for(i=0; i<mNumTilesX*mNumTilesY; i++) stmp[i] = mBackgroundWindow[i]->GetWallpaperFile();
 	if(this->UnPackValue(s,KeyBackgroundWindowWallpaperFile(),stmp,mNumTilesX*mNumTilesY))
 	{
@@ -614,7 +615,7 @@ void iImageComposer::UnPackStateBody(const iString &s)
 		if(mForegroundWindow.Size() > mNumTilesX*mNumTilesY)
 		{
 			delete [] itmp;
-			itmp = new int[mForegroundWindow.Size()]; IERROR_ASSERT_NULL_POINTER(itmp);
+			itmp = new int[mForegroundWindow.Size()]; IERROR_ASSERT(itmp);
 		}
 		
 		for(i=0; i<mForegroundWindow.Size(); i++) itmp[i] = mForegroundWindow[i]->GetViewModule()->GetWindowNumber();
@@ -654,7 +655,7 @@ void iImageComposer::UnPackStateBody(const iString &s)
 			}
 		}
 
-		iColor *ctmp = new iColor[mForegroundWindow.Size()]; IERROR_ASSERT_NULL_POINTER(ctmp);
+		iColor *ctmp = new iColor[mForegroundWindow.Size()]; IERROR_ASSERT(ctmp);
 		for(i=0; i<mForegroundWindow.Size(); i++) ctmp[i] = mForegroundWindow[i]->GetBorderColor();
 		if(this->UnPackValue(s,KeyForegroundWindowBorderColor(),ctmp,mForegroundWindow.Size()))
 		{
@@ -665,7 +666,7 @@ void iImageComposer::UnPackStateBody(const iString &s)
 		}
 		delete [] ctmp;
 
-		float *ftmp = new float[mForegroundWindow.Size()]; IERROR_ASSERT_NULL_POINTER(ftmp);
+		float *ftmp = new float[mForegroundWindow.Size()]; IERROR_ASSERT(ftmp);
 		for(i=0; i<mForegroundWindow.Size(); i++) ftmp[i] = mForegroundWindow[i]->GetScale();
 		if(this->UnPackValue(s,KeyForegroundWindowScale(),ftmp,mForegroundWindow.Size()))
 		{
