@@ -157,8 +157,6 @@ public:
 private:
 
 	const iObjectType *mPointer;
-
-	iObjectTypePointer(const iObjectTypePointer&);  // Not implemented.
 };
 
 
@@ -175,12 +173,12 @@ iArray<iObjectTypePointer>& iObjectTypeRegistry::List()
 
 const iObjectType* iObjectTypeRegistry::CreateType(iObjectType::ClassId c, const char *fp, const char *sp)
 {
-	iObjectType *tmp = new iObjectType(c,fp,sp); IERROR_ASSERT_NULL_POINTER(tmp);
+	iObjectType *tmp = new iObjectType(c,fp,sp); IERROR_ASSERT(tmp);
 #if defined(I_DEBUG) && defined (I_CHECK_DUPLICATES)
 	const iObjectType *k;
 	if((k=iObjectTypeRegistry::FindType(tmp->mFullName,true))!=0 || (k=iObjectTypeRegistry::FindType(tmp->mShortName,true))!=0)
 	{
-		IERROR_REPORT_ERROR("Duplicate type.");
+		IERROR_REPORT("Duplicate type.");
 	}
 #endif
 	//
@@ -369,7 +367,7 @@ const iString& iObjectKey::SpecialSeparator()
 
 const iObjectType& iObjectKey::Type() const
 {
-	IERROR_ASSERT_NULL_POINTER(mType);
+	IERROR_ASSERT(mType);
 	return *mType;
 }
 
@@ -509,8 +507,6 @@ public:
 private:
 
 	const iObjectKey *mPointer;
-
-	iObjectKeyPointer(const iObjectKeyPointer&);  // Not implemented.
 };
 
 
@@ -535,12 +531,12 @@ iArray<iObjectKey*>& iObjectKeyRegistry::TempKeys()
 const iObjectKey* iObjectKeyRegistry::CreateKey(const iObjectType &type, const char *fk, const char *sk, iObjectKey::Arg a, int d, const iObjectType* parent, const iObjectKey* helpOwner)
 {
 	iObjectKey *tmp = new iObjectKey(&type,fk,sk,a,d,parent);
-	IERROR_ASSERT_NULL_POINTER(tmp);
+	IERROR_ASSERT(tmp);
 #if defined(I_DEBUG) && defined (I_CHECK_DUPLICATES)
 	const iObjectKey *k;
 	if((k=iObjectKeyRegistry::FindKey(tmp->mPrefixedFullKey,true))!=0 || (k=iObjectKeyRegistry::FindKey(tmp->mPrefixedShortKey,true))!=0) 
 	{
-		IERROR_REPORT_ERROR("Duplicate key.");
+		IERROR_REPORT("Duplicate key.");
 	}
 #endif
 	//
@@ -667,10 +663,21 @@ const iObjectKey* iObjectKeyRegistry::GetNextKey(bool hidden)
 //  *****************************************************************
 //
 const iString iObject::mSlash = "@@";
+int iObject::mMissingKeysStack = 0;
+
+
+void iObject::ReportMissingKeys(bool s)
+{
+	if(s) mMissingKeysStack--; else mMissingKeysStack++;
+	if(mMissingKeysStack < 0) mMissingKeysStack = 0;
+}
+
+
+void iObject::ReportAMissingKey(const iObjectKey &key)
+{
+	if(mMissingKeysStack == 0) IERROR_REPORT((iString("Missing key: ")+key.PrefixedFullName()).ToCharPointer());
+}
 
-#ifdef I_CHECK1
-bool iObject::ReportMissingKeys = true;
-#endif
 
 iObject::iObject()
 {
@@ -684,6 +691,26 @@ iObject::~iObject()
 }
 
 
+const iString& iObject::GetThisClassName() const
+{
+	static const iString name("iObject");
+	return name;
+}
+
+
+bool iObject::IsOfType(const iString &name) const
+{
+	static const iString thisName("iObject");
+	return (name == thisName);
+}
+
+
+void iObject::ReportBadCast(const char *self, const char *file, int line)
+{
+	iConsole::Instance()->DisplayFatalErrorMessage(("Invalid cast to "+iString(self)).ToCharPointer(),file,line);
+}
+
+
 void iObject::ClearCache()
 {
 	mCacheInvalid = true;
@@ -812,14 +839,14 @@ bool iObjectKey::IndexHelper(Arg a, int n, int index, int &imin, int &imax) cons
 	if(!this->IsArgumentCompatible(a))
 	{
 		// incompatible arguments, exit without doing anything.
-		IERROR_REPORT_ERROR("Incompatible key argument.");
+		IERROR_REPORT("Incompatible key argument.");
 		return true;
 	}
 
 	if(n<0 || (mDim!=0 && ((index<0 && n!=mDim) || (index>=0 && n!=1 && index>=mDim))))  //  dim = 0 disables bound checking 
 	{
 		// incorrect key index, exit without doing anything.
-		IERROR_REPORT_ERROR("Incorrect key index.");
+		IERROR_REPORT("Incorrect key index.");
 		return true;
 	}
 
@@ -827,7 +854,7 @@ bool iObjectKey::IndexHelper(Arg a, int n, int index, int &imin, int &imax) cons
 	{
 		if(n == 0)
 		{
-			IERROR_REPORT_ERROR("Incorrect key index.");
+			IERROR_REPORT("Incorrect key index.");
 			return true;
 		}
 		imin = 0;
@@ -837,7 +864,7 @@ bool iObjectKey::IndexHelper(Arg a, int n, int index, int &imin, int &imax) cons
 	{
 		if(mDim == 1)
 		{
-			IERROR_REPORT_ERROR("Incorrect key index.");
+			IERROR_REPORT("Incorrect key index.");
 			return true;
 		}
 		imin = index;
@@ -949,17 +976,17 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, int* val, int
 			return false;
 		}
 		if(key.Argument() == iObjectKey::_OffsetInt) offset = 1;
-		int* v = new int[num+1]; IERROR_ASSERT_NULL_POINTER(v); // num+1 is because arrays go from 1 to num
+		int* v = new int[num+1]; IERROR_ASSERT(v); // num+1 is because arrays go from 1 to num
 		for(i=i1; ok && i<i2; i++)
 		{
 			v[i] = tmp.Section(key.FieldSeparator(),i+1-i1,i+1-i1).ToInt(ok) - offset;
 		}
-		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(int)); else IERROR_REPORT_ERROR("Invalid key value.");
+		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(int)); else IERROR_REPORT("Invalid key value.");
 		delete [] v;
 	}
 	else ok = false;
 #ifdef I_CHECK1
-	if(!ok && ReportMissingKeys) IERROR_REPORT_ERROR("Missing key.");
+	if(!ok) ReportAMissingKey(key);
 #endif
 	if(ok) mUnPackedSomething = true;
 	return ok;
@@ -979,17 +1006,17 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, bool* val, in
 		{
 			return false;
 		}
-		bool* v = new bool[num+1]; IERROR_ASSERT_NULL_POINTER(v);
+		bool* v = new bool[num+1]; IERROR_ASSERT(v);
 		for(i=i1; ok && i<i2; i++)
 		{
 			v[i] = (tmp.Section(key.FieldSeparator(),i+1-i1,i+1-i1).ToInt(ok) != 0);
 		}
-		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(bool)); else IERROR_REPORT_ERROR("Invalid key value.");
+		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(bool)); else IERROR_REPORT("Invalid key value.");
 		delete [] v;
 	}
 	else ok = false;
 #ifdef I_CHECK1
-	if(!ok && ReportMissingKeys) IERROR_REPORT_ERROR("Missing key.");
+	if(!ok) ReportAMissingKey(key);
 #endif
 	if(ok) mUnPackedSomething = true;
 	return ok;
@@ -1009,17 +1036,17 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, float* val, i
 		{
 			return false;
 		}
-		float* v = new float[num+1]; IERROR_ASSERT_NULL_POINTER(v);
+		float* v = new float[num+1]; IERROR_ASSERT(v);
 		for(i=i1; ok && i<i2; i++)
 		{
 			v[i] = tmp.Section(key.FieldSeparator(),i+1-i1,i+1-i1).ToFloat(ok);
 		}
-		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(float)); else IERROR_REPORT_ERROR("Invalid key value.");
+		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(float)); else IERROR_REPORT("Invalid key value.");
 		delete [] v;
 	}
 	else ok = false;
 #ifdef I_CHECK1
-	if(!ok && ReportMissingKeys) IERROR_REPORT_ERROR("Missing key.");
+	if(!ok) ReportAMissingKey(key);
 #endif
 	if(ok) mUnPackedSomething = true;
 	return ok;
@@ -1039,17 +1066,17 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, double* val,
 		{
 			return false;
 		}
-		double* v = new double[num+1]; IERROR_ASSERT_NULL_POINTER(v);
+		double* v = new double[num+1]; IERROR_ASSERT(v);
 		for(i=i1; ok && i<i2; i++)
 		{
 			v[i] = tmp.Section(key.FieldSeparator(),i+1-i1,i+1-i1).ToDouble(ok);
 		}
-		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(double)); else IERROR_REPORT_ERROR("Invalid key value.");
+		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(double)); else IERROR_REPORT("Invalid key value.");
 		delete [] v;
 	}
 	else ok = false;
 #ifdef I_CHECK1
-	if(!ok && ReportMissingKeys) IERROR_REPORT_ERROR("Missing key.");
+	if(!ok) ReportAMissingKey(key);
 #endif
 	if(ok) mUnPackedSomething = true;
 	return ok;
@@ -1070,7 +1097,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, iColor* val,
 		{
 			return false;
 		}
-		iColor* v = new iColor[num+1]; IERROR_ASSERT_NULL_POINTER(v);
+		iColor* v = new iColor[num+1]; IERROR_ASSERT(v);
 		for(i=i1; ok && i<i2; i++)
 		{
 			s1 = tmp.Section(key.FieldSeparator(),i+1-i1,i+1-i1);
@@ -1079,12 +1106,12 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, iColor* val,
 			b = s1.Section(key.SubSubSeparator(),2,2).ToInt(ok1); ok = ok && ok1;
 			v[i] = iColor(r,g,b);
 		}
-		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(iColor)); else IERROR_REPORT_ERROR("Invalid key value.");
+		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(iColor)); else IERROR_REPORT("Invalid key value.");
 		delete [] v;
 	}
 	else ok = false;
 #ifdef I_CHECK1
-	if(!ok && ReportMissingKeys) IERROR_REPORT_ERROR("Missing key.");
+	if(!ok) ReportAMissingKey(key);
 #endif
 	if(ok) mUnPackedSomething = true;
 	return ok;
@@ -1112,7 +1139,7 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, iString* val,
 	}
 	else ok = false;
 #ifdef I_CHECK1
-	if(!ok && ReportMissingKeys) IERROR_REPORT_ERROR("Missing key.");
+	if(!ok) ReportAMissingKey(key);
 #endif
 	if(ok) mUnPackedSomething = true;
 	return ok;
@@ -1154,7 +1181,7 @@ bool iObject::UnPackValuePiecewiseFunction(const iString &s, const iObjectKey &k
 		{
 			return false;
 		}
-		iPiecewiseFunction* v = iPiecewiseFunction::New(); IERROR_ASSERT_NULL_POINTER(v);
+		iPiecewiseFunction* v = iPiecewiseFunction::New(); IERROR_ASSERT(v);
 		iString tmp1, tmp2;
 		float x1, x2;
 		bool ok1;
@@ -1180,13 +1207,13 @@ bool iObject::UnPackValuePiecewiseFunction(const iString &s, const iObjectKey &k
 			{
 				if(f[i] != 0) f[i]->Copy(v);
 			}
-			else IERROR_REPORT_ERROR("Invalid key value.");
+			else IERROR_REPORT("Invalid key value.");
 		}
 		v->Delete();
 	}
 	else ok = false;
 #ifdef I_CHECK1
-	if(!ok && ReportMissingKeys) IERROR_REPORT_ERROR("Missing key.");
+	if(!ok) ReportAMissingKey(key);
 #endif
 	if(ok) mUnPackedSomething = true;
 	return ok;
@@ -1226,7 +1253,7 @@ bool iObject::UnPackValueRangeCollection(const iString &s, const iObjectKey &key
 		{
 			return false;
 		}
-		iRangeCollection* v = new iRangeCollection[num+1]; IERROR_ASSERT_NULL_POINTER(v);
+		iRangeCollection* v = new iRangeCollection[num+1]; IERROR_ASSERT(v);
 		iString tmp1, tmp2;
 		float x1, x2;
 		bool ok1;
@@ -1251,12 +1278,12 @@ bool iObject::UnPackValueRangeCollection(const iString &s, const iObjectKey &key
 		{
 			for(i=i1; f[i]!=0 && i<i2; i++) f[i]->Copy(v+i);
 		}
-		else IERROR_REPORT_ERROR("Invalid key value.");
+		else IERROR_REPORT("Invalid key value.");
 		delete [] v;
 	}
 	else ok = false;
 #ifdef I_CHECK1
-	if(!ok && ReportMissingKeys) IERROR_REPORT_ERROR("Missing key.");
+	if(!ok) ReportAMissingKey(key);
 #endif
 	if(ok) mUnPackedSomething = true;
 	return ok;
