@@ -224,6 +224,11 @@ private:
 	static const iObjectType *mTraversalType;
 };
 
+#define IOBJECT_DECLARE_SELF(_self_,_parent_) \
+	static _self_* SafeDownCast(iObject *self) { if(self!=0 && self->IsOfType(#_self_)) return (_self_*)self; else; return 0; } \
+	static _self_* RequiredCast(iObject *self) { if(self==0 || !self->IsOfType(#_self_)) iObject::ReportBadCast(#_self_,__FILE__,__LINE__); return (_self_*)self; } \
+	virtual bool IsOfType(const iString &name) const { static const iString thisName(#_self_); if(name == thisName) return true; else return this->_parent_::IsOfType(name); } \
+	virtual const iString& GetThisClassName() const { static const iString thisName(#_self_); return thisName; }
 
 #define IOBJECT_DECLARE_PACKUNPACK(_type1_,_type2_) \
 	void PackValue(iString &s, const iObjectKey &key, const _type1_* val, int num, int index = -1, bool prefixed = false) const; \
@@ -236,6 +241,9 @@ class iObject
 	
 public:
 
+	virtual const iString& GetThisClassName() const = 0;
+	virtual bool IsOfType(const iString &name) const;
+
 	virtual void PackCompleteState(iString &s) const;
 	virtual void UnPackCompleteState(const iString &s);
 
@@ -273,11 +281,9 @@ public:
 	inline bool UnPackedSomething() const { return mUnPackedSomething; }
 	inline void ClearUnPackedSomethingFlag() { mUnPackedSomething = false; }
 
-	void ClearCache();
+	virtual void ClearCache();
 
-#ifdef I_CHECK1
-	static bool ReportMissingKeys;
-#endif
+	static void ReportMissingKeys(bool s);
 
 protected:
 	
@@ -293,6 +299,13 @@ protected:
 	bool mUnPackedSomething;
 	mutable bool mCacheInvalid;
 	mutable iString mCache;
+
+	static void ReportBadCast(const char *self, const char *file, int line);
+	static void ReportAMissingKey(const iObjectKey &key);
+
+private:
+
+	static int mMissingKeysStack;
 };
 
 
@@ -317,6 +330,13 @@ protected:
 		return *__p##_object_##_fkey_##_arg_; \
 	}
 
+#define IOBJECT_DEFINE_EXTRINSIC_KEY(_owner_,_object_,_fkey_,_skey_,_arg_,_dim_) \
+	static const iObjectKey *__p##_object_##_fkey_##_arg_ = iObjectKeyRegistry::CreateKey(_owner_::Type(),#_fkey_,#_skey_,iObjectKey::_##_arg_,_dim_); \
+	const iObjectKey& _object_::Key##_fkey_() \
+	{ \
+		return *__p##_object_##_fkey_##_arg_; \
+	}
+
 #define IOBJECT_DEFINE_INHERITED_KEY(_parent_,_object_,_fkey_,_skey_,_arg_,_dim_) \
 	static const iObjectKey *__p##_object_##_fkey_##_arg_ = iObjectKeyRegistry::CreateKey(_object_::Type(),#_fkey_,#_skey_,iObjectKey::_##_arg_,_dim_,&_parent_::Type()); \
 	const iObjectKey& _object_::Key##_fkey_() \
