@@ -30,26 +30,26 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "ierror.h"
+#include "iorthoslicer.h"
 #include "imath.h"
 
+#include <vtkCellArray.h>
+#include <vtkPointData.h>
+#include <vtkStructuredPoints.h>
+
 //
 //  Templates
 //
 #include "igenericfiltertemplate.h"
 
 
-iOrthoTexturePlaneFilter::iOrthoTexturePlaneFilter() 
+iOrthoTexturePlaneFilter::iOrthoTexturePlaneFilter(iViewSubject *vo) : iGenericFilter<vtkStructuredPointsToPolyDataFilter,vtkImageData,vtkPolyData>(vo,1,true,false) 
 {
 	mTexture = 0;
 	mOffX = mOffY = 0;
 }
 
 
-iOrthoTexturePlaneFilter::~iOrthoTexturePlaneFilter() 
-{
-}
-
-
 void iOrthoTexturePlaneFilter::SetTexturePiece(vtkImageData *texture, int offx, int offy)
 {
 	mTexture = texture;
@@ -60,20 +60,24 @@ void iOrthoTexturePlaneFilter::SetTexturePiece(vtkImageData *texture, int offx,
 }
 
 
-void iOrthoTexturePlaneFilter::ProduceOutput(vtkImageData *input, vtkPolyData *output)
+void iOrthoTexturePlaneFilter::ProduceOutput()
 {
 	int dims[3], dimsTexture[3];
 	double org[3], spa[3];
 
+	vtkImageData *input = this->GetInput();
+	vtkPolyData *output = this->GetOutput();
+
 	output->Initialize();
 
 	if(mTexture == 0) return;
-	
-    input->GetOrigin(org);
-    input->GetSpacing(spa);
-    input->GetDimensions(dims);
 
-	mTexture->GetDimensions(dimsTexture);
+	//
+	//  Prepare texture support
+	//
+	input->GetOrigin(org);
+	input->GetSpacing(spa);
+	input->GetDimensions(dims);
 
 	int i, Axis = -1;
 	for(i=0; i<3; i++)
@@ -82,12 +86,98 @@ void iOrthoTexturePlaneFilter::ProduceOutput(vtkImageData *input, vtkPolyData *o
 	}
 	if(Axis == -1) return;
 
-    int Uidx=(Axis+1)%3,  Vidx=(Axis+2)%3;
+    int Uidx, Vidx;
+	iOrthoSlicer::GetUV(Axis,Uidx,Vidx);
 
+	mTexture->GetDimensions(dimsTexture);
+
+	float tc[2];
+	static vtkIdType pts[4]={0,1,2,3};
 
-	//	
-	//  Fill in the mTexture
 	//
+	//  AppenPolyDataFilter does not merge texture coordinates into one, so we need to create the correct texture support here.
+	//  We create it for zero offset instance, and skip it altogether for other instances.
+	//
+	if(mOffX==0 && mOffY==0)
+	{
+		//
+		// We'll create the building blocks of polydata including data attributes.
+		//
+		vtkPoints *points;
+		points = vtkPoints::New(VTK_FLOAT); IERROR_ASSERT(points);
+
+		vtkCellArray *polys;
+		polys = vtkCellArray::New(); IERROR_ASSERT(polys);
+
+		vtkFloatArray *tcoords;
+		tcoords = vtkFloatArray::New(); IERROR_ASSERT(tcoords);
+
+		points->SetNumberOfPoints(4);
+		tcoords->SetNumberOfComponents(2);
+		tcoords->SetNumberOfTuples(4);
+
+		//
+		// Load the cell, and data attributes.
+		//
+		polys->InsertNextCell(4,pts);
+
+		//
+		//  Place the support plane
+		//
+		double x1[3];
+		x1[Axis] = org[Axis];
+		//
+		//  LL point 
+		//
+		x1[Uidx] = org[Uidx];
+		x1[Vidx] = org[Vidx];
+		points->SetPoint(0,x1);
+		tc[0] = 0.0;
+		tc[1] = 0.0;
+		tcoords->SetTuple(0,tc);
+		//
+		//  LR point 
+		//
+		x1[Uidx] = org[Uidx] + spa[Uidx]*dimsTexture[0];
+		x1[Vidx] = org[Vidx];
+		points->SetPoint(1,x1);
+		tc[0] = 1.0;
+		tc[1] = 0.0;
+		tcoords->SetTuple(1,tc);
+		//
+		//  UR point 
+		//
+		x1[Uidx] = org[Uidx] + spa[Uidx]*dimsTexture[0];
+		x1[Vidx] = org[Vidx] + spa[Vidx]*dimsTexture[1];
+		points->SetPoint(2,x1);
+		tc[0] = 1.0;
+		tc[1] = 1.0;
+		tcoords->SetTuple(2,tc);
+		//
+		//  UL point 
+		//
+		x1[Uidx] = org[Uidx];
+		x1[Vidx] = org[Vidx] + spa[Vidx]*dimsTexture[1];
+		points->SetPoint(3,x1);
+		tc[0] = 0.0;
+		tc[1] = 1.0;
+		tcoords->SetTuple(3,tc);
+
+		//
+		// We now assign the pieces to the vtkPolyData.
+		//
+		output->SetPolys(polys);
+		output->SetPoints(points);
+		output->GetPointData()->SetTCoords(tcoords);
+		polys->Delete();
+		points->Delete();
+		tcoords->Delete();
+	}
+
+	//
+	//  Fill in out portion of the texture
+	//
+ 	int ncomIn = input->GetPointData()->GetScalars()->GetNumberOfComponents();
     float *ptrIn = (float *)input->GetScalarPointer();
 	float *ptrOut = (float *)mTexture->GetScalarPointer();
 
@@ -126,10 +216,10 @@ void iOrthoTexturePlaneFilter::ProduceOutput(vtkImageData *input, vtkPolyData *o
 	case 1:
 		{
 			//
-			//  Uidx = 2, Vidx = 0;
+			//  Uidx = 0, Vidx = 1;
 			//
-			off1 = dims[0]*dims[1];
-			off2 = 1;
+			off1 = 1;
+			off2 = dims[0]*dims[1];
 			break;
 		}
 	case 2:
@@ -143,6 +233,8 @@ void iOrthoTexturePlaneFilter::ProduceOutput(vtkImageData *input, vtkPolyData *o
 		}
 	}
 
+	off1 *= ncomIn;
+	off2 *= ncomIn;
 	off3 = off1 + off2;
 
 	vtkIdType lIn, lOut;
@@ -151,11 +243,12 @@ void iOrthoTexturePlaneFilter::ProduceOutput(vtkImageData *input, vtkPolyData *o
 		this->UpdateProgress((float)(ijk[Vidx]-ijkmin[Vidx])/(ijknum[Vidx]-ijkmin[Vidx]+1));
 		if(this->GetAbortExecute()) break;
 
-		lOut = dimsTexture[0]*(ijk[Vidx]+mOffY);
 		for(ijk[Uidx]=ijkmin[Uidx]; ijk[Uidx]<ijknum[Uidx]; ijk[Uidx]++)
 		{
-			lIn = ijk[0] + dims[0]*(ijk[1]+(vtkIdType)dims[1]*ijk[2]);
-			ptrOut[lOut+mOffX+ijk[Uidx]] = 0.25f*(ptrIn[lIn]+ptrIn[lIn+off1]+ptrIn[lIn+off2]+ptrIn[lIn+off3]);
+			lIn = ncomIn*(ijk[0]+dims[0]*(ijk[1]+(vtkIdType)dims[1]*ijk[2]));
+			lOut = mOffX + ijk[Uidx] + dimsTexture[0]*(mOffY+ijk[Vidx]);
+			ptrOut[lOut] = 0.25f*(ptrIn[lIn]+ptrIn[lIn+off1]+ptrIn[lIn+off2]+ptrIn[lIn+off3]);
+//			ptrOut[lOut] = pow10(-0.1*float(ijk[Uidx]));
 		}
 	}
 
