@@ -37,7 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "irangemapping.h"
 #include "itune.h"
 #include "iviewmodule.h"
-#include "iviewobject.h"
+#include "iviewsubject.h"
 
 #include <vtkCellArray.h>
 #include <vtkDoubleArray.h>
@@ -115,7 +115,7 @@ void Sort(iParticleSplitter *me, vtkIdType n, int ncom, int attSort, T *Points,
 {
 	T poi1[3];
 	float nrm1[3];
-	float *att1; att1 = new float[ncom]; IERROR_ASSERT_NULL_POINTER(att1);
+	float *att1; att1 = new float[ncom]; IERROR_ASSERT(att1);
 
 	SortWorker(me,0,n-1,ncom,attSort,Points,Atts,Nrms,poi1,att1,nrm1);
 	
@@ -186,13 +186,7 @@ void SortWorker(iParticleSplitter *me, vtkIdType l, vtkIdType r, int ncom, int a
 using namespace iParticleSplitter_Private;
 
 
-iParticleSplitter* iParticleSplitter::New(iViewObject *vo)
-{
-	return new iParticleSplitter(vo);
-}
-
-
-iParticleSplitter::iParticleSplitter(iViewObject *vo) : iViewObjectComponent(vo)
+iParticleSplitter::iParticleSplitter(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkPolyDataToPolyDataFilter>(vo,1,true,true)
 {
 	mRangeSet = mOwnsData = false;
 
@@ -203,9 +197,9 @@ iParticleSplitter::iParticleSplitter(iViewObject *vo) : iViewObjectComponent(vo)
 
 	mSorted = false;
 
-	mRanges = new iRangeCollection;  IERROR_ASSERT_NULL_POINTER(mRanges);
-	mHistogramMaker = iHistogramMaker::New(this->GetViewObject()->GetViewModule()); IERROR_ASSERT_NULL_POINTER(mHistogramMaker);
-	mMapping = new iRangeMapping(mRanges,mHistogramMaker,this);  IERROR_ASSERT_NULL_POINTER(mRanges);
+	mRanges = new iRangeCollection;  IERROR_ASSERT(mRanges);
+	mHistogramMaker = iHistogramMaker::New(this->GetViewSubject()->GetViewModule()); IERROR_ASSERT(mHistogramMaker);
+	mMapping = new iRangeMapping(mRanges,mHistogramMaker,this);  IERROR_ASSERT(mRanges);
 
 	mRanges->SetGlobalRange(-mAttRange,mAttRange);
 	mRanges->SetRange(0,-mAttRange,mAttRange);
@@ -354,10 +348,10 @@ void iParticleSplitter::TakeOverData(bool s)
 	mOwnsData = s;
 	if(mOwnsData)
 	{
-		mPoints = vtkPoints::New(); IERROR_ASSERT_NULL_POINTER(mPoints);
-		mVerts = vtkCellArray::New(); IERROR_ASSERT_NULL_POINTER(mVerts);
-		mNorms = vtkFloatArray::New(); IERROR_ASSERT_NULL_POINTER(mNorms);
-		mAtts = vtkFloatArray::New(); IERROR_ASSERT_NULL_POINTER(mAtts);
+		mPoints = vtkPoints::New(); IERROR_ASSERT(mPoints);
+		mVerts = vtkCellArray::New(); IERROR_ASSERT(mVerts);
+		mNorms = vtkFloatArray::New(); IERROR_ASSERT(mNorms);
+		mAtts = vtkFloatArray::New(); IERROR_ASSERT(mAtts);
 	}
 	else
 	{
@@ -416,7 +410,7 @@ void iParticleSplitter::UpdateRange()
 	vtkPolyData *input = this->GetInput();
 	if(input == 0) return;
 
-	vtkFloatArray *inatt = iPointerCast<vtkFloatArray,vtkDataArray>(input->GetPointData()->GetScalars());
+	vtkFloatArray *inatt = vtkFloatArray::SafeDownCast(input->GetPointData()->GetScalars());
 	if(inatt == 0) return;
 	float *data = inatt->GetPointer(0);
 	if(data == 0) return;
@@ -475,8 +469,11 @@ void iParticleSplitter::UpdateRange()
 }
 
 	
-void iParticleSplitter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
+void iParticleSplitter::ProduceOutput()
 {
+	vtkPolyData *input = this->GetInput();
+	vtkPolyData *output = this->GetOutput();
+
 	output->Initialize();
 	//
 	//  Do it again in case the attribute was Set before the data were loaded, like in
@@ -507,13 +504,13 @@ void iParticleSplitter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
 		mVerts->DeepCopy(input->GetVerts());
 		if(input->GetPointData()->GetNormals() != 0)
 		{
-			mNorms->DeepCopy(iPointerCast<vtkFloatArray,vtkDataArray>(input->GetPointData()->GetNormals()));
+			mNorms->DeepCopy(input->GetPointData()->GetNormals());
 		}
 		else
 		{
 			mNorms = 0;
 		}
-		mAtts->DeepCopy(iPointerCast<vtkFloatArray,vtkDataArray>(input->GetPointData()->GetScalars()));
+		mAtts->DeepCopy(input->GetPointData()->GetScalars());
 	}
 	else
 	{
@@ -521,13 +518,13 @@ void iParticleSplitter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
 		mVerts = input->GetVerts();
 		if(input->GetPointData()->GetNormals() != 0)
 		{
-			mNorms = iPointerCast<vtkFloatArray,vtkDataArray>(input->GetPointData()->GetNormals());
+			mNorms = vtkFloatArray::SafeDownCast(input->GetPointData()->GetNormals());
 		}
 		else
 		{
 			mNorms = 0;
 		}
-		mAtts = iPointerCast<vtkFloatArray,vtkDataArray>(input->GetPointData()->GetScalars());
+		mAtts = vtkFloatArray::SafeDownCast(input->GetPointData()->GetScalars());
 	}
 
 	float *pPointsF = 0;
@@ -579,7 +576,7 @@ void iParticleSplitter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
 #ifdef I_CHECK2
 		for(vtkIdType l=0; l<ntup-1; l++) if(pAtts[mAtt+ncom*l] > pAtts[mAtt+ncom*(l+1)])
 		{
-			IERROR_REPORT_ERROR("Sorted incorrectly.");
+			IERROR_REPORT("Sorted incorrectly.");
 			break;
 		}
 #endif
@@ -620,11 +617,11 @@ void iParticleSplitter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
 			
 			if(iTotal > 0)
 			{
-				newPoints = vtkPoints::New(mPoints->GetDataType()); IERROR_ASSERT_NULL_POINTER(newPoints);
+				newPoints = vtkPoints::New(mPoints->GetDataType()); IERROR_ASSERT(newPoints);
 
 				if(pointsAreFloat)
 				{
-					fArray = vtkFloatArray::New(); IERROR_ASSERT_NULL_POINTER(fArray);
+					fArray = vtkFloatArray::New(); IERROR_ASSERT(fArray);
 					fArray->SetNumberOfComponents(3);
 					fArray->SetArray(pPointsF+3*iStart,3*iTotal,1);
 					newPoints->SetData(fArray);
@@ -632,7 +629,7 @@ void iParticleSplitter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
 				}
 				else
 				{
-					dArray = vtkDoubleArray::New(); IERROR_ASSERT_NULL_POINTER(dArray);
+					dArray = vtkDoubleArray::New(); IERROR_ASSERT(dArray);
 					dArray->SetNumberOfComponents(3);
 					dArray->SetArray(pPointsD+3*iStart,3*iTotal,1);
 					newPoints->SetData(dArray);
@@ -641,7 +638,7 @@ void iParticleSplitter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
 				output->SetPoints(newPoints);
 				newPoints->Delete();
 
-				newAtts = vtkFloatArray::New(); IERROR_ASSERT_NULL_POINTER(newAtts);
+				newAtts = vtkFloatArray::New(); IERROR_ASSERT(newAtts);
 				newAtts->SetNumberOfComponents(ncom);
 				newAtts->SetArray(pAtts+ncom*iStart,ncom*iTotal,1);
 				output->GetPointData()->SetScalars(newAtts);
@@ -649,15 +646,15 @@ void iParticleSplitter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
 
 				if(mNorms != 0) 
 				{
-					newNorms = vtkFloatArray::New(); IERROR_ASSERT_NULL_POINTER(newNorms);
+					newNorms = vtkFloatArray::New(); IERROR_ASSERT(newNorms);
 					newNorms->SetNumberOfComponents(3);
 					newNorms->SetArray(pNorms+3*iStart,3*iTotal,1);
 					output->GetPointData()->SetNormals(newNorms);
 					newNorms->Delete();
 				}
 
-				newVerts = vtkCellArray::New(); IERROR_ASSERT_NULL_POINTER(newVerts);
-				jArray = vtkIdTypeArray::New(); IERROR_ASSERT_NULL_POINTER(jArray);
+				newVerts = vtkCellArray::New(); IERROR_ASSERT(newVerts);
+				jArray = vtkIdTypeArray::New(); IERROR_ASSERT(jArray);
 				jArray->SetNumberOfComponents(1);
 				jArray->SetArray(pVerts,2*iTotal,1);
 				newVerts->SetCells(iTotal,jArray);
@@ -670,9 +667,9 @@ void iParticleSplitter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
 }
 
 
-void iParticleSplitter::SyncWithData(int info, void *)
+void iParticleSplitter::SyncWithData(const iDataSyncRequest &r)
 {
-	if(info==0 || info==1+mAtt)
+	if(r.Var()==-1 || r.Var()==mAtt)
 	{
 		this->Modified();
 		mRangeSet = false;
