@@ -47,70 +47,36 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "igenericfiltertemplate.h"
 
 
-iProbeFilter* iProbeFilter::New(iViewObject *vo)
+iProbeFilter::iProbeFilter(iViewSubject *vo) : iGenericFilter<vtkProbeFilter,vtkDataSet,vtkDataSet>(vo,1,true,true)
 {
-	return new iProbeFilter(vo);
 }
 
 
-iProbeFilter::iProbeFilter(iViewObject *vo) : iViewObjectComponent(vo)
+void iProbeFilter::ProduceOutput()
 {
-	mActive = true;
-	mSource = 0;
-}
+	vtkDataObject *input = this->GetInput();
+	vtkDataSet *output = this->GetOutput();
+	vtkDataObject *source = this->GetSource();
 
-
-iProbeFilter::~iProbeFilter()
-{
-	if(mSource != 0) mSource->UnRegister(this);
-}
-
-
-void iProbeFilter::SyncWithData(int, void *)
-{
-	this->Modified();
-}
-
-
-void iProbeFilter::SetActive(bool s)
-{
-	mActive = s;
-	if(s) this->SetNthInput(1,mSource); else this->SetNthInput(1,0);
-	this->Modified();
-}
-
-
-void iProbeFilter::SetSource(vtkImageData *input)
-{
-	if(mSource != 0) mSource->UnRegister(this);
-	mSource = input;
-	if(input != 0) input->Register(this);
-	this->SetActive(mActive);
-}
-
-
-void iProbeFilter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
-{
-	//
-	//  Adopted in part from vtkProbeFilter
-	//
-	vtkImageData *source = this->GetSource();
-
-	output->ShallowCopy(input);
-
-	//
-	//  If not active, just pass the data.
-	//
-	if(!mActive)
+	if(source->IsA("vtkImageData") && input->IsA("vtkPointSet") && output->IsA("vtkPointSet"))
 	{
-		return;
+		this->ProduceOutputForImageData(vtkPointSet::SafeDownCast(input),vtkPointSet::SafeDownCast(output),vtkImageData::SafeDownCast(source));
 	}
+	else
+	{
+#ifdef IVTK_4
+		this->vtkProbeFilter::ExecuteData(output);
+#else
+		output->ShallowCopy(input); // Probe does not copy normals...
+		this->vtkProbeFilter::Probe(vtkDataSet::SafeDownCast(input),vtkDataSet::SafeDownCast(source),output);
+#endif
+	}
+}
 
-	if(source == 0)
-    {
-		vtkErrorMacro("Source is not set.");
-		return;
-    }
+
+void iProbeFilter::ProduceOutputForImageData(vtkPointSet *input, vtkPointSet *output, vtkImageData *source)
+{
+	output->ShallowCopy(input);
 
 	vtkPoints *inpts = input->GetPoints();
 	if(inpts == 0) return;
@@ -147,7 +113,7 @@ void iProbeFilter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
 		inpts->GetPoint(l,x);
 
 		// Find the cell that contains xyz and get it
-		iGridDataSubject::GetCICInterpolation(per,dims,org,spa,x,ijk1,ijk2,d1,d2);
+		iUniformGridDataSubject::GetCICInterpolation(per,dims,org,spa,x,ijk1,ijk2,d1,d2);
 		loff111	= wScalarDimIn*(ijk1[0]+dims[0]*(ijk1[1]+(vtkIdType)dims[1]*ijk1[2]));
 		loff112	= wScalarDimIn*(ijk1[0]+dims[0]*(ijk1[1]+(vtkIdType)dims[1]*ijk2[2]));
 		loff121	= wScalarDimIn*(ijk1[0]+dims[0]*(ijk2[1]+(vtkIdType)dims[1]*ijk1[2]));
