@@ -187,7 +187,7 @@ protected:
 iRenderTool* iRenderTool::New(iViewModule *vm)
 {
 	iRenderTool *tmp =  iExtensionFactory::CreateRenderTool(vm);
-	IERROR_ASSERT_NULL_POINTER(tmp);
+	IERROR_ASSERT(tmp);
 	return tmp;
 }
 
@@ -197,12 +197,12 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : i
 	//
 	//  Main Window stuff
 	//
-	mMainWin = iShellFactory::CreateRenderWindow(this); IERROR_ASSERT_NULL_POINTER(mMainWin);
+	mMainWin = iShellFactory::CreateRenderWindow(this); IERROR_ASSERT(mMainWin);
 	if(ren == 0)
 	{
-		mMainRen = vtkRenderer::New(); IERROR_ASSERT_NULL_POINTER(mMainRen);
-		mMainInt = iShellFactory::CreateRenderWindowInteractor(this); IERROR_ASSERT_NULL_POINTER(mMainInt);
-		mMainCam = iCamera::New(this); IERROR_ASSERT_NULL_POINTER(mMainCam);
+		mMainRen = vtkRenderer::New(); IERROR_ASSERT(mMainRen);
+		mMainInt = iShellFactory::CreateRenderWindowInteractor(this); IERROR_ASSERT(mMainInt);
+		mMainCam = iCamera::New(this); IERROR_ASSERT(mMainCam);
 		mMainRen->SetActiveCamera(mMainCam);
 		mMainCam->Delete();
 		//
@@ -221,12 +221,12 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : i
 		//
 		//  Create and initiate lights
 		//
-		mLights = iLightKit::New(); IERROR_ASSERT_NULL_POINTER(mLights);	
+		mLights = iLightKit::New(); IERROR_ASSERT(mLights);	
 		mLights->AddLightsToRenderer(mMainRen);
 		//
 		//  Image magnifier
 		//
-		mMagnifier = iMagnifier::New(); IERROR_ASSERT_NULL_POINTER(mMagnifier);
+		mMagnifier = iMagnifier::New(); IERROR_ASSERT(mMagnifier);
 	}
 	else
 	{
@@ -234,7 +234,7 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : i
 		mMainInt = 0;
 		mMainCam = 0;
 		mLights = 0;
-		mMagnifier = mag; IERROR_ASSERT_NULL_POINTER(mMagnifier);
+		mMagnifier = mag; IERROR_ASSERT(mMagnifier);
 		mMagnifier->Register(ren);
 	}
 
@@ -258,17 +258,17 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : i
 	//
 	//  Dual window observer
 	//
-	mDualWindowObserver = iDualWindowObserver::New(this); IERROR_ASSERT_NULL_POINTER(mDualWindowObserver);
+	mDualWindowObserver = iDualWindowObserver::New(this); IERROR_ASSERT(mDualWindowObserver);
 
 	//
 	//  Dual window alignment markers (only needed for the primary window)
 	//
 	if(ren == 0)
 	{
-		mStereoAlignmentMarkersActor = vtkPropAssembly::New(); IERROR_ASSERT_NULL_POINTER(mStereoAlignmentMarkersActor);
+		mStereoAlignmentMarkersActor = vtkPropAssembly::New(); IERROR_ASSERT(mStereoAlignmentMarkersActor);
 		mStereoAlignmentMarkersActor->VisibilityOff();
 		mStereoAlignmentMarkersActor->PickableOff();
-		vtkPolyDataMapper2D *mapper2D = vtkPolyDataMapper2D::New(); IERROR_ASSERT_NULL_POINTER(mapper2D);
+		vtkPolyDataMapper2D *mapper2D = vtkPolyDataMapper2D::New(); IERROR_ASSERT(mapper2D);
 		vtkLineSource *ls;
 		vtkActor2D *actor2D[8];
 
@@ -277,9 +277,9 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : i
 		int i;
 		for(i=0; i<8; i++)
 		{
-			actor2D[i] = vtkActor2D::New(); IERROR_ASSERT_NULL_POINTER(actor2D[i]);
-			mapper2D = vtkPolyDataMapper2D::New(); IERROR_ASSERT_NULL_POINTER(mapper2D);
-			ls = vtkLineSource::New(); IERROR_ASSERT_NULL_POINTER(ls);
+			actor2D[i] = vtkActor2D::New(); IERROR_ASSERT(actor2D[i]);
+			mapper2D = vtkPolyDataMapper2D::New(); IERROR_ASSERT(mapper2D);
+			ls = vtkLineSource::New(); IERROR_ASSERT(ls);
 			ls->SetResolution(1);
 			if(i%2 == 0)
 			{
@@ -294,7 +294,7 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : i
 			ls->Update();
 			mapper2D->SetInput(ls->GetOutput());
 			ls->Delete();
-			vtkCoordinate *c = vtkCoordinate::New(); IERROR_ASSERT_NULL_POINTER(c);
+			vtkCoordinate *c = vtkCoordinate::New(); IERROR_ASSERT(c);
 			c->SetCoordinateSystemToView();
 			mapper2D->SetTransformCoordinate(c);
 			c->Delete();
@@ -320,7 +320,7 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : i
 	//
 	//  Clipping range controls
 	//
-	mRendererObserver = iRendererObserver::New(this); IERROR_ASSERT_NULL_POINTER(mRendererObserver);
+	mRendererObserver = iRendererObserver::New(this); IERROR_ASSERT(mRendererObserver);
 	mAutoClippingRange = true;
 	mMainRen->AddObserver(vtkCommand::ResetCameraClippingRangeEvent,mRendererObserver);
 	mMainRen->AddObserver(vtkCommand::ModifiedEvent,mRendererObserver);
@@ -328,7 +328,7 @@ iRenderTool::iRenderTool(iViewModule *vm, vtkRenderer *ren, iMagnifier *mag) : i
 	//
 	//  RenderWindow collection
 	//
-	mWindowCollection = vtkRenderWindowCollection::New(); IERROR_ASSERT_NULL_POINTER(mWindowCollection);
+	mWindowCollection = vtkRenderWindowCollection::New(); IERROR_ASSERT(mWindowCollection);
 	mWindowCollectionUpToDate = false;
 
 	//
@@ -733,9 +733,9 @@ void iRenderTool::ShowDualWindow(bool s)
 		{
 			if(mMainWin->GetStereoRender() == 0)
 			{
-				IERROR_REPORT_ERROR("Creating DualWindow in the non-stereo mode.");
+				IERROR_REPORT("Creating DualWindow in the non-stereo mode.");
 			}
-			mDualWin = iShellFactory::CreateRenderWindow(this); IERROR_ASSERT_NULL_POINTER(mDualWin);
+			mDualWin = iShellFactory::CreateRenderWindow(this); IERROR_ASSERT(mDualWin);
 			int *s = mMainWin->GetSize();
 			mDualWin->SetSize(s[0],s[1]);
 			mDualWin->StereoCapableWindowOn();
