@@ -33,7 +33,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "iparallel.h"
 #include "iviewmodule.h"
-#include "iviewobject.h"
+#include "iviewsubject.h"
 
 #include <vtkImageData.h>
 #include <vtkPointData.h>
@@ -41,15 +41,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <vtkUnsignedCharArray.h>
 
 
-
-//------------------------------------------------------------------------------
-iReplicatedGridData* iReplicatedGridData::New(iViewObject *vo)
-{
-	return new iReplicatedGridData(vo);
-}
-
-
-iReplicatedGridData::iReplicatedGridData(iViewObject *vo) : iParallelWorker(vo->GetViewModule()->GetParallelManager()), iReplicated(vo->GetReplicator(),true)
+iReplicatedGridData::iReplicatedGridData(iViewSubject *vo) : iGenericFilter<vtkStructuredPointsToStructuredPointsFilter,vtkImageData,vtkStructuredPoints>(vo,1,true,true), iParallelWorker(vo->GetViewModule()->GetParallelManager()), iReplicated(vo->GetReplicator(),true)
 {
 }
 
@@ -60,18 +52,14 @@ void iReplicatedGridData::UpdateReplicas()
 }
 
 
-void iReplicatedGridData::ExecuteInformation()
+void iReplicatedGridData::InitExecution()
 {
 	int i, ext[6];
 	double org[3];
+	
 	vtkImageData *input = this->GetInput();
-	vtkStructuredPoints *output = this->GetOutput();
-	
-	if (output == 0 || input == 0)
-    {
-		return;
-    }
-	
+	vtkImageData *output = this->GetOutput();
+
 	input->GetWholeExtent(ext);
 	input->GetOrigin(org);
 	
@@ -87,17 +75,16 @@ void iReplicatedGridData::ExecuteInformation()
 }
 
 
-void iReplicatedGridData::ExecuteData(vtkDataObject *)
+void iReplicatedGridData::ProduceOutput()
 {
-	vtkImageData *input = this->GetInput();
-	vtkStructuredPoints *output = this->GetOutput();
 	int extDown[3], extUp[3];
 	int i;
 	double pos[3];
 	
-	output->Initialize();
+	vtkImageData *input = this->GetInput();
+	vtkImageData *output = this->GetOutput();
 
-	if(input == 0) return;
+	output->Initialize();
 
 	int n = input->GetNumberOfScalarComponents();
 	if(n == 0) return;
@@ -143,7 +130,7 @@ void iReplicatedGridData::ExecuteData(vtkDataObject *)
 	output->SetDimensions(wDimsOut);
 
 	vtkUnsignedCharArray *data;
-	data = vtkUnsignedCharArray::New(); IERROR_ASSERT_NULL_POINTER(data);
+	data = vtkUnsignedCharArray::New(); IERROR_ASSERT(data);
 	data->SetNumberOfComponents(wSize);
 	data->SetNumberOfTuples((vtkIdType)wDimsOut[0]*wDimsOut[1]*wDimsOut[2]);
 	output->GetPointData()->SetScalars(data);
@@ -189,5 +176,5 @@ int iReplicatedGridData::ExecuteStep(int, iParallel::ProcessorInfo &p)
 
 float iReplicatedGridData::GetMemorySize()
 {
-	if(this->IsReplicated()) return this->GetOutput()->GetActualMemorySize(); else return 0.0;
+	if(this->IsReplicated()) return this->iGenericFilter<vtkStructuredPointsToStructuredPointsFilter,vtkImageData,vtkStructuredPoints>::GetMemorySize(); else return 0.0;
 }
