@@ -53,7 +53,7 @@ int iValue::cval[999];
 void ReportUnallowedPath()
 {
 #ifdef I_CHECK1
-	IERROR_REPORT_ERROR("Bug in iScript: unallowed path.");
+	IERROR_REPORT("Bug in iScript: unallowed path.");
 #endif
 	exit(-1);
 }
@@ -172,7 +172,7 @@ iValue* iValue::New(iValue *v0, bool ref)
 			iValue** arr = 0;
 			if(v->Size>0 && v->Array!=0)
 			{
-				arr = new iValue*[v->Size]; IERROR_ASSERT_NULL_POINTER(arr);
+				arr = new iValue*[v->Size]; IERROR_ASSERT(arr);
 				int i;
 				for(i=0; i<v->Size; i++) 
 				{
@@ -836,7 +836,7 @@ bool iValue_VA::GetValue(int n, int *p) const
 
 	if(iValue::AreTypesCompatible(_Value_IS,v))
 	{
-		w = new int[n]; IERROR_ASSERT_NULL_POINTER(w);
+		w = new int[n]; IERROR_ASSERT(w);
 		ok = true;
 		for(i=0; i<n && ok; i++) 
 		{
@@ -877,7 +877,7 @@ bool iValue_VA::GetValue(int n, double *p) const
 
 	if(iValue::AreTypesCompatible(_Value_RS,v))
 	{
-		w = new double[n]; IERROR_ASSERT_NULL_POINTER(w);
+		w = new double[n]; IERROR_ASSERT(w);
 		ok = true;
 		for(i=0; i<n && ok; i++) 
 		{
@@ -1231,7 +1231,7 @@ iScript::iScript(iScript *parent) : mAliasWords(AliasWord()), mPrefixWords(""),
 	mEntryPointIteration = -1;
 	mEntryPointIterationCount = 0;
 
-	mParser = new iExpressionParser; IERROR_ASSERT_NULL_POINTER(mParser);
+	mParser = new iExpressionParser; IERROR_ASSERT(mParser);
 
 	//
 	//  Standard parameters
@@ -1285,7 +1285,7 @@ iScript::~iScript()
 		int i;
 		for(i=0; i<999; i++) if (iValue::cval[i] != 0)
 		{
-			IERROR_REPORT_ERROR("Uncollected values.");
+			IERROR_REPORT("Uncollected values.");
 		}
 	}
 #endif
@@ -1736,7 +1736,7 @@ void iScript::ExecuteOneLine()
 		//
 		//  Update the compiler stack if needed. 
 		//
-		if(mCompilerStackEntryPoint >= mCompilerStack.Last())
+		if(mCompilerStackEntryPoint >= mCompilerStack.MaxIndex())
 		{
 			mCompilerStack.Add(StackEntry());
 		}
@@ -2229,7 +2229,7 @@ TEST:
 					//
 					//  Create an array of iValues
 					//
-					iValue **arr = new iValue*[n]; IERROR_ASSERT_NULL_POINTER(arr);
+					iValue **arr = new iValue*[n]; IERROR_ASSERT(arr);
 					if(arr == 0)
 					{
 						this->GetErrorStatus()->Set("Not enough memory to create this array.");
@@ -2482,7 +2482,7 @@ TEST:
 	//
 	//  save the command in pseudo code if this is the first time we reached this line
 	//
-	if(mCode[mCodeEntryPoint] == 0)
+	if(mCode.Size() == mCodeEntryPoint)
 	{
 		iOperation *tmp = 0;
 		switch(mCommand[comind]->Type)
@@ -2680,7 +2680,7 @@ iValue* iScript::TransformSingleTokenToValue(const iString &pv0, bool acceptArra
 		//
 		//  Create an array of iValues
 		//
-		iValue **arr = new iValue*[n]; IERROR_ASSERT_NULL_POINTER(arr);
+		iValue **arr = new iValue*[n]; IERROR_ASSERT(arr);
 
 		//
 		//  Fill it in
@@ -2998,7 +2998,7 @@ iValue* iScript::TransformExpressionToValue(const iString &pv0, bool NotUsed(acc
 		//  Create an array of iValues
 		//
 		n = 3;
-		iValue **arr = new iValue*[n]; IERROR_ASSERT_NULL_POINTER(arr);
+		iValue **arr = new iValue*[n]; IERROR_ASSERT(arr);
 		
 		//
 		//  Fill it in
