@@ -41,6 +41,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ishellfactory.h"
 #include "ivtk.h"
 
+#include <vtkTimerLog.h>
+#include <vtkImageData.h>
+
 //
 //  Templates
 //
@@ -66,12 +69,24 @@ void iShell::RunApplication(const iString &t, int argc, char **argv)
 
 iShell::iShell(int, char **) : mOptions(Option())
 {
+	int i;
+
 	mRunning = false;
 	mControlModule = 0; // control module must be created after the constructor is finished
 	mOutputWindow = 0; // output window must be created after the constructor is finished
 	mType = "undefined";
 	mNumProcs = 0;
 
+	mCurInitStep = 0;
+	for(i=0; i<4; i++)
+	{
+		mInitSteps[i].Current = 0;
+	}
+	mInitSteps[0].Total = 10;		// needs to be set manually during development. How to do it automatically?
+	mInitSteps[1].Total = 161;		// needs to be set manually during development. How to do it automatically?
+	mInitSteps[2].Total = 1382;		// needs to be set manually during development. How to do it automatically?
+	mInitSteps[3].Total = 13;		// needs to be set manually during development. How to do it automatically?
+
 	//
 	//  Define some basic command-line options
 	//
@@ -130,6 +145,9 @@ iShell::iShell(int, char **) : mOptions(Option())
     e = getenv("IFRIT_IMAGE_DIR");              if(e != 0) mEnvImageDir = iString(e) + this->GetDirSeparator(); else mEnvImageDir = this->GetCurrentDir() + this->GetDirSeparator();
     e = getenv("IFRIT_SCRIPT_DIR");             if(e != 0) mEnvScriptDir = iString(e) + this->GetDirSeparator(); else mEnvScriptDir = mEnvBaseDir;
     e = getenv("IFRIT_PALETTE_DIR");            if(e != 0) mEnvPaletteDir = iString(e) + this->GetDirSeparator(); else mEnvPaletteDir = mEnvBaseDir;
+
+	mInitTimer = vtkTimerLog::New(); IERROR_ASSERT(mInitTimer);
+	mInitTimer->StartTimer();
 }
 
 
@@ -139,6 +157,7 @@ iShell::~iShell()
 	//  This ensures that control module is deleted after the shell is deleted.
 	//
 //	mControlModule->Delete();
+	mInitTimer->Delete();
 }
 
 
@@ -185,6 +204,22 @@ iShell* iShell::New(const iString &t, int argc, char **argv)
 		exit(0);
 	}
 	//
+	//  Test that VTK is compiled with RTTI 
+	//
+	vtkDataSet *pp = vtkImageData::New();
+	if(pp == 0)
+	{
+		tmp->OutputStartupMessage("There is not enough memory to run IFrIT.");
+		exit(0);
+	}
+	vtkImageData *ps = dynamic_cast<vtkImageData*>(pp);
+	if(ps == 0)
+	{
+		tmp->OutputStartupMessage("VTK has not been compiled with the RTTI (Run-Time Type Information) support.\nIFrIT needs all components to be compiled with the RTTI support.\nPlease re-compile VTK with the RTTI support enabled.");
+		exit(0);
+	}
+	ps->Delete();
+	//
 	//  Create console: need the fully created "tmp->this" pointer
 	//
 	iConsole::CreateInstance(tmp);
@@ -213,23 +248,34 @@ iShell* iShell::New(const iString &t, int argc, char **argv)
 	tmp->DefineSpecificCommandLineOptions();
 	tmp->ParseCommandLineOptions(argc,argv);
 	tmp->PrepareForConstruction();
+#ifdef I_DEVEL
+	tmp->InitHelper();
+#endif
 	//
 	//  This ensures that "tmp->this" pointer is correct before a control module is created.
 	//
-	tmp->mControlModule = iControlModule::New(tmp); IERROR_ASSERT_NULL_POINTER(tmp->mControlModule);
-	if(tmp->mNumProcs > 0) tmp->mControlModule->GetParallelManager()->ResetMaxNumberOfProcessors(tmp->mNumProcs);
+	tmp->mCurInitStep = 1;
+	tmp->mControlModule = iControlModule::New(tmp); IERROR_ASSERT(tmp->mControlModule);
+	if(tmp->mNumProcs >= 0) tmp->mControlModule->GetParallelManager()->ResetMaxNumberOfProcessors(tmp->mNumProcs);
+#ifdef I_DEVEL
+	tmp->InitHelper();
+#endif
 	//
 	//  Really construct the shell: control module needs to be fully initialized before a shell 
 	//  is really constructed.
 	//
+	tmp->mCurInitStep = 2;
 	tmp->ConstructorBody(); 
 	//
 	//   Load widget info into ObjectKeyHelp objects.
 	//
-	tmp->LoadObjectKeyHelp();
+#ifdef I_DEVEL
+	tmp->InitHelper();
+#endif
 	//
 	//  Load the state file if needed
 	//
+	tmp->mCurInitStep = 3;
 	if(tmp->mStateFileName.IsEmpty())
 	{
 		iString fname = tmp->mControlModule->GetFileName(_EnvironmentBase,"ifrit.ini");
@@ -239,6 +285,9 @@ iShell* iShell::New(const iString &t, int argc, char **argv)
 	{
 		tmp->LoadStateFile(tmp->mStateFileName);
 	}
+#ifdef I_DEVEL
+	tmp->InitHelper();
+#endif
 	//
 	//  Start the shell
 	//
@@ -288,21 +337,6 @@ void iShell::Run()
 }
 
 
-void iShell::LoadObjectKeyHelp()
-{
-	const iObjectKey *key;
-
-	iObjectKeyRegistry::InitTraversal();
-	while((key=iObjectKeyRegistry::GetNextKey()) != 0)
-	{
-		//
-		//  We are accesing the class members directly since key->GetHelp() is const.
-		//
-//		this->FindWidgetForKey(key,key->mHelp->mWidgetName,key->mHelp->mWidgetDescription);
-	}
-}
-
-
 void iShell::AddCommandLineOption(const iString &root, bool hasValue, const iString &help)
 {
 	Option tmp;
@@ -477,3 +511,37 @@ const iString& iShell::GetCurrentDir() const
 	return cur;
 }
 
+
+void iShell::OnInitAtom()
+{
+	mInitSteps[mCurInitStep].Current++;
+	mInitTimer->StopTimer();
+	if(mInitTimer->GetElapsedTime() > 0.1)
+	{
+		mInitTimer->StartTimer();
+		this->OnInitAtomBody(true);
+	}
+	else
+	{
+		this->OnInitAtomBody(false);
+	}
+}
+
+
+void iShell::OnInitAtomBody(bool timed)
+{
+}
+
+
+#ifdef I_DEVEL
+void iShell::InitHelper()
+{
+	if(mInitSteps[mCurInitStep].Current != mInitSteps[mCurInitStep].Total)
+	{
+		int step = mCurInitStep;
+		int total = mInitSteps[mCurInitStep].Current;
+		int bp = 0;
+	}
+}
+#endif
+
