@@ -75,16 +75,15 @@ namespace iSmoothPolyDataFilter_Private
 using namespace iSmoothPolyDataFilter_Private;
 
 
-iSmoothPolyDataFilter* iSmoothPolyDataFilter::New()
+iSmoothPolyDataFilter::iSmoothPolyDataFilter(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkWindowedSincPolyDataFilter>(vo,1,true,false)
 {
-	return new iSmoothPolyDataFilter;
 }
 	
     
-void iSmoothPolyDataFilter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
+void iSmoothPolyDataFilter::ProduceOutput()
 {
 	//
-	//  The code between === lines is copied from vtkRenderLargeImage.cxx file with minor modifications, as marked behind /// comments
+	//  The code between === lines is copied from vtkWindowedSincPolyDataFilter.cxx file with minor modifications, as marked behind /// comments
 	//  Below is the original copyright notice.
 	//
 	//  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
@@ -112,8 +111,11 @@ void iSmoothPolyDataFilter::ProduceOutput(vtkPolyData *input, vtkPolyData *outpu
 	vtkMeshVertexPtr Verts;
 	/// ------ Removed ------------------------------------------
 	/// vtkPolyData *input = this->GetInput();
-	/// vtkPolyData *output = this->GetOutput();
 	/// ---------------------------------------------------------
+	/// ++++++ Added ++++++++++++++++++++++++++++++++++++++++++++
+	vtkPolyData *input = vtkPolyData::SafeDownCast(this->GetInput());
+	/// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+	vtkPolyData *output = this->GetOutput();
 
 	// variables specific to windowed sinc interpolation
 	double theta_pb, k_pb, sigma, p_x0[3], p_x1[3], p_x3[3];
