@@ -38,10 +38,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ieventobserver.h"
 #include "iexpressionparser.h"
 #include "ifile.h"
+#include "ihistogrammaker.h"
 #include "iparallel.h"
 #include "iparallelfft.h"
 #include "iparallelmanager.h"
 #include "iparallelworker.h"
+#include "iprobefilter.h"
 #include "isystem.h"
 #include "itune.h"
 #include "iviewmodule.h"
@@ -83,21 +85,15 @@ IDATASUBJECT_DEFINE_INHERITED_KEYS(iUniformTensorsDataSubject);
 
 
 //
-//  ********************************************************************
+//  Helper classes for parallel executions
 //
-//  Generic GridDataSubject class
-//
-//  ********************************************************************
-//
-//  Helper class for parallel executions
-//
-class iGridDataHelper : protected iParallelWorker
+class iUniformGridDataHelper : protected iParallelWorker
 {
 
 public:
 
-	iGridDataHelper(iGridDataSubject *subject);
-	~iGridDataHelper();
+	iUniformGridDataHelper(iUniformGridDataSubject *subject);
+	~iUniformGridDataHelper();
 
 	void TransformToPointData(int mode, bool arrayIsVertical, int numComponents, float *&cellData, int cellDims[3]);
 	void ShiftData(int numCom, int dim, int dn, int dataDims[3], float *data, float *buf);
@@ -117,7 +113,7 @@ protected:
 	void ExecuteTransformToPointData3(iParallel::ProcessorInfo &p);
 	void ExecuteShiftData(iParallel::ProcessorInfo &p);
 
-	iGridDataSubject *mSubject;
+	iUniformGridDataSubject *mSubject;
 	iParallelFFT *mFft;
 
 	int mNc, mMode;
@@ -140,10 +136,46 @@ protected:
 };
 
 
+class iUniformScalarsDataHelper : protected iParallelWorker
+{
+
+public:
+
+	iUniformScalarsDataHelper(iUniformScalarsDataSubject *subject);
+
+	void OperateOnData1(int nvar, int dims[3], iExpressionParser *calc, bool doVector, float ps, float dp);
+	void OperateOnData2(int nvar, int dims[3], float *fMin, float *fMax, bool &overflow, float ps, float dp);
+
+protected:
+
+	virtual int ExecuteStep(int step, iParallel::ProcessorInfo &p);
+
+	void ExecuteOperateOnData1(iParallel::ProcessorInfo &p);
+	void ExecuteOperateOnData2(iParallel::ProcessorInfo &p);
+
+	iUniformScalarsDataSubject *mSubject;
+	iProgressEventObserver *mObserver;
+	iExpressionParser *mCalculator;
+
+	int mNumVars, mNumProcs, *mDims;
+
+	iBuffer<float> mMin, mMax;
+	float mProgStart, mProgStep;
+
+	bool mDoVector, mOverflow;
+};
+
+
 //
-//  Main class
+//  Main classes
 //
-iGridDataSubject::iGridDataSubject(iDataReader *r, const iDataType &type) : iDataSubject(r,type), mMaxDimension(1670000)
+//  ********************************************************************
+//
+//  Generic GridDataSubject class
+//
+//  ********************************************************************
+//
+iUniformGridDataSubject::iUniformGridDataSubject(iDataReader *r, const iDataType &type) : iDataSubject(r,type), mMaxDimension(1670000)
 {
 	mCellToPointMode = 2;
 	mVoxelLocation = 0;
@@ -155,20 +187,20 @@ iGridDataSubject::iGridDataSubject(iDataReader *r, const iDataType &type) : iDat
 
 	mScaledDim = -1;
 
-	mInternalData = mData = vtkStructuredPoints::New(); IERROR_ASSERT_NULL_POINTER(mInternalData);
-	mExternalData =         vtkStructuredPoints::New(); IERROR_ASSERT_NULL_POINTER(mExternalData);
+	mInternalData = mData = vtkStructuredPoints::New(); IERROR_ASSERT(mInternalData);
+	mExternalData =         vtkStructuredPoints::New(); IERROR_ASSERT(mExternalData);
 
-	mHelper = new iGridDataHelper(this); IERROR_ASSERT_NULL_POINTER(mHelper);
+	mHelper = new iUniformGridDataHelper(this); IERROR_ASSERT(mHelper);
 }
 
 
-iGridDataSubject::~iGridDataSubject()
+iUniformGridDataSubject::~iUniformGridDataSubject()
 {
 	delete mHelper;
 }
 
 
-void iGridDataSubject::ReadFileBody(const iString &suffix, const iString &fname)
+void iUniformGridDataSubject::ReadFileBody(const iString &suffix, const iString &fname)
 {
 	//
 	//  is the suffix valid?
@@ -186,7 +218,7 @@ void iGridDataSubject::ReadFileBody(const iString &suffix, const iString &fname)
 }
 
 
-void iGridDataSubject::ReadBinFile(const iString &fname)
+void iUniformGridDataSubject::ReadBinFile(const iString &fname)
 {
 	int i;
 	vtkIdType l, ntot;
@@ -206,7 +238,7 @@ void iGridDataSubject::ReadBinFile(const iString &fname)
 	//
 	// auto-detect data endiness
 	//
-	if(!this->DetectFileStructureFromFirstRecord(F,3*sizeof(int)))
+	if(!this->DetectFortranFileStructure(F,3*sizeof(int)))
 	{ 
 		F.Close(); 
 		mObserver->Finished();
@@ -292,7 +324,7 @@ void iGridDataSubject::ReadBinFile(const iString &fname)
 		err = !this->ReadFortranRecord(F,Buffer(d,ntot),0.01+prog1*i,prog1);
 		if(err || mObserver->IsAborted()) break;
 
-		this->AssignBinData(i,ntot,d);
+		this->AssignBinData(nvar,ntot,i,d);
 		vmin = vmax = d[0];
 		for(l=1; l<ntot; l++)
 		{
@@ -321,7 +353,7 @@ void iGridDataSubject::ReadBinFile(const iString &fname)
 }
 
 
-void iGridDataSubject::ReadTxtFile(const iString &fname)
+void iUniformGridDataSubject::ReadTxtFile(const iString &fname)
 {
 	int i, n1, n2, n3, ret;
 	iString s;
@@ -453,7 +485,7 @@ void iGridDataSubject::ReadTxtFile(const iString &fname)
 }
 
 
-void iGridDataSubject::EraseBuffer()
+void iUniformGridDataSubject::EraseBuffer()
 {
 	delete [] mBuffer; 
 	mBuffer = 0; 
@@ -461,7 +493,7 @@ void iGridDataSubject::EraseBuffer()
 }
 
 
-void iGridDataSubject::FinalizeBody()
+void iUniformGridDataSubject::FinalizeBody()
 {
 	//
 	//  Now we need to decide whether the data are CellData or PointData.
@@ -477,7 +509,7 @@ void iGridDataSubject::FinalizeBody()
 #ifdef I_CHECK1
 		if(mNumVars != mNumArrays*mNumComponents)
 		{
-			IERROR_REPORT_ERROR("Bug in iGridDataSubject.");
+			IERROR_REPORT("Bug in iUniformGridDataSubject.");
 		}
 #endif
 		
@@ -485,7 +517,7 @@ void iGridDataSubject::FinalizeBody()
 		{
 			if(mNumArrays>1 && mNumComponents!=1)
 			{
-				IERROR_REPORT_ERROR("This array configuration is not supported.");
+				IERROR_REPORT("This array configuration is not supported.");
 			}
 			else
 			{
@@ -504,7 +536,7 @@ void iGridDataSubject::FinalizeBody()
 }
 
 
-void iGridDataSubject::Polish()
+void iUniformGridDataSubject::Polish()
 {
 #ifndef IVTK_4
 	//
@@ -516,7 +548,7 @@ void iGridDataSubject::Polish()
 		vtkInformation *info = d->GetPipelineInformation();
 		if(info == 0)
 		{
-			info = vtkInformation::New(); IERROR_ASSERT_NULL_POINTER(info);
+			info = vtkInformation::New(); IERROR_ASSERT(info);
 			d->SetPipelineInformation(info);
 		}
 
@@ -531,7 +563,7 @@ void iGridDataSubject::Polish()
 }
 
 
-void iGridDataSubject::SetScaledDimension(int v)
+void iUniformGridDataSubject::SetScaledDimension(int v)
 {
 	if(v>=-2 && v<=2)
 	{
@@ -553,7 +585,7 @@ void iGridDataSubject::SetScaledDimension(int v)
 }
 
 
-void iGridDataSubject::ComputeSpacing()
+void iUniformGridDataSubject::ComputeSpacing()
 {
 	if(mDims[0]<=0 || mDims[1]<=0 || mDims[2]<=0) return;
 
@@ -599,7 +631,7 @@ void iGridDataSubject::ComputeSpacing()
 }
 
 
-void iGridDataSubject::ShiftDataBody(int d, double dx)
+void iUniformGridDataSubject::ShiftDataBody(int d, double dx)
 {
 	if(d<0 || d>2 || !this->IsThereData()) return;
 
@@ -609,7 +641,7 @@ void iGridDataSubject::ShiftDataBody(int d, double dx)
 		this->GetCellDims(dimt);
 
 		int dn = round(dx*dimt[d]);
-		if(dn==0 || abs(dn)>=dimt[d]) return;
+		if(dn==0 || iMath::Abs(dn)>=dimt[d]) return;
 
 		vtkIdType size = (vtkIdType)mDims[0]*mDims[1]*mDims[2]*mNumComponents;
 		float *buf = new float[mNumComponents*mDims[d]]; if(buf == 0) return;
@@ -636,52 +668,424 @@ void iGridDataSubject::ShiftDataBody(int d, double dx)
 }
 
 
-void iGridDataSubject::SetCellToPointMode(int m)
+void iUniformGridDataSubject::SetCellToPointMode(int m)
 { 
 	if(m>=0 && m<=5) mCellToPointMode = m;
 }
 
 
-void iGridDataSubject::SetVoxelLocation(int m)
+void iUniformGridDataSubject::SetVoxelLocation(int m)
 { 
 	if(m>=0 && m<=1) mVoxelLocation = m;
 }
 
 
-void iGridDataSubject::GetCellDims(int dimCell[3]) const
+void iUniformGridDataSubject::GetCellDims(int dimCell[3]) const
 {
 	int n;
 	for(n=0; n<3; n++) if(this->GetVoxelLocation() == 0) dimCell[n] = mDims[n] - 1; else dimCell[n] = mDims[n];
 }
 
 
-void iGridDataSubject::DataSubjectPackStateBody(iString &) const
+void iUniformGridDataSubject::DataSubjectPackStateBody(iString &) const
 {
 }
 
 
-void iGridDataSubject::DataSubjectUnPackStateBody(const iString &)
+void iUniformGridDataSubject::DataSubjectUnPackStateBody(const iString &)
 {
 }
 
 
+iProbeFilter* iUniformGridDataSubject::CreateProbeFilter(iViewSubject *vo) const
+{
+	return iProbeFilter::New(vo);
+}
+
+
+iHistogramMaker* iUniformGridDataSubject::CreateHistogramMaker() const
+{
+	return iHistogramMaker::New(this->GetViewModule());
+}
+
+
+//
+//  ********************************************************************
+//
+//  iUniformVectorsDataSubject class
+//
+//  ********************************************************************
+//
+iUniformVectorsDataSubject::iUniformVectorsDataSubject(iDataReader *r) : iUniformGridDataSubject(r,iData::UniformVectors())
+{
+}
+
+
+void iUniformVectorsDataSubject::SetIndicies(int &nvar, int &ncomp)
+{
+	nvar = 3;
+	ncomp = 3;
+}
+
+
+void iUniformVectorsDataSubject::AssignBinData(int, vtkIdType ntot, int com, float *d)
+{
+	vtkIdType l;
+	for(l=0; l<ntot; l++) mBuffer[com+3*l] = d[l];
+}
+
+
+void iUniformVectorsDataSubject::AssignTxtData(int, vtkIdType, vtkIdType ind, float *f)
+{
+	int n;
+	for(n=0; n<3; n++) mBuffer[n+3*ind] = f[n];
+}
+
+
+void iUniformVectorsDataSubject::SetArraysAndComponents()
+{
+	mNumArrays = 1;
+	mNumComponents = 3;
+	this->GetLimits()->AddVar(0);
+	if(mAdjustableLimits)
+	{
+		this->GetLimits()->SetMin(0,0.0f);
+		this->GetLimits()->SetMax(0,sqrt(mVarMax[0]*mVarMax[0]+mVarMax[1]*mVarMax[1]+mVarMax[2]*mVarMax[2]));
+	}
+}
+
+
+void iUniformVectorsDataSubject::AttachBuffer()
+{
+	//
+	//  Attach the actual data
+	//
+	vtkIdType size = (vtkIdType)mDims[0]*mDims[1]*mDims[2]*3;
+	vtkFloatArray *array = vtkFloatArray::New(); IERROR_ASSERT(array);
+	array->SetNumberOfComponents(3);
+	array->SetArray(mBuffer,size,1);
+	array->SetName("Vectors");
+	mData->GetPointData()->SetVectors(array);
+	array->Delete();
+}
+
+
+iDataLimits* iUniformVectorsDataSubject::CreateLimits() const
+{
+	return new iDataLimits(this,1,"Vector");
+}
+
+
+//
+//  ********************************************************************
+//
+//  iUniformTensorsDataSubject class
+//
+//  ********************************************************************
+//
+iUniformTensorsDataSubject::iUniformTensorsDataSubject(iDataReader *r) : iUniformGridDataSubject(r,iData::UniformTensors())
+{
+}
+
+
+void iUniformTensorsDataSubject::SetIndicies(int &nvar, int &ncomp)
+{
+	nvar = 9;
+	ncomp = 6;
+}
+
+
+void iUniformTensorsDataSubject::AssignBinData(int, vtkIdType ntot, int com, float *d)
+{
+	int noff1, noff2;
+	vtkIdType l;
+
+	switch(com)
+	{
+	case 0: { noff1 = 0; noff2 = -1; break; }
+	case 1: { noff1 = 1; noff2 = 3; break; }
+	case 2: { noff1 = 2; noff2 = 6; break; }
+	case 3: { noff1 = 4; noff2 = -1; break; }
+	case 4: { noff1 = 5; noff2 = 7; break; }
+	case 5: { noff1 = 8; noff2 = -1; break; }
+	default: 
+		{
+			noff1 = 0; noff2 = -1;
+			IERROR_REPORT("Bug detected.");
+		}
+	}
+
+	for(l=0; l<ntot; l++) mBuffer[noff1+9*l] = d[l];
+	if(noff2 > 0) for(l=0; l<ntot; l++) mBuffer[noff2+9*l] = d[l];
+}
+
+
+void iUniformTensorsDataSubject::AssignTxtData(int, vtkIdType, vtkIdType ind, float *f)
+{
+	//
+	//  Fill in 3x3 tensor with 6 components
+	//
+	mBuffer[0+9*ind] = f[0];
+	mBuffer[1+9*ind] = f[1];
+	mBuffer[2+9*ind] = f[2];
+	mBuffer[3+9*ind] = f[1];
+	mBuffer[4+9*ind] = f[3];
+	mBuffer[5+9*ind] = f[4];
+	mBuffer[6+9*ind] = f[2];
+	mBuffer[7+9*ind] = f[4];
+	mBuffer[8+9*ind] = f[5];
+}
+
+
+void iUniformTensorsDataSubject::SetArraysAndComponents()
+{
+	mNumArrays = 1;
+	mNumComponents = 9;
+	this->GetLimits()->AddVar(0);
+	if(mAdjustableLimits)
+	{
+		this->GetLimits()->SetMin(0,0.0f);
+		this->GetLimits()->SetMax(0,sqrt(mVarMax[0]*mVarMax[0]+mVarMax[1]*mVarMax[1]+mVarMax[2]*mVarMax[2]+mVarMax[3]*mVarMax[3]+mVarMax[4]*mVarMax[4]+mVarMax[5]*mVarMax[5]+mVarMax[6]*mVarMax[6]+mVarMax[7]*mVarMax[7]+mVarMax[8]*mVarMax[8]));
+	}
+}
+
+
+void iUniformTensorsDataSubject::AttachBuffer()
+{
+	//
+	//  Attach the actual data
+	//
+	vtkIdType size = (vtkIdType)mDims[0]*mDims[1]*mDims[2]*9;
+	vtkFloatArray *array = vtkFloatArray::New(); IERROR_ASSERT(array);
+	array->SetNumberOfComponents(9);
+	array->SetArray(mBuffer,size,1);
+	array->SetName("Tensors");
+	mData->GetPointData()->SetTensors(array);
+	array->Delete();
+}
+
+
+iDataLimits* iUniformTensorsDataSubject::CreateLimits() const
+{
+	return new iDataLimits(this,1,"Tensor");
+}
+
+
+//
+//  ********************************************************************
+//
+//  iUniformScalarsDataSubject class
+//
+//  ********************************************************************
+//
+iUniformScalarsDataSubject::iUniformScalarsDataSubject(iDataReader *r, iUniformVectorsDataSubject *vs) : iUniformGridDataSubject(r,iData::UniformScalars())
+{
+	mVectorFieldSubject = vs;
+
+	mCalculatorOutputVariable = 0;
+//	mCalculatorFunction = "";
+
+	mCalculator = new iExpressionParser; IERROR_ASSERT(mCalculator);
+	mHelper2 = new iUniformScalarsDataHelper(this); IERROR_ASSERT(mHelper2);
+}
+
+
+iUniformScalarsDataSubject::~iUniformScalarsDataSubject()
+{
+	delete mHelper2;
+	delete mCalculator;
+}
+
+
+void iUniformScalarsDataSubject::SetIndicies(int &nvar, int &ncomp)
+{
+	//
+	//  Try to set all the records from the file. DataLimits will either expand to accommodate 
+	//  all of them or limit the allowed number to the number of listed records.
+	//
+	this->GetLimits()->BlockNotifications(true);
+	this->GetLimits()->AssignVars(nvar);
+	this->GetLimits()->BlockNotifications(false);
+	ncomp = nvar = this->GetLimits()->GetNumVars();
+}
+
+
+void iUniformScalarsDataSubject::AssignBinData(int nvar, vtkIdType ntot, int com, float *d)
+{
+	vtkIdType l;
+	for(l=0; l<ntot; l++) mBuffer[com+nvar*l] = d[l];
+}
+
+
+void iUniformScalarsDataSubject::AssignTxtData(int nvar, vtkIdType ntot, vtkIdType ind, float *f)
+{
+	int n;
+	for(n=0; n<nvar; n++) mBuffer[n+nvar*ind] = f[n];
+}
+
+
+void iUniformScalarsDataSubject::AttachBuffer()
+{
+	//
+	//  Attach the actual data
+	//
+	vtkIdType size = (vtkIdType)mDims[0]*mDims[1]*mDims[2]*mNumVars;
+	vtkFloatArray *array = vtkFloatArray::New(); IERROR_ASSERT(array);
+	array->SetNumberOfComponents(mNumVars);
+	array->SetArray(mBuffer,size,1);
+	array->SetName("Scalars");
+	mData->GetPointData()->SetScalars(array);
+	array->Delete();
+
+	this->OperateOnData();
+}
+
+
+void iUniformScalarsDataSubject::SetArraysAndComponents()
+{
+	mNumArrays = 1;
+	mNumComponents = mNumVars;
+	this->GetLimits()->AssignVars(mNumVars);
+	//
+	//  Limits are set after the data are operated upon
+	//
+}
+
+
+iDataLimits* iUniformScalarsDataSubject::CreateLimits() const
+{
+	return new iDataLimits(this,3,"Variable");
+}
+
+
+void iUniformScalarsDataSubject::SetCalculatorOutputVariable(int n)
+{
+	if(n>=0 && n<this->GetLimits()->GetNumVars()) 
+	{
+		mCalculatorOutputVariable = n;
+		this->GetLimits()->RestoreNames();
+	}
+}
+
+
+void iUniformScalarsDataSubject::SetCalculatorFunction(const iString &s)
+{
+	mCalculatorFunction = s;
+	if(s.IsEmpty()) this->GetLimits()->RestoreNames();
+}
+
+
+void iUniformScalarsDataSubject::OperateOnData()
+{
+	int n;
+	float fMin = iMath::_LargeFloat, fMax = -iMath::_LargeFloat, f = 0.0;
+
+	int nvar = this->GetLimits()->GetNumVars();
+
+	iDataLimits *slim = this->GetLimits();
+	iDataLimits *vlim = mVectorFieldSubject->GetLimits();
+	slim->BlockNotifications(true);
+
+	//
+	//  Do the array function first
+	//
+	if(mCalculatorOutputVariable>=0 && mCalculatorOutputVariable<nvar && !mCalculatorFunction.IsEmpty())
+	{
+		this->GetObserver()->Started(iProgressEventObserver::_Operating);
+		this->GetObserver()->SetProgress(0.0);
+
+		mCalculator->SetFunction(mCalculatorFunction);
+
+		bool doVector = false;
+		if(mVectorFieldSubject->IsThereData() && this->GetDim(0)==mVectorFieldSubject->GetDim(0) && this->GetDim(1)==mVectorFieldSubject->GetDim(1) && this->GetDim(2)==mVectorFieldSubject->GetDim(2)) doVector = true;
+
+		mHelper2->OperateOnData1(nvar,mDims,mCalculator,doVector,0.0,1.0);
+	}
+
+	this->GetObserver()->Started(iProgressEventObserver::_Formatting);
+	this->GetObserver()->SetProgress(0.0);
+
+	//
+	//  Format everything in parallel
+	//
+	mVarMin.Extend(nvar);
+	mVarMax.Extend(nvar);
+	mHelper2->OperateOnData2(nvar,mDims,mVarMin,mVarMax,mOverflow,0.0,1.0);
+
+#ifdef I_CHECK2
+	//
+	//  Format everything serially
+	//
+	vtkIdType lMin, lMax, size = (vtkIdType)mDims[0]*mDims[1]*mDims[2];
+	for(n=0; n<nvar; n++)
+	{
+		fMin = iMath::_LargeFloat;
+		fMax = -iMath::_LargeFloat;
+		long l;
+		for(l=0; l<size; l++)
+		{
+			f = mBuffer[n+nvar*l];
+			if(f > fMax)
+			{
+				lMax = l;
+				fMax = f;
+			}
+			if(f < fMin)
+			{
+				lMin = l;
+				fMin = f;
+			}
+		}
+		if(fabs(mVarMin[n]-fMin)>iMath::_FloatRes || fabs(mVarMax[n]-fMax)>iMath::_FloatRes)
+		{
+			IERROR_REPORT_BUG;
+		}
+	}
+#endif
+
+	this->GetObserver()->SetProgress(1.0);
+	this->GetObserver()->Finished();
+
+	slim->BlockNotifications(false);
+
+	//
+	//  Correct limits in log stretching
+	//
+	if(mAdjustableLimits)
+	{
+		for(n=0; n<nvar; n++)
+		{
+			fMin = mVarMin[n];
+			fMax = mVarMax[n];
+			if(slim->GetStretch(n) == 1)
+			{
+				fMin = 0.1*floor(10.0*fMin);
+				fMax = 0.1*floor(1+10.0*fMax);
+			}
+			slim->SetMin(n,fMin);
+			slim->SetMax(n,fMax);
+		}
+	}
+}
+
+
 //
 //  Helper class
 //
-iGridDataHelper::iGridDataHelper(iGridDataSubject *subject) : iParallelWorker(subject->GetViewModule()->GetParallelManager())
+iUniformGridDataHelper::iUniformGridDataHelper(iUniformGridDataSubject *subject) : iParallelWorker(subject->GetViewModule()->GetParallelManager())
 {
 	mSubject = subject;
-	mFft = iParallelFFT::New(this->GetManager()); IERROR_ASSERT_NULL_POINTER(mFft);
+	mFft = iParallelFFT::New(this->GetManager()); IERROR_ASSERT(mFft);
 }
 
 
-iGridDataHelper::~iGridDataHelper()
+iUniformGridDataHelper::~iUniformGridDataHelper()
 {
 	mFft->Delete();
 }
 
 
-void iGridDataHelper::TransformToPointData(int mode, bool arrayIsVertical, int numComponents, float *&cellData, int cellDims[3])
+void iUniformGridDataHelper::TransformToPointData(int mode, bool arrayIsVertical, int numComponents, float *&cellData, int cellDims[3])
 {
 	int i, n;
 	long cellOffset[3], pointOffset[3], cellComponentOffset, pointComponentOffset;
@@ -797,7 +1201,7 @@ void iGridDataHelper::TransformToPointData(int mode, bool arrayIsVertical, int n
 }
 
 
-void iGridDataHelper::CopyArray(int numCom, int dims[3], float *src, bool srcVertical, float *dst, bool dstVertical)
+void iUniformGridDataHelper::CopyArray(int numCom, int dims[3], float *src, bool srcVertical, float *dst, bool dstVertical)
 {
 	mNc = numCom;
 	mN1 = dims[0];
@@ -812,7 +1216,7 @@ void iGridDataHelper::CopyArray(int numCom, int dims[3], float *src, bool srcVer
 }
 
 
-void iGridDataHelper::TransformToPointData1(int dims[3], float *data, float *dnyq, float ps, float dp)
+void iUniformGridDataHelper::TransformToPointData1(int dims[3], float *data, float *dnyq, float ps, float dp)
 {
 	mN1 = dims[0];
 	mN2 = dims[1];
@@ -826,7 +1230,7 @@ void iGridDataHelper::TransformToPointData1(int dims[3], float *data, float *dny
 }
 
 
-void iGridDataHelper::TransformToPointData2(bool per[3], int cellDims[3], long cellOffset[3], long cellComponentOffset, float *cellData, float *data, float ps, float dp)
+void iUniformGridDataHelper::TransformToPointData2(bool per[3], int cellDims[3], long cellOffset[3], long cellComponentOffset, float *cellData, float *data, float ps, float dp)
 {
 	mN1 = cellDims[0];
 	mN2 = cellDims[1];
@@ -843,7 +1247,7 @@ void iGridDataHelper::TransformToPointData2(bool per[3], int cellDims[3], long c
 }
 
 
-void iGridDataHelper::TransformToPointData3(int cellToPointMode, int numCom, bool per[3], int cellDims[3], long cellOffset[3], long cellComponentOffset, float *cellData, int pointDims[3], long pointOffset[3], long pointComponentOffset, float *pointData, float ps, float dp)
+void iUniformGridDataHelper::TransformToPointData3(int cellToPointMode, int numCom, bool per[3], int cellDims[3], long cellOffset[3], long cellComponentOffset, float *cellData, int pointDims[3], long pointOffset[3], long pointComponentOffset, float *pointData, float ps, float dp)
 {
 	mMode = cellToPointMode;
 	mNc = numCom;
@@ -865,7 +1269,7 @@ void iGridDataHelper::TransformToPointData3(int cellToPointMode, int numCom, boo
 }
 
 
-void iGridDataHelper::ShiftData(int numCom, int dim, int dn, int dataDims[3], float *data, float *buf)
+void iUniformGridDataHelper::ShiftData(int numCom, int dim, int dn, int dataDims[3], float *data, float *buf)
 {
 	mNc = numCom;
 	mDims2 = dataDims;
@@ -878,7 +1282,7 @@ void iGridDataHelper::ShiftData(int numCom, int dim, int dn, int dataDims[3], fl
 }
 
 
-int iGridDataHelper::ExecuteStep(int step, iParallel::ProcessorInfo &p)
+int iUniformGridDataHelper::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 {
 	switch(step)
 	{
@@ -918,7 +1322,7 @@ int iGridDataHelper::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 }
 
 
-void iGridDataHelper::ExecuteCopyArray(iParallel::ProcessorInfo &p)
+void iUniformGridDataHelper::ExecuteCopyArray(iParallel::ProcessorInfo &p)
 {
 	long size = (long)mN1*(long)mN2*(long)mN3;
 	long ntot = mNc*size; 
@@ -978,7 +1382,7 @@ void iGridDataHelper::ExecuteCopyArray(iParallel::ProcessorInfo &p)
 //
 //  Fourier shift
 //
-void iGridDataHelper::ExecuteTransformToPointData1(iParallel::ProcessorInfo &p)
+void iUniformGridDataHelper::ExecuteTransformToPointData1(iParallel::ProcessorInfo &p)
 {
 	int i, j, k, jj, kk;
 	long lf;
@@ -1031,7 +1435,7 @@ void iGridDataHelper::ExecuteTransformToPointData1(iParallel::ProcessorInfo &p)
 //
 //  Limit with the cell data
 //
-void iGridDataHelper::ExecuteTransformToPointData2(iParallel::ProcessorInfo &p)
+void iUniformGridDataHelper::ExecuteTransformToPointData2(iParallel::ProcessorInfo &p)
 {
 	int i, j, k, m;
 	long lim, ljm, lkm, lip, ljp, lkp;  // cell offSets
@@ -1127,7 +1531,7 @@ void iGridDataHelper::ExecuteTransformToPointData2(iParallel::ProcessorInfo &p)
 //
 //  Projection
 //
-void iGridDataHelper::ExecuteTransformToPointData3(iParallel::ProcessorInfo &p)
+void iUniformGridDataHelper::ExecuteTransformToPointData3(iParallel::ProcessorInfo &p)
 {
 	int i, j, k, n, ii, jj;
 	long lim, ljm, lkm, lip, ljp, lkp;  // cell offSets
@@ -1268,7 +1672,7 @@ void iGridDataHelper::ExecuteTransformToPointData3(iParallel::ProcessorInfo &p)
 //
 //  Shift an nc-component vertical array (treat the mesh array as nvar 1-component vertical arrays)
 //
-void iGridDataHelper::ExecuteShiftData(iParallel::ProcessorInfo &p)
+void iUniformGridDataHelper::ExecuteShiftData(iParallel::ProcessorInfo &p)
 {
 	int n, l1, l2, l, lold, add1;
 	int d1 = 0, d2 = 0;
@@ -1331,408 +1735,6 @@ void iGridDataHelper::ExecuteShiftData(iParallel::ProcessorInfo &p)
 }
 
 
-//
-//  ********************************************************************
-//
-//  iUniformVectorsDataSubject class
-//
-//  ********************************************************************
-//
-iUniformVectorsDataSubject::iUniformVectorsDataSubject(iDataReader *r) : iGridDataSubject(r,iDataType::UniformVectors())
-{
-}
-
-
-void iUniformVectorsDataSubject::SetIndicies(int &nvar, int &ncomp)
-{
-	nvar = 3;
-	ncomp = 3;
-}
-
-
-void iUniformVectorsDataSubject::AssignBinData(int n, vtkIdType ntot, float *d)
-{
-	vtkIdType l;
-	for(l=0; l<ntot; l++) mBuffer[n+3*l] = d[l];
-}
-
-
-void iUniformVectorsDataSubject::AssignTxtData(int nvar, vtkIdType ntot, vtkIdType ind, float *f)
-{
-	int n;
-	for(n=0; n<3; n++) mBuffer[n+3*ind] = f[n];
-}
-
-
-void iUniformVectorsDataSubject::SetArraysAndComponents()
-{
-	mNumArrays = 1;
-	mNumComponents = 3;
-	this->GetLimits()->AddVar(0);
-	if(mAdjustableLimits)
-	{
-		this->GetLimits()->SetMin(0,0.0f);
-		this->GetLimits()->SetMax(0,sqrt(mVarMax[0]*mVarMax[0]+mVarMax[1]*mVarMax[1]+mVarMax[2]*mVarMax[2]));
-	}
-}
-
-
-void iUniformVectorsDataSubject::AttachBuffer()
-{
-	//
-	//  Attach the actual data
-	//
-	vtkIdType size = (vtkIdType)mDims[0]*mDims[1]*mDims[2]*3;
-	vtkFloatArray *array = vtkFloatArray::New(); IERROR_ASSERT_NULL_POINTER(array);
-	array->SetNumberOfComponents(3);
-	array->SetArray(mBuffer,size,1);
-	array->SetName("Vectors");
-	mData->GetPointData()->SetVectors(array);
-	array->Delete();
-}
-
-
-iDataLimits* iUniformVectorsDataSubject::CreateLimits() const
-{
-	return new iDataLimits(this,1,"Vector");
-}
-
-
-//
-//  ********************************************************************
-//
-//  iUniformTensorsDataSubject class
-//
-//  ********************************************************************
-//
-iUniformTensorsDataSubject::iUniformTensorsDataSubject(iDataReader *r) : iGridDataSubject(r,iDataType::UniformTensors())
-{
-}
-
-
-void iUniformTensorsDataSubject::SetIndicies(int &nvar, int &ncomp)
-{
-	nvar = 9;
-	ncomp = 6;
-}
-
-
-void iUniformTensorsDataSubject::AssignBinData(int n, vtkIdType ntot, float *d)
-{
-	int noff1, noff2;
-	vtkIdType l;
-
-	switch (n)
-	{
-	case 0: { noff1 = 0; noff2 = -1; break; }
-	case 1: { noff1 = 1; noff2 = 3; break; }
-	case 2: { noff1 = 2; noff2 = 6; break; }
-	case 3: { noff1 = 4; noff2 = -1; break; }
-	case 4: { noff1 = 5; noff2 = 7; break; }
-	case 5: { noff1 = 8; noff2 = -1; break; }
-	default: 
-		{
-			noff1 = 0; noff2 = -1;
-			IERROR_REPORT_ERROR("Bug detected.");
-		}
-	}
-
-	for(l=0; l<ntot; l++) mBuffer[noff1+9*l] = d[l];
-	if(noff2 > 0) for(l=0; l<ntot; l++) mBuffer[noff2+9*l] = d[l];
-}
-
-
-void iUniformTensorsDataSubject::AssignTxtData(int nvar, vtkIdType ntot, vtkIdType ind, float *f)
-{
-	//
-	//  Fill in 3x3 tensor with 6 components
-	//
-	mBuffer[0+9*ind] = f[0];
-	mBuffer[1+9*ind] = f[1];
-	mBuffer[2+9*ind] = f[2];
-	mBuffer[3+9*ind] = f[1];
-	mBuffer[4+9*ind] = f[3];
-	mBuffer[5+9*ind] = f[4];
-	mBuffer[6+9*ind] = f[2];
-	mBuffer[7+9*ind] = f[4];
-	mBuffer[8+9*ind] = f[5];
-}
-
-
-void iUniformTensorsDataSubject::SetArraysAndComponents()
-{
-	mNumArrays = 1;
-	mNumComponents = 9;
-	this->GetLimits()->AddVar(0);
-	if(mAdjustableLimits)
-	{
-		this->GetLimits()->SetMin(0,0.0f);
-		this->GetLimits()->SetMax(0,sqrt(mVarMax[0]*mVarMax[0]+mVarMax[1]*mVarMax[1]+mVarMax[2]*mVarMax[2]+mVarMax[3]*mVarMax[3]+mVarMax[4]*mVarMax[4]+mVarMax[5]*mVarMax[5]+mVarMax[6]*mVarMax[6]+mVarMax[7]*mVarMax[7]+mVarMax[8]*mVarMax[8]));
-	}
-}
-
-
-void iUniformTensorsDataSubject::AttachBuffer()
-{
-	//
-	//  Attach the actual data
-	//
-	vtkIdType size = (vtkIdType)mDims[0]*mDims[1]*mDims[2]*9;
-	vtkFloatArray *array = vtkFloatArray::New(); IERROR_ASSERT_NULL_POINTER(array);
-	array->SetNumberOfComponents(9);
-	array->SetArray(mBuffer,size,1);
-	array->SetName("Tensors");
-	mData->GetPointData()->SetTensors(array);
-	array->Delete();
-}
-
-
-iDataLimits* iUniformTensorsDataSubject::CreateLimits() const
-{
-	return new iDataLimits(this,1,"Tensor");
-}
-
-
-//
-//  ********************************************************************
-//
-//  iUniformScalarsDataSubject class
-//
-//  ********************************************************************
-//
-//  Helper class for parallel executions
-//
-class iUniformScalarsDataHelper : protected iParallelWorker
-{
-
-public:
-
-	iUniformScalarsDataHelper(iUniformScalarsDataSubject *subject);
-
-	void OperateOnData1(int nvar, int dims[3], iExpressionParser *calc, bool doVector, float ps, float dp);
-	void OperateOnData2(int nvar, int dims[3], float *fMin, float *fMax, bool &overflow, float ps, float dp);
-
-protected:
-
-	virtual int ExecuteStep(int step, iParallel::ProcessorInfo &p);
-
-	void ExecuteOperateOnData1(iParallel::ProcessorInfo &p);
-	void ExecuteOperateOnData2(iParallel::ProcessorInfo &p);
-
-	iUniformScalarsDataSubject *mSubject;
-	iProgressEventObserver *mObserver;
-	iExpressionParser *mCalculator;
-
-	int mNumVars, mNumProcs, *mDims;
-
-	iBuffer<float> mMin, mMax;
-	float mProgStart, mProgStep;
-
-	bool mDoVector, mOverflow;
-};
-
-
-//
-//  Main class
-//
-iUniformScalarsDataSubject::iUniformScalarsDataSubject(iDataReader *r, iUniformVectorsDataSubject *vs) : iGridDataSubject(r,iDataType::UniformScalars())
-{
-	mVectorFieldSubject = vs;
-
-	mCalculatorOutputVariable = 0;
-//	mCalculatorFunction = "";
-
-	mCalculator = new iExpressionParser; IERROR_ASSERT_NULL_POINTER(mCalculator);
-	mHelper2 = new iUniformScalarsDataHelper(this); IERROR_ASSERT_NULL_POINTER(mHelper2);
-}
-
-
-iUniformScalarsDataSubject::~iUniformScalarsDataSubject()
-{
-	delete mHelper2;
-	delete mCalculator;
-}
-
-
-void iUniformScalarsDataSubject::SetIndicies(int &nvar, int &ncomp)
-{
-	//
-	//  Try to set all the records from the file. DataLimits will either expand to accommodate 
-	//  all of them or limit the allowed number to the number of listed records.
-	//
-	this->GetLimits()->BlockNotifications(true);
-	this->GetLimits()->AssignVars(nvar);
-	this->GetLimits()->BlockNotifications(false);
-	ncomp = nvar = this->GetLimits()->GetNumVars();
-}
-
-
-void iUniformScalarsDataSubject::AssignBinData(int n, vtkIdType ntot, float *d)
-{
-	memcpy((void *)(mBuffer+n*ntot),(void *)d,ntot*sizeof(float));
-}
-
-
-void iUniformScalarsDataSubject::AssignTxtData(int nvar, vtkIdType ntot, vtkIdType ind, float *f)
-{
-	int n;
-
-	for(n=0; n<nvar; n++) mBuffer[ind+n*ntot] = f[n];
-}
-
-
-void iUniformScalarsDataSubject::AttachBuffer()
-{
-	//
-	//  Attach the actual data
-	//
-	int i;
-	vtkIdType size = (vtkIdType)mDims[0]*mDims[1]*mDims[2];
-	vtkFloatArray *array;
-	iString name = "Scalars";
-	for(i=0; i<mNumVars; i++)
-	{
-		array = vtkFloatArray::New(); IERROR_ASSERT_NULL_POINTER(array);
-		array->SetNumberOfComponents(1);
-		array->SetArray(mBuffer+i*size,size,1);
-		array->SetName((name+iString::FromNumber(i)).ToCharPointer());
-		mData->GetPointData()->AddArray(array);
-		array->Delete();
-	}
-
-	this->OperateOnData();
-}
-
-
-void iUniformScalarsDataSubject::SetArraysAndComponents()
-{
-	mNumArrays = mNumVars;
-	mNumComponents = 1;
-	this->GetLimits()->AssignVars(mNumArrays);
-	//
-	//  Limits are set after the data are operated upon
-	//
-}
-
-
-iDataLimits* iUniformScalarsDataSubject::CreateLimits() const
-{
-	return new iDataLimits(this,3,"Variable");
-}
-
-
-void iUniformScalarsDataSubject::SetCalculatorOutputVariable(int n)
-{
-	if(n>=0 && n<this->GetLimits()->GetNumVars()) 
-	{
-		mCalculatorOutputVariable = n;
-		this->GetLimits()->RestoreNames();
-	}
-}
-
-
-void iUniformScalarsDataSubject::SetCalculatorFunction(const iString &s)
-{
-	mCalculatorFunction = s;
-	if(s.IsEmpty()) this->GetLimits()->RestoreNames();
-}
-
-
-void iUniformScalarsDataSubject::OperateOnData()
-{
-	int n;
-	float fMin = iMath::_LargeFloat, fMax = -iMath::_LargeFloat, f = 0.0;
-
-	int nvar = this->GetLimits()->GetNumVars();
-
-	iDataLimits *slim = this->GetLimits();
-	iDataLimits *vlim = mVectorFieldSubject->GetLimits();
-	slim->BlockNotifications(true);
-
-	//
-	//  Do the array function first
-	//
-	if(mCalculatorOutputVariable>=0 && mCalculatorOutputVariable<nvar && !mCalculatorFunction.IsEmpty())
-	{
-		this->GetObserver()->Started(iProgressEventObserver::_Operating);
-		this->GetObserver()->SetProgress(0.0);
-
-		mCalculator->SetFunction(mCalculatorFunction);
-
-		bool doVector = false;
-		if(mVectorFieldSubject->IsThereData() && this->GetDim(0)==mVectorFieldSubject->GetDim(0) && this->GetDim(1)==mVectorFieldSubject->GetDim(1) && this->GetDim(2)==mVectorFieldSubject->GetDim(2)) doVector = true;
-
-		mHelper2->OperateOnData1(nvar,mDims,mCalculator,doVector,0.0,1.0);
-	}
-
-	this->GetObserver()->Started(iProgressEventObserver::_Formatting);
-	this->GetObserver()->SetProgress(0.0);
-
-	//
-	//  Format everything in parallel
-	//
-	mVarMin.Extend(nvar);
-	mVarMax.Extend(nvar);
-	mHelper2->OperateOnData2(nvar,mDims,mVarMin,mVarMax,mOverflow,0.0,1.0);
-
-#ifdef I_CHECK2
-	//
-	//  Format everything serially
-	//
-	vtkIdType lMin, lMax, size = (vtkIdType)mDims[0]*mDims[1]*mDims[2];
-	for(n=0; n<nvar; n++)
-	{
-		fMin = iMath::_LargeFloat;
-		fMax = -iMath::_LargeFloat;
-		long l;
-		float *p = mBuffer + n*size;
-		for(l=0; l<size; l++)
-		{
-			f = p[l];
-			if(f > fMax)
-			{
-				lMax = l;
-				fMax = f;
-			}
-			if(f < fMin)
-			{
-				lMin = l;
-				fMin = f;
-			}
-		}
-		if(fabs(mVarMin[n]-fMin)>iMath::_FloatRes || fabs(mVarMax[n]-fMax)>iMath::_FloatRes)
-		{
-			IERROR_REPORT_BUG;
-		}
-	}
-#endif
-
-	this->GetObserver()->SetProgress(1.0);
-	this->GetObserver()->Finished();
-
-	slim->BlockNotifications(false);
-
-	//
-	//  Correct limits in log stretching
-	//
-	if(mAdjustableLimits)
-	{
-		for(n=0; n<nvar; n++)
-		{
-			fMin = mVarMin[n];
-			fMax = mVarMax[n];
-			if(slim->GetStretch(n) == 1)
-			{
-				fMin = 0.1*floor(10.0*fMin);
-				fMax = 0.1*floor(1+10.0*fMax);
-			}
-			slim->SetMin(n,fMin);
-			slim->SetMax(n,fMax);
-		}
-	}
-}
-
-
 //
 //  Helper class
 //
@@ -1833,9 +1835,8 @@ void iUniformScalarsDataHelper::ExecuteOperateOnData1(iParallel::ProcessorInfo &
 	if(arr1==0 || (mDoVector && arr2==0)) return;
 
 	long size = (long)mDims[0]*mDims[1]*mDims[2];
-	long l, loff = mSubject->GetCalculatorOutputVariable()*size;
-	int n;
-	long kbeg, kend, kstp;
+	int n, nout = mSubject->GetCalculatorOutputVariable();
+	long l, kbeg, kend, kstp;
 	iParallel::SplitRange(p,size,kbeg,kend,kstp);
 
 	float progScale = mProgStep/kstp;
@@ -1850,7 +1851,7 @@ void iUniformScalarsDataHelper::ExecuteOperateOnData1(iParallel::ProcessorInfo &
 		for(n=0; n<mNumVars; n++)
 		{
 			arName[3] = (char)((int)'1'+n);
-			mCalculator->SetScalarVariableValue(arName,arr1[n*size+l]);
+			mCalculator->SetScalarVariableValue(arName,arr1[n+mNumVars*l]);
 		}
 		if(mDoVector)
 		{
@@ -1861,7 +1862,7 @@ void iUniformScalarsDataHelper::ExecuteOperateOnData1(iParallel::ProcessorInfo &
 			mCalculator->SetVectorVariableValue("Vector",0.0,0.0,0.0);
 		}
 		
-		if(mCalculator->GetScalarResult(res)) arr1[loff+l] = res;
+		if(mCalculator->GetScalarResult(res)) arr1[nout+mNumVars*l] = res;
 	}
 }
 
@@ -1878,11 +1879,11 @@ void iUniformScalarsDataHelper::ExecuteOperateOnData2(iParallel::ProcessorInfo &
 	//
 	iDataLimits *lim = mSubject->GetLimits();
 
-	long l;
+	long l, larr;
 	int n;
 
-	float *arr1, *arr0 = mSubject->GetDataPointer();
-	if(arr0 == 0) return;
+	float *arr1 = mSubject->GetDataPointer();
+	if(arr1 == 0) return;
 
 	float progScale = mProgStep/(mNumVars*kstp);
 
@@ -1890,15 +1891,15 @@ void iUniformScalarsDataHelper::ExecuteOperateOnData2(iParallel::ProcessorInfo &
 	{
 		fMin = iMath::_LargeFloat;
 		fMax = -iMath::_LargeFloat;
-		arr1 = arr0 + n*size;
 
-		for(l=kbeg; l<kend; l++)
+		for(larr=kbeg; larr<kend; larr++)
 		{
-			if(l%10000==0 && mObserver!=0)
+			if(larr%10000==0 && mObserver!=0)
 			{
-				if(this->IsMaster(p)) mObserver->SetProgress(mProgStart+progScale*(l-kbeg+n*kstp));
+				if(this->IsMaster(p)) mObserver->SetProgress(mProgStart+progScale*(larr-kbeg+n*kstp));
 				if(mObserver->IsAborted()) return;
 			}
+			l = n + mNumVars*larr;
 			if(arr1[l] < -iMath::_LargeFloat)
 			{
 				mOverflow = true;
@@ -1925,7 +1926,7 @@ void iUniformScalarsDataHelper::ExecuteOperateOnData2(iParallel::ProcessorInfo &
 //
 //  Two helper functions
 //
-void iGridDataSubject::GetCICInterpolation(bool periodic[3], int dims[3], double org[3], double spa[3], float pos[3], int ijk1[3], int ijk2[3], double d1[3], double d2[3])
+void iUniformGridDataSubject::GetCICInterpolation(bool periodic[3], int dims[3], double org[3], double spa[3], float pos[3], int ijk1[3], int ijk2[3], double d1[3], double d2[3])
 {
 	int i;
 	for(i=0; i<3; i++)
@@ -1960,7 +1961,7 @@ void iGridDataSubject::GetCICInterpolation(bool periodic[3], int dims[3], double
 }
 
 
-void iGridDataSubject::GetCICInterpolation(bool periodic[3], int dims[3], double org[3], double spa[3], double pos[3], int ijk1[3], int ijk2[3], double d1[3], double d2[3])
+void iUniformGridDataSubject::GetCICInterpolation(bool periodic[3], int dims[3], double org[3], double spa[3], double pos[3], int ijk1[3], int ijk2[3], double d1[3], double d2[3])
 {
 	int i;
 	for(i=0; i<3; i++)
