@@ -37,11 +37,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iclipplane.h"
 #include "icolorbars.h"
 #include "icontrolmodule.h"
-#include "icrosssectionviewobject.h"
+#include "icrosssectionviewsubject.h"
 #include "icubeaxesactor.h"
 #include "idata.h"
 #include "idatahandler.h"
 #include "idatareader.h"
+#include "iedition.h"
 #include "ierror.h"
 #include "ierrorstatus.h"
 #include "ieventobserver.h"
@@ -52,26 +53,28 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ikeyboardinteractorstyle.h"
 #include "ilegend.h"
 #include "ilightkit.h"
-#include "imarkerviewobject.h"
+#include "imarker.h"
+#include "imarkerfamily.h"
 #include "imath.h"
 #include "imeasuringbox.h"
 #include "imeasuringboxinteractorstyle.h"
-#include "irendertool.h"
 #include "ipalette.h"
 #include "iparallelmanager.h"
-#include "iparticlesviewobject.h"
+#include "iparticlesviewsubject.h"
 #include "ipicker.h"
 #include "ipointglyph.h"
 #include "iposition.h"
-#include "ishell.h"
-#include "isurfaceviewobject.h"
+#include "irendertool.h"
 #include "iruler.h"
+#include "ishell.h"
+#include "isurfaceviewsubject.h"
 #include "ishellfactory.h"
-#include "itensorfieldviewobject.h"
+#include "itensorfieldviewsubject.h"
 #include "itextactor.h"
+#include "ivectorfieldviewsubject.h"
+#include "iviewobject.h"
 #include "iviewobjectfamily.h"
-#include "ivectorfieldviewobject.h"
-#include "ivolumeviewobject.h"
+#include "ivolumeviewsubject.h"
 #include "iwriter.h"
 
 #include <vtkActor2D.h>
@@ -108,8 +111,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //  Templates
 //
 #include "iarraytemplate.h"
-#include "ifamilytemplate.h"
-#include "iviewobjectfamilytemplate.h"
+#include "iviewfamilytemplate.h"
 
 
 using namespace iParameter;
@@ -134,7 +136,7 @@ IOBJECT_DEFINE_KEY(iViewModule,ClipPlane,cp,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,ClipPlaneDirection,cpd,Float,3);
 IOBJECT_DEFINE_KEY(iViewModule,ClipPlaneDistance,cpl,Float,1);
 IOBJECT_DEFINE_KEY(iViewModule,DumpImage,di,Bool,1);
-IOBJECT_DEFINE_KEY(iViewModule,FontSize,fs,Int,1);
+IOBJECT_DEFINE_KEY(iViewModule,FontScale,fs,Int,1);
 IOBJECT_DEFINE_KEY(iViewModule,FontType,ft,Int,1);
 IOBJECT_DEFINE_KEY(iViewModule,GlassClipPlane,gcp,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,OpenGLCoordinates,glc,Bool,1);
@@ -175,6 +177,14 @@ IOBJECT_DEFINE_KEY(iViewModule,StereoType,st,Int,1);
 IOBJECT_DEFINE_KEY(iViewModule,WindowNumber,wn,Int,1);
 
 IOBJECT_DEFINE_KEY(iViewModule,JustifyLabelLeft,-lj,Bool,1);
+IOBJECT_DEFINE_KEY(iViewModule,FontSize,-fsize,Int,1);  // for backward compatibility, read-only
+
+
+#define IVIEWMODULE_DEFINE_VIEWSUBJECT(_name_) \
+i##_name_##ViewSubject* iViewModule::Get##_name_##ViewSubject(int n) const \
+{ \
+	return (i##_name_##ViewSubject*)((n==-1)?mViewObjectFamilies[_ObjectType##_name_]->GetCurrentMember()->GetViewSubject():mViewObjectFamilies[_ObjectType##_name_]->GetMember(n)->GetViewSubject()); \
+} // we can do C-style cast here since it is guaranteed to be correct
 
 
 //
@@ -182,15 +192,31 @@ IOBJECT_DEFINE_KEY(iViewModule,JustifyLabelLeft,-lj,Bool,1);
 //
 iViewModule* iViewModule::New(iControlModule *cm)
 {
-	return iExtensionFactory::CreateViewModule(cm);
+	int i;
+
+	iViewModule *tmp = new iViewModule(cm); IERROR_ASSERT(tmp);
+	iExtensionFactory::InstallExtensions(tmp);
+
+	iViewObjectFamily *fam;
+	for(i=0; i<tmp->mExtensions.Size(); i++)
+	{
+		while((fam = ((iViewModuleExtension *)tmp->mExtensions[i])->AddNewViewObjectFamily()) != 0)
+		{
+			tmp->mViewObjectFamilies.Add(fam);
+		}
+	}
+
+	iEdition::ApplySettings(tmp,iViewModule::Type());
+
+	return tmp;
 }
 
 
-iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
+iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm), mViewObjectFamilies(0)
 {
 	int i;
 	
-	mFontSize = 16;
+	mFontScale = 0;
 	mFontType = _TextTypeBitmap;
 	mBoxType = -1; // needs to be reset
 	mImageMagnification = 1;
@@ -229,18 +255,29 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	//  Create render view
 	//
 	mRenderTool = 0; // must have this zeroing - who knows what happens inside the call to iExtensionFactory::CreateRenderTool
-	mRenderTool = iExtensionFactory::CreateRenderTool(this); IERROR_ASSERT_NULL_POINTER(mRenderTool);
+	mRenderTool = iExtensionFactory::CreateRenderTool(this); IERROR_ASSERT(mRenderTool);
+
+	//
+	//  Attach to Interactor Observer
+	//
+	mRenderTool->GetInteractor()->AddObserver(vtkCommand::LeftButtonPressEvent,this->GetControlModule()->GetInteractorObserver());
+	mRenderTool->GetInteractor()->AddObserver(vtkCommand::LeftButtonReleaseEvent,this->GetControlModule()->GetInteractorObserver());
+	mRenderTool->GetInteractor()->AddObserver(vtkCommand::MiddleButtonPressEvent,this->GetControlModule()->GetInteractorObserver());
+	mRenderTool->GetInteractor()->AddObserver(vtkCommand::MiddleButtonReleaseEvent,this->GetControlModule()->GetInteractorObserver());
+	mRenderTool->GetInteractor()->AddObserver(vtkCommand::RightButtonPressEvent,this->GetControlModule()->GetInteractorObserver());
+	mRenderTool->GetInteractor()->AddObserver(vtkCommand::RightButtonReleaseEvent,this->GetControlModule()->GetInteractorObserver());
+	mRenderTool->GetInteractor()->AddObserver(vtkCommand::MouseMoveEvent,this->GetControlModule()->GetInteractorObserver());
 
 	//
 	//  File reader, gateway, volume converter
 	//
-	mDataReader = iDataReader::New(this); IERROR_ASSERT_NULL_POINTER(mDataReader);
-	mAnimator = iAnimator::New(this); IERROR_ASSERT_NULL_POINTER(mAnimator);
+	mDataReader = iDataReader::New(this); IERROR_ASSERT(mDataReader);
+	mAnimator = iAnimator::New(this); IERROR_ASSERT(mAnimator);
 	
 	//
 	//  Image writer
 	//
-	mWriter = iWriter::New(this); IERROR_ASSERT_NULL_POINTER(mWriter); 
+	mWriter = iWriter::New(this); IERROR_ASSERT(mWriter); 
 
 	//
 	//  Bounding boxes
@@ -253,10 +290,10 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	static float x[8][3]={{-1,-1,-1}, {1,-1,-1}, {1,1,-1}, {-1,1,-1}, {-1,-1,1}, {1,-1,1}, {1,1,1}, {-1,1,1}};
 	static vtkIdType lns[12][2]={{0,1}, {1,2}, {2,3}, {3,0}, {0,4}, {1,5}, {2,6}, {3,7}, {4,5}, {5,6}, {6,7}, {7,4}};
 
-	vtkPolyData *pd = vtkPolyData::New(); IERROR_ASSERT_NULL_POINTER(pd);
-	vtkPoints *points = vtkPoints::New(VTK_FLOAT); IERROR_ASSERT_NULL_POINTER(points);
-	vtkCellArray *polys = vtkCellArray::New(); IERROR_ASSERT_NULL_POINTER(polys);
-	vtkFloatArray *scalars = vtkFloatArray::New(); IERROR_ASSERT_NULL_POINTER(scalars);
+	vtkPolyData *pd = vtkPolyData::New(); IERROR_ASSERT(pd);
+	vtkPoints *points = vtkPoints::New(VTK_FLOAT); IERROR_ASSERT(points);
+	vtkCellArray *polys = vtkCellArray::New(); IERROR_ASSERT(polys);
+	vtkFloatArray *scalars = vtkFloatArray::New(); IERROR_ASSERT(scalars);
 	//
 	// Load the point, cell, and data attributes.
 	//
@@ -279,7 +316,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	//
 	//  Configure the actor
 	//
-	mBox1Actor = iActor::New(); IERROR_ASSERT_NULL_POINTER(mBox1Actor);
+	mBox1Actor = iActor::New(); IERROR_ASSERT(mBox1Actor);
 	mBox1Actor->PickableOff();
 	mBox1Actor->VisibilityOff();
 //	mBox1Actor->SetScalarRange(0,1);
@@ -300,9 +337,9 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	float diam = 0.02;
 	for(i=0; i<12; i++) 
 	{
-		actor[i] = iActor::New(); IERROR_ASSERT_NULL_POINTER(actor[i]);
+		actor[i] = iActor::New(); IERROR_ASSERT(actor[i]);
 		actor[i]->PickableOff();
-		cs = vtkCylinderSource::New(); IERROR_ASSERT_NULL_POINTER(cs);
+		cs = vtkCylinderSource::New(); IERROR_ASSERT(cs);
 		cs->SetResolution(6);
 		cs->SetHeight(2.0+2.0*diam);
 		cs->SetRadius(diam);
@@ -336,7 +373,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	actor[10]->SetPosition(0.0, 1.0,-1.0);
 	actor[11]->SetPosition(0.0, 1.0, 1.0);
 	
-	mBox2Actor = iActorCollection::New(); IERROR_ASSERT_NULL_POINTER(mBox2Actor);
+	mBox2Actor = iActorCollection::New(); IERROR_ASSERT(mBox2Actor);
 	for(i=0; i<12; i++) 
 	{
 		actor[i]->GetProperty()->SetAmbient(0.2);
@@ -355,9 +392,9 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	vtkArrowSource *as;
 	for(i=0; i<3; i++) 
 	{
-		actor[i] = iActor::New(); IERROR_ASSERT_NULL_POINTER(actor[i]);
+		actor[i] = iActor::New(); IERROR_ASSERT(actor[i]);
 		actor[i]->PickableOff();
-		as = vtkArrowSource::New(); IERROR_ASSERT_NULL_POINTER(as);
+		as = vtkArrowSource::New(); IERROR_ASSERT(as);
 		as->SetShaftResolution(6);
 		as->SetTipResolution(6);
 		as->SetTipLength(0.15);
@@ -372,9 +409,9 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	diam *= 0.75;
 	for(i=3; i<12; i++) 
 	{
-		actor[i] = iActor::New(); IERROR_ASSERT_NULL_POINTER(actor[i]);
+		actor[i] = iActor::New(); IERROR_ASSERT(actor[i]);
 		actor[i]->PickableOff();
-		cs = vtkCylinderSource::New(); IERROR_ASSERT_NULL_POINTER(cs);
+		cs = vtkCylinderSource::New(); IERROR_ASSERT(cs);
 		cs->SetResolution(6);
 		cs->SetHeight(2.0+2.0*diam);
 		cs->SetRadius(diam);
@@ -416,7 +453,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	actor[10]->SetPosition(0.0,-1.0, 1.0);
 	actor[11]->SetPosition(0.0, 1.0, 1.0);
 	
-	mBox3Actor = iActorCollection::New(); IERROR_ASSERT_NULL_POINTER(mBox3Actor);
+	mBox3Actor = iActorCollection::New(); IERROR_ASSERT(mBox3Actor);
 	for(i=0; i<12; i++) 
 	{
 		actor[i]->GetProperty()->SetAmbient(0.2);
@@ -428,7 +465,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	}
 	mBox3Actor->SetVisibility(false);
 	
-	mBox3AxesLabels = iCubeAxesActor::New(mRenderTool); IERROR_ASSERT_NULL_POINTER(mBox3AxesLabels);
+	mBox3AxesLabels = iCubeAxesActor::New(mRenderTool); IERROR_ASSERT(mBox3AxesLabels);
 	mBox3AxesLabels->PickableOff();
 	mBox3AxesLabels->VisibilityOff();
 	mBox3AxesLabels->SetCamera(mRenderTool->GetCamera());
@@ -444,7 +481,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	//
 	//  Ruler actor
 	//
-	mRulerActor = iRuler::New(this); IERROR_ASSERT_NULL_POINTER(mRulerActor);
+	mRulerActor = iRuler::New(this); IERROR_ASSERT(mRulerActor);
 	mRulerActor->VisibilityOff();
 	mRulerActor->PickableOff();
 	
@@ -453,7 +490,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	//
 	//  Text label actors
 	//
-	mLabelActor = iTextActor::New(mRenderTool); IERROR_ASSERT_NULL_POINTER(mLabelActor);
+	mLabelActor = iTextActor::New(mRenderTool); IERROR_ASSERT(mLabelActor);
 	mLabelActor->SetText("");
 	mLabelActor->SetBold(true);
 	mLabelActor->SetHJustification(_TextJustRight);
@@ -467,36 +504,36 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	//
 	//  Measuring box
 	//
-	mMeasuringBox = iMeasuringBox::New(this); IERROR_ASSERT_NULL_POINTER(mMeasuringBox);
+	mMeasuringBox = iMeasuringBox::New(this); IERROR_ASSERT(mMeasuringBox);
 	mMeasuringBox->VisibilityOff();
 	mRenderTool->AddObject(mMeasuringBox);
 
-	mInteractorStyleMeasuringBox = iMeasuringBoxInteractorStyle::New(); IERROR_ASSERT_NULL_POINTER(mInteractorStyleMeasuringBox);
+	mInteractorStyleMeasuringBox = iMeasuringBoxInteractorStyle::New(); IERROR_ASSERT(mInteractorStyleMeasuringBox);
 	mInteractorStyleMeasuringBox->SetMeasuringBox(mMeasuringBox);
 
 	//
 	//  Color bars
 	//
-	mColorBars = iColorBars::New(this); IERROR_ASSERT_NULL_POINTER(mColorBars);
+	mColorBars = iColorBars::New(this); IERROR_ASSERT(mColorBars);
 	mColorBars->PickableOff();
 	mRenderTool->AddObject(mColorBars);
 
 	//
 	//  Clipping plane
 	//
-	mClipPlane = iClipPlane::New(this); IERROR_ASSERT_NULL_POINTER(mClipPlane);
+	mClipPlane = iClipPlane::New(this); IERROR_ASSERT(mClipPlane);
 
 	//
 	//  Progress callback functions
 	//
-	mObsProgress = iProgressEventObserver::New(this); IERROR_ASSERT_NULL_POINTER(mObsProgress);
+	mObsProgress = iProgressEventObserver::New(this); IERROR_ASSERT(mObsProgress);
 	
-	mObsAbortRender = iAbortRenderEventObserver::New(this); IERROR_ASSERT_NULL_POINTER(mObsAbortRender);
+	mObsAbortRender = iAbortRenderEventObserver::New(this); IERROR_ASSERT(mObsAbortRender);
 	mRenderTool->AddObserver(vtkCommand::AbortCheckEvent,mObsAbortRender);
 	mRenderTool->AddObserver(vtkCommand::StartEvent,mObsAbortRender);
 	mRenderTool->AddObserver(vtkCommand::EndEvent,mObsAbortRender);
 
-	mObsSlaveAbortRender = iSlaveAbortRenderEventObserver::New(mObsAbortRender); IERROR_ASSERT_NULL_POINTER(mObsSlaveAbortRender);
+	mObsSlaveAbortRender = iSlaveAbortRenderEventObserver::New(mObsAbortRender); IERROR_ASSERT(mObsSlaveAbortRender);
 
 	//
 	//  Interactor styles
@@ -511,7 +548,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	mInteractorStyle[_InteractorStyleKeyboard] = iKeyboardInteractorStyle::New();
 //	mInteractorStyle[_InteractorStyleKeyboard] = vtkInteractorStyleUnicam::New();
 
-	for(i=0; i<__NumInteractorStyles; i++) IERROR_ASSERT_NULL_POINTER(mInteractorStyle[i]);
+	for(i=0; i<__NumInteractorStyles; i++) IERROR_ASSERT(mInteractorStyle[i]);
 
 	isf->SetAngleStepSize(0.1);
 	isf->SetMotionStepSize(0.001);
@@ -532,8 +569,8 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	diam = 0.2;
 	for(i=0; i<3; i++) 
 	{
-		actor[i] = iActor::New(); IERROR_ASSERT_NULL_POINTER(actor[i]);
-		as = vtkArrowSource::New(); IERROR_ASSERT_NULL_POINTER(as);
+		actor[i] = iActor::New(); IERROR_ASSERT(actor[i]);
+		as = vtkArrowSource::New(); IERROR_ASSERT(as);
 		as->SetShaftResolution(6);
 		as->SetTipResolution(18);
 		as->SetTipLength(0.5);
@@ -559,7 +596,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	actor[ 1]->SetPosition(0.0,0.0,0.0);
 	actor[ 2]->SetPosition(0.0,0.0,0.0);
 
-	mDebugActor = iActorCollection::New(); IERROR_ASSERT_NULL_POINTER(mDebugActor);
+	mDebugActor = iActorCollection::New(); IERROR_ASSERT(mDebugActor);
 	for(i=0; i<3; i++) 
 	{
 		mDebugActor->AddActor(actor[i]);
@@ -571,9 +608,9 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	//
 	// icon
 	//
-	mIconActor = vtkActor2D::New(); IERROR_ASSERT_NULL_POINTER(mIconActor);
-	vtkPolyDataMapper2D *mapper2D = vtkPolyDataMapper2D::New(); IERROR_ASSERT_NULL_POINTER(mapper2D);
-	vtkDiskSource *ds = vtkDiskSource::New(); IERROR_ASSERT_NULL_POINTER(ds);
+	mIconActor = vtkActor2D::New(); IERROR_ASSERT(mIconActor);
+	vtkPolyDataMapper2D *mapper2D = vtkPolyDataMapper2D::New(); IERROR_ASSERT(mapper2D);
+	vtkDiskSource *ds = vtkDiskSource::New(); IERROR_ASSERT(ds);
 
 	ds->SetInnerRadius(0.03);
 	ds->SetOuterRadius(0.07);
@@ -583,7 +620,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	ds->Update();
 	int npoi = ds->GetOutput()->GetPoints()->GetNumberOfPoints();
 	vtkFloatArray *mpoi;
-	mpoi = vtkFloatArray::New(); IERROR_ASSERT_NULL_POINTER(mpoi);
+	mpoi = vtkFloatArray::New(); IERROR_ASSERT(mpoi);
 	mpoi->SetNumberOfComponents(1);
 	mpoi->SetNumberOfTuples(npoi);
 	for(i=0; i<npoi; i++)
@@ -595,7 +632,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 
 	mapper2D->SetInput(ds->GetOutput());
 	ds->Delete();
-	vtkCoordinate *c = vtkCoordinate::New(); IERROR_ASSERT_NULL_POINTER(c);
+	vtkCoordinate *c = vtkCoordinate::New(); IERROR_ASSERT(c);
 	c->SetCoordinateSystemToView();
 	mapper2D->SetTransformCoordinate(c);
 	c->Delete();
@@ -616,7 +653,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	//
 	//  Picker
 	//
-	mPicker = iPicker::New(this); IERROR_ASSERT_NULL_POINTER(mPicker);
+	mPicker = iPicker::New(this); IERROR_ASSERT(mPicker);
 	mRenderTool->GetInteractor()->SetPicker(mPicker);
 
 	//
@@ -625,15 +662,15 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	mIsMarkerLegendOn = false;
 	mMarkerLegendPosition = 0;
 
-	mEventRecorder = iInteractorEventRecorder::New(); IERROR_ASSERT_NULL_POINTER(mEventRecorder);
+	mEventRecorder = iInteractorEventRecorder::New(); IERROR_ASSERT(mEventRecorder);
 	mEventRecorder->SetInteractor(mRenderTool->GetInteractor());
 	mEventRecorder->SetEnabled(1);
 
-	mObsRecord = iRecordEventObserver::New(this); IERROR_ASSERT_NULL_POINTER(mObsRecord);
+	mObsRecord = iRecordEventObserver::New(this); IERROR_ASSERT(mObsRecord);
 
 	for(i=0; i<__NumInteractorStyles; i++) mInteractorStyle[i]->AddObserver(vtkCommand::InteractionEvent,mObsRecord);
 
-	mMarkerPlacer = vtkPointWidget::New(); IERROR_ASSERT_NULL_POINTER(mMarkerPlacer);
+	mMarkerPlacer = vtkPointWidget::New(); IERROR_ASSERT(mMarkerPlacer);
 	mMarkerPlacer->XShadowsOn();
 	mMarkerPlacer->YShadowsOn();
 	mMarkerPlacer->ZShadowsOn();
@@ -646,7 +683,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	mMarkerPlacer->GetSelectedProperty()->SetLineWidth(2.0);
 	mMarkerPlacer->PlaceWidget(-1.0,1.0,-1.0,1.0,-1.0,1.0);
 
-	mObsMarker = iMarkerEventObserver::New(this); IERROR_ASSERT_NULL_POINTER(mObsMarker);
+	mObsMarker = iMarkerEventObserver::New(this); IERROR_ASSERT(mObsMarker);
 
 	mMarkerPlacer->AddObserver(vtkCommand::InteractionEvent,mObsMarker);
 
@@ -655,12 +692,12 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	//  markers cannot be positioned without the vtkPointWidgets, so the legend
 	//  is useless then too.
 	//
-	mMarkerLegend = iLegend::New(mRenderTool); IERROR_ASSERT_NULL_POINTER(mMarkerLegend);
+	mMarkerLegend = iLegend::New(mRenderTool); IERROR_ASSERT(mMarkerLegend);
 	this->SetMarkerLegendPosition(mMarkerLegendPosition);
 	mRenderTool->AddObject(mMarkerLegend);
 	mMarkerLegend->VisibilityOff();
 
-	mInteractorStyleCaption = iCaptionInteractorStyle::New(this); IERROR_ASSERT_NULL_POINTER(mInteractorStyleCaption);
+	mInteractorStyleCaption = iCaptionInteractorStyle::New(this); IERROR_ASSERT(mInteractorStyleCaption);
 
 	//
 	//  Image composer
@@ -668,21 +705,23 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	mImageComposer = 0;
 
 	//
-	//  iViewObjects
+	//  iViewSubjects
 	//
-	mFamSurface = iViewObjectFamily<iSurfaceViewObject>::New(this); IERROR_ASSERT_NULL_POINTER(mFamSurface);
-	mFamCrossSection = iViewObjectFamily<iCrossSectionViewObject>::New(this); IERROR_ASSERT_NULL_POINTER(mFamCrossSection);
-	mFamVolume = iViewObjectFamily<iVolumeViewObject>::New(this); IERROR_ASSERT_NULL_POINTER(mFamVolume);
-	mFamVectorField = iViewObjectFamily<iVectorFieldViewObject>::New(this); IERROR_ASSERT_NULL_POINTER(mFamVectorField);
-	mFamTensorField = iViewObjectFamily<iTensorFieldViewObject>::New(this); IERROR_ASSERT_NULL_POINTER(mFamTensorField);
-	mFamParticles = iViewObjectFamily<iParticlesViewObject>::New(this); IERROR_ASSERT_NULL_POINTER(mFamParticles);
+	mMarkerFamily = iMarkerFamily::New(this); IERROR_ASSERT(mMarkerFamily);
 
-	mFamMarker = iViewObjectFamily<iMarkerViewObject>::New(this); IERROR_ASSERT_NULL_POINTER(mFamMarker);
+	mViewObjectFamilies.Add(iViewObjectFamily::New(this,iCrossSectionViewSubject::Type(),false));
+	mViewObjectFamilies.Add(iViewObjectFamily::New(this,iParticlesViewSubject::Type(),true));
+	mViewObjectFamilies.Add(iViewObjectFamily::New(this,iSurfaceViewSubject::Type(),false));
+	mViewObjectFamilies.Add(iViewObjectFamily::New(this,iTensorFieldViewSubject::Type(),true));
+	mViewObjectFamilies.Add(iViewObjectFamily::New(this,iVectorFieldViewSubject::Type(),true));
+	mViewObjectFamilies.Add(iViewObjectFamily::New(this,iVolumeViewSubject::Type(),true));
+	
+	for(i=0; i<mViewObjectFamilies.Size(); i++) IERROR_ASSERT(mViewObjectFamilies[i]);
 
 	//
 	//  Timer
 	//
-	mUpdateTimer = vtkTimerLog::New(); IERROR_ASSERT_NULL_POINTER(mUpdateTimer);
+	mUpdateTimer = vtkTimerLog::New(); IERROR_ASSERT(mUpdateTimer);
 	mUpdateTime = 0.0f;
 
 	//
@@ -701,7 +740,7 @@ iViewModule::iViewModule(iControlModule *cm) : iControlModuleComponent(cm)
 	//
 	//  Set the font size
 	//
-	this->SetFontSize(mFontSize);
+	this->SetFontScale(mFontScale);
 	this->SetFontType(mFontType);
 	this->SetAntialiasing(mAntialiasing);
 	this->SetBackgroundColor(mBgColor);
@@ -737,7 +776,7 @@ iViewModule::~iViewModule()
 	//  Check that all clones are already deleted
 	//
 #ifdef I_CHECK1
-	if(mClones.Size() > 0) IERROR_REPORT_ERROR("Deleting a window with undeleted clones.");
+	if(mClones.Size() > 0) IERROR_REPORT("Deleting a window with undeleted clones.");
 #endif
 
 	//
@@ -746,10 +785,6 @@ iViewModule::~iViewModule()
 	mRenderTool->GetInteractor()->SetPicker(0);
 	mPicker->Delete();
 
-//	if(mRenderTool->GetRenderWindowInteractor() != 0)
-//	{
-//		iPointerCast<vtkInteractorStyle,vtkInteractorObserver>(mRenderTool->GetRenderWindowInteractor()->GetInteractorStyle())->HighlightProp(0);
-//	}
 	mEventRecorder->SetInteractor(0);
 	mEventRecorder->Delete();
 	mObsRecord->Delete();
@@ -759,14 +794,9 @@ iViewModule::~iViewModule()
 	mMarkerLegend->Delete();
 	mInteractorStyleCaption->Delete();
 
-	mFamSurface->Delete();
-	mFamCrossSection->Delete();
-	mFamVolume->Delete();
-	mFamParticles->Delete();
-	mFamVectorField->Delete();
-	mFamTensorField->Delete();
+	for(i=0; i<mViewObjectFamilies.Size(); i++) mViewObjectFamilies[i]->Delete();
 
-	mFamMarker->Delete();
+	mMarkerFamily->Delete();
 	
 	mUpdateTimer->Delete();
 
@@ -808,6 +838,11 @@ iViewModule::~iViewModule()
 	mObsSlaveAbortRender->Delete();
 	mObsAbortRender->Delete();
 
+	//
+	//  Extensions may use RenderTool, so we need to delete them before we delete mRenderTool
+	//
+	while(mExtensions.Size() > 0) mExtensions.RemoveLast()->Delete();
+
 	mRenderTool->Delete();
 
 	//
@@ -815,7 +850,7 @@ iViewModule::~iViewModule()
 	//
 	if(mDataConsumers.Size() > 0)
 	{
-		IERROR_REPORT_FATAL_ERROR("Not all DataConsumers have been deleted.");
+		IERROR_FINISH("Not all DataConsumers have been deleted.");
 	}
 }
 
@@ -856,7 +891,7 @@ bool iViewModule::BecomeClone(iViewModule *v)
 #ifdef I_CHECK1
 			if(v != mCloneOfModule)
 			{
-				IERROR_REPORT_ERROR("Clones configured incorrectly.");
+				IERROR_REPORT("Clones configured incorrectly.");
 			}
 #endif
 			mCloneOfModule = 0;
@@ -864,19 +899,14 @@ bool iViewModule::BecomeClone(iViewModule *v)
 			//
 			//  Re-create data reader
 			//
-			mDataReader = iDataReader::New(this); IERROR_ASSERT_NULL_POINTER(mDataReader);
+			mDataReader = iDataReader::New(this); IERROR_ASSERT(mDataReader);
 			mDataReader->CopyState(v->mDataReader);
 
-			mFamSurface->Reset();
-			mFamCrossSection->Reset();
-			mFamVolume->Reset();
-			mFamParticles->Reset();
-			mFamVectorField->Reset();
-			mFamTensorField->Reset();
+			for(i=0; i<mViewObjectFamilies.Size(); i++) mViewObjectFamilies[i]->Reset();
 
-			for(i=0; i<=mFamParticles->GetMaxMemberIndex(); i++)
+			for(i=0; i<=mViewObjectFamilies[_ObjectTypeParticles]->GetMaxMemberIndex(); i++)
 			{
-				mFamParticles->GetMember(i)->BecomeClone(0);
+				this->GetParticlesViewSubject(i)->BecomeClone(0);
 			}
 			//
 			//  Un-show label
@@ -899,22 +929,19 @@ bool iViewModule::BecomeClone(iViewModule *v)
 			mDataReader->Delete();
 			mDataReader = v->mDataReader;
 			//
-			//  Copy iViewObject families
+			//  Copy iViewSubject families
 			//
-			ret = ret & mFamSurface->Copy(v->mFamSurface);
-			ret = ret & mFamCrossSection->Copy(v->mFamCrossSection);
-			ret = ret & mFamVolume->Copy(v->mFamVolume);
-			ret = ret & mFamVectorField->Copy(v->mFamVectorField);
-			ret = ret & mFamTensorField->Copy(v->mFamTensorField);
-			ret = ret & mFamParticles->Copy(v->mFamParticles);
-			ret = ret & mFamMarker->Copy(v->mFamMarker);
+			ret = ret & mMarkerFamily->Copy(v->mMarkerFamily);
+
+			for(i=0; i<mViewObjectFamilies.Size(); i++) ret = ret & mViewObjectFamilies[i]->Copy(v->mViewObjectFamilies[i]);
+
 			//
-			//  ParticleSet family is never shown as a whole, so show individual members
+			//  Particles family is never shown as a whole, so show individual members
 			//
-			for(i=0; i<=mFamParticles->GetMaxMemberIndex(); i++)
+			for(i=0; i<=mViewObjectFamilies[_ObjectTypeParticles]->GetMaxMemberIndex(); i++)
 			{
-				mFamParticles->GetMember(i)->BecomeClone(v->mFamParticles->GetMember(i));
-				mFamParticles->GetMember(i)->Show(v->mFamParticles->GetMember(i)->IsVisible());
+				this->GetParticlesViewSubject(i)->BecomeClone(v->GetParticlesViewSubject(i));
+				this->GetParticlesViewSubject(i)->Show(v->GetParticlesViewSubject(i)->IsVisible());
 			}
 			//
 			//  Copy Animator state
@@ -1024,6 +1051,28 @@ void iViewModule::UpdatePerformance()
 }
 
 
+void iViewModule::UpdateAfterFileLoad()
+{
+	this->UpdateLabel();
+	this->UpdatePerformance();
+	//
+	//  Also make sure the current particles have the data (if there is any particle data)
+	//
+	if(!mViewObjectFamilies[_ObjectTypeParticles]->GetCurrentMember()->IsDataPresent())
+	{
+		int i;
+		for(i=0; i<=mViewObjectFamilies[_ObjectTypeParticles]->GetMaxMemberIndex(); i++)
+		{
+			if(mViewObjectFamilies[_ObjectTypeParticles]->GetMember(i)->IsDataPresent())
+			{
+				mViewObjectFamilies[_ObjectTypeParticles]->SetCurrentMemberIndex(i);
+				break;
+			}
+		}
+	}
+}
+
+
 void iViewModule::SetAxesBox(const iString &labelX, const iString &labelY, const iString &labelZ, float xMin, float xMax, float yMin, float yMax, float zMin, float zMax)
 {
 	mBox3AxesLabels->SetXLabel(labelX.ToCharPointer());
@@ -1034,19 +1083,19 @@ void iViewModule::SetAxesBox(const iString &labelX, const iString &labelY, const
 }
 
 
-void iViewModule::SetFontSize(int s)
+void iViewModule::SetFontScale(int s)
 {
-	mLabelActor->SetFontSize(s); 
-	if(s == mLabelActor->GetFontSize())
+	mLabelActor->SetFontScale(s); 
+	if(s == mLabelActor->GetFontScale())
 	{
-		mFontSize = s;
-		mRulerActor->SetFontSize(s);
-		mMeasuringBox->GetTextActor()->SetFontSize(s);
-		mColorBars->SetFontSize(s);
-		mBox3AxesLabels->SetFontSize(s);
+		mFontScale = s;
+		mRulerActor->SetFontScale(s);
+		mMeasuringBox->GetTextActor()->SetFontScale(s);
+		mColorBars->SetFontScale(s);
+		mBox3AxesLabels->SetFontScale(s);
 		int i;
-		for(i=0; i<=mFamMarker->GetMaxMemberIndex(); i++) mFamMarker->GetMember(i)->SetFontSize(s);
-		mMarkerLegend->SetFontSize(s);
+		for(i=0; i<=mMarkerFamily->GetMaxMemberIndex(); i++) mMarkerFamily->GetMember(i)->SetFontScale(s);
+		mMarkerLegend->SetFontScale(s);
 		this->ClearCache();
 	}
 }
@@ -1153,12 +1202,8 @@ void iViewModule::ShowGlassClipPlane(bool s)
 void iViewModule::ShowClipPlane(bool s)
 {
 	int i;
-	
-	for(i=0; i<=mFamSurface->GetMaxMemberIndex(); i++) mFamSurface->GetMember(i)->ShowClipPlane(s);
-	for(i=0; i<=mFamVolume->GetMaxMemberIndex(); i++) mFamVolume->GetMember(i)->ShowClipPlane(s);
-	for(i=0; i<=mFamParticles->GetMaxMemberIndex(); i++) mFamParticles->GetMember(i)->ShowClipPlane(s);
-	for(i=0; i<=mFamVectorField->GetMaxMemberIndex(); i++) mFamVectorField->GetMember(i)->ShowClipPlane(s);
-	for(i=0; i<=mFamTensorField->GetMaxMemberIndex(); i++) mFamTensorField->GetMember(i)->ShowClipPlane(s);
+	for(i=0; i<mViewObjectFamilies.Size(); i++) mViewObjectFamilies[i]->ShowClipPlane(s);
+
 	mIsClipPlaneOn = s;
 	if(mIsClipPlaneOn) mClipPlane->SetGlassPlaneVisible(mIsGlassClipPlaneOn); else mClipPlane->SetGlassPlaneVisible(false); 
 	this->ClearCache();
@@ -1298,7 +1343,7 @@ void iViewModule::SetBackgroundColor(const iColor &bg)
 	mMarkerLegend->GetProperty()->SetColor(fg.ToVTK());
 	mMarkerLegend->GetEntryTextProperty()->SetColor(fg.ToVTK());
 	mMarkerPlacer->GetProperty()->SetColor(fg.ToVTK());
-	for(int i=0; i<=mFamMarker->GetMaxMemberIndex(); i++) if(mFamMarker->GetMember(i)->GetColorAutomatic()) mFamMarker->GetMember(i)->SetTextColor(fg);
+	for(int i=0; i<=mMarkerFamily->GetMaxMemberIndex(); i++) if(mMarkerFamily->GetMember(i)->GetColorAutomatic()) mMarkerFamily->GetMember(i)->SetTextColor(fg);
 	this->ClearCache();
 }
 
@@ -1503,7 +1548,7 @@ void iViewModule::DumpImages(const iStereoImageArray &images, int m)
 	if(images.Size() != mRenderTool->GetNumberOfActiveViews()) 
 	{
 		this->CreateImages(tmp);
-		if(images.Size() != 0) IERROR_REPORT_ERROR("Incorrect number of images in ImageArray in DumpImages."); 
+		if(images.Size() != 0) IERROR_REPORT("Incorrect number of images in ImageArray in DumpImages."); 
 	}
 	else
 	{
@@ -1524,7 +1569,7 @@ void iViewModule::DumpImages(const iStereoImageArray &images, int m)
 //
 //  Two functions used in saving/restoring the state and in creating new instances with
 //
-void iViewModule::PackStateBody(iString &s) const
+void iViewModule::ExtendableObjectPackStateBody(iString &s) const
 {
 	int i; float fv[6]; iString sv[3];
 
@@ -1554,7 +1599,7 @@ void iViewModule::PackStateBody(iString &s) const
 	this->PackValue(s,KeyLabelScale(),mLabelScale);
 	this->PackValue(s,KeyLabelDigits(),mLabelDigits);
 
-	this->PackValue(s,KeyFontSize(),mFontSize);
+	this->PackValue(s,KeyFontScale(),mFontScale);
 	this->PackValue(s,KeyFontType(),mFontType);
 	this->PackValue(s,KeyBoundingBoxType(),mBoxType);
 	this->PackValue(s,KeyImageFormat(),mWriter->GetImageFormat());
@@ -1594,24 +1639,24 @@ void iViewModule::PackStateBody(iString &s) const
 	//
 	//  Extra keys for data quering
 	//
-	this->PackValue(s,KeyMarkerCurrent(),mFamMarker->GetCurrentMemberIndex());
-	this->PackValue(s,KeyParticlesCurrent(),mFamParticles->GetCurrentMemberIndex());
-	this->PackValue(s,KeySurfaceCurrent(),mFamSurface->GetCurrentMemberIndex());
-	this->PackValue(s,KeyCrossSectionCurrent(),mFamCrossSection->GetCurrentMemberIndex());
+	this->PackValue(s,KeyMarkerCurrent(),mMarkerFamily->GetCurrentMemberIndex());
+	this->PackValue(s,KeyCrossSectionCurrent(),mViewObjectFamilies[_ObjectTypeCrossSection]->GetCurrentMemberIndex());
+	this->PackValue(s,KeyParticlesCurrent(),this->GetParticlesObject()->GetActiveDataTypeIndex());
+	this->PackValue(s,KeySurfaceCurrent(),mViewObjectFamilies[_ObjectTypeSurface]->GetCurrentMemberIndex());
 
-	i = mFamMarker->GetMaxMemberIndex();
-	if(i==0 && !mFamMarker->GetMember(0)->IsVisible()) i = -1;
+	i = mMarkerFamily->GetMaxMemberIndex();
+	if(i==0 && !mMarkerFamily->GetMember(0)->IsVisible()) i = -1;
 	this->PackValue(s,KeyMarkerMax(),i);
-	this->PackValue(s,KeyParticlesMax(),mFamParticles->GetMaxMemberIndex());
-	this->PackValue(s,KeySurfaceMax(),mFamSurface->GetMaxMemberIndex());
-	this->PackValue(s,KeyCrossSectionMax(),mFamCrossSection->GetMaxMemberIndex());
+	this->PackValue(s,KeyParticlesMax(),this->GetParticlesObject()->GetNumberOfTypes()-1);
+	this->PackValue(s,KeySurfaceMax(),mViewObjectFamilies[_ObjectTypeSurface]->GetMaxMemberIndex());
+	this->PackValue(s,KeyCrossSectionMax(),mViewObjectFamilies[_ObjectTypeCrossSection]->GetMaxMemberIndex());
 
 	this->PackValue(s,KeyPlaceMarker(),mMarkerPlacer->GetEnabled()!=0);
 	this->PackValue(s,KeyMoveMarkerCaption(),mRenderTool->GetInteractor()->GetInteractorStyle()==mInteractorStyleCaption);
 }
 
 
-void iViewModule::UnPackStateBody(const iString &s)
+void iViewModule::ExtendableObjectUnPackStateBody(const iString &s)
 {
 	int i, iv[2]; bool b; float f, fv[6]; iColor c; iString w, sv[3];
 
@@ -1638,7 +1683,11 @@ void iViewModule::UnPackStateBody(const iString &s)
 	if(this->UnPackValue(s,KeyStereo(),b)) this->SetStereo(b);
 	if(this->UnPackValue(s,KeyStereoAlignmentMarkers(),b)) this->ShowStereoAlignmentMarkers(b);
 
-	if(this->UnPackValue(s,KeyFontSize(),i)) this->SetFontSize(i);
+	iObject::ReportMissingKeys(false);
+	if(this->UnPackValue(s,KeyFontSize(),i)) this->SetFontScale(round(log(i/16.0)/0.3)); // for backward compatibility only
+	iObject::ReportMissingKeys(true);
+
+	if(this->UnPackValue(s,KeyFontScale(),i)) this->SetFontScale(i);
 	if(this->UnPackValue(s,KeyFontType(),i)) this->SetFontType(i);
 	if(this->UnPackValue(s,KeyBoundingBoxType(),i)) this->SetBoundingBoxType(i);
 	if(this->UnPackValue(s,KeyImageFormat(),i)) mWriter->SetImageFormat(i);
@@ -1701,40 +1750,35 @@ void iViewModule::UnPackStateBody(const iString &s)
 	//
 	if(this->UnPackValue(s,KeyMarkerCurrent(),i))
 	{
-		mFamMarker->SetCurrentMemberIndex(i);
-		this->ClearCache();
-	}
-	if(this->UnPackValue(s,KeyParticlesCurrent(),i))
-	{
-		mFamParticles->SetCurrentMemberIndex(i);
-		this->ClearCache();
-	}
-	if(this->UnPackValue(s,KeySurfaceCurrent(),i))
-	{
-		mFamSurface->SetCurrentMemberIndex(i);
+		mMarkerFamily->SetCurrentMemberIndex(i);
 		this->ClearCache();
 	}
 	if(this->UnPackValue(s,KeyCrossSectionCurrent(),i))
 	{
-		mFamCrossSection->SetCurrentMemberIndex(i);
+		mViewObjectFamilies[_ObjectTypeCrossSection]->SetCurrentMemberIndex(i);
+		this->ClearCache();
+	}
+	if(this->UnPackValue(s,KeyParticlesCurrent(),i))
+	{
+		this->GetParticlesObject()->SetActiveDataTypeIndex(i);
+		this->ClearCache();
+	}
+	if(this->UnPackValue(s,KeySurfaceCurrent(),i))
+	{
+		mViewObjectFamilies[_ObjectTypeSurface]->SetCurrentMemberIndex(i);
 		this->ClearCache();
 	}
 
 	//
 	//  "Action" keys
 	//
-#ifdef I_CHECK1
-	bool saveReportMissingKeys = iObject::ReportMissingKeys;
-	iObject::ReportMissingKeys = false; //action keys are not part of the states
-#endif
+	iObject::ReportMissingKeys(false); //action keys are not part of the states
 
 	if(this->UnPackValue(s,KeyPlaceMarker(),b)) this->PlaceMarker(b);
 	if(this->UnPackValue(s,KeyMoveMarkerCaption(),b)) this->MoveMarkerCaption(b);
 	if(this->UnPackValue(s,KeyDumpImage(),b) && b) this->DumpImages();
 
-#ifdef I_CHECK1
-	iObject::ReportMissingKeys = saveReportMissingKeys;
-#endif
+	iObject::ReportMissingKeys(true);
 }
 
 
@@ -1742,7 +1786,7 @@ void iViewModule::PlaceMarker(bool s)
 {
 	if(s)
 	{
-		mMarkerPlacer->SetPosition(mFamMarker->GetCurrentMember()->GetPosition()[0],mFamMarker->GetCurrentMember()->GetPosition()[1],mFamMarker->GetCurrentMember()->GetPosition()[2]);
+		mMarkerPlacer->SetPosition(mMarkerFamily->GetCurrentMember()->GetPosition()[0],mMarkerFamily->GetCurrentMember()->GetPosition()[1],mMarkerFamily->GetCurrentMember()->GetPosition()[2]);
 		mMarkerPlacer->On();
 	}
 	else
@@ -1781,15 +1825,15 @@ void iViewModule::ShowMarkerLegend(bool s)
 void iViewModule::BuildMarkerLegend(int n)
 {
 	int i;
-	if(n<0 || n>mFamMarker->GetMaxMemberIndex())
+	if(n<0 || n>mMarkerFamily->GetMaxMemberIndex())
 	{
-		mMarkerLegend->SetNumberOfEntries(1+mFamMarker->GetMaxMemberIndex());
-		for(i=0; i<=mFamMarker->GetMaxMemberIndex(); i++)
+		mMarkerLegend->SetNumberOfEntries(1+mMarkerFamily->GetMaxMemberIndex());
+		for(i=0; i<=mMarkerFamily->GetMaxMemberIndex(); i++)
 		{
 			//
 			//  Fix a bug in vtkLegendBoxActor
 			//
-			if(mFamMarker->GetMember(i)->GetCaptionText().Length() > 0) mMarkerLegend->SetEntry(i,mFamMarker->GetMember(i)->GetMarkerObject()->GetOutput(),mFamMarker->GetMember(i)->GetCaptionText().ToCharPointer(),mFamMarker->GetMember(i)->GetColor(0).ToVTK()); else mMarkerLegend->SetEntry(i,mFamMarker->GetMember(i)->GetMarkerObject()->GetOutput()," ",mFamMarker->GetMember(i)->GetColor(0).ToVTK());
+			if(mMarkerFamily->GetMember(i)->GetCaptionText().Length() > 0) mMarkerLegend->SetEntry(i,mMarkerFamily->GetMember(i)->GetMarkerObject()->GetOutput(),mMarkerFamily->GetMember(i)->GetCaptionText().ToCharPointer(),mMarkerFamily->GetMember(i)->GetColor(0).ToVTK()); else mMarkerLegend->SetEntry(i,mMarkerFamily->GetMember(i)->GetMarkerObject()->GetOutput()," ",mMarkerFamily->GetMember(i)->GetColor(0).ToVTK());
 		}
 	}
 	else
@@ -1797,7 +1841,7 @@ void iViewModule::BuildMarkerLegend(int n)
 		//
 		//  Fix a bug in vtkLegendBoxActor
 		//
-		if(mFamMarker->GetMember(n)->GetCaptionText().Length() > 0) mMarkerLegend->SetEntry(n,mFamMarker->GetMember(n)->GetMarkerObject()->GetOutput(),mFamMarker->GetMember(n)->GetCaptionText().ToCharPointer(),mFamMarker->GetMember(n)->GetColor(0).ToVTK()); else mMarkerLegend->SetEntry(n,mFamMarker->GetMember(n)->GetMarkerObject()->GetOutput()," ",mFamMarker->GetMember(n)->GetColor(0).ToVTK());
+		if(mMarkerFamily->GetMember(n)->GetCaptionText().Length() > 0) mMarkerLegend->SetEntry(n,mMarkerFamily->GetMember(n)->GetMarkerObject()->GetOutput(),mMarkerFamily->GetMember(n)->GetCaptionText().ToCharPointer(),mMarkerFamily->GetMember(n)->GetColor(0).ToVTK()); else mMarkerLegend->SetEntry(n,mMarkerFamily->GetMember(n)->GetMarkerObject()->GetOutput()," ",mMarkerFamily->GetMember(n)->GetColor(0).ToVTK());
 	}
 }
 
@@ -1827,14 +1871,12 @@ void iViewModule::SetMarkerLegendPosition(int p)
 
 float iViewModule::GetMemorySize() const
 {
+	int i;
 	float s = 0.0;
+
+	for(i=0; i<mViewObjectFamilies.Size(); i++) s += mViewObjectFamilies[i]->GetMemorySize();
 	s += mDataReader->GetMemorySize();
-	s += mFamSurface->GetMemorySize();
-	s += mFamCrossSection->GetMemorySize();
-	s += mFamVolume->GetMemorySize();
-	s += mFamParticles->GetMemorySize();
-	s += mFamVectorField->GetMemorySize();
-	s += mFamTensorField->GetMemorySize();
+
 	return s;
 }
 
@@ -1922,12 +1964,12 @@ void iViewModule::UnRegisterDataConsumer(iDataConsumer *c)
 }
 
 
-void iViewModule::NotifyDataConsumers(const iDataType &type, int info, void *data)
+void iViewModule::NotifyDataConsumers(const iDataSyncRequest &r)
 {
 	int i;
-	for(i=0; i<mDataConsumers.Size(); i++) if(mDataConsumers[i]->IsUsingData(type,false))
+	for(i=0; i<mDataConsumers.Size(); i++) if(mDataConsumers[i]->IsUsingData(r.Data(),false))
 	{
-		mDataConsumers[i]->SyncWithData(info,data);
+		mDataConsumers[i]->SyncWithData(r);
 	}
 }
 
@@ -2038,3 +2080,55 @@ void iViewModule::SetLabelDigits(int v)
 		this->ClearCache();
 	}
 }
+
+
+void iViewModule::ForceCrossSectionToUsePolygonalMethod(bool s)
+{
+	int k;
+
+	for(k=0; k<=mViewObjectFamilies[_ObjectTypeCrossSection]->GetMaxMemberIndex(); k++)
+	{
+		this->GetCrossSectionViewSubject(k)->ForcePolygonalMethod(s);
+	}
+}
+
+
+iMarker* iViewModule::GetMarker(int n) const
+{
+	return (n==-1) ? mMarkerFamily->GetCurrentMember() : mMarkerFamily->GetMember(n);
+}
+
+
+iViewObject* iViewModule::GetParticlesObject(int n) const
+{ 
+	return (n==-1) ? mViewObjectFamilies[_ObjectTypeParticles]->GetCurrentMember() : mViewObjectFamilies[_ObjectTypeParticles]->GetMember(n); 
+}
+
+
+IVIEWMODULE_DEFINE_VIEWSUBJECT(CrossSection);
+IVIEWMODULE_DEFINE_VIEWSUBJECT(Particles);
+IVIEWMODULE_DEFINE_VIEWSUBJECT(Surface);
+IVIEWMODULE_DEFINE_VIEWSUBJECT(TensorField);
+IVIEWMODULE_DEFINE_VIEWSUBJECT(VectorField);
+IVIEWMODULE_DEFINE_VIEWSUBJECT(Volume);
+
+
+//
+//  Extension class
+//
+IOBJECTEXTENSION_DEFINE_ABSTRACT(iViewModule);
+
+void iViewModuleExtension::Define()
+{
+	mMinViewObjectFamilyIndex = mRealOwner->GetNumberOfGetViewObjectFamilies();
+	mMaxViewObjectFamilyIndex = mMinViewObjectFamilyIndex - 1;
+}
+
+
+iViewObjectFamily* iViewModuleExtension::AddNewViewObjectFamily()
+{
+	iViewObjectFamily *fam = this->CreateObjectFamily(mMaxViewObjectFamilyIndex-mMinViewObjectFamilyIndex+1);
+	if(fam != 0) mMaxViewObjectFamilyIndex++;
+	return fam;
+}
+
