@@ -29,8 +29,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewmodulecomponent.h"
 
 
+#include "icontrolmodule.h"
+#include "ishell.h"
+#include "iviewmodule.h"
+
+
 iViewModuleComponent::iViewModuleComponent(iViewModule *vm) 
 { 
 	mViewModule = vm; 
+
+	if(vm != 0) vm->GetControlModule()->GetShell()->OnInitAtom();
 }
 
