@@ -117,7 +117,7 @@ namespace iHelpFactory_Private
 #ifdef I_DEBUG
 			if(ss && !sorted)
 			{
-				IERROR_REPORT_ERROR("Help data are not sorted.");
+				IERROR_REPORT("Help data are not sorted.");
 			}
 #endif
 		}
@@ -463,7 +463,7 @@ iHelpDataBuffer* iHelpFactory::FindData(const char *tag, InfoSource source, bool
 
 	if(level > 9)
 	{
-		IERROR_REPORT_ERROR("References are looped.");
+		IERROR_REPORT("References are looped.");
 		return new iHelpDataBuffer(null,true);
 	}
 
@@ -662,7 +662,7 @@ void iHelpFactory::CreateUserGuide(bool full)
 #ifdef I_DEBUG
 				if(dtmp2->GetTitle().IsEmpty())
 				{
-					IERROR_REPORT_ERROR("Referenced item is missing a title.");
+					IERROR_REPORT("Referenced item is missing a title.");
 				}
 #endif
 				stmp = iString("<br>See <a href=\"") + dtmp2->mData.Tag + "\">" + dtmp2->GetTitle() + "</a>.";
