@@ -41,7 +41,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 ibgRenderWindowSubject::ibgRenderWindowSubject(iggRenderWindow *owner) : ibgWindowSubject(owner?owner->GetViewModule()->GetControlModule()->GetShell():0)
 {
-	mOwner = owner; IERROR_ASSERT_NULL_POINTER(owner);
+	mOwner = owner; IERROR_ASSERT(owner);
 	mInteractor = 0;
 }
 
