@@ -34,7 +34,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 ibgShellSubject::ibgShellSubject(iggShell *owner, int , char **)
 {
-	mOwner = owner; IERROR_ASSERT_NULL_POINTER(owner);
+	mOwner = owner; IERROR_ASSERT(owner);
 }
 
 
