@@ -39,7 +39,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 ibgWidgetSubject::ibgWidgetSubject(iggWidget *owner)
 {
-	IERROR_ASSERT_NULL_POINTER(owner);
+	IERROR_ASSERT(owner);
 	mOwner = owner;
 	mWidgetHelper = 0;
 }
@@ -47,6 +47,6 @@ ibgWidgetSubject::ibgWidgetSubject(iggWidget *owner)
 
 ibgWidgetSubject::~ibgWidgetSubject()
 {
-	IERROR_ASSERT_NULL_POINTER(mWidgetHelper);
+	IERROR_ASSERT(mWidgetHelper);
 	delete mWidgetHelper;
 }
