@@ -82,7 +82,7 @@ void iggExtensionFrameBook::OnInt1Body(int i)
 //
 iggAbstractExtension::iggAbstractExtension(iggMainWindow *mw, const iImage *icon, const iString &title, bool withbook) : iggFrame(mw?mw->GetShell():0,1), mIcon(icon), mTitle(title), mWithBook(withbook)
 {
-	IERROR_ASSERT_NULL_POINTER(mw);
+	IERROR_ASSERT(mw);
 	mMainWindow = mw;
 	mBook = 0;
  
@@ -98,7 +98,7 @@ void iggAbstractExtension::CompleteInitialization()
 {
 	if(mWithBook)
 	{
-		mBook = new iggExtensionFrameBook(this); IERROR_ASSERT_NULL_POINTER(mBook);
+		mBook = new iggExtensionFrameBook(this); IERROR_ASSERT(mBook);
 		this->AddLine(mBook);
 	}
 
