@@ -57,7 +57,7 @@ iggDialog::iggDialog(iShell *shell, unsigned int mode, const iImage *icon, const
 
 iggDialog::iggDialog(const iggMenuWindow *mw, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, bool withclose, const char *closetext) : iShellComponent(mw==0?0:mw->GetShell())
 {
-	IERROR_ASSERT_NULL_POINTER(mw);
+	IERROR_ASSERT(mw);
 	mMainWindow = mw->GetMainWindow();
 	this->Define(mw->GetSubject(),mode,icon,title,helpkey,cols,withclose,closetext);
 }
@@ -65,7 +65,7 @@ iggDialog::iggDialog(const iggMenuWindow *mw, unsigned int mode, const iImage *i
 
 iggDialog::iggDialog(const iggDialog *pd, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, bool withclose, const char *closetext) : iShellComponent(pd==0?0:pd->GetShell())
 {
-	IERROR_ASSERT_NULL_POINTER(pd);
+	IERROR_ASSERT(pd);
 	mMainWindow = pd->GetMainWindow();
 	this->Define(pd->GetSubject(),mode,icon,title,helpkey,cols,withclose,closetext);
 }
@@ -73,22 +73,22 @@ iggDialog::iggDialog(const iggDialog *pd, unsigned int mode, const iImage *icon,
 
 void iggDialog::Define(const ibgWindowSubject *base, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, bool withclose, const char *closetext)
 {
-	mSubject = iggSubjectFactory::CreateDialogSubject(this,base,mode,icon,title.IsEmpty()?title:("IFrIT - "+title)); IERROR_ASSERT_NULL_POINTER(mSubject);
+	mSubject = iggSubjectFactory::CreateDialogSubject(this,base,mode,icon,title.IsEmpty()?title:("IFrIT - "+title)); IERROR_ASSERT(mSubject);
 	if(mMainWindow != 0) mMainWindow->Register(mSubject);
 
 	if(cols < 1)
 	{
 		cols = 1;
-		IERROR_REPORT_ERROR("Incorrect number of columns in iggDialog frame.");
+		IERROR_REPORT("Incorrect number of columns in iggDialog frame.");
 	}
 
 	mMode = mode;
 
 	if(withclose)
 	{
-		iggFrame *tmp = new iggFrame(this->GetShell(),3); IERROR_ASSERT_NULL_POINTER(tmp);
+		iggFrame *tmp = new iggFrame(this->GetShell(),3); IERROR_ASSERT(tmp);
 		mSubject->SetFrame(tmp->GetSubject());
-		mFrame = new iggFrame(tmp,cols); IERROR_ASSERT_NULL_POINTER(mFrame);
+		mFrame = new iggFrame(tmp,cols); IERROR_ASSERT(mFrame);
 		tmp->AddLine(mFrame,3);
 		tmp->AddLine((iggWidget *)0,new iggWidgetDialogCloseButton(this,tmp,closetext),(iggWidget *)0);
 		tmp->SetColStretch(0,10);
@@ -100,7 +100,7 @@ void iggDialog::Define(const ibgWindowSubject *base, unsigned int mode, const iI
 	}
 	else
 	{
-		mFrame = new iggFrame(this->GetShell(),cols); IERROR_ASSERT_NULL_POINTER(mFrame);
+		mFrame = new iggFrame(this->GetShell(),cols); IERROR_ASSERT(mFrame);
 		mSubject->SetFrame(mFrame->GetSubject());
 	}
 	mFrame->SetPadding(true);
@@ -157,7 +157,7 @@ void iggDialog::Show(bool s)
 {
 	if(mFrame == 0)
 	{
-		IERROR_REPORT_ERROR("No frame was set for this dialog.");
+		IERROR_REPORT("No frame was set for this dialog.");
 		return;
 	}
 
@@ -182,7 +182,7 @@ void iggDialog::UpdateDialog()
 {
 	if(mFrame == 0)
 	{
-		IERROR_REPORT_ERROR("No frame was set for this dialog.");
+		IERROR_REPORT("No frame was set for this dialog.");
 		return;
 	}
 	mFrame->UpdateWidget();
