@@ -175,7 +175,7 @@ namespace iggDialogCommandLine_Private
 				}
 			default:
 				{
-					IERROR_REPORT_ERROR("Ivalid text type.");
+					IERROR_REPORT("Ivalid text type.");
 				}
 			}
 		}
@@ -332,9 +332,8 @@ namespace iggDialogCommandLine_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
-			return true;
 		}
 
 		virtual void OnVoid1Body()
@@ -356,10 +355,10 @@ namespace iggDialogCommandLine_Private
 				{
 					mCurLine = mSubject->GetText();
 				}
-				if(mCurHistoryLine < mHistory.Last())
+				if(mCurHistoryLine < mHistory.MaxIndex())
 				{
 					mCurHistoryLine++;
-					mSubject->SetText(mHistory[mHistory.Last()-mCurHistoryLine]);
+					mSubject->SetText(mHistory[mHistory.MaxIndex()-mCurHistoryLine]);
 				}
 			}
 			else
@@ -373,7 +372,7 @@ namespace iggDialogCommandLine_Private
 					}
 					else
 					{
-						mSubject->SetText(mHistory[mHistory.Last()-mCurHistoryLine]);
+						mSubject->SetText(mHistory[mHistory.MaxIndex()-mCurHistoryLine]);
 					}
 				}
 			}
