@@ -105,7 +105,7 @@ namespace iggDialogDataExplorer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody();
+		virtual void UpdateWidgetBody();
 		virtual void OnInt1Body(int i);
 
 		VariablePropertyDialog *mDialog;
@@ -126,7 +126,7 @@ namespace iggDialogDataExplorer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody();
+		virtual void UpdateWidgetBody();
 		virtual void OnVoid1Body();
 
 		VariablePropertyDialog *mDialog;
@@ -175,10 +175,9 @@ namespace iggDialogDataExplorer_Private
 		iggWidgetHistogramArea *mArea;
 	};
 
-	bool VariablePropertyDialogOpacitySlider::UpdateWidgetBody()
+	void VariablePropertyDialogOpacitySlider::UpdateWidgetBody()
 	{
 		if(mDialog->GetVariable() != 0) mSubject->SetValue(round(20.0*mDialog->GetVariable()->Opacity));
-		return true;
 	}
 
 	void VariablePropertyDialogOpacitySlider::OnInt1Body(int)
@@ -190,10 +189,9 @@ namespace iggDialogDataExplorer_Private
 		}
 	}
 
-	bool VariablePropertyDialogColorSelection::UpdateWidgetBody()
+	void VariablePropertyDialogColorSelection::UpdateWidgetBody()
 	{
 		if(mDialog->GetVariable() != 0) mSubject->SetColor(mDialog->GetVariable()->Color);
-		return true;
 	}
 
 	void VariablePropertyDialogColorSelection::OnVoid1Body()
@@ -285,7 +283,7 @@ namespace iggDialogDataExplorer_Private
 				}
 				else
 				{
-					this->InsertFormattedEntry(mVariables.Last());
+					this->InsertFormattedEntry(mVariables.MaxIndex());
 				}
 				this->UpdateDependents();
 			}
@@ -295,7 +293,8 @@ namespace iggDialogDataExplorer_Private
 		{
 			if(n>=0 && n<mVariables.Size())
 			{
-				mVariables.Remove(n).Explorer->Delete();
+				mVariables[n].Explorer->Delete();
+				mVariables.Remove(n);
 			}
 		}
 
@@ -359,7 +358,7 @@ namespace iggDialogDataExplorer_Private
 				}
 			case 2:
 				{
-					if(mSelectedRange[1] == mVariables.Last()) return; // already there
+					if(mSelectedRange[1] == mVariables.MaxIndex()) return; // already there
 
 					v = mVariables[mSelectedRange[1]+1];
 					for(i=mSelectedRange[1]; i>=mSelectedRange[0]; i--)
@@ -381,7 +380,7 @@ namespace iggDialogDataExplorer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			bool ok;
 			int i, j, wn, n = mVariables.Size();
@@ -461,7 +460,7 @@ namespace iggDialogDataExplorer_Private
 				this->UpdateDependents();
 			}
 
-			return iggWidgetListView::UpdateWidgetBody();
+			this->iggWidgetListView::UpdateWidgetBody();
 		}
 
 		void InsertFormattedEntry(int n)
@@ -556,7 +555,7 @@ namespace iggDialogDataExplorer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			static iString dummy;
 			//
@@ -617,7 +616,8 @@ namespace iggDialogDataExplorer_Private
 				mView = mView1;
 				this->ShowLayer(0);
 			}
-			return iggFrameFlip::UpdateWidgetBody();
+
+			this->iggFrameFlip::UpdateWidgetBody();
 		}
 
 		float mValue;
@@ -823,7 +823,7 @@ namespace iggDialogDataExplorer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			mSelector->UpdateWidget();
 
@@ -861,7 +861,7 @@ namespace iggDialogDataExplorer_Private
 			}
 			else this->Clear();
 
-			return iggWidgetListView::UpdateWidgetBody();
+			this->iggWidgetListView::UpdateWidgetBody();
 		}
 
 		virtual void OnReturnPressed()
@@ -895,10 +895,9 @@ namespace iggDialogDataExplorer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			this->Enable(mList->HasSelection());
-			return true;
 		}
 
 		virtual void Execute()
@@ -947,17 +946,16 @@ namespace iggDialogDataExplorer_Private
 				}
 			default:
 				{
-					IERROR_REPORT_FATAL_ERROR("Invalid type");
+					IERROR_FINISH("Invalid type");
 				}
 			}
 		}
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			this->Enable(mList->HasSelection());
-			return true;
 		}
 
 		virtual void Execute()
@@ -990,7 +988,7 @@ namespace iggDialogDataExplorer_Private
 				}
 			default:
 				{
-					IERROR_REPORT_FATAL_ERROR("Invalid type");
+					IERROR_FINISH("Invalid type");
 				}
 			}
 			mNeedsBaloonHelp = false;
@@ -998,7 +996,7 @@ namespace iggDialogDataExplorer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			mSubject->Clear();
 			
@@ -1030,7 +1028,6 @@ namespace iggDialogDataExplorer_Private
 					}
 				}
 			}
-			return true;
 		}
 
 		int mType;
@@ -1053,7 +1050,7 @@ namespace iggDialogDataExplorer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			if(mList->GetVariables().Size() > 0)
 			{
@@ -1078,7 +1075,6 @@ namespace iggDialogDataExplorer_Private
 				}
 			}
 			else this->Display(0.0);
-			return true;
 		}
 
 		int mType;
@@ -1134,7 +1130,7 @@ namespace iggDialogDataExplorer_Private
 					}
 				default:
 					{
-						IERROR_REPORT_ERROR("Invalid choice.");
+						IERROR_REPORT("Invalid choice.");
 						p = 0;
 					}
 				}
@@ -1149,10 +1145,10 @@ namespace iggDialogDataExplorer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			this->Enable(mList->GetVariables().Size() > 0);
-			return iggFrameMoveFocalPointButton::UpdateWidgetBody();
+			this->iggFrameMoveFocalPointButton::UpdateWidgetBody();
 		}
 
 		ExploredVariablesList *mList;
@@ -1189,10 +1185,9 @@ namespace iggDialogDataExplorer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			mSubject->SetValue(mDataExplorer->GetStretch());
-			return true;
 		}
 
 		void OnInt1Body(int s)
@@ -1228,7 +1223,7 @@ iggDialogDataExplorer::iggDialogDataExplorer(iggMainWindow *parent) : iggDialog(
 
 	mStretch = 1;
 
-	mProvider = new iggKeywordDataTypeProvider("ScalarField,ParticleSet",this->GetFrame()); IERROR_ASSERT_NULL_POINTER(mProvider);
+	mProvider = new iggKeywordDataTypeProvider("ScalarField,ParticleSet",this->GetFrame()); IERROR_ASSERT(mProvider);
 
 	mFlashFrame = new iggFrameFlip(mFrame);
 	tmp1 = new iggFrame(mFlashFrame,2);
@@ -1303,7 +1298,7 @@ iggDialogDataExplorer::iggDialogDataExplorer(iggMainWindow *parent) : iggDialog(
 	tmp1->AddLine(b1);
 	tmp1->AddSpace(10);
 	box2->AddLine(tmp1,al);
-	box2->AddLine(dts,2);
+	box2->AddLine((iggWidget*)0,dts);
 
 //	mFrame->AddLine(box1,box2);
 	mFrame->AddLine(mFlashFrame,2);
