@@ -140,7 +140,7 @@ namespace iggDialogHelp_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			switch(mMode)
 			{
@@ -155,7 +155,6 @@ namespace iggDialogHelp_Private
 					break;
 				}
 			}
-			return true;
 		}
 
 		virtual void Execute()
