@@ -166,7 +166,7 @@ namespace iggDialogImageComposer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			//
 			//  Compute reduction factor
@@ -176,7 +176,7 @@ namespace iggDialogImageComposer_Private
 			mScaleFactor = (f1 > f2) ? f2 : f1;
 			if(mScaleFactor > 1.0) mScaleFactor = 1.0;
 
-			return iggWidgetDrawArea::UpdateWidgetBody();
+			this->iggWidgetDrawArea::UpdateWidgetBody();
 		}
 
 		virtual void DrawBackgroundBody()
@@ -402,10 +402,10 @@ namespace iggDialogImageComposer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			this->SetText("%b"+iString::FromNumber(mDialog->GetImageComposer()->GetImageWidth())+" x "+iString::FromNumber(mDialog->GetImageComposer()->GetImageHeight()));
-			return iggWidgetTextArea::UpdateWidgetBody();
+			this->iggWidgetTextArea::UpdateWidgetBody();
 		}
 
 		iggDialogImageComposer *mDialog;
@@ -429,7 +429,7 @@ namespace iggDialogImageComposer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			int i, val = this->GetShell()->GetControlModule()->GetNumberOfViewModules();
 			if(mSubject->Count() != val+1)
@@ -454,7 +454,6 @@ namespace iggDialogImageComposer_Private
 					}
 				}
 			}
-			return true;
 		}
 
 		virtual void OnInt1Body(int v)
@@ -501,10 +500,9 @@ namespace iggDialogImageComposer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			this->Enable(mDialog->GetCurrentBackgroundWindow()>=0 && mDialog->GetImageComposer()->GetBackgroundWindow(mDialog->GetCurrentBackgroundWindow())->GetViewModule() == 0);
-			return true;
 		}
 
 		virtual void Execute()
@@ -539,10 +537,9 @@ namespace iggDialogImageComposer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			this->Enable(mDialog->GetImageComposer()->GetNumForegroundWindows()>0);
-			return true;
 		}
 
 		virtual void Execute()
@@ -609,10 +606,10 @@ namespace iggDialogImageComposer_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			this->Enable(mDialog->GetImageComposer()->GetNumForegroundWindows()>0);
-			return iggFrame::UpdateWidgetBody();
+			this->iggFrame::UpdateWidgetBody();
 		}
 
 		iggDialogImageComposer *mDialog;
