@@ -66,7 +66,7 @@ namespace iggDialogPerformanceMeter_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			float v;
 			int p = 0;
@@ -127,8 +127,6 @@ namespace iggDialogPerformanceMeter_Private
 			}
 
 			if(fabs(mValue-prev) > acc) this->Display(mValue,p);
-
-			return true;
 		}
 
 		int mWarning;
