@@ -213,7 +213,7 @@ namespace iggDialogScriptDebugger_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			const iString &text(mDebugger->GetAnimator()->GetScript()->GetText());
 			if(mSubject->GetText() != text)
@@ -221,7 +221,7 @@ namespace iggDialogScriptDebugger_Private
 				mDebugger->Debug(false);
 				mSubject->SetText(text);
 			}
-			return this->iggWidgetTextEditor::UpdateWidgetBody();
+			this->iggWidgetTextEditor::UpdateWidgetBody();
 		}
 
 		virtual void OnTextChanged()
@@ -271,9 +271,8 @@ namespace iggDialogScriptDebugger_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
-			return true;
 		}
 
 		ibgWidgetEntrySubject *mSubject;
@@ -386,7 +385,7 @@ namespace iggDialogScriptDebugger_Private
 				}
 			default:
 				{
-					IERROR_REPORT_FATAL_ERROR("Incorrectly configured Script Debugger.");
+					IERROR_FINISH("Incorrectly configured Script Debugger.");
 				}
 			}
 		}
@@ -426,9 +425,8 @@ namespace iggDialogScriptDebugger_Private
 			mDebugger->SetDelayTime(0.01f*v*v);
 		}
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
-			return true;
 		}
 
 		ibgWidgetEntrySubject *mSubject;
@@ -1061,7 +1059,7 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 
 	if(id < 0)
 	{
-		IERROR_REPORT_ERROR("Invalid menu item id.");
+		IERROR_REPORT("Invalid menu item id.");
 	}
 
 	if(id <= _MenuFileMax)
@@ -1097,7 +1095,7 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 			}
 		default:
 			{
-				IERROR_REPORT_ERROR("Invalid menu item id.");
+				IERROR_REPORT("Invalid menu item id.");
 			}
 		}
 		return;
@@ -1123,7 +1121,7 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 			}
 		default:
 			{
-				IERROR_REPORT_ERROR("Invalid menu item id.");
+				IERROR_REPORT("Invalid menu item id.");
 			}
 		}
 		return;
@@ -1156,7 +1154,7 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 			}
 		default:
 			{
-				IERROR_REPORT_ERROR("Invalid menu item id.");
+				IERROR_REPORT("Invalid menu item id.");
 			}
 		}
 		return;
@@ -1178,12 +1176,12 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 			}
 		default:
 			{
-				IERROR_REPORT_ERROR("Invalid menu item id.");
+				IERROR_REPORT("Invalid menu item id.");
 			}
 		}
 		return;
 	}
 
-	IERROR_REPORT_ERROR("Invalid menu item id.");
+	IERROR_REPORT("Invalid menu item id.");
 }
 
