@@ -56,7 +56,7 @@ using namespace iggParameter;
 iggExtensionWindow::iggExtensionWindow(iggMainWindow *mw) : iShellComponent(mw?mw->GetShell():0), mExt(0)
 {
 	mCurExt = 0;
-	mMainWindow = mw; IERROR_ASSERT_NULL_POINTER(mw);
+	mMainWindow = mw; IERROR_ASSERT(mw);
 
 	//
 	//  Query iggExtensionFactory for all extensions
@@ -98,7 +98,7 @@ iggExtensionWindow::~iggExtensionWindow()
 
 void iggExtensionWindow::AttachSubject(ibgExtensionWindowSubject *subject)
 {
-	mSubject = subject; IERROR_ASSERT_NULL_POINTER(subject);
+	mSubject = subject; IERROR_ASSERT(subject);
 }
 
 
