@@ -32,7 +32,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "icontrolmodule.h"
 #include "ierror.h"
 #include "iimagefactory.h"
-#include "imarkerviewobject.h"
+#include "imarker.h"
 #include "iobjecthelp.h"
 #include "ishell.h"
 #include "iviewmodule.h"
@@ -65,9 +65,8 @@ namespace iggFrameDoubleButton_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
-			return true;
 		}
 
 		virtual void OnVoid1Body()
@@ -98,7 +97,7 @@ namespace iggFrameDoubleButton_Private
 			mReadyIcon = iImageFactory::FindIcon("ready.png");
 			if(mDelayIcon==0 || mReadyIcon==0)
 			{
-				IERROR_REPORT_ERROR("Icon images are not found.");
+				IERROR_REPORT("Icon images are not found.");
 			}
 
 			mSubject = iggSubjectFactory::CreateWidgetButtonSubject(this,_ButtonTypeToggleButton,"",1);
@@ -110,7 +109,7 @@ namespace iggFrameDoubleButton_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			if(mConcreteParent->GetMoveInstantly())
 			{
@@ -122,7 +121,6 @@ namespace iggFrameDoubleButton_Private
 				if(mDelayIcon != 0) mSubject->SetIcon(*mDelayIcon);
 				mSubject->SetDown(false);
 			}
-			return true;
 		}
 
 		virtual void OnVoid1Body()
@@ -154,10 +152,10 @@ namespace iggFrameDoubleButton_Private
 		{
 			double x[3];
 			mConcreteParent->GetPosition(x);
-			if(this->GetShell()->GetControlModule()->CreateObject(iMarkerViewObject::Type(),false,mConcreteParent->GetWindowNumber()))
+			if(this->GetShell()->GetControlModule()->CreateObject(iMarker::Type(),false,mConcreteParent->GetWindowNumber()))
 			{
 				iString ws;
-				this->GetShell()->GetControlModule()->PackCommand(ws,iMarkerViewObject::KeyPosition(true),x,3);
+				this->GetShell()->GetControlModule()->PackCommand(ws,iMarker::KeyPosition(true),x,3);
 				this->GetShell()->GetControlModule()->Execute(ws,true,0,mConcreteParent->GetWindowNumber());
 
 				this->GetMainWindow()->UpdateAll();
@@ -230,35 +228,32 @@ void iggFrameCreateDeleteButton::OnButton2()
 }
 
 
-bool iggFrameCreateDeleteButton::UpdateWidgetBody()
+void iggFrameCreateDeleteButton::UpdateWidgetBody()
 {
 	int i;
 	bool b;
 	const iObjectKey *key;
 
 	bool work;
-	key = iObjectKeyRegistry::FindKey(iViewObject::KeyDataPresent().RetypedKey(mType)); IERROR_ASSERT_NULL_POINTER(key);
+	key = iObjectKeyRegistry::FindKey(iViewSubject::KeyDataPresent().RetypedKey(mType)); IERROR_ASSERT(key);
 	if(this->GetShell()->GetControlModule()->QueryValue(*key,work))
 	{
 		work = work && mActive;
 		this->Enable(work);
-		if(!work) return true;
+		if(!work) return;
 	}
-	else return this->UpdateFailed();
 
-	key = iObjectKeyRegistry::FindKey(iViewModule::KeyMarkerMax().PrefixedKey().Substitute("Marker",mType.FullName())); IERROR_ASSERT_NULL_POINTER(key);
+	key = iObjectKeyRegistry::FindKey(iViewModule::KeyMarkerMax().PrefixedKey().Substitute("Marker",mType.FullName())); IERROR_ASSERT(key);
 	if(this->GetShell()->GetControlModule()->QueryValue(*key,i))
 	{
 		b = false;
 		if(!mKeepLast)
 		{
-			key = iObjectKeyRegistry::FindKey(iViewObject::KeyVisible().RetypedKey(mType)); IERROR_ASSERT_NULL_POINTER(key);
+			key = iObjectKeyRegistry::FindKey(iViewSubject::KeyVisible().RetypedKey(mType)); IERROR_ASSERT(key);
 			if(!this->GetShell()->GetControlModule()->QueryValue(*key,b)) b = false;
 		}
 		mDeleteButton->Enable(i>0 || (!mKeepLast && b));
-		return true;
 	}
-	else return this->UpdateFailed();
 }
 
 
