@@ -59,10 +59,9 @@ namespace iggFrameHistogramAreaExtra_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			mSubject->SetDown(mArea->GetLogScale());
-			return true;
 		}
 
 		virtual void OnVoid1Body()
@@ -85,7 +84,7 @@ using namespace iggFrameHistogramAreaExtra_Private;
 //
 iggFrameHistogramAreaExtra::iggFrameHistogramAreaExtra(iggWidgetHistogramArea *area, iggFrame *parent) : iggFrame(parent,3)
 {
-	mArea = area; IERROR_ASSERT_NULL_POINTER(area);
+	mArea = area; IERROR_ASSERT(area);
 	mArea->AddExtra(this);
 
 	mDisplayMin = new iggWidgetNumberDisplay("",this);
@@ -96,12 +95,12 @@ iggFrameHistogramAreaExtra::iggFrameHistogramAreaExtra(iggWidgetHistogramArea *a
 }
 
 
-bool iggFrameHistogramAreaExtra::UpdateWidgetBody()
+void iggFrameHistogramAreaExtra::UpdateWidgetBody()
 {
 	float min = 0.0, max = 0.0;
 	mArea->GetHistogramRange(min,max);
 	mDisplayMin->Display(min);
 	mDisplayMax->Display(max);
 
-	return iggFrame::UpdateWidgetBody();
+	this->iggFrame::UpdateWidgetBody();
 }
