@@ -44,7 +44,7 @@ using namespace iggParameter;
 #include "iggwidgetkeyhandlertemplate.h"
 
 
-iggFramePaletteSelection::iggFramePaletteSelection(const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggFramePaletteSelectionBase(true,parent)
+iggFramePaletteSelection::iggFramePaletteSelection(bool withbrightness, const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggFramePaletteSelectionBase(true,withbrightness,parent)
 {
 	//
 	//  This class combines the functionality of iggWidgetKeyHandler and iggFramePaletteSelectionBase.
@@ -77,6 +77,6 @@ void iggFramePaletteSelection::SetCurrentPaletteIndexBody(int i)
 
 iPalette* iggFramePaletteSelection::GetCurrentPalette() const
 {
-	return this->GetShell()->GetControlModule()->GetPalette(mCurrentPaletteIndex);
+	return this->GetShell()->GetControlModule()->GetPalette(iMath::Abs(mCurrentPaletteIndex)-1);
 }
 
