@@ -46,7 +46,7 @@ class iggFramePaletteSelection : public iggFramePaletteSelectionBase
 
 public:
 
-	iggFramePaletteSelection(const iObjectKey &key, iggFrame*parent, int index = -1, const iObjectKey *indkey = 0);
+	iggFramePaletteSelection(bool withbrightness, const iObjectKey &key, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);
 	virtual ~iggFramePaletteSelection();
 
 	void SetIndex(int i);
