@@ -37,6 +37,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggdialogpaletteeditor.h"
 #include "iggmainwindow.h"
 #include "iggwidgetarea.h"
+#include "iggwidgetmisc.h"
 #include "iggwidgetotherbutton.h"
 
 #include "ibgwidgetselectionboxsubject.h"
@@ -63,14 +64,45 @@ namespace iggFramePaletteSelectionBase_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
+			static const iImage dummy;
 			if(mFrame->GetCurrentPalette() != 0)
 			{
 				this->SetImage(*mFrame->GetCurrentPalette()->GetImage(),true);
-				return iggWidgetImageArea::UpdateWidgetBody();
 			}
-			else return false;
+			else
+			{
+				this->SetImage(dummy,true);
+			}
+			this->iggWidgetImageArea::UpdateWidgetBody();
+		}
+
+		iggFramePaletteSelectionBase *mFrame;
+	};
+
+	
+	class IsReversedCheckBox : public iggWidgetSimpleCheckBox
+	{
+
+	public:
+
+		IsReversedCheckBox(iggFramePaletteSelectionBase *parent) : iggWidgetSimpleCheckBox("Reversed",parent)
+		{
+			mFrame = parent;
+			this->SetBaloonHelp("Reverse the current palette","Use this check box to flip the order of colors in the current palette.");
+		}
+
+	protected:
+
+		virtual void UpdateWidgetBody()
+		{
+			this->Enable(mFrame->GetCurrentPaletteIndex() != 0);
+		}
+
+		virtual void OnChecked(bool s)
+		{
+			mFrame->SetCurrentPaletteIndex(iMath::Abs(mFrame->GetCurrentPaletteIndex())*(s?-1:1));
 		}
 
 		iggFramePaletteSelectionBase *mFrame;
@@ -82,10 +114,12 @@ namespace iggFramePaletteSelectionBase_Private
 
 	public:
 
-		PaletteList(iggFramePaletteSelectionBase *parent) : iggWidget(parent)
+		PaletteList(IsReversedCheckBox *rb, bool withbrightness, iggFramePaletteSelectionBase *parent) : iggWidget(parent)
 		{
 			mSubject = iggSubjectFactory::CreateWidgetComboBoxSubject(this,"Palette");
 			mFrame = parent;
+			mReverseBox = rb;
+			mOffset = (withbrightness ? 0 : 1);
 
 			this->SetBaloonHelp("Choose palette from the list","Choose a palette from the list of all available palettes. Use Palette Editor from the dialog menus to create new or change existing palettes.");
 		}
@@ -101,25 +135,27 @@ namespace iggFramePaletteSelectionBase_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			int i, np = this->GetShell()->GetControlModule()->GetNumberOfPalettes();
 
 			mSubject->Clear();
+			if(mOffset == 0) mSubject->InsertItem("Brightness");
 			for(i=0; i<np; i++)
 			{
 				mSubject->InsertItem(this->GetShell()->GetControlModule()->GetPalette(i)->GetName());
 			}
 
-			mSubject->SetValue(mFrame->GetCurrentPaletteIndex());
-			return true;
+			mSubject->SetValue(iMath::Abs(mFrame->GetCurrentPaletteIndex())-mOffset);
 		}
 
 		virtual void OnInt1Body(int n)
 		{
-			mFrame->SetCurrentPaletteIndex(n);
+			mFrame->SetCurrentPaletteIndex((mOffset+n)*(mReverseBox->IsDown()?-1:1));
 		}
 
+		int mOffset;
+		IsReversedCheckBox *mReverseBox;
 		iggFramePaletteSelectionBase *mFrame;
 		ibgWidgetComboBoxSubject *mSubject;
 	};
@@ -154,14 +190,16 @@ namespace iggFramePaletteSelectionBase_Private
 using namespace iggFramePaletteSelectionBase_Private;
 
 
-iggFramePaletteSelectionBase::iggFramePaletteSelectionBase(bool witheditor, iggFrame *parent) : iggFrame("Current palette",parent,2)
+iggFramePaletteSelectionBase::iggFramePaletteSelectionBase(bool witheditor, bool withbrightness, iggFrame *parent) : iggFrame("Current palette",parent,3)
 {
-	mCurrentPaletteIndex = 0;
+	mCurrentPaletteIndex = 1;
 
 	PaletteView *view = new PaletteView(this);
-	PaletteList *list = new PaletteList(this);
-	this->AddLine(view,2);
-	this->AddLine(list,2);
+	IsReversedCheckBox *rb = new IsReversedCheckBox(this);
+	PaletteList *list = new PaletteList(rb,withbrightness,this);
+	list->AddDependent(rb);
+	this->AddLine(view,3);
+	this->AddLine(list,2,rb,1);
 
 	if(witheditor)
 	{
@@ -183,12 +221,12 @@ iggFramePaletteSelectionBase::~iggFramePaletteSelectionBase()
 
 void iggFramePaletteSelectionBase::SetCurrentPaletteIndex(int n)
 {
-	if(n>=0 && n<this->GetShell()->GetControlModule()->GetNumberOfPalettes())
+	if(n>-this->GetShell()->GetControlModule()->GetNumberOfPalettes() && n<this->GetShell()->GetControlModule()->GetNumberOfPalettes())
 	{
 		mCurrentPaletteIndex = n;
 		this->SetCurrentPaletteIndexBody(n);
 	}
-	else IERROR_REPORT_ERROR("Incorrect palette number.");
+	else IERROR_REPORT("Incorrect palette number.");
 }
 
 
