@@ -58,7 +58,7 @@ namespace iggFramePosition_Private
 		{
 			if(!this->GetShell()->GetControlModule()->QueryValue(mKey,x,3))
 			{
-				IERROR_REPORT_ERROR("Unable to query the position value.");
+				IERROR_REPORT("Unable to query the position value.");
 			}
 		}
 
@@ -76,7 +76,7 @@ iggFramePosition::iggFramePosition(const iString &title, const iObjectKey &key,
 {
 	if(key.Argument()!=iObjectKey::_Double || key.Dimension()!=3)
 	{
-		IERROR_REPORT_FATAL_ERROR("iggFramePosition is configured incorrectly.");
+		IERROR_FINISH("iggFramePosition is configured incorrectly.");
 	}
 
 	this->AddLine(new iggWidgetKeyPositionSlider(5,"%b%+X",key,_RenderModeUseGlobal,this,0));
