@@ -50,8 +50,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggparameter.h"
 using namespace iggParameter;
 
-#include <stdlib.h>
-
 //
 //  Templates (needed for some compilers)
 //
@@ -98,7 +96,7 @@ namespace iggFrameRangeMapping_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody();
+		virtual void UpdateWidgetBody();
 
 		virtual void DrawForegroundBody()
 		{
@@ -162,7 +160,7 @@ namespace iggFrameRangeMapping_Private
  			}
 			else
 			{
-				IERROR_REPORT_ERROR("Unable to query RangeMapping.");
+				IERROR_REPORT("Unable to query RangeMapping.");
 			}
 		}
 		
@@ -222,9 +220,8 @@ namespace iggFrameRangeMapping_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
-			return true;
 		}
 
 		ibgWidgetEntrySubject *mSubject;
@@ -335,7 +332,7 @@ namespace iggFrameRangeMapping_Private
 	//
 	//  Area functions
 	//
-	bool Area::UpdateWidgetBody()
+	void Area::UpdateWidgetBody()
 	{
 		iRangeMapping *rm = 0;
 		
@@ -347,9 +344,8 @@ namespace iggFrameRangeMapping_Private
 			int nBins = round(rm->GetEstimatedNumberOfBins()*mHistogramSlider->GetValue());
 			if(nBins < 2) nBins = 2;
 			this->SetHistogram(rm->GetHistogram(nBins),0);
-			return iggWidgetHistogramArea::UpdateWidgetBody();
+			this->iggWidgetHistogramArea::UpdateWidgetBody();
 		}
-		else return this->UpdateFailed();
 	}
 
 
@@ -396,14 +392,14 @@ namespace iggFrameRangeMapping_Private
 					ix2 = round(dx*(aMax-attMin));
 					if(ix2<=ixmax && ix2>ixmax-lineWidth/2) ix2 = ixmax-lineWidth/2;
 					
-					idx = abs(x-ix1);
+					idx = iMath::Abs(x-ix1);
 					if(idxmin > idx)
 					{
 						indmin = i;
 						idxmin = idx;
 						isMax = false;
 					}
-					idx = abs(x-ix2);
+					idx = iMath::Abs(x-ix2);
 					if(idxmin > idx)
 					{
 						indmin = i;
