@@ -31,7 +31,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "ianimator.h"
 #include "icontrolmodule.h"
-#include "icrosssectionviewobject.h"
+#include "icrosssectionviewsubject.h"
 #include "idata.h"
 #include "idataexplorer.h"
 #include "idatalimits.h"
@@ -43,16 +43,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ihelpfactory.h"
 #include "iimagefactory.h"
 #include "iparallelmanager.h"
-#include "iparticlesviewobject.h"
+#include "iparticlesviewsubject.h"
 #include "ishell.h"
-#include "isurfaceviewobject.h"
+#include "isurfaceviewsubject.h"
 #include "isystem.h"
-#include "itensorfieldviewobject.h"
+#include "itensorfieldviewsubject.h"
 #include "itextactor.h"
-#include "ivectorfieldviewobject.h"
+#include "ivectorfieldviewsubject.h"
 #include "iversion.h"
 #include "iviewmodule.h"
-#include "ivolumeviewobject.h"
+#include "ivolumeviewsubject.h"
 
 #include "iggdialoganimatingprogress.h"
 #include "iggdialogcommandline.h"
@@ -178,18 +178,17 @@ namespace iggMainWindow_Private
 	const int _MenuOptionAxesBox = 314;
 	const int _MenuOptionFontTypeBitmap = 322;
 	const int _MenuOptionFontTypeVector = 323;
-	const int _MenuOptionFontSize10 = 331;
-	const int _MenuOptionFontSize12 = 332;
-	const int _MenuOptionFontSize14 = 333;
-	const int _MenuOptionFontSize16 = 334;
-	const int _MenuOptionFontSize20 = 335;
-	const int _MenuOptionFontSize24 = 336;
-	const int _MenuOptionFontSize32 = 337;
-	const int _MenuOptionFontSize40 = 338;
-	const int _MenuOptionFontSize48 = 339;
-	const int _MenuOptionFontSize64 = 340;
-	const int _MenuOptionFontSize80 = 341;
-	const int _MenuOptionFontSize96 = 342;
+	const int _MenuOptionFontSizem5 = 331;
+	const int _MenuOptionFontSizem4 = 332;
+	const int _MenuOptionFontSizem3 = 333;
+	const int _MenuOptionFontSizem2 = 334;
+	const int _MenuOptionFontSizem1 = 335;
+	const int _MenuOptionFontSizec0 = 336;
+	const int _MenuOptionFontSizep1 = 337;
+	const int _MenuOptionFontSizep2 = 338;
+	const int _MenuOptionFontSizep3 = 339;
+	const int _MenuOptionFontSizep4 = 340;
+	const int _MenuOptionFontSizep5 = 341;
 	const int _MenuOptionImageFormatPNG = 351;
 	const int _MenuOptionImageFormatJPG = 352;
 	const int _MenuOptionImageFormatPPM = 353;
@@ -272,7 +271,7 @@ namespace iggMainWindow_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			static Entry data0[] = 
 			{ 
@@ -386,9 +385,8 @@ namespace iggMainWindow_Private
 			if(n == 0)
 			{
 #ifdef I_CHECK1
-				IERROR_REPORT_ERROR("Should not be here");
+				IERROR_REPORT("Should not be here");
 #endif
-				return false;
 			}
 
 			if(data != mShownData)
@@ -405,7 +403,7 @@ namespace iggMainWindow_Private
 				}
 				mShownData = data;
 			}
-			return iggWidgetTextBrowser::UpdateWidgetBody();
+			this->iggWidgetTextBrowser::UpdateWidgetBody();
 		}
 
 		Entry* mShownData;
@@ -432,9 +430,8 @@ namespace iggMainWindow_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
-			return true;
 		}
 	};
 
@@ -453,7 +450,7 @@ namespace iggMainWindow_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			int i, k, n = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetNumberOfVisitedFiles();
 			const iDataReader::VisitedFile *list = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetVisitedFilesList();
@@ -469,8 +466,6 @@ namespace iggMainWindow_Private
 				if(k == 0) k += 4; else k++;
 			}
 			while(!mSubject->DoesContentFit());
-
-			return true;
 		}
 
 		virtual void OnInt1Body(int v)
@@ -624,9 +619,8 @@ namespace iggMainWindow_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
-			return true;
 		}
 
 		void OnVoid1Body()
@@ -650,9 +644,8 @@ namespace iggMainWindow_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
-			return true;
 		}
 
 		void OnVoid1Body()
@@ -733,7 +726,7 @@ using namespace iggMainWindow_Private;
 //
 //  **************************************************************************************
 //
-iggMainWindow::iggMainWindow(iShell *shell) : iggMenuWindow(shell), mThemeList(iString()), mReloadDataInfo(iDataInfo::Null()), mEraseDataInfo(iDataInfo::Null())
+iggMainWindow::iggMainWindow(iShell *shell) : iggMenuWindow(shell), mThemeList(iString()), mReloadDataInfo(new iDataInfo), mEraseDataInfo(new iDataInfo)
 {
 	mInitialized = mDocked = mDoNotOfferToReload = mDetailLoadedDataInfo = false;
 	mInteractorHelp = mToolTips = mOptionsAreGlobal = mWindowUnderFocusCurrent = true;
@@ -750,6 +743,9 @@ iggMainWindow::iggMainWindow(iShell *shell) : iggMenuWindow(shell), mThemeList(i
 	mPrevPos[0] = mPrevPos[1] = -1;
 
 	mMainWindow = this;
+
+	IERROR_ASSERT(mReloadDataInfo);
+	IERROR_ASSERT(mEraseDataInfo);
 }
 
 
@@ -781,8 +777,8 @@ void iggMainWindow::StartInitialization()
 
 	mMainSubject->SetTopParentSubjects(mBusyIndicatorFrame,mVisitedFileListFrame);
 
-	IERROR_ASSERT_NULL_POINTER(mBusyIndicatorFrame->GetSubject());
-	IERROR_ASSERT_NULL_POINTER(mVisitedFileListFrame->GetSubject());
+	IERROR_ASSERT(mBusyIndicatorFrame->GetSubject());
+	IERROR_ASSERT(mVisitedFileListFrame->GetSubject());
 
 	//
 	//  Other components
@@ -821,23 +817,23 @@ void iggMainWindow::StartInitialization()
 	//
 	//  Create dialogs (needed for book pages)
 	//
-	mDialogAbout = new DialogAbout(this); IERROR_ASSERT_NULL_POINTER(mDialogAbout);
-	mDialogAnimatingProgress = new iggDialogAnimatingProgress(this); IERROR_ASSERT_NULL_POINTER(mDialogAnimatingProgress);
-	mDialogAxesLabels = new AxesLabelsDialog(this); IERROR_ASSERT_NULL_POINTER(mDialogAxesLabels);
-	mDialogCommandLine = new iggDialogCommandLine(this); IERROR_ASSERT_NULL_POINTER(mDialogCommandLine);
-	mDialogDataExplorer = new iggDialogDataExplorer(this); IERROR_ASSERT_NULL_POINTER(mDialogDataExplorer);
-	mDialogDocking = new DialogDocking(this); IERROR_ASSERT_NULL_POINTER(mDialogDocking);
-	mDialogEventRecorder = new iggDialogEventRecorder(this); IERROR_ASSERT_NULL_POINTER(mDialogEventRecorder);
-	mDialogFileSetExplorer = new iggDialogFileSetExplorer(this); IERROR_ASSERT_NULL_POINTER(mDialogFileSetExplorer);
-	mDialogHelp = new iggDialogHelp(this); IERROR_ASSERT_NULL_POINTER(mDialogHelp);
-	mDialogImageComposer = new iggDialogImageComposer(this); IERROR_ASSERT_NULL_POINTER(mDialogImageComposer);
-	mDialogLoadFile = new iggDialogLoadFile(this); IERROR_ASSERT_NULL_POINTER(mDialogLoadFile);
-	mDialogPaletteEditor = new iggDialogPaletteEditor(this); IERROR_ASSERT_NULL_POINTER(mDialogPaletteEditor);
-	mDialogParallelController = new iggDialogParallelController(this); IERROR_ASSERT_NULL_POINTER(mDialogParallelController);
-	mDialogPerformanceMeter = new iggDialogPerformanceMeter(this); IERROR_ASSERT_NULL_POINTER(mDialogPerformanceMeter);
-	mDialogPickerWindow = new iggDialogPickerWindow(this); IERROR_ASSERT_NULL_POINTER(mDialogPickerWindow);
+	mDialogAbout = new DialogAbout(this); IERROR_ASSERT(mDialogAbout);
+	mDialogAnimatingProgress = new iggDialogAnimatingProgress(this); IERROR_ASSERT(mDialogAnimatingProgress);
+	mDialogAxesLabels = new AxesLabelsDialog(this); IERROR_ASSERT(mDialogAxesLabels);
+	mDialogCommandLine = new iggDialogCommandLine(this); IERROR_ASSERT(mDialogCommandLine);
+	mDialogDataExplorer = new iggDialogDataExplorer(this); IERROR_ASSERT(mDialogDataExplorer);
+	mDialogDocking = new DialogDocking(this); IERROR_ASSERT(mDialogDocking);
+	mDialogEventRecorder = new iggDialogEventRecorder(this); IERROR_ASSERT(mDialogEventRecorder);
+	mDialogFileSetExplorer = new iggDialogFileSetExplorer(this); IERROR_ASSERT(mDialogFileSetExplorer);
+	mDialogHelp = new iggDialogHelp(this); IERROR_ASSERT(mDialogHelp);
+	mDialogImageComposer = new iggDialogImageComposer(this); IERROR_ASSERT(mDialogImageComposer);
+	mDialogLoadFile = new iggDialogLoadFile(this); IERROR_ASSERT(mDialogLoadFile);
+	mDialogPaletteEditor = new iggDialogPaletteEditor(this); IERROR_ASSERT(mDialogPaletteEditor);
+	mDialogParallelController = new iggDialogParallelController(this); IERROR_ASSERT(mDialogParallelController);
+	mDialogPerformanceMeter = new iggDialogPerformanceMeter(this); IERROR_ASSERT(mDialogPerformanceMeter);
+	mDialogPickerWindow = new iggDialogPickerWindow(this); IERROR_ASSERT(mDialogPickerWindow);
 	mDialogRenderingProgress = 0; // we create this one later, so that it does not pop up during the initialization process
-	mDialogScriptDebugger = new iggDialogScriptDebugger(this); IERROR_ASSERT_NULL_POINTER(mDialogScriptDebugger);
+	mDialogScriptDebugger = new iggDialogScriptDebugger(this); IERROR_ASSERT(mDialogScriptDebugger);
 
 	//
 	//  Create the book
@@ -850,7 +846,7 @@ void iggMainWindow::StartInitialization()
 	mDataPage = new iggPageData(mBook);
 //	iggPage::SetDelayedConstruction(true);
 
-	iParticlesViewObject::UseFullState(false); // optimization, since we use iParticleGroup keys
+	iParticlesViewSubject::UseFullState(false); // optimization, since we use iParticleGroup keys
 
 	mBook->AddPage("View",iImageFactory::FindIcon("view.png"),mViewPage);
 	mBook->AddPage("Surface",iImageFactory::FindIcon("surf.png"),new iggPageSurface(mBook));
@@ -925,7 +921,7 @@ void iggMainWindow::PreShowInitialization()
 
 void iggMainWindow::PostShowInitialization()
 {
-	mDialogRenderingProgress = new iggDialogRenderingProgress(this); IERROR_ASSERT_NULL_POINTER(mDialogRenderingProgress);
+	mDialogRenderingProgress = new iggDialogRenderingProgress(this); IERROR_ASSERT(mDialogRenderingProgress);
 
 	int wg[4];
 	this->GetSubject()->GetWindowGeometry(wg);
@@ -977,6 +973,9 @@ iggMainWindow::~iggMainWindow()
 	{
 		delete mMainSubject;
 	}
+
+	delete mReloadDataInfo;
+	delete mEraseDataInfo;
 }
 
 
@@ -1041,16 +1040,16 @@ void iggMainWindow::LoadData(const iDataType &type, const iString &filename, int
 
 void iggMainWindow::AddReloadDataType(const iDataType &type)
 {
-	mReloadDataInfo += type;
+	*mReloadDataInfo += type;
 }
 
 
 void iggMainWindow::ReloadData()
 {
 	mProgressBarMode = 1;
-	mDialogLoadFile->ReloadData(mReloadDataInfo);
+	mDialogLoadFile->ReloadData(*mReloadDataInfo);
 	mProgressBarMode = 0;
-	mReloadDataInfo.Erase();
+	mReloadDataInfo->Erase();
 }
 
 
@@ -1071,13 +1070,13 @@ void iggMainWindow::RequestReloadData(const iDataInfo &info)
 
 void iggMainWindow::AddEraseDataType(const iDataType &type)
 {
-	mEraseDataInfo += type;
+	*mEraseDataInfo += type;
 }
 
 
 void iggMainWindow::RemoveEraseDataType(const iDataType &type)
 {
-	mEraseDataInfo -= type;
+	*mEraseDataInfo -= type;
 }
 
 
@@ -1087,14 +1086,14 @@ void iggMainWindow::EraseData()
 
 	this->Block(true);
 	
-	for(i=0; i<mEraseDataInfo.Count(); i++)
+	for(i=0; i<mEraseDataInfo->Count(); i++)
 	{
-		this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->EraseData(mEraseDataInfo.Type(i));
-		this->AfterEraseData(mEraseDataInfo.Type(i));
+		this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->EraseData(mEraseDataInfo->Type(i));
+		this->AfterEraseData(mEraseDataInfo->Type(i));
 	}
 	
 	this->Block(false);
-	mEraseDataInfo.Erase();
+	mEraseDataInfo->Erase();
 }
 
 
@@ -1114,7 +1113,7 @@ void iggMainWindow::AfterLoadData(const iDataType &type, const iString &)
 		if(this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->IsSet())
 		{
 			int m = 0;
-			while(this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetFileSetDataType(m) != iDataType::Null())
+			while(this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetFileSetDataType(m) != iData::None())
 			{
 				this->WriteToLog((m==0)?"File Set":"        ",this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetFileSetDataType(m).GetTextName());
 				m++;
@@ -1168,13 +1167,13 @@ void iggMainWindow::LogDataInfo(const iDataType &type, bool details)
 
 	this->WriteToLog("","");
 
-	if(type==iDataType::UniformScalars() && dr->IsThereData(iDataType::UniformScalars()))
+	if(type==iData::UniformScalars() && dr->IsThereData(iData::UniformScalars()))
 	{
 		int i, dims[3];
 
-		sub = dr->GetSubject(iDataType::UniformScalars());
-		lim = dr->GetLimits(iDataType::UniformScalars());
-		vtkStructuredPoints *data = iPointerCast<vtkStructuredPoints,vtkDataSet>(dr->GetOutput(iDataType::UniformScalars()));
+		sub = dr->GetSubject(iData::UniformScalars());
+		lim = dr->GetLimits(iData::UniformScalars());
+		vtkStructuredPoints *data = iPointerCast<vtkStructuredPoints,vtkDataSet>(dr->GetOutput(iData::UniformScalars()));
 		data->GetDimensions(dims);
 
 		this->WriteToLog("Uniform Scalars file","");
@@ -1183,7 +1182,7 @@ void iggMainWindow::LogDataInfo(const iDataType &type, bool details)
 
 		if(de != 0)
 		{
-			de->SetActiveDataType(iDataType::UniformScalars());
+			de->SetActiveDataType(iData::UniformScalars());
             for(i=0; i<de->GetNumberOfInputComponents(); i++)
 			{
 				de->SetInputComponent(i);
@@ -1193,40 +1192,40 @@ void iggMainWindow::LogDataInfo(const iDataType &type, bool details)
 		}
 	}
 
-	if(type==iDataType::UniformVectors() && dr->IsThereData(iDataType::UniformVectors()))
+	if(type==iData::UniformVectors() && dr->IsThereData(iData::UniformVectors()))
 	{
 		int dims[3];
 
-		sub = dr->GetSubject(iDataType::UniformVectors());
-		lim = dr->GetLimits(iDataType::UniformVectors());
-		vtkStructuredPoints *data = iPointerCast<vtkStructuredPoints,vtkDataSet>(dr->GetOutput(iDataType::UniformVectors()));
+		sub = dr->GetSubject(iData::UniformVectors());
+		lim = dr->GetLimits(iData::UniformVectors());
+		vtkStructuredPoints *data = iPointerCast<vtkStructuredPoints,vtkDataSet>(dr->GetOutput(iData::UniformVectors()));
 		data->GetDimensions(dims);
 
 		this->WriteToLog("Uniform Vectors file","");
 		this->WriteToLog("Dimensions",iString::FromNumber(dims[0])+" x "+iString::FromNumber(dims[1])+" x "+iString::FromNumber(dims[2]));
 		if(de != 0)
 		{
-			de->SetActiveDataType(iDataType::UniformVectors());
+			de->SetActiveDataType(iData::UniformVectors());
 			de->SetInputComponent(0);
 			di = de->GetInfo(true);
 			this->WriteToLog("Vector amplitude",iString::FromNumber(di.Maximum)+" ("+iString::FromNumber(log10(1.0e-30+fabs(di.Maximum)))+" dex)");
 		}
 	}
 
-	if(type==iDataType::UniformTensors() && dr->IsThereData(iDataType::UniformTensors()))
+	if(type==iData::UniformTensors() && dr->IsThereData(iData::UniformTensors()))
 	{
 		int i, dims[3];
 
-		sub = dr->GetSubject(iDataType::UniformTensors());
-		lim = dr->GetLimits(iDataType::UniformTensors());
-		vtkStructuredPoints *data = iPointerCast<vtkStructuredPoints,vtkDataSet>(dr->GetOutput(iDataType::UniformTensors()));
+		sub = dr->GetSubject(iData::UniformTensors());
+		lim = dr->GetLimits(iData::UniformTensors());
+		vtkStructuredPoints *data = iPointerCast<vtkStructuredPoints,vtkDataSet>(dr->GetOutput(iData::UniformTensors()));
 		data->GetDimensions(dims);
 
 		this->WriteToLog("Uniform Tensors file","");
 		this->WriteToLog("Dimensions",iString::FromNumber(dims[0])+" x "+iString::FromNumber(dims[1])+" x "+iString::FromNumber(dims[2]));
 		if(de != 0)
 		{
-			de->SetActiveDataType(iDataType::UniformTensors());
+			de->SetActiveDataType(iData::UniformTensors());
             for(i=0; i<3; i++)
 			{
 				de->SetInputComponent(i);
@@ -1236,20 +1235,20 @@ void iggMainWindow::LogDataInfo(const iDataType &type, bool details)
 		}
 	}
 
-	if(type==iDataType::BasicParticles() && dr->IsThereData(iDataType::BasicParticles()))
+	if(type==iData::BasicParticles() && dr->IsThereData(iData::BasicParticles()))
 	{
 		int i;
 
-		sub = dr->GetSubject(iDataType::BasicParticles());
-		lim = dr->GetLimits(iDataType::BasicParticles());
-		vtkPolyData *data = iPointerCast<vtkPolyData,vtkDataSet>(dr->GetOutput(iDataType::BasicParticles()));
+		sub = dr->GetSubject(iData::BasicParticles());
+		lim = dr->GetLimits(iData::BasicParticles());
+		vtkPolyData *data = iPointerCast<vtkPolyData,vtkDataSet>(dr->GetOutput(iData::BasicParticles()));
 
 		this->WriteToLog("Basic Particles file","");
 		this->WriteToLog("Number of particles",iString::FromNumber(long(data->GetNumberOfPoints())));
 		this->WriteToLog("Number of attributes",iString::FromNumber(lim->GetNumVars()));
 		if(de != 0)
 		{
-			de->SetActiveDataType(iDataType::BasicParticles());
+			de->SetActiveDataType(iData::BasicParticles());
             for(i=0; i<de->GetNumberOfInputComponents(); i++)
 			{
 				de->SetInputComponent(i);
@@ -1857,18 +1856,17 @@ void iggMainWindow::BuildMenus()
 
 			this->GetSubject()->BeginMenu("Font &size",true);
 			{
-				this->GetSubject()->AddMenuItem(_MenuOptionFontSize10,"10",0,"",true,false,0,false,&iViewModule::KeyFontSize(),10);
-				this->GetSubject()->AddMenuItem(_MenuOptionFontSize12,"12",0,"",true,false,0,false,&iViewModule::KeyFontSize(),12);
-				this->GetSubject()->AddMenuItem(_MenuOptionFontSize14,"14",0,"",true,false,0,false,&iViewModule::KeyFontSize(),14);
-				this->GetSubject()->AddMenuItem(_MenuOptionFontSize16,"16",0,"",true,false,0,false,&iViewModule::KeyFontSize(),16);
-				this->GetSubject()->AddMenuItem(_MenuOptionFontSize20,"20",0,"",true,false,0,false,&iViewModule::KeyFontSize(),20);
-				this->GetSubject()->AddMenuItem(_MenuOptionFontSize24,"24",0,"",true,false,0,false,&iViewModule::KeyFontSize(),24);
-				this->GetSubject()->AddMenuItem(_MenuOptionFontSize32,"32",0,"",true,false,0,false,&iViewModule::KeyFontSize(),32);
-				this->GetSubject()->AddMenuItem(_MenuOptionFontSize40,"40",0,"",true,false,0,false,&iViewModule::KeyFontSize(),40);
-				this->GetSubject()->AddMenuItem(_MenuOptionFontSize48,"48",0,"",true,false,0,false,&iViewModule::KeyFontSize(),48);
-				this->GetSubject()->AddMenuItem(_MenuOptionFontSize64,"64",0,"",true,false,0,false,&iViewModule::KeyFontSize(),64);
-				this->GetSubject()->AddMenuItem(_MenuOptionFontSize80,"80",0,"",true,false,0,false,&iViewModule::KeyFontSize(),80);
-				this->GetSubject()->AddMenuItem(_MenuOptionFontSize96,"96",0,"",true,false,0,false,&iViewModule::KeyFontSize(),96);
+				this->GetSubject()->AddMenuItem(_MenuOptionFontSizem5," 20%",0,"",true,false,0,false,&iViewModule::KeyFontScale(),-5);
+				this->GetSubject()->AddMenuItem(_MenuOptionFontSizem4," 30%",0,"",true,false,0,false,&iViewModule::KeyFontScale(),-4);
+				this->GetSubject()->AddMenuItem(_MenuOptionFontSizem3," 40%",0,"",true,false,0,false,&iViewModule::KeyFontScale(),-3);
+				this->GetSubject()->AddMenuItem(_MenuOptionFontSizem2," 60%",0,"",true,false,0,false,&iViewModule::KeyFontScale(),-2);
+				this->GetSubject()->AddMenuItem(_MenuOptionFontSizem1," 75%",0,"",true,false,0,false,&iViewModule::KeyFontScale(),-1);
+				this->GetSubject()->AddMenuItem(_MenuOptionFontSizec0,"100%",0,"",true,false,0,false,&iViewModule::KeyFontScale(),0);
+				this->GetSubject()->AddMenuItem(_MenuOptionFontSizep1,"130%",0,"",true,false,0,false,&iViewModule::KeyFontScale(),+1);
+				this->GetSubject()->AddMenuItem(_MenuOptionFontSizep2,"180%",0,"",true,false,0,false,&iViewModule::KeyFontScale(),+2);
+				this->GetSubject()->AddMenuItem(_MenuOptionFontSizep3,"250%",0,"",true,false,0,false,&iViewModule::KeyFontScale(),+3);
+				this->GetSubject()->AddMenuItem(_MenuOptionFontSizep4,"330%",0,"",true,false,0,false,&iViewModule::KeyFontScale(),+4);
+				this->GetSubject()->AddMenuItem(_MenuOptionFontSizep5,"450%",0,"",true,false,0,false,&iViewModule::KeyFontScale(),+5);
 			}
 			this->GetSubject()->EndMenu();
 		}
@@ -1964,12 +1962,12 @@ void iggMainWindow::BuildMenus()
 	this->GetSubject()->AddToolBarButton(_MenuFileOpenUniformTensors,"Open UniformTensors data file");
 	mExtensionWindow->PopulateFileToolBar();
 	this->GetSubject()->AddToolBarSeparator();
-	this->GetSubject()->AddToolBarButton(_ToolBarShowSurface,"Show surface",iImageFactory::FindIcon("surf.png"),true,&iSurfaceViewObject::KeyReady(),false,&iSurfaceViewObject::KeyVisible());
-	this->GetSubject()->AddToolBarButton(_ToolBarShowCrossSection,"Show cross section",iImageFactory::FindIcon("xsec.png"),true,&iCrossSectionViewObject::KeyReady(),false,&iCrossSectionViewObject::KeyVisible());
-	this->GetSubject()->AddToolBarButton(_ToolBarShowVolume,"Show volume",iImageFactory::FindIcon("volv.png"),true,&iVolumeViewObject::KeyReady(),false,&iVolumeViewObject::KeyVisible());
-	this->GetSubject()->AddToolBarButton(_ToolBarShowParticleSet,"Show particles",iImageFactory::FindIcon("part.png"),true,&iParticlesViewObject::KeyReady(),false,&iParticlesViewObject::KeyVisible());
-	this->GetSubject()->AddToolBarButton(_ToolBarShowVectorField,"Show vector field",iImageFactory::FindIcon("vect.png"),true,&iVectorFieldViewObject::KeyReady(),false,&iVectorFieldViewObject::KeyVisible());
-	this->GetSubject()->AddToolBarButton(_ToolBarShowTensorField,"Show tensor field",iImageFactory::FindIcon("tens.png"),true,&iTensorFieldViewObject::KeyReady(),false,&iTensorFieldViewObject::KeyVisible());
+	this->GetSubject()->AddToolBarButton(_ToolBarShowSurface,"Show surface",iImageFactory::FindIcon("surf.png"),true,&iSurfaceViewSubject::KeyReady(),false,&iSurfaceViewSubject::KeyVisible());
+	this->GetSubject()->AddToolBarButton(_ToolBarShowCrossSection,"Show cross section",iImageFactory::FindIcon("xsec.png"),true,&iCrossSectionViewSubject::KeyReady(),false,&iCrossSectionViewSubject::KeyVisible());
+	this->GetSubject()->AddToolBarButton(_ToolBarShowVolume,"Show volume",iImageFactory::FindIcon("volv.png"),true,&iVolumeViewSubject::KeyReady(),false,&iVolumeViewSubject::KeyVisible());
+	this->GetSubject()->AddToolBarButton(_ToolBarShowParticleSet,"Show particles",iImageFactory::FindIcon("part.png"),true,&iParticlesViewSubject::KeyReady(),false,&iParticlesViewSubject::KeyVisible());
+	this->GetSubject()->AddToolBarButton(_ToolBarShowVectorField,"Show vector field",iImageFactory::FindIcon("vect.png"),true,&iVectorFieldViewSubject::KeyReady(),false,&iVectorFieldViewSubject::KeyVisible());
+	this->GetSubject()->AddToolBarButton(_ToolBarShowTensorField,"Show tensor field",iImageFactory::FindIcon("tens.png"),true,&iTensorFieldViewSubject::KeyReady(),false,&iTensorFieldViewSubject::KeyVisible());
 	mExtensionWindow->PopulateShowToolBar();
 	this->GetSubject()->AddToolBarSeparator();
 	this->GetSubject()->AddToolBarButton(_ToolBarOpenWindowsPage,"Switch to page with multiple windows controls",iImageFactory::FindIcon("wins.png"),false);
@@ -1990,7 +1988,7 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 
 	if(id < 0)
 	{
-		IERROR_REPORT_ERROR("Invalid menu item id.");
+		IERROR_REPORT("Invalid menu item id.");
 	}
 
 	if(id <= _MenuFileMax)
@@ -1999,34 +1997,34 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 		{
 		case _MenuFileOpenUniformScalars:
 			{
-				iString ws = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLastFileName(iDataType::UniformScalars());
+				iString ws = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLastFileName(iData::UniformScalars());
 				if(ws.IsEmpty()) ws = this->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentScalarFieldData);
 				fname = this->GetFileName("Choose a file",ws,"Scalar field files (*.bin *.txt)");
-				if(!fname.IsEmpty()) this->LoadData(iDataType::UniformScalars(),fname);
+				if(!fname.IsEmpty()) this->LoadData(iData::UniformScalars(),fname);
 				break;
 			}
 		case _MenuFileOpenUniformVectors:
 			{
-				iString ws = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLastFileName(iDataType::UniformVectors());
+				iString ws = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLastFileName(iData::UniformVectors());
 				if(ws.IsEmpty()) ws = this->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentVectorFieldData);
 				fname = this->GetFileName("Choose a file",ws,"Vector field files (*.bin *.txt)");
-				if(!fname.IsEmpty()) this->LoadData(iDataType::UniformVectors(),fname);
+				if(!fname.IsEmpty()) this->LoadData(iData::UniformVectors(),fname);
 				break;
 			}
 		case _MenuFileOpenUniformTensors:
 			{
-				iString ws = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLastFileName(iDataType::UniformTensors());
+				iString ws = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLastFileName(iData::UniformTensors());
 				if(ws.IsEmpty()) ws = this->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentTensorFieldData);
 				fname = this->GetFileName("Choose a file",ws,"Tensor field files (*.bin *.txt)");
-				if(!fname.IsEmpty()) this->LoadData(iDataType::UniformTensors(),fname);
+				if(!fname.IsEmpty()) this->LoadData(iData::UniformTensors(),fname);
 				break;
 			}
 		case _MenuFileOpenBasicParticles:
 			{
-				iString ws = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLastFileName(iDataType::BasicParticles());
+				iString ws = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLastFileName(iData::BasicParticles());
 				if(ws.IsEmpty()) ws = this->GetShell()->GetControlModule()->GetEnvironment(_EnvironmentParticleSetData);
 				fname = this->GetFileName("Choose a file",ws,"Particle set files (*.bin *.txt)");
-				if(!fname.IsEmpty()) this->LoadData(iDataType::BasicParticles(),fname);
+				if(!fname.IsEmpty()) this->LoadData(iData::BasicParticles(),fname);
 				break;
 			}
 		case _MenuFileExit:
@@ -2036,7 +2034,7 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 			}
 		default:
 			{
-				IERROR_REPORT_ERROR("Invalid menu item id.");
+				IERROR_REPORT("Invalid menu item id.");
 			}
 		}
 		return;
@@ -2098,7 +2096,7 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 			}
 		default:
 			{
-				IERROR_REPORT_ERROR("Invalid menu item id.");
+				IERROR_REPORT("Invalid menu item id.");
 			}
 		}
 		return;
@@ -2187,7 +2185,7 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 				{
 					if(on) this->SetTheme(id-_MenuStyleTheme);
 				}
-				else IERROR_REPORT_ERROR("Invalid menu item id.");
+				else IERROR_REPORT("Invalid menu item id.");
 			}
 		}
 		return;
@@ -2260,64 +2258,59 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontType(),_TextTypeVector);
 				break;
 			}
-		case _MenuOptionFontSize10:
+		case _MenuOptionFontSizem5:
 			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontSize(),10);
+				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontScale(),-5);
 				break;
 			}
-		case _MenuOptionFontSize12:
+		case _MenuOptionFontSizem4:
 			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontSize(),12);
+				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontScale(),-4);
 				break;
 			}
-		case _MenuOptionFontSize14:
+		case _MenuOptionFontSizem3:
 			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontSize(),14);
+				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontScale(),-3);
 				break;
 			}
-		case _MenuOptionFontSize16:
+		case _MenuOptionFontSizem2:
 			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontSize(),16);
+				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontScale(),-2);
 				break;
 			}
-		case _MenuOptionFontSize20:
+		case _MenuOptionFontSizem1:
 			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontSize(),20);
+				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontScale(),-1);
 				break;
 			}
-		case _MenuOptionFontSize24:
+		case _MenuOptionFontSizec0:
 			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontSize(),24);
+				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontScale(),0);
 				break;
 			}
-		case _MenuOptionFontSize32:
+		case _MenuOptionFontSizep1:
 			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontSize(),32);
+				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontScale(),1);
 				break;
 			}
-		case _MenuOptionFontSize40:
+		case _MenuOptionFontSizep2:
 			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontSize(),40);
+				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontScale(),2);
 				break;
 			}
-		case _MenuOptionFontSize48:
+		case _MenuOptionFontSizep3:
 			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontSize(),48);
+				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontScale(),3);
 				break;
 			}
-		case _MenuOptionFontSize64:
+		case _MenuOptionFontSizep4:
 			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontSize(),64);
+				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontScale(),4);
 				break;
 			}
-		case _MenuOptionFontSize80:
+		case _MenuOptionFontSizep5:
 			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontSize(),80);
-				break;
-			}
-		case _MenuOptionFontSize96:
-			{
-				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontSize(),96);
+				if(on) this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyFontScale(),5);
 				break;
 			}
 		case _MenuOptionImageFormatPNG:
@@ -2507,7 +2500,7 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 			}
 		default:
 			{
-				IERROR_REPORT_ERROR("Invalid menu item id.");
+				IERROR_REPORT("Invalid menu item id.");
 			}
 		}
 		if(!ws.IsEmpty()) this->GetShell()->GetControlModule()->Execute(ws,true,option);
@@ -2537,7 +2530,7 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 #endif
 		default:
 			{
-				IERROR_REPORT_ERROR("Invalid menu item id.");
+				IERROR_REPORT("Invalid menu item id.");
 			}
 		}
 		return;
@@ -2566,55 +2559,55 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 			}
 		case _ToolBarShowSurface:
 			{
+				this->GetShell()->GetControlModule()->Show(iSurfaceViewSubject::Type(),on);
 				mBook->OpenPage(1);
 				mExtensionWindow->OpenBookPageByIndex(1);
-				this->GetShell()->GetControlModule()->Show(iSurfaceViewObject::Type(),on);
 				mBook->GetPage(1)->UpdateWidget();
 				break;
 			}
 		case _ToolBarShowCrossSection:
 			{
+				this->GetShell()->GetControlModule()->Show(iCrossSectionViewSubject::Type(),on);
 				mBook->OpenPage(2);
 				mExtensionWindow->OpenBookPageByIndex(2);
-				this->GetShell()->GetControlModule()->Show(iCrossSectionViewObject::Type(),on);
 				mBook->GetPage(2)->UpdateWidget();
 				break;
 			}
 		case _ToolBarShowVolume:
 			{
+				this->GetShell()->GetControlModule()->Show(iVolumeViewSubject::Type(),on);
 				mBook->OpenPage(3);
 				mExtensionWindow->OpenBookPageByIndex(3);
-				this->GetShell()->GetControlModule()->Show(iVolumeViewObject::Type(),on);
 				mBook->GetPage(3)->UpdateWidget();
 				break;
 			}
 		case _ToolBarShowParticleSet:
 			{
+				this->GetShell()->GetControlModule()->Show(iParticlesViewSubject::Type(),on);
 				mBook->OpenPage(4);
 				mExtensionWindow->OpenBookPageByIndex(4);
-				this->GetShell()->GetControlModule()->Show(iParticlesViewObject::Type(),on);
 				mBook->GetPage(4)->UpdateWidget();
 				break;
 			}
 		case _ToolBarShowVectorField:
 			{
+				this->GetShell()->GetControlModule()->Show(iVectorFieldViewSubject::Type(),on);
 				mBook->OpenPage(5);
 				mExtensionWindow->OpenBookPageByIndex(5);
-				this->GetShell()->GetControlModule()->Show(iVectorFieldViewObject::Type(),on);
 				mBook->GetPage(5)->UpdateWidget();
 				break;
 			}
 		case _ToolBarShowTensorField:
 			{
+				this->GetShell()->GetControlModule()->Show(iTensorFieldViewSubject::Type(),on);
 				mBook->OpenPage(6);
 				mExtensionWindow->OpenBookPageByIndex(6);
-				this->GetShell()->GetControlModule()->Show(iTensorFieldViewObject::Type(),on);
 				mBook->GetPage(6)->UpdateWidget();
 				break;
 			}
 		default:
 			{
-				IERROR_REPORT_ERROR("Invalid menu item id.");
+				IERROR_REPORT("Invalid menu item id.");
 			}
 		}
 		return;
@@ -2622,6 +2615,6 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 
 	if(!mExtensionWindow->OnMenuBody(id,on))
 	{
-		IERROR_REPORT_ERROR("Invalid menu item id.");
+		IERROR_REPORT("Invalid menu item id.");
 	}
 }
