@@ -49,7 +49,7 @@ iggMenuWindow::iggMenuWindow(iShell *shell) : iShellComponent(shell)
 
 iggMenuWindow::iggMenuWindow(iggMainWindow *mainWindow) : iShellComponent(mainWindow?mainWindow->GetShell():0)
 {
-	IERROR_ASSERT_NULL_POINTER(mainWindow);
+	IERROR_ASSERT(mainWindow);
 	mMainWindow = mainWindow;
 	mMenuSubject = 0;
 	mGlobalFrame = 0;
@@ -64,7 +64,7 @@ iggMenuWindow::~iggMenuWindow()
 
 void iggMenuWindow::Show(bool s)
 {
-	IERROR_ASSERT_NULL_POINTER(mMenuSubject);
+	IERROR_ASSERT(mMenuSubject);
 
 	if(s)
 	{
@@ -83,7 +83,7 @@ iString iggMenuWindow::GetFileName(const iString &header, const iString &file, c
 
 void iggMenuWindow::UpdateAll()
 {
-	IERROR_ASSERT_NULL_POINTER(mMenuSubject);
+	IERROR_ASSERT(mMenuSubject);
 
 	mMenuSubject->UpdateMenus();
 	this->UpdateContents();
@@ -92,17 +92,17 @@ void iggMenuWindow::UpdateAll()
 
 void iggMenuWindow::AttachSubject(ibgMenuWindowSubject *subject, int cols)
 {
-	mMenuSubject = subject; IERROR_ASSERT_NULL_POINTER(mMenuSubject);
+	mMenuSubject = subject; IERROR_ASSERT(mMenuSubject);
 
 	mGlobalFrame = new iggFrameTopParent(this->GetShell());
 	mMenuSubject->SetGlobalFrame(mGlobalFrame,cols);
-	IERROR_ASSERT_NULL_POINTER(mGlobalFrame->GetSubject());
+	IERROR_ASSERT(mGlobalFrame->GetSubject());
 }
 
 
 void iggMenuWindow::OnMenu(int id, bool on)
 {
-	IERROR_ASSERT_NULL_POINTER(mMainWindow);
+	IERROR_ASSERT(mMainWindow);
 
 	mMainWindow->Block(true);
 	this->OnMenuBody(id,on);
