@@ -36,7 +36,7 @@ iggPage::iggPage(iggFrameBase *parent, bool withbook) : iggFrame(parent)
 {
 	if(withbook)
 	{
-		mBook = new iggFrameBook(this); IERROR_ASSERT_NULL_POINTER(mBook);
+		mBook = new iggFrameBook(this); IERROR_ASSERT(mBook);
 		this->AddLine(mBook);
 	}
 	else mBook = 0;
