@@ -95,7 +95,7 @@ namespace iggPageData_Private
 
 		virtual void QueryValue(iString &val) const
 		{
-			IERROR_REPORT_ERROR("This function should never be called.");
+			IERROR_REPORT("This function should never be called.");
 		}
 
 		virtual void UpdateValue(iString val)
@@ -199,15 +199,13 @@ namespace iggPageData_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			//
 			//  Optimization - direct access
 			//
 			iDataLimits *lim = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLimits(mPage->GetProvider()->GetActiveDataType());
-			if(mIndex >= lim->GetNumVars()) return true;
-
-			return iggWidgetKeyComboBox::UpdateWidgetBody();
+			if(mIndex < lim->GetNumVars()) this->iggWidgetKeyComboBox::UpdateWidgetBody();
 		}
 
 		virtual void OnInt1Body(int i)
@@ -235,7 +233,7 @@ namespace iggPageData_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			iDataLimits *lim = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLimits(mPage->GetProvider()->GetActiveDataType());
 			if(lim != 0) this->Show(!lim->AreNamesFixed()); else this->Show(false);
@@ -243,8 +241,7 @@ namespace iggPageData_Private
 			//  Optimization - direct access
 			//
 			mSubject->SetText(lim->GetName(mIndex));
-			return true;
-//			return iggWidgetKeyTextLineEdit::UpdateWidgetBody();
+			this->iggWidgetKeyTextLineEdit::UpdateWidgetBody();
 		}
 
 		virtual void OnVoid1Body()
@@ -271,21 +268,21 @@ namespace iggPageData_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			//
 			//  Optimization - direct access
 			//
 			iDataLimits *lim = this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->GetLimits(mPage->GetProvider()->GetActiveDataType());
-			if(mIndex >= lim->GetNumVars()) return true;
-
-			mMin = lim->GetMin(mIndex);
-			mMax = lim->GetMax(mIndex);
-			mStretch = lim->GetStretch(mIndex);
-			mResolution = this->ComputeResolution();
-			this->SetRange(0,mResolution);
-			return iggWidgetKeyFloatSlider::UpdateWidgetBody();
-//			return iggWidgetKeyVariableLimitsSlider::UpdateWidgetBody();
+			if(mIndex < lim->GetNumVars())
+			{
+				mMin = lim->GetMin(mIndex);
+				mMax = lim->GetMax(mIndex);
+				mStretch = lim->GetStretch(mIndex);
+				mResolution = this->ComputeResolution();
+				this->SetRange(0,mResolution);
+				this->iggWidgetKeyFloatSlider::UpdateWidgetBody();
+			}
 		}
 
 		const iggPageData *mPage;
@@ -314,11 +311,10 @@ namespace iggPageData_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 //			int n;
 //			iString s;
-			bool ret;
 			
 			if(mPage->GetProvider()->IsThereDataType())
 			{
@@ -336,20 +332,17 @@ namespace iggPageData_Private
 					this->SetTitle(lim->GetName(mIndex));
 					mStretchBox->Show(!lim->GetFixedStretch(mIndex));
 					this->Show(true);
-					ret = iggFrame::UpdateWidgetBody();
+					this->iggFrame::UpdateWidgetBody();
 				}
 				else
 				{
 					this->Show(false);
-					ret = true;
 				}
 			}
 			else
 			{
 				this->Show(false);
-				ret = true;
 			}
-			return ret;
 		}
 
 		int mIndex;
@@ -466,11 +459,10 @@ namespace iggPageData_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			mSubject->SetDown(false);
 			mWidgetHelper->Enable(this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->IsThereData(mType));
-			return true;
 		}
 
 		virtual void OnVoid1Body()
@@ -503,10 +495,9 @@ namespace iggPageData_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			this->Enable(this->GetMainWindow()->GetEraseDataInfo().Count()>0 && this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->IsThereData(this->GetMainWindow()->GetEraseDataInfo()));
-			return true;
 		}
 
 		virtual void Execute()
@@ -577,9 +568,8 @@ namespace iggPageData_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
-			return true;
 		}
 
 		ibgWidgetEntrySubject *mSubject;
@@ -658,7 +648,7 @@ namespace iggPageData_Private
 		{
 			mLineEdit = le;
 
-			mParser = new iExpressionParser; IERROR_ASSERT_NULL_POINTER(mParser);
+			mParser = new iExpressionParser; IERROR_ASSERT(mParser);
 
 			mParser->SetScalarVariableValue("Var1",1.0);
 			mParser->SetScalarVariableValue("Var2",1.0);
@@ -746,7 +736,7 @@ namespace iggPageData_Private
 
 			if(mCalculatorLineEdit->GetText() != line)
 			{
-				this->GetMainWindow()->RequestReloadData(iDataType::UniformScalars());
+				this->GetMainWindow()->RequestReloadData(iData::UniformScalars());
 			}
 
 		}
@@ -816,14 +806,14 @@ iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent)
 {
 	const iImage *icon = iImageFactory::FindIcon("data.png");
 
-	mInfoBuffer = new iDataInfo[__NumData]; IERROR_ASSERT_NULL_POINTER(mInfoBuffer);
-	mProvider = new iggKeywordDataTypeProvider("ScalarField",this); IERROR_ASSERT_NULL_POINTER(mProvider);
+	mInfoBuffer = new iDataInfo[__NumData]; IERROR_ASSERT(mInfoBuffer);
+	mProvider = new iggKeywordDataTypeProvider("ScalarField",this); IERROR_ASSERT(mProvider);
 
-	mInfoBuffer[_DataOnBoundaryCondition] = iDataType::UniformScalars() + iDataType::UniformVectors() + iDataType::UniformTensors() + iDataType::BasicParticles();
-	mInfoBuffer[_DataOnVoxelLocation] = iDataType::UniformScalars() + iDataType::UniformVectors() + iDataType::UniformTensors();
-	mInfoBuffer[_DataOnCellToPointMode] = iDataType::UniformScalars() + iDataType::UniformVectors() + iDataType::UniformTensors();
-	mInfoBuffer[_DataOnParticlesDownsample] = iDataType::BasicParticles();
-	mInfoBuffer[_DataOnParticlesOrderInFileIsAttribute] = iDataType::BasicParticles();
+	mInfoBuffer[_DataOnBoundaryCondition] = iData::UniformScalars() + iData::UniformVectors() + iData::UniformTensors() + iData::BasicParticles();
+	mInfoBuffer[_DataOnVoxelLocation] = iData::UniformScalars() + iData::UniformVectors() + iData::UniformTensors();
+	mInfoBuffer[_DataOnCellToPointMode] = iData::UniformScalars() + iData::UniformVectors() + iData::UniformTensors();
+	mInfoBuffer[_DataOnParticlesDownsample] = iData::BasicParticles();
+	mInfoBuffer[_DataOnParticlesOrderInFileIsAttribute] = iData::BasicParticles();
 
 	this->GetMainWindow()->GetExtensionWindow()->AddReloadingDataTypes(this);
 
