@@ -35,10 +35,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "iimagefactory.h"
 #include "iparticlegroup.h"
-#include "iparticlesviewobject.h"
+#include "iparticlesviewsubject.h"
 #include "ipointglyph.h"
 #include "ishell.h"
 #include "iviewmodule.h"
+#include "iviewobject.h"
 #include "iviewobjectfamily.h"
 
 #include "iggdatatypeprovider.h"
@@ -81,7 +82,7 @@ namespace iggPageParticles_Private
 		
 	public:
 		
-		RangeMapping(iggFrame *dependent, iggFrame *parent) : iggFrameRangeMapping(iParticlesViewObject::KeySplitRanges(),iParticlesViewObject::KeySplitRangesTiled(),parent)
+		RangeMapping(iggFrame *dependent, iggFrame *parent) : iggFrameRangeMapping(iParticlesViewSubject::KeySplitRanges(),iParticlesViewSubject::KeySplitRangesTiled(),parent)
 		{
 			mDependent = dependent;
 		}
@@ -89,19 +90,19 @@ namespace iggPageParticles_Private
 		virtual bool IsActive()
 		{
 			int att;
-			return (this->GetShell()->GetControlModule()->QueryValue(iParticlesViewObject::KeyAttributeToSplit(),att) && att>=0);
+			return (this->GetShell()->GetControlModule()->QueryValue(iParticlesViewSubject::KeyAttributeToSplit(),att) && att>=0);
 		}
 
 		virtual int GetCurrentRange()
 		{
 			int cur;
-			if(this->GetShell()->GetControlModule()->QueryValue(iParticlesViewObject::KeyCurrentGroup(),cur))
+			if(this->GetShell()->GetControlModule()->QueryValue(iParticlesViewSubject::KeyCurrentGroup(),cur))
 			{
 				return cur;
 			}
 			else
 			{
-				IERROR_REPORT_ERROR("Failed querying iParticlesViewObject::KeyCurrentGroup() key.");
+				IERROR_REPORT("Failed querying iParticlesViewSubject::KeyCurrentGroup() key.");
 				return 0;
 			}
 		}
@@ -109,7 +110,7 @@ namespace iggPageParticles_Private
 		virtual void SetCurrentRange(int c)
 		{
 			iString ws;
-			this->GetShell()->GetControlModule()->PackCommand(ws,iParticlesViewObject::KeyCurrentGroup(),c);
+			this->GetShell()->GetControlModule()->PackCommand(ws,iParticlesViewSubject::KeyCurrentGroup(),c);
 			this->GetShell()->GetControlModule()->Execute(ws,false,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
 		}
 
@@ -136,12 +137,12 @@ namespace iggPageParticles_Private
 			//
 			iString ws;
 			int att = 0;
-			if(this->GetShell()->GetControlModule()->QueryValue(iParticlesViewObject::KeyAttributeToSplit(),att))
+			if(this->GetShell()->GetControlModule()->QueryValue(iParticlesViewSubject::KeyAttributeToSplit(),att))
 			{
-				this->GetShell()->GetControlModule()->PackCommand(ws,iParticlesViewObject::KeyAttributeToSplit(),-1);
+				this->GetShell()->GetControlModule()->PackCommand(ws,iParticlesViewSubject::KeyAttributeToSplit(),-1);
 				this->GetShell()->GetControlModule()->Execute(ws,false,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
 				ws.Clear();
-				this->GetShell()->GetControlModule()->PackCommand(ws,iParticlesViewObject::KeyAttributeToSplit(),att);
+				this->GetShell()->GetControlModule()->PackCommand(ws,iParticlesViewSubject::KeyAttributeToSplit(),att);
 				this->GetShell()->GetControlModule()->Execute(ws,false,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
 				if(mDependent != 0) mDependent->UpdateWidget();
 			}
@@ -191,7 +192,7 @@ namespace iggPageParticles_Private
 
 		ParticleSetTypeProvider(iggPageParticles *page) : iggDataTypeProvider((page==0)?0:page->GetShell())
 		{
-			mPage = page; IERROR_ASSERT_NULL_POINTER(page);
+			mPage = page; IERROR_ASSERT(page);
 		}
 
 		virtual ~ParticleSetTypeProvider()
@@ -200,31 +201,31 @@ namespace iggPageParticles_Private
 
 		virtual int GetActiveDataTypeIndex() const
 		{
-			return mPage->GetViewModule()->GetParticlesFamily()->GetCurrentMemberIndex();
+			return mPage->GetParticlesObject()->GetActiveDataTypeIndex();
 		}
 
 		virtual void SetActiveDataTypeIndex(int v)
 		{
-			if(v != mPage->GetViewModule()->GetParticlesFamily()->GetCurrentMemberIndex())
+			if(v != this->GetActiveDataTypeIndex())
 			{
 				mPage->SetCurrentParticleSet(v);
 				mPage->GetMainWindow()->UpdateAll();
 			}
 		}
 		
-		virtual const iDataInfo* GetDataInfo() const
+		virtual const iDataInfo& GetDataInfo() const
 		{
 			static iDataInfo info;
 			if(info.Count() == 0)
 			{
 				iDataType::FindAllTypesByKeywords(info,"ParticleSet");
 			}
-			return &info;
+			return info;
 		}
 
 		virtual const iDataType& GetActiveDataType() const
 		{
-			return mPage->GetViewModule()->GetParticlesFamily()->GetCurrentMember()->GetActiveDataType();
+			return mPage->GetParticlesObject()->GetDataType();
 		}
 
 		iggPageParticles *mPage;
@@ -235,7 +236,7 @@ namespace iggPageParticles_Private
 using namespace iggPageParticles_Private;
 
 
-iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageViewObject(parent), mIcons(0)
+iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,iParameter::_ObjectTypeParticles), mIcons(0)
 {
 	int i;
 
@@ -243,13 +244,13 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageViewObject(par
 
 	mIcons.Add(iImageFactory::FindIcon("part.png"));
 
-	mCurrentParticleSet = this->GetShell()->GetControlModule()->GetViewModule()->GetParticlesFamily()->GetCurrentMemberIndex();
+	mCurrentParticleSet = this->GetParticlesObject()->GetActiveDataTypeIndex();
 
 	//
 	//  Replace provider
 	//
 	delete mProvider;
-	mProvider = new ParticleSetTypeProvider(this); IERROR_ASSERT_NULL_POINTER(mProvider);
+	mProvider = new ParticleSetTypeProvider(this); IERROR_ASSERT(mProvider);
 
 	//
 	//  Main page
@@ -260,9 +261,9 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageViewObject(par
 	//
 	//  Show
 	//
-	iggFrameCurrentInstance *ci = new iggFrameCurrentInstance(false,"Group","Group",iParticlesViewObject::KeyCurrentGroup(),iParticlesViewObject::KeyMaxGroup(),page0);
+	iggFrameCurrentInstance *ci = new iggFrameCurrentInstance(false,"Group","Group",iParticlesViewSubject::KeyCurrentGroup(),iParticlesViewSubject::KeyMaxGroup(),page0);
 	ci->AddDependent(this);
-	page0->AddLine(new iggWidgetShowButton(iParticlesViewObject::Type(),page0),(iggWidget *)0,ci);
+	page0->AddLine(new iggWidgetShowButton(iParticlesViewSubject::Type(),page0),(iggWidget *)0,ci);
 	page0->AddSpace(2);
 	//
 	//  Method & color normals
@@ -340,7 +341,7 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageViewObject(par
 
 	pbpage0->AddSpace(10);
 
-	pbpage0->AddLine(new iggFramePaletteSelection(iParticleGroup::KeyPalette(),pbpage0),2);
+	pbpage0->AddLine(new iggFramePaletteSelection(true,iParticleGroup::KeyPalette(),pbpage0),2);
 	pbpage0->AddSpace(20);
 
 	pbpage0->SetColStretch(1,10);
@@ -431,7 +432,7 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageViewObject(par
 	//
 	//  Replicate
 	//
-	page3->AddLine(new iggFrameReplicate(iParticlesViewObject::Type(),page3));
+	page3->AddLine(new iggFrameReplicate(iParticlesViewSubject::Type(),page3));
 	page3->AddSpace(10);
 	page3->SetColStretch(1,3);
 
@@ -464,12 +465,12 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageViewObject(par
 	iggFrame *dbpage0 = new iggFrame(db,2);
 	db->AddPage("Main",icon,dbpage0);
 
-	iggFrameDataVariableList *av = new iggFrameDataVariableList(mProvider,"Split by...",iParticlesViewObject::KeyAttributeToSplit(),0,dbpage0);
+	iggFrameDataVariableList *av = new iggFrameDataVariableList(mProvider,"Split by...",iParticlesViewSubject::KeyAttributeToSplit(),0,dbpage0);
 	av->InsertItem("Do not split");
 	av->Complete(); // splitter's attributes start with -1
 	dbpage0->AddLine(av);
 
-	iggWidgetKeyStretchComboBox *as = new iggWidgetKeyStretchComboBox(iParticlesViewObject::KeySplitRangesStretch(),dbpage0);
+	iggWidgetKeyStretchComboBox *as = new iggWidgetKeyStretchComboBox(iParticlesViewSubject::KeySplitRangesStretch(),dbpage0);
 	dbpage0->AddLine(as);
 	dbpage0->AddSpace(10);
 	dbpage0->SetColStretch(1,3);
@@ -504,21 +505,15 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageViewObject(par
 }
 
 
-iViewObject* iggPageParticles::GetViewObject() const
-{
-	return this->GetViewModule()->GetParticlesFamily()->GetCurrentMember();
-}
-
-
 void iggPageParticles::SetCurrentParticleSet(int n)
 {
-	if(n>=0 && n<=this->GetShell()->GetControlModule()->GetViewModule()->GetParticlesFamily()->GetMaxMemberIndex())
+	if(n>=0 && n<=this->GetParticlesObject()->GetNumberOfTypes())
 	{
 		mCurrentParticleSet = n;
 		iString ws;
 		this->GetShell()->GetControlModule()->PackCommand(ws,iViewModule::KeyParticlesCurrent(),n);
 		this->GetShell()->GetControlModule()->Execute(ws,false);
-		if(n < mIcons.Size()) this->GetMainWindow()->UpdateParticleSetWidgets(mIcons[n]); else this->GetMainWindow()->UpdateParticleSetWidgets(mIcons[0]);
+		this->GetMainWindow()->UpdateParticleSetWidgets(mIcons[n]);
 	}
 }
 
@@ -529,11 +524,18 @@ void iggPageParticles::AddIcon(const iImage *image)
 }
 
 
-bool iggPageParticles::UpdateWidgetBody()
+void iggPageParticles::UpdateWidgetBody()
 {
-	if(mCurrentParticleSet != this->GetViewModule()->GetParticlesFamily()->GetCurrentMemberIndex())
+	if(mCurrentParticleSet != this->GetParticlesObject()->GetActiveDataTypeIndex())
 	{
-		this->SetCurrentParticleSet(this->GetViewModule()->GetParticlesFamily()->GetCurrentMemberIndex());
+		this->SetCurrentParticleSet(this->GetParticlesObject()->GetActiveDataTypeIndex());
 	}
-	return iggPage::UpdateWidgetBody();
+//	this->GetMainWindow()->UpdateParticleSetWidgets(mIcons[mCurrentParticleSet]);
+	this->iggPage::UpdateWidgetBody();
+}
+
+
+iViewObject* iggPageParticles::GetParticlesObject() const
+{
+	return this->GetShell()->GetControlModule()->GetViewModule()->GetParticlesObject();
 }
