@@ -33,9 +33,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "iimagefactory.h"
 #include "ishell.h"
-#include "isurfaceviewobject.h"
+#include "isurfaceviewsubject.h"
 #include "iviewmodule.h"
-#include "iviewobjectfamily.h"
 
 #include "iggdatatypeprovider.h"
 #include "iggframecurrentinstance.h"
@@ -100,11 +99,10 @@ namespace iggPageSurface_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
-			bool ret = iggWidgetKeyRadioBox::UpdateWidgetBody();
-			if(ret) this->UpdateBuddy();
-			return ret;
+			this->iggWidgetKeyRadioBox::UpdateWidgetBody();
+			this->UpdateBuddy();
 		}
 		
 		virtual void OnInt1Body(int i)
@@ -151,7 +149,7 @@ namespace iggPageSurface_Private
 				}
 			default:
 				{
-					IERROR_REPORT_ERROR("Incorrect button in MethodRadioBox.");
+					IERROR_REPORT("Incorrect button in MethodRadioBox.");
 				}
 			}
 		}
@@ -192,10 +190,9 @@ namespace iggPageSurface_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			this->UpdateBuddy();
-			return true;
 		}
 		
 		virtual void OnInt1Body(int)
@@ -264,12 +261,12 @@ namespace iggPageSurface_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			int n;
 			bool dataPresent;
 
-			if(!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyDataPresent(),dataPresent) || !this->GetShell()->GetControlModule()->QueryValue(iViewModule::KeySurfaceMax(),n))
+			if(!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyDataPresent(),dataPresent) || !this->GetShell()->GetControlModule()->QueryValue(iViewModule::KeySurfaceMax(),n))
 			{
 				this->Enable(false);
 				return this->UpdateFailed();
@@ -297,7 +294,6 @@ namespace iggPageSurface_Private
 			}
 
 			mWidgetHelper->Enable(this->AreTwoInstancesConsistent());
-			return true;
 		}
 		
 		bool AreTwoInstancesConsistent() const
@@ -305,12 +301,12 @@ namespace iggPageSurface_Private
 			int m1, m2, v1, v2, dc1, dc2;
 
 			if(mSpinBox1->GetValue()==mSpinBox2->GetValue() ||
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyMethod(),m1,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyMethod(),m2,-1,mSpinBox2->GetValue()-1) ||
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyIsoSurfaceVar(),v1,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyIsoSurfaceVar(),v2,-1,mSpinBox2->GetValue()-1) ||
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyActiveDataType(),dc1,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyActiveDataType(),dc2,-1,mSpinBox2->GetValue()-1))
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyMethod(),m1,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyMethod(),m2,-1,mSpinBox2->GetValue()-1) ||
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceVar(),v1,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceVar(),v2,-1,mSpinBox2->GetValue()-1) ||
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyDataType(),dc1,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyDataType(),dc2,-1,mSpinBox2->GetValue()-1))
 			{
 				return false; 
 			}
@@ -335,29 +331,29 @@ namespace iggPageSurface_Private
 			
 			if(!this->AreTwoInstancesConsistent())
 			{
-				IERROR_REPORT_ERROR("Two isosurafces instances are not compatible or are not isosurfaces.");
+				IERROR_REPORT("Two isosurafces instances are not compatible or are not isosurfaces.");
 				mWidgetHelper->Enable(false);
 				return;
 			}
 
 			if(
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyMethod(),m,-1,mSpinBox1->GetValue()-1) ||
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyIsoSurfaceVar(),v,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyActiveDataType(),dc,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyIsoSurfaceLevel(),lmin,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyIsoSurfaceLevel(),lmax,-1,mSpinBox2->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyPosition(true),pmin,3,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyPosition(true),pmax,3,-1,mSpinBox2->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeySize(true),smin,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeySize(true),smax,-1,mSpinBox2->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyPlaneDirection(),dmin,3,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyPlaneDirection(),dmax,3,-1,mSpinBox2->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyOpacity(),0,omin,2,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyOpacity(),0,omax,2,-1,mSpinBox2->GetValue()-1) ||
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyColor(),0,cmin,2,-1,mSpinBox1->GetValue()-1) || 
-				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewObject::KeyColor(),0,cmax,2,-1,mSpinBox2->GetValue()-1)) 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyMethod(),m,-1,mSpinBox1->GetValue()-1) ||
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceVar(),v,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyDataType(),dc,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceLevel(),lmin,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyIsoSurfaceLevel(),lmax,-1,mSpinBox2->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyPosition(true),pmin,3,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyPosition(true),pmax,3,-1,mSpinBox2->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeySize(true),smin,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeySize(true),smax,-1,mSpinBox2->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyPlaneDirection(),dmin,3,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyPlaneDirection(),dmax,3,-1,mSpinBox2->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyOpacity(),0,omin,2,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyOpacity(),0,omax,2,-1,mSpinBox2->GetValue()-1) ||
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyColor(),0,cmin,2,-1,mSpinBox1->GetValue()-1) || 
+				!this->GetShell()->GetControlModule()->QueryValue(iSurfaceViewSubject::KeyColor(),0,cmax,2,-1,mSpinBox2->GetValue()-1)) 
 			{
-				IERROR_REPORT_ERROR("Unable to query Surface object.");
+				IERROR_REPORT("Unable to query Surface object.");
 				mWidgetHelper->Enable(false);
 				return;
 			}
@@ -378,7 +374,7 @@ namespace iggPageSurface_Private
 
 			if((m==_SurfaceMethodIsoSurface) && (fabs(lstp)<0.01))
 			{
-				IERROR_REPORT_ERROR("Cannot create new isosurface: the two limits are too close.");
+				IERROR_REPORT("Cannot create new isosurface: the two limits are too close.");
 				mWidgetHelper->Enable(false);
 				return;
 			}
@@ -395,21 +391,21 @@ namespace iggPageSurface_Private
 					d[i] = dmin[i] + dstp[i]*(n+1);
 				}
 
-				if(this->GetShell()->GetControlModule()->CreateObject(iSurfaceViewObject::Type(),false))
+				if(this->GetShell()->GetControlModule()->CreateObject(iSurfaceViewSubject::Type(),false))
 				{
 					//
 					//  Set the parameters of the new instance
 					//
 					iString ws;
-					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewObject::KeyActiveDataType(),dc);
-					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewObject::KeyMethod(),m);
-					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewObject::KeyOpacity(),0,o);
-					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewObject::KeyColor(),0,c);
-					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewObject::KeyIsoSurfaceVar(),v);
-					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewObject::KeyIsoSurfaceLevel(),l);
-					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewObject::KeyPosition(true),p,3);
-					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewObject::KeySize(true),s);
-					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewObject::KeyPlaneDirection(),d,3);
+					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyDataType(),dc);
+					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyMethod(),m);
+					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyOpacity(),0,o);
+					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyColor(),0,c);
+					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyIsoSurfaceVar(),v);
+					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyIsoSurfaceLevel(),l);
+					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyPosition(true),p,3);
+					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeySize(true),s);
+					this->GetShell()->GetControlModule()->PackCommand(ws,iSurfaceViewSubject::KeyPlaneDirection(),d,3);
 					this->GetShell()->GetControlModule()->Execute(ws,false,iggWidgetKeyHandlerBase::GetGlobalExecuteFlags());
 				}
 			}
@@ -426,7 +422,7 @@ namespace iggPageSurface_Private
 using namespace iggPageSurface_Private;
 
 
-iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageViewObject(parent)
+iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageObject(parent,iParameter::_ObjectTypeSurface)
 {
 	const iImage *icon = iImageFactory::FindIcon("surf.png");
 
@@ -444,7 +440,7 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageViewObject(parent)
 	//
 	//  Show
 	//
-	iggWidget *show = new iggWidgetShowButton(iSurfaceViewObject::Type(),page0top);
+	iggWidget *show = new iggWidgetShowButton(iSurfaceViewSubject::Type(),page0top);
 	iggFrameCurrentInstance *ci1 = new iggFrameCurrentInstance(false,"Instance","Instance",iViewModule::KeySurfaceCurrent(),iViewModule::KeySurfaceMax(),page0top);
 	ci1->AddDependent(this);
 	page0top->AddLine(show,(iggWidget *)0,(iggWidget *)0,ci1);
@@ -453,17 +449,17 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageViewObject(parent)
 	//  Method & flip normals
 	//
 	iggFrame *mf = new iggFrame(page0top,2);
-	MethodRadioBox *mb = new MethodRadioBox(iSurfaceViewObject::KeyMethod(),mf);
+	MethodRadioBox *mb = new MethodRadioBox(iSurfaceViewSubject::KeyMethod(),mf);
 	iggFrame *mf2 = new iggFrame(mf,1);
-	mf2->AddLine(new iggWidgetKeyColorSelection(iSurfaceViewObject::KeyColor(),mf2,false,0));
-	mf2->AddLine(new iggWidgetKeyCheckBox("Flip normals",iSurfaceViewObject::KeyNormalsFlipped(),mf2));
+	mf2->AddLine(new iggWidgetKeyColorSelection(iSurfaceViewSubject::KeyColor(),mf2,false,0));
+	mf2->AddLine(new iggWidgetKeyCheckBox("Flip normals",iSurfaceViewSubject::KeyNormalsFlipped(),mf2));
 	mf->AddLine(mb,mf2);
 	page0top->AddLine(mf,2);
 	page0top->AddSpace(2);
 	//
 	//  Opacity
 	//
-	iggWidgetKeyFloatSlider *os = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,5,"Opacity",iSurfaceViewObject::KeyOpacity(),_RenderModeUseGlobal,page0top,0);
+	iggWidgetKeyFloatSlider *os = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,5,"Opacity",iSurfaceViewSubject::KeyOpacity(),_RenderModeUseGlobal,page0top,0);
 	page0top->AddLine(os,3);
 	iggWidgetAllInstancesCheckBox *li = new iggWidgetAllInstancesCheckBox(page0top);
 	li->AddDependent(os);
@@ -491,30 +487,30 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageViewObject(parent)
 	msflip->AddLayer(mspage0);
 
 	iggFrame *iv = new iggFrame(mspage0,1);
-	iggFrameDataVariableList *io = new iggFrameDataVariableList(mProvider,"Isosurface of...",iSurfaceViewObject::KeyIsoSurfaceVar(),0,iv);
+	iggFrameDataVariableList *io = new iggFrameDataVariableList(mProvider,"Isosurface of...",iSurfaceViewSubject::KeyIsoSurfaceVar(),0,iv);
 	io->Complete();
 	io->AddDependent(show);
 	iv->AddLine(io);
-	iv->AddLine(new iggWidgetKeyCheckBox("Optimize",iSurfaceViewObject::KeyIsoSurfaceOptimization(),iv));
+	iv->AddLine(new iggWidgetKeyCheckBox("Optimize",iSurfaceViewSubject::KeyIsoSurfaceOptimization(),iv));
 	
-	iggWidgetKeyRadioBox *id = new iggWidgetKeyRadioBox(1,"Reduction",0,iSurfaceViewObject::KeyIsoSurfaceReduction(),mspage0);
+	iggWidgetKeyRadioBox *id = new iggWidgetKeyRadioBox(1,"Reduction",0,iSurfaceViewSubject::KeyIsoSurfaceReduction(),mspage0);
 	id->InsertItem("None");
 	id->InsertItem("Light");
 	id->InsertItem("Medium");
 	id->InsertItem("Heavy");
 
-	iggWidgetKeyRadioBox *is = new iggWidgetKeyRadioBox(1,"Smoothing",0,iSurfaceViewObject::KeyIsoSurfaceSmoothing(),mspage0);
+	iggWidgetKeyRadioBox *is = new iggWidgetKeyRadioBox(1,"Smoothing",0,iSurfaceViewSubject::KeyIsoSurfaceSmoothing(),mspage0);
 	is->InsertItem("None");
 	is->InsertItem("Light");
 	is->InsertItem("Medium");
 	is->InsertItem("Heavy");
 
 	mspage0->AddLine(iv,id,is);
-	mspage0->AddLine(new iggWidgetKeyCheckBox("Use alternative reduction method",iSurfaceViewObject::KeyAlternativeIsoSurfaceReductionMethod(),mspage0),3);
+	mspage0->AddLine(new iggWidgetKeyCheckBox("Use alternative reduction method",iSurfaceViewSubject::KeyAlternativeIsoSurfaceReductionMethod(),mspage0),3);
 	
 	mspage0->AddSpace(10);
 
-	iggWidget *il = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Level",iSurfaceViewObject::KeyIsoSurfaceLevel(),&iSurfaceViewObject::KeyIsoSurfaceVar(),0,_RenderModeUseGlobal,mspage0);
+	iggWidget *il = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Level",iSurfaceViewSubject::KeyIsoSurfaceLevel(),&iSurfaceViewSubject::KeyIsoSurfaceVar(),0,_RenderModeUseGlobal,mspage0);
 	io->AddDependent(il);
 	mspage0->AddLine(il,3);
 	
@@ -527,7 +523,7 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageViewObject(parent)
 	iggFrame *mspage1 = new iggFrame(msflip);
 	msflip->AddLayer(mspage1);
 
-	iggFrameObjectControls *sc= new iggFrameObjectControls("",iSurfaceViewObject::KeyPosition(true),iSurfaceViewObject::KeyPlaneDirection(),iSurfaceViewObject::KeySize(true),iSurfaceViewObject::KeyAttachProbeToMarker(),iSurfaceViewObject::KeyProbePositionToPickedPoint(),mspage1);
+	iggFrameObjectControls *sc= new iggFrameObjectControls("",iSurfaceViewSubject::KeyPosition(true),iSurfaceViewSubject::KeyPlaneDirection(),iSurfaceViewSubject::KeySize(true),iSurfaceViewSubject::KeyAttachProbeToMarker(),iSurfaceViewSubject::KeyProbePositionToPickedPoint(),mspage1);
 	mb->SetObjectBuddy(sc);
 	mspage1->AddLine(sc);
 
@@ -552,7 +548,7 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageViewObject(parent)
 	pb->AddPage("Palette",icon,pbpage0);
 
 	iggFrame *pf = new iggFrame(pbpage0,2);
-	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mProvider,"Paint with...",iSurfaceViewObject::KeyPaintVar(),0,pf,0);
+	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mProvider,"Paint with...",iSurfaceViewSubject::KeyPaintVar(),0,pf,0);
 	pl->InsertItem("None");
 	pl->Complete();
 
@@ -564,7 +560,7 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageViewObject(parent)
 
 	pbpage0->AddSpace(10);
 
-	iggFramePaletteSelection *ps = new iggFramePaletteSelection(iSurfaceViewObject::KeyPalette(),pbpage0,0);
+	iggFramePaletteSelection *ps = new iggFramePaletteSelection(true,iSurfaceViewSubject::KeyPalette(),pbpage0,0);
 	ss->SetPalBuddy(ps);
 
 	pbpage0->AddLine(ps,2);
@@ -580,7 +576,7 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageViewObject(parent)
 	iggFrame *pbpage1 = new iggFrame(pb,2);
 	pb->AddPage("Material",icon,pbpage1);
 
-	iggFrameMaterialProperties *mp = new iggFrameMaterialProperties(false,true,iSurfaceViewObject::Type(),pbpage1,0);
+	iggFrameMaterialProperties *mp = new iggFrameMaterialProperties(false,true,iSurfaceViewSubject::Type(),pbpage1,0);
 	pbpage1->AddLine(mp);
 	
 	pbpage1->AddSpace(10);
@@ -603,7 +599,7 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageViewObject(parent)
 	//
 	//  Color
 	//
-	page2->AddLine(new iggWidgetKeyColorSelection(iSurfaceViewObject::KeyColor(),page2,false,0),new iggFrameCreateDeleteButton(this,iSurfaceViewObject::Type(),true,"instance",page2));
+	page2->AddLine(new iggWidgetKeyColorSelection(iSurfaceViewSubject::KeyColor(),page2,false,0),new iggFrameCreateDeleteButton(this,iSurfaceViewSubject::Type(),true,"instance",page2));
 	page2->AddSpace(10);
 
 	page2->AddLine(new BatchCreateFrame(page2),2);
@@ -620,13 +616,8 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageViewObject(parent)
 	//
 	//  Replicate
 	//
-	page3->AddLine(new iggFrameReplicate(iSurfaceViewObject::Type(),page3));
+	page3->AddLine(new iggFrameReplicate(iSurfaceViewSubject::Type(),page3));
 	page3->AddSpace(10);
 	page3->SetColStretch(1,3);
 }
 
-
-iViewObject* iggPageSurface::GetViewObject() const
-{
-	return this->GetViewModule()->GetSurfaceFamily()->GetCurrentMember();
-}
