@@ -32,9 +32,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "idatasubject.h"
 #include "ierror.h"
 #include "iimagefactory.h"
-#include "ivectorfieldviewobject.h"
+#include "ivectorfieldviewsubject.h"
 #include "iviewmodule.h"
-#include "iviewobjectfamily.h"
 
 #include "iggdatatypeprovider.h"
 #include "iggframedatavariablelist.h"
@@ -85,17 +84,16 @@ namespace iggPageVectorField_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
-			bool ret = iggWidgetKeyRadioBox::UpdateWidgetBody();
-			if(ret) this->UpdateBuddy();
-			return ret;
+			this->iggWidgetKeyRadioBox::UpdateWidgetBody();
+			this->UpdateBuddy();
 		}
 		
 		virtual void OnInt1Body(int i)
 		{
 			this->UpdateBuddy();
-			iggWidgetKeyRadioBox::OnInt1Body(i);
+			this->iggWidgetKeyRadioBox::OnInt1Body(i);
 		}
 
 		virtual void UpdateBuddy()
@@ -134,7 +132,7 @@ namespace iggPageVectorField_Private
 				}
 			default:
 				{
-					IERROR_REPORT_ERROR("Incorrect button in MethodRadioBox.");
+					IERROR_REPORT("Incorrect button in MethodRadioBox.");
 				}
 			}
 		}
@@ -147,7 +145,7 @@ namespace iggPageVectorField_Private
 using namespace iggPageVectorField_Private;
 
 
-iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageViewObject(parent)
+iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageObject(parent,iParameter::_ObjectTypeVectorField)
 {
 	const iImage *icon = iImageFactory::FindIcon("vect.png");
 
@@ -160,32 +158,32 @@ iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageViewObject
 	//
 	//  Show
 	//
-	page0->AddLine(new iggWidgetShowButton(iVectorFieldViewObject::Type(),page0));
+	page0->AddLine(new iggWidgetShowButton(iVectorFieldViewSubject::Type(),page0));
 	page0->AddSpace(2);
 	//
 	//  Method & color
 	//
 	iggFrame *mc = new iggFrame(page0,2);
-	iggWidgetKeyRadioBox *mb = new iggWidgetKeyRadioBox(1,"Method",0,iVectorFieldViewObject::KeyMethod(),mc);
+	iggWidgetKeyRadioBox *mb = new iggWidgetKeyRadioBox(1,"Method",0,iVectorFieldViewSubject::KeyMethod(),mc);
 	mb->InsertItem("Glyph");
 	mb->InsertItem("Stream lines");
 	mb->InsertItem("Stream tubes");
 	mb->InsertItem("Strean bands");
-	mc->AddLine(mb,new iggWidgetKeyColorSelection(iVectorFieldViewObject::KeyColor(),mc,false,0));
+	mc->AddLine(mb,new iggWidgetKeyColorSelection(iVectorFieldViewSubject::KeyColor(),mc,false,0));
 	page0->AddLine(mc);
 	page0->AddSpace(10);
 	//
 	//  Glyph size
 	//
-	page0->AddLine(new iggWidgetKeySizeSlider(1.0e-5,0,"Glyph size",iVectorFieldViewObject::KeyGlyphSize(true),_RenderModeUseGlobal,page0),2);
+	page0->AddLine(new iggWidgetKeySizeSlider(1.0e-5,0,"Glyph size",iVectorFieldViewSubject::KeyGlyphSize(true),_RenderModeUseGlobal,page0),2);
 	page0->AddSpace(2);
 	//
 	//  Vector magnitude and downsample
 	//
-	iggWidgetKeyVariableLimitsSlider *ms = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Vector magnitude",iDataSubject::KeyUpperLimit(),0,0,_RenderModeUseGlobal,page0,-1,&iVectorFieldViewObject::KeyDataOffset());
+	iggWidgetKeyVariableLimitsSlider *ms = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Vector magnitude",iDataSubject::KeyUpperLimit(),0,0,_RenderModeUseGlobal,page0,-1,&iVectorFieldViewSubject::KeyDataOffset());
 	ms->SetStretch(5,10,0);
 	page0->AddLine(ms,2);
-	iggWidgetKeyIntSlider *rs = new iggWidgetKeyIntSlider(1,20,5,"Sample rate",iVectorFieldViewObject::KeyGlyphSampleRate(),_RenderModeUseGlobal,page0);
+	iggWidgetKeyIntSlider *rs = new iggWidgetKeyIntSlider(1,20,5,"Sample rate",iVectorFieldViewSubject::KeyGlyphSampleRate(),_RenderModeUseGlobal,page0);
 	rs->SetStretch(5,10,0);
 	page0->AddLine(rs,2);
 	page0->AddSpace(10);
@@ -210,7 +208,7 @@ iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageViewObject
 	iggFrame *pbpage0 = new iggFrame(pb,3);
 	pb->AddPage("Palette",icon,pbpage0);
 
-	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mScalarFieldProvider,"Paint with...",iVectorFieldViewObject::KeyColorBy(),&iVectorFieldViewObject::KeyConnectedToScalars(),pbpage0);
+	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mScalarFieldProvider,"Paint with...",iVectorFieldViewSubject::KeyColorBy(),&iVectorFieldViewSubject::KeyConnectedToScalars(),pbpage0);
 	pl->InsertItem("Vector magnitude");
 	pl->InsertItem("Vorticity");
 	pl->InsertItem("Divergence");
@@ -218,7 +216,7 @@ iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageViewObject
 	pl->Complete();
 	pbpage0->AddLine(pl);
 	pbpage0->AddSpace(10);
-	pbpage0->AddLine(new iggFramePaletteSelection(iVectorFieldViewObject::KeyPalette(),pbpage0,0),2);
+	pbpage0->AddLine(new iggFramePaletteSelection(true,iVectorFieldViewSubject::KeyPalette(),pbpage0,0),2);
 	pbpage0->AddSpace(20);
 	pbpage0->SetColStretch(1,10);
 	pbpage0->SetColStretch(2,3);
@@ -228,7 +226,7 @@ iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageViewObject
 	iggFrame *pbpage1 = new iggFrame(pb,2);
 	pb->AddPage("Material",icon,pbpage1);
 
-	pbpage1->AddLine(new iggFrameMaterialProperties(false,false,iVectorFieldViewObject::Type(),pbpage1));
+	pbpage1->AddLine(new iggFrameMaterialProperties(false,false,iVectorFieldViewSubject::Type(),pbpage1));
 	pbpage1->AddSpace(10);
 	pbpage1->SetColStretch(0,10);
 	pbpage1->SetColStretch(1,3);
@@ -250,11 +248,11 @@ iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageViewObject
 	iggFrame *sbpage0 = new iggFrame(sb,4);
 	sb->AddPage("Main",icon,sbpage0);
 
-	sbpage0->AddLine(new iggWidgetKeySpinBox(1,10000,"Number of streamlines",0,iVectorFieldViewObject::KeyNumberOfStreamLines(),sbpage0));
+	sbpage0->AddLine(new iggWidgetKeySpinBox(1,10000,"Number of streamlines",0,iVectorFieldViewSubject::KeyNumberOfStreamLines(),sbpage0));
 
-	MethodRadioBox *lt = new MethodRadioBox(iVectorFieldViewObject::KeySourceType(),sbpage0);
+	MethodRadioBox *lt = new MethodRadioBox(iVectorFieldViewSubject::KeySourceType(),sbpage0);
 
-	iggWidgetKeyRadioBox *ld = new iggWidgetKeyRadioBox(2,"Streamline direction",0,iVectorFieldViewObject::KeyLineDir(),sbpage0);
+	iggWidgetKeyRadioBox *ld = new iggWidgetKeyRadioBox(2,"Streamline direction",0,iVectorFieldViewSubject::KeyLineDir(),sbpage0);
 	ld->InsertItem("Up stream");
 	ld->InsertItem("Down stream");
 	ld->InsertItem("Forward");
@@ -263,20 +261,20 @@ iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageViewObject
 	sbpage0->AddLine(lt,ld);
 	sbpage0->AddSpace(5);
 
-	iggWidgetKeyFloatSlider *ll = new iggWidgetKeyFloatSlider(1.0e-4f,1.0f,40,1,0,"Length",iVectorFieldViewObject::KeyLineLength(),_RenderModeUseGlobal,sbpage0);
+	iggWidgetKeyFloatSlider *ll = new iggWidgetKeyFloatSlider(1.0e-4f,1.0f,40,1,0,"Length",iVectorFieldViewSubject::KeyLineLength(),_RenderModeUseGlobal,sbpage0);
 	ll->SetStretch(3,10);
-	iggWidgetKeyIntSlider *lw = new iggWidgetKeyIntSlider(1,10,0,"Width",iVectorFieldViewObject::KeyTubeSize(),_RenderModeUseGlobal,sbpage0);
+	iggWidgetKeyIntSlider *lw = new iggWidgetKeyIntSlider(1,10,0,"Width",iVectorFieldViewSubject::KeyTubeSize(),_RenderModeUseGlobal,sbpage0);
 	lw->SetStretch(3,10);
 	sbpage0->AddLine(ll,3);
 	sbpage0->AddLine(lw,3);
 	sbpage0->AddSpace(10);
 
 	iggFrame *ab = new iggFrame("Adjustments",sbpage0,1);
-	iggWidgetKeyIntSlider *lq = new iggWidgetKeyIntSlider(1,7,0,"Line quality",iVectorFieldViewObject::KeyLineQuality(),_RenderModeUseGlobal,ab);
+	iggWidgetKeyIntSlider *lq = new iggWidgetKeyIntSlider(1,7,0,"Line quality",iVectorFieldViewSubject::KeyLineQuality(),_RenderModeUseGlobal,ab);
 	lq->SetStretch(5,10);
-	iggWidgetKeyFloatSlider *tr = new iggWidgetKeyFloatSlider(1.0,20.0,20,0,0,"Tube range",iVectorFieldViewObject::KeyTubeRangeFactor(),_RenderModeUseGlobal,ab);
+	iggWidgetKeyFloatSlider *tr = new iggWidgetKeyFloatSlider(1.0,20.0,20,0,0,"Tube range",iVectorFieldViewSubject::KeyTubeRangeFactor(),_RenderModeUseGlobal,ab);
 	tr->SetStretch(5,10);
-	iggWidgetKeyFloatSlider *tv = new iggWidgetKeyFloatSlider(1.0e-4f,1.0f,40,1,0,"Tube variation",iVectorFieldViewObject::KeyTubeVariationFactor(),_RenderModeUseGlobal,ab);
+	iggWidgetKeyFloatSlider *tv = new iggWidgetKeyFloatSlider(1.0e-4f,1.0f,40,1,0,"Tube variation",iVectorFieldViewSubject::KeyTubeVariationFactor(),_RenderModeUseGlobal,ab);
 	tv->SetStretch(5,10);
 	ab->AddLine(lq);
 	ab->AddLine(tr);
@@ -292,7 +290,7 @@ iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageViewObject
 	iggFrame *sbpage1 = new iggFrame(sb,2);
 	sb->AddPage("Source",icon,sbpage1);
 
-	iggFrameObjectControls *sc = new iggFrameObjectControls("Source",iVectorFieldViewObject::KeySourcePosition(true),iVectorFieldViewObject::KeySourceDirection(),iVectorFieldViewObject::KeySourceSize(true),iVectorFieldViewObject::KeyAttachSourceToMarker(),iVectorFieldViewObject::KeySourcePositionToPickedPoint(),sbpage1);
+	iggFrameObjectControls *sc = new iggFrameObjectControls("Source",iVectorFieldViewSubject::KeySourcePosition(true),iVectorFieldViewSubject::KeySourceDirection(),iVectorFieldViewSubject::KeySourceSize(true),iVectorFieldViewSubject::KeyAttachSourceToMarker(),iVectorFieldViewSubject::KeySourcePositionToPickedPoint(),sbpage1);
 	lt->SetObjectBuddy(sc);
 
 	sbpage1->AddLine(sc);
@@ -300,8 +298,8 @@ iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageViewObject
 	sbpage1->AddSpace(5);
 
 	iggFrame *of = new iggFrame("Source object",sbpage1,1);
-	iggWidgetKeyCheckBox *sv = new iggWidgetKeyCheckBox("Show",iVectorFieldViewObject::KeyShowSourceObject(),of);
-	iggWidgetKeyFloatSlider *so = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,0,"Opacity",iVectorFieldViewObject::KeySourceOpacity(),_RenderModeUseGlobal,of);
+	iggWidgetKeyCheckBox *sv = new iggWidgetKeyCheckBox("Show",iVectorFieldViewSubject::KeyShowSourceObject(),of);
+	iggWidgetKeyFloatSlider *so = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,0,"Opacity",iVectorFieldViewSubject::KeySourceOpacity(),_RenderModeUseGlobal,of);
 	so->SetStretch(3,10);
 	of->AddLine(sv);
 	of->AddLine(so);
@@ -321,13 +319,8 @@ iggPageVectorField::iggPageVectorField(iggFrameBase *parent) : iggPageViewObject
 	//
 	//  Replicate
 	//
-	page3->AddLine(new iggFrameReplicate(iVectorFieldViewObject::Type(),page3));
+	page3->AddLine(new iggFrameReplicate(iVectorFieldViewSubject::Type(),page3));
 	page3->AddSpace(10);
 	page3->SetColStretch(1,3);
 }
 
-
-iViewObject* iggPageVectorField::GetViewObject() const
-{
-	return this->GetViewModule()->GetVectorFieldFamily()->GetCurrentMember();
-}
