@@ -38,13 +38,13 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ierror.h"
 #include "ierrorstatus.h"
 #include "iimagefactory.h"
-#include "imarkerviewobject.h"
+#include "imarker.h"
+#include "imarkerfamily.h"
 #include "ipalette.h"
 #include "ipointglyph.h"
 #include "irendertool.h"
-#include "iviewmodule.h"
-#include "iviewobjectfamily.h"
 #include "ishell.h"
+#include "iviewmodule.h"
 #include "ivtk.h"
 #include "iwriter.h"
 
@@ -143,17 +143,16 @@ namespace iggPageView_Private
 			mAutomaticBox = autobox;
 			autobox->AddDependent(this);
 
-			this->AddLine(new ShowColorBarCheckBox(key,this));
+			//this->AddLine(new ShowColorBarCheckBox(key,this));
+			this->AddLine(new iggWidgetTextArea("Palette",this));
+			mPaletteList = new iggWidgetKeyComboBox("",0,key,this,2);
+			this->AddLine(mPaletteList);
 
 			iggFrameDataVariableList *vl = new iggFrameDataVariableList(mProvider,"Variable",key,0,this,0);
 			vl->Complete(-1);
 			this->AddLine(vl);
 			this->AddSpace(2);
 
-			this->AddLine(new iggWidgetTextArea("Palette",this));
-			mPaletteList = new iggWidgetKeyComboBox("",-1,key,this,2);
-			this->AddLine(mPaletteList);
-
 			this->AddLine(new iggWidgetTextArea("Data type",this));
 			this->AddLine(new iggFrameDataTypeSelector(mProvider,false,"",this));
 		}
@@ -165,7 +164,7 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			//
 			//  Are we enabled?
@@ -181,9 +180,15 @@ namespace iggPageView_Private
 				//
 				int i, np = this->GetShell()->GetControlModule()->GetNumberOfPalettes();
 				mPaletteList->Clear();
+				mPaletteList->SetOffset(np-1);
+				for(i=-np+1; i<=0; i++)
+				{
+					mPaletteList->InsertItem(this->GetShell()->GetControlModule()->GetPalette(-i)->GetName()+" reversed");
+				}
+				mPaletteList->InsertItem("Do not show");
 				for(i=0; i<np; i++)
 				{
-					mPaletteList->InsertItem(this->GetShell()->GetControlModule()->GetPalette(i)->GetName().ToCharPointer());
+					mPaletteList->InsertItem(this->GetShell()->GetControlModule()->GetPalette(i)->GetName());
 				}
 				//
 				//  Update data type
@@ -195,7 +200,7 @@ namespace iggPageView_Private
 			//
 			//  Update the rest
 			//
-			return iggFrame::UpdateWidgetBody();
+			this->iggFrame::UpdateWidgetBody();
 		}
 
 		const iObjectKey &mKey;
@@ -220,10 +225,9 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			mWidgetHelper->Enable(this->GetShell()->GetControlModule()->GetViewModule()->GetReader()->IsFileAnimatable());
-			return true;
 		}
 
 		virtual void Execute()
@@ -354,10 +358,10 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			mWidgetHelper->Enable(!mView->GetImage().IsEmpty());
-			return iggWidgetKeyFileNameButton::UpdateWidgetBody();
+			this->iggWidgetKeyFileNameButton::UpdateWidgetBody();
 		}
 
 		iggWidgetImageArea *mView;
@@ -379,16 +383,16 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			mWidgetHelper->Enable(!mView->GetImage().IsEmpty());
-			return iggWidgetLaunchButton::UpdateWidgetBody();
+			this->iggWidgetLaunchButton::UpdateWidgetBody();
 		}
 
 		virtual void OnVoid1Body()
 		{
 			mWindow->SetImage(mView->GetImage());
-			iggWidgetLaunchButton::OnVoid1Body();
+			this->iggWidgetLaunchButton::OnVoid1Body();
 		}
 
 		iggWidgetImageArea *mView;
@@ -412,15 +416,13 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			mSubject->Clear();
 
 			int i, n = this->GetShell()->GetControlModule()->GetNumberOfViewModules();
 			for(i=0; i<n; i++) mSubject->InsertItem("Window "+iString::FromNumber(i+1));
 			mSubject->SetValue(this->GetShell()->GetControlModule()->GetCurrentViewModuleIndex());
-
-			return true;
 		}
 
 		void OnInt1Body(int v)
@@ -486,7 +488,7 @@ namespace iggPageView_Private
 					this->SetBaloonHelp("Clone the current window","This button creates a clone of the current visualization window. The clone shares the data with the parent window, and at birth has the same values of all parameters for all visualization objects. It does have a separate set of visualization objects however, so the parameters of the parent and the clone window can be changed independently.");
 					break;
 				}
-			default: IERROR_REPORT_FATAL_ERROR("Incorrect button type");
+			default: IERROR_FINISH("Incorrect button type");
 			}
         }
 
@@ -537,10 +539,9 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			mWidgetHelper->Enable(this->GetShell()->GetControlModule()->GetNumberOfViewModules() > 1);
-			return true;
 		}
 
 		virtual void Execute()
@@ -576,10 +577,9 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			mSubject->SetDown(this->GetMainWindow()->GetWindowUnderFocusCurrent());
-			return true;
 		}
 
 		void OnVoid1Body()
@@ -604,9 +604,8 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
-			return true;
 		}
 
 		void OnVoid1Body()
@@ -650,7 +649,7 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			if(this->GetShell()->GetControlModule()->GetViewModule()->IsClone())
 			{
@@ -662,7 +661,7 @@ namespace iggPageView_Private
 				mIconView->SetImage(*mIcon1,false);
 				mTextView->SetText(mText1);
 			}
-			return iggFrame::UpdateWidgetBody();
+			this->iggFrame::UpdateWidgetBody();
 		}
 
 		const iImage *mIcon1, *mIcon2;
@@ -686,17 +685,16 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			if(this->GetShell()->GetControlModule()->GetViewModule()->GetMarkerFamily()->GetMaxMemberIndex()>0 || this->GetShell()->GetControlModule()->GetViewModule()->GetMarkerFamily()->IsVisible())
 			{
 				this->Enable(true);
-				return iggFrame::UpdateWidgetBody();
+				this->iggFrame::UpdateWidgetBody();
 			}
 			else
 			{
 				this->Enable(false);
-				return true;
 			}
 		}
 	};
@@ -713,7 +711,7 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			int i, n = this->GetShell()->GetControlModule()->GetViewModule()->GetMarkerFamily()->GetMaxMemberIndex() + 1;
 
@@ -737,7 +735,7 @@ namespace iggPageView_Private
 					mSubject->SetItem("#"+iString::FromNumber(i+1)+" "+this->GetShell()->GetControlModule()->GetViewModule()->GetMarkerFamily()->GetMember(i)->GetTypeAsString(),i,true);
 				}
 			}
-			return iggWidgetKeyComboBox::UpdateWidgetBody();
+			this->iggWidgetKeyComboBox::UpdateWidgetBody();
 		}
 	};
 
@@ -779,7 +777,7 @@ namespace iggPageView_Private
 
 	public:
 
-		MarkerPositionFrame(iggFrame *parent) : iggFramePosition("Position",iMarkerViewObject::KeyPosition(true),parent,true), iggRenderWindowObserver(parent)
+		MarkerPositionFrame(iggFrame *parent) : iggFramePosition("Position",iMarker::KeyPosition(true),parent,true), iggRenderWindowObserver(parent)
 		{
 		}
 
@@ -787,7 +785,7 @@ namespace iggPageView_Private
 
 		virtual void OnRenderWindowModified()
 		{
-			iggFramePosition::UpdateWidgetBody();
+			this->iggFramePosition::UpdateWidgetBody();
 		}
 	};
 
@@ -928,12 +926,11 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			bool v;
 			mBuddy->QueryValue(v);
 			this->Enable(!v);
-			return true;
 		}
 
 		virtual void Execute()
@@ -988,7 +985,7 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			double cr[2];
 
@@ -999,20 +996,15 @@ namespace iggPageView_Private
 				case 0:
 					{
 						this->Display(cr[0]);
-						return true;
+						break;
 					}
 				case 1:
 					{
 						this->Display(cr[1]);
-						return true;
-					}
-				default:
-					{
-						return false;
+						break;
 					}
 				}
 			}
-			else return false;
 		}
 
 		virtual void OnRenderWindowModified()
@@ -1035,13 +1027,13 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			iAnimator *an = this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator();
 			this->Enable(an->GetMode() == 4);
 			iPointerCast<iggAnimatorEventObserver,iAnimatorEventObserver>(an->GetObserver())->AddDependent(this);
 			this->SetRange(0,this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->GetNumberOfCameraPathSteps()-1);
-			return iggWidgetKeyIntSlider::UpdateWidgetBody();
+			this->iggWidgetKeyIntSlider::UpdateWidgetBody();
 		}
 	};
 
@@ -1058,16 +1050,39 @@ namespace iggPageView_Private
 
 	protected:
 
-		virtual bool UpdateWidgetBody()
+		virtual void UpdateWidgetBody()
 		{
 			this->Enable(this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->GetMode() == 4);
-			return true;
 		}
 	};
 
 	//
 	//  Window size dialog and its widgets
 	//
+	class WindowSizeButton : public iggWidgetSimpleButton
+	{
+
+	public:
+
+		WindowSizeButton(iggWidgetSimpleSpinBox **boxes, const iString &title, float scale, iggFrame *parent) : iggWidgetSimpleButton(title,parent)
+		{
+			mBoxes = boxes;
+			mScale = scale;
+			this->SetBaloonHelp(title+" the window size","This button "+title+"s the size of the current view window.");
+        }
+
+	protected:
+
+		virtual void Execute()
+		{
+			int i;
+			for(i=0; i<2; i++) mBoxes[i]->SetValue(round(mScale*mBoxes[i]->GetValue()));
+		}
+
+		float mScale;
+		iggWidgetSimpleSpinBox **mBoxes;
+	};
+
 	class WindowSizeDialog : public iggDialog
 	{
 
@@ -1077,6 +1092,10 @@ namespace iggPageView_Private
 		{
 			mBox[0] = new iggWidgetSimpleSpinBox(120,32768,1,"",mFrame);
 			mBox[1] = new iggWidgetSimpleSpinBox(120,32768,1,"",mFrame);
+
+			iggFrame* tmp = new iggFrame(mFrame,2);
+			tmp->AddLine(new WindowSizeButton(mBox,"half",0.5f,tmp),new WindowSizeButton(mBox,"double",2.0f,tmp));
+			mFrame->AddLine(tmp,2);
 			mFrame->AddLine(new iggWidgetTextArea("%bWidth:",mFrame),mBox[0]);
 			mFrame->AddLine(new iggWidgetTextArea("%bHeight:",mFrame),mBox[1]);
 			mFrame->AddSpace(10);
@@ -1208,7 +1227,8 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 		isb->InsertItem("Joystick");
 		isb->InsertItem("Flight");
 		isb->InsertItem("Keyboard");
-		iggWidget *wid = new iggWidgetKeyColorSelection(iViewModule::KeyBackgroundColor(),fb2,false);
+		iggWidgetKeyColorSelection *wid = new iggWidgetKeyColorSelection(iViewModule::KeyBackgroundColor(),fb2,false);
+		wid->SetText("Background color");
 		if(this->GetMainWindow()->GetDialogImageComposer() != 0) wid->AddDependent(this->GetMainWindow()->GetDialogImageComposer()->GetArea());
 		fb2->AddLine(isb);
 		fb2->AddLine(wid);
@@ -1602,7 +1622,7 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			iggFrame *msb = new MarkerFrameBox(mbpage0);
 			CurrentMarkerBox *mcm = new CurrentMarkerBox(msb);
 			msb->AddLine(new iggWidgetTextArea("Current",msb),mcm);
-			iggWidgetKeyComboBox *mcs = new iggWidgetKeyComboBox("",0,iMarkerViewObject::KeyType(),msb);
+			iggWidgetKeyComboBox *mcs = new iggWidgetKeyComboBox("",0,iMarker::KeyType(),msb);
 			mcs->AddDependent(mcm);
 			mcm->AddDependent(mbpage0);
 			for(i=0; i<__NumPointTypes; i++)
@@ -1610,11 +1630,11 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 				mcs->InsertItem(iPointGlyph::GetName(i));
 			}
 			msb->AddLine(new iggWidgetTextArea("Type",msb),mcs);
-			msb->AddLine(new iggWidgetTextArea("Caption",msb),new iggWidgetKeyTextLineEdit(false,"",iMarkerViewObject::KeyCaptionText(),_RenderModeUseGlobal,msb));
-			msb->AddLine(new iggWidgetTextArea("Marker size",msb),new iggWidgetKeySizeSlider(1.0e-5,0,"",iMarkerViewObject::KeySize(true),_RenderModeUseGlobal,msb));
+			msb->AddLine(new iggWidgetTextArea("Caption",msb),new iggWidgetKeyTextLineEdit(false,"",iMarker::KeyCaptionText(),_RenderModeUseGlobal,msb));
+			msb->AddLine(new iggWidgetTextArea("Marker size",msb),new iggWidgetKeySizeSlider(1.0e-5,0,"",iMarker::KeySize(true),_RenderModeUseGlobal,msb));
 
 			iggFrame *mcb = new iggFrame("Controls",mbpage0,1);
-			iggFrameCreateDeleteButton *mcd = new iggFrameCreateDeleteButton(page3,iMarkerViewObject::Type(),false,"marker",mcb);
+			iggFrameCreateDeleteButton *mcd = new iggFrameCreateDeleteButton(page3,iMarker::Type(),false,"marker",mcb);
 			mcd->AddDependent(mbpage0);
 			mcb->AddLine(mcd);
 
@@ -1631,10 +1651,10 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			mbpage0->AddLine(msb,(iggWidget *)0,mcb);
 
 			iggFrame *mfc = new iggFrame("Colors",mbpage0,1);
-			iggWidgetKeyColorSelection *mcc = new iggWidgetKeyColorSelection(iMarkerViewObject::KeyColor(),mfc,false);
+			iggWidgetKeyColorSelection *mcc = new iggWidgetKeyColorSelection(iMarker::KeyColor(),mfc,false);
 			mcc->SetText("Marker");
 			mfc->AddLine(mcc);
-			mcc = new iggWidgetKeyColorSelection(iMarkerViewObject::KeyTextColor(),mfc,false);
+			mcc = new iggWidgetKeyColorSelection(iMarker::KeyTextColor(),mfc,false);
 			mcc->SetText("Caption");
 			mfc->AddLine(mcc);
 
@@ -1642,8 +1662,8 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			mbpage0->AddLine(mpos,2,mfc,1);
 			mmm->AddDependent(mpos);
 
-			mbpage0->AddLine(new iggWidgetKeyCheckBox("Move objects interactively",iMarkerViewObject::KeyInteractiveMove(),mbpage0),3);
-			mbpage0->AddLine(new iggWidgetKeyCheckBox("Scale marker to keep size fixed",iMarkerViewObject::KeyScaled(),mbpage0),3);
+			mbpage0->AddLine(new iggWidgetKeyCheckBox("Move objects interactively",iMarker::KeyInteractiveMove(),mbpage0),3);
+			mbpage0->AddLine(new iggWidgetKeyCheckBox("Scale marker to keep size fixed",iMarker::KeyScaled(),mbpage0),3);
 
 			mbpage0->AddSpace(10);
 			mbpage0->SetColStretch(1,10);
@@ -1656,8 +1676,8 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			iggFrame *mbpage1 = new iggFrame(mb,2);
 			mb->AddPage("Material ",icon,mbpage1);
 
-			mbpage1->AddLine(new iggFrameMaterialProperties(false,false,iMarkerViewObject::Type(),mbpage1));
-			mbpage1->AddLine(new iggWidgetKeyFloatSlider(0.0f,1.0f,10,0,0,"Opacity",iMarkerViewObject::KeyOpacity(),_RenderModeUseGlobal,mbpage1));
+			mbpage1->AddLine(new iggFrameMaterialProperties(false,false,iMarker::Type(),mbpage1));
+			mbpage1->AddLine(new iggWidgetKeyFloatSlider(0.0f,1.0f,10,0,0,"Opacity",iMarker::KeyOpacity(),_RenderModeUseGlobal,mbpage1));
 
 			mbpage1->AddSpace(10);
 			mbpage1->SetColStretch(0,10);
@@ -1688,15 +1708,15 @@ iggPageView::iggPageView(iggFrameBase *parent) : iggPageMain(parent)
 			mb->AddPage("Transform",icon,mbpage3);
 
 			iggFrame *mtb = new iggFrame("Scale",mbpage3,1);
-			mtb->AddLine(new iggWidgetKeyFloatSlider(0.01f,100.0f,200,1,5,"X",iMarkerViewObject::KeyTransform(),_RenderModeUseGlobal,mtb,3));
-			mtb->AddLine(new iggWidgetKeyFloatSlider(0.01f,100.0f,200,1,5,"Y",iMarkerViewObject::KeyTransform(),_RenderModeUseGlobal,mtb,4));
-			mtb->AddLine(new iggWidgetKeyFloatSlider(0.01f,100.0f,200,1,5,"Z",iMarkerViewObject::KeyTransform(),_RenderModeUseGlobal,mtb,5));
+			mtb->AddLine(new iggWidgetKeyFloatSlider(0.01f,100.0f,200,1,5,"X",iMarker::KeyTransform(),_RenderModeUseGlobal,mtb,3));
+			mtb->AddLine(new iggWidgetKeyFloatSlider(0.01f,100.0f,200,1,5,"Y",iMarker::KeyTransform(),_RenderModeUseGlobal,mtb,4));
+			mtb->AddLine(new iggWidgetKeyFloatSlider(0.01f,100.0f,200,1,5,"Z",iMarker::KeyTransform(),_RenderModeUseGlobal,mtb,5));
 			mbpage3->AddLine(mtb);
 
 			mtb = new iggFrame("Rotate",mbpage3,1);
-			mtb->AddLine(new iggWidgetKeyFloatSlider(-180.0,180.0,360,0,5,"X",iMarkerViewObject::KeyTransform(),_RenderModeUseGlobal,mtb,0));
-			mtb->AddLine(new iggWidgetKeyFloatSlider(-180.0,180.0,360,0,5,"Y",iMarkerViewObject::KeyTransform(),_RenderModeUseGlobal,mtb,1));
-			mtb->AddLine(new iggWidgetKeyFloatSlider(-180.0,180.0,360,0,5,"Z",iMarkerViewObject::KeyTransform(),_RenderModeUseGlobal,mtb,2));
+			mtb->AddLine(new iggWidgetKeyFloatSlider(-180.0,180.0,360,0,5,"X",iMarker::KeyTransform(),_RenderModeUseGlobal,mtb,0));
+			mtb->AddLine(new iggWidgetKeyFloatSlider(-180.0,180.0,360,0,5,"Y",iMarker::KeyTransform(),_RenderModeUseGlobal,mtb,1));
+			mtb->AddLine(new iggWidgetKeyFloatSlider(-180.0,180.0,360,0,5,"Z",iMarker::KeyTransform(),_RenderModeUseGlobal,mtb,2));
 			mbpage3->AddLine(mtb);
 
 			mbpage3->AddSpace(10);
