@@ -30,12 +30,10 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "icontrolmodule.h"
-#include "icrosssectionviewobject.h"
 #include "ierror.h"
 #include "ieventobserver.h"
 #include "iopengl.h"
 #include "iviewmodule.h"
-#include "iviewobjectfamily.h"
 
 #include "iggmainwindow.h"
 #include "iggshell.h"
@@ -64,7 +62,7 @@ bool iggRenderWindow::mRenderIntoMemory = false;
 
 iggRenderWindow::iggRenderWindow(iViewModule *vm) : iViewModuleComponent(vm), iShellComponent(vm?vm->GetControlModule()->GetShell():0)
 {
-	mSubject = iggSubjectFactory::CreateRenderWindowSubject(this); IERROR_ASSERT_NULL_POINTER(mSubject);
+	mSubject = iggSubjectFactory::CreateRenderWindowSubject(this); IERROR_ASSERT(mSubject);
 
 	mInitialized = mResizing = mMoving = false;
 
@@ -360,8 +358,7 @@ void iggRenderWindow::RenderIntoMemory()
 	//
 	//  QGLWidget::renderPixmap does nor render textures under Unix - force polygonal mode for xsections
 	//
-	int k;
-	for(k=0; k<=this->GetViewModule()->GetCrossSectionFamily()->GetMaxMemberIndex(); k++) this->GetViewModule()->GetCrossSectionFamily()->GetMember(k)->ForcePolygonalMethod(true);
+	this->GetViewModule()->ForceCrossSectionToUsePolygonalMethod(true);
 	//
 	//  Need to reset all existing display lists
 	//
@@ -385,6 +382,6 @@ void iggRenderWindow::RenderIntoMemory()
 	this->DoubleBuffer = db;
 
 	vtkMapper::GlobalImmediateModeRenderingOff();
-	for(k=0; k<=this->GetViewModule()->GetCrossSectionFamily()->GetMaxMemberIndex(); k++) this->GetViewModule()->GetCrossSectionFamily()->GetMember(k)->ForcePolygonalMethod(false);
+	this->GetViewModule()->ForceCrossSectionToUsePolygonalMethod(false);
 }
 
