@@ -90,10 +90,15 @@ namespace iggShell_Private
 
 		virtual void Show(bool s)
 		{
-//			if(s) mFlipper->Start(); else mFlipper->Abort();
+			mFlipper->Reset();
 			iggDialog::Show(s);
 		}
 
+		void OnInitAtom()
+		{
+			mFlipper->Advance();
+		}
+
 		void PlaceOnDesktop(int dw, int dh)
 		{
 			int wg[4];
@@ -215,7 +220,7 @@ void iggShell::PrepareForConstruction()
 	//
 	if(mShowFlashWindow)
 	{
-		mFlashWindow = new iggShell_Private::DialogFlashWindow(this); IERROR_ASSERT_NULL_POINTER(mFlashWindow);
+		mFlashWindow = new iggShell_Private::DialogFlashWindow(this); IERROR_ASSERT(mFlashWindow);
 		//
 		//  calculate the position of the flash window
 		//
@@ -279,7 +284,10 @@ void iggShell::LoadStateFile(const iString &fname)
 		iPointerCast<iggShell_Private::DialogFlashWindow,iggDialog>(mFlashWindow)->DisplayMessage("Loading the state file...");
 		mSubject->ProcessEvents(false);
 	}
-	if(!this->GetControlModule()->LoadStateFromFile(fname)) mMainWindow->PopupWindow("The state file is corrupted.\n Default values of parameters will be used.",_PopupWindowError);
+	if(!this->GetControlModule()->LoadStateFromFile(fname))
+	{
+		mMainWindow->PopupWindow("The state file is corrupted.\n Default values of parameters will be used.",_PopupWindowError);
+	}
 }
 
 
@@ -460,6 +468,7 @@ void iggShell::Start()
 		//
 		mFlashWindow->Show(false);
 		delete mFlashWindow;
+		mFlashWindow = 0;
 	}
 
 	mSubject->ProcessEvents(false);
@@ -637,3 +646,9 @@ void iggShell::ProcessEvents(bool sync)
 	mSubject->ProcessEvents(sync);
 }
 
+
+void iggShell::OnInitAtomBody(bool timed)
+{
+	if(timed && mFlashWindow!=0) iPointerCast<iggShell_Private::DialogFlashWindow,iggDialog>(mFlashWindow)->OnInitAtom();
+}
+
