@@ -112,12 +112,11 @@ iggWidgetKeyExecButton::iggWidgetKeyExecButton(const iString &text, const iObjec
 }
 
 
-bool iggWidgetKeyExecButton::UpdateWidgetBody()
+void iggWidgetKeyExecButton::UpdateWidgetBody()
 {
 	//
 	//  Nothing to update
 	//
-	return true;
 }
 
 
@@ -139,12 +138,11 @@ iggWidgetKeyToolButton::iggWidgetKeyToolButton(const iString &text, const iObjec
 }
 
 
-bool iggWidgetKeyToolButton::UpdateWidgetBody()
+void iggWidgetKeyToolButton::UpdateWidgetBody()
 {
 	//
 	//  Nothing to update
 	//
-	return true;
 }
 
 
@@ -189,12 +187,11 @@ void iggWidgetKeyFileNameButton::SetDefaut(const iString &s)
 }
 
 
-bool iggWidgetKeyFileNameButton::UpdateWidgetBody()
+void iggWidgetKeyFileNameButton::UpdateWidgetBody()
 {
 	//
 	//  Nothing to update
 	//
-	return true;
 }
 
 
@@ -235,12 +232,11 @@ void iggWidgetKeyExecIntButton::QueryValue(int &val) const
 }
 
 
-bool iggWidgetKeyExecIntButton::UpdateWidgetBody()
+void iggWidgetKeyExecIntButton::UpdateWidgetBody()
 {
 	//
 	//  Nothing to update
 	//
-	return true;
 }
 
 
