@@ -130,7 +130,7 @@ void iggWidgetKeySlider<T>::OnVoid1Body()
 		ivmin = this->GetInternalValue(dvmin);
 		dvmax = this->GetDisplayedValue(vmax);
 		ivmax = this->GetInternalValue(dvmax);
-		IERROR_REPORT_FATAL_ERROR("Bug: GetDisplayedValue and GetInternalValue are NOT consistent.");
+		IERROR_FINISH("Bug: GetDisplayedValue and GetInternalValue are NOT consistent.");
 	}
 #endif
 }
