@@ -58,7 +58,7 @@ iggWidgetKeyTrackBall::iggWidgetKeyTrackBall(const iObjectKey &dirkey, bool foll
 {
 	if(this->GetKey().Argument()!=iObjectKey::_Float || this->GetKey().Dimension()<2 || this->GetKey().Dimension()>3)
 	{
-		IERROR_REPORT_ERROR("Widget iggWidgetKeyTrackBall is congifured incorrectly.");
+		IERROR_REPORT("Widget iggWidgetKeyTrackBall is congifured incorrectly.");
 	}
 
 	mIsVectorKey = (this->GetKey().Dimension() == 3);
@@ -72,7 +72,7 @@ iggWidgetKeyTrackBall::~iggWidgetKeyTrackBall()
 }
 
 
-bool iggWidgetKeyTrackBall::UpdateWidgetBody()
+void iggWidgetKeyTrackBall::UpdateWidgetBody()
 {
 	this->UpdateHelp();
 
@@ -82,9 +82,7 @@ bool iggWidgetKeyTrackBall::UpdateWidgetBody()
 		if(this->GetShell()->GetControlModule()->QueryValue(this->GetKey(),n,3))
 		{
 			this->SetDirection(n);
-			return true;
 		}
-		else return this->UpdateFailed();
 	}
 	else
 	{
@@ -92,9 +90,7 @@ bool iggWidgetKeyTrackBall::UpdateWidgetBody()
 		if(this->GetShell()->GetControlModule()->QueryValue(this->GetKey(),a,2))
 		{
 			this->SetAngles(a[0],a[1]);
-			return true;
 		}
-		else return this->UpdateFailed();
 	}
 }
 
@@ -128,7 +124,7 @@ void iggWidgetKeyTrackBall::OnBool1Body(bool final)
 	}
 
 	bool ret = this->GetShell()->GetControlModule()->Execute(ws,final || this->GetRenderMode()==_RenderModeImmediate,this->GetExecuteFlags());
-	if(!ret) IERROR_REPORT_ERROR("iggWidgetKeyTrackBall::OnDirection failed.");
+	if(!ret) IERROR_REPORT("iggWidgetKeyTrackBall::OnDirection failed.");
 }
 
 
