@@ -69,7 +69,7 @@ iqtFrameSubject::~iqtFrameSubject()
 //
 iqtFrameBookSubject::iqtFrameBookSubject(iggFrameBook *owner, bool withFeedback) : QTabWidget(iqtAssistant::Convert(owner->GetParent())), ibgFrameBookSubject(owner,withFeedback)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT_NULL_POINTER(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
 
@@ -82,9 +82,9 @@ iqtFrameBookSubject::iqtFrameBookSubject(iggFrameBook *owner, bool withFeedback)
 	if(withFeedback)
 	{
 #ifdef IQT_3
-		if(!this->connect(this,SIGNAL(currentChanged(QWidget*)),this,SLOT(OnCurrentChanged(QWidget*)))) IERROR_REPORT_ERROR("Missed connection.");
+		if(!this->connect(this,SIGNAL(currentChanged(QWidget*)),this,SLOT(OnCurrentChanged(QWidget*)))) IERROR_REPORT("Missed connection.");
 #else
-		if(!this->connect(this,SIGNAL(currentChanged(int)),this,SLOT(OnCurrentChanged(int)))) IERROR_REPORT_ERROR("Missed connection.");
+		if(!this->connect(this,SIGNAL(currentChanged(int)),this,SLOT(OnCurrentChanged(int)))) IERROR_REPORT("Missed connection.");
 #endif
 	}
 }
@@ -132,7 +132,7 @@ void iqtFrameBookSubject::OpenPage(int i)
 
 void iqtFrameBookSubject::AddPage(const iString &title, const iImage *image, iggFrame *frame)
 {
-	QWidget *w = iqtAssistant::Convert(frame); IERROR_ASSERT_NULL_POINTER(w);
+	QWidget *w = iqtAssistant::Convert(frame); IERROR_ASSERT(w);
 #ifndef IQT_3
 	iqtAssistant::SetParent(w,0);
 #endif
@@ -242,7 +242,7 @@ void iqtFrameBookSubject::ChangeIcon(int n, const iImage &image)
 //
 iqtFrameFlipSubject::iqtFrameFlipSubject(iggFrameFlip *owner, bool expanding) : QStackedWidget(iqtAssistant::Convert(owner->GetParent())), ibgFrameFlipSubject(owner,expanding)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT_NULL_POINTER(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,expanding?QSizePolicy::Expanding:QSizePolicy::Minimum));
 }
@@ -292,7 +292,7 @@ void iqtFrameFlipSubject::AddLayerBody(iggFrame *page)
 //
 iqtFrameScrollSubject::iqtFrameScrollSubject(iggFrameScroll *owner, bool withHor) : QScrollArea(iqtAssistant::Convert(owner->GetParent())), ibgFrameScrollSubject(owner,withHor)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT_NULL_POINTER(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
 #ifdef IQT_3
 	this->setVScrollBarMode(QScrollView::Auto);
