@@ -205,7 +205,7 @@ int iqtMainWindowSubject::PopupWindow(const iggFrame *parent, const iString &tex
 		}
 	default:
 		{
-			IERROR_REPORT_ERROR("Incorrect type for pop-up window.");
+			IERROR_REPORT("Incorrect type for pop-up window.");
 		}
 	}
 	return -1;
@@ -233,7 +233,7 @@ void iqtMainWindowSubject::PlaceWindowsInDockedPositions()
 {
 	if(mMainFrame != 0)
 	{
-		IERROR_REPORT_FATAL_ERROR("Invalid call to iqtMainWindowSubject::PlaceWindowsInDockedPositions.");
+		IERROR_FINISH("Invalid call to iqtMainWindowSubject::PlaceWindowsInDockedPositions.");
 	}
 
 	QSize s = this->size();
@@ -243,7 +243,7 @@ void iqtMainWindowSubject::PlaceWindowsInDockedPositions()
 	mMainFrame = this->centralWidget();
 
 	QWidget *base = new QWidget(this);
-	QGridLayout *l = iqtAssistant::NewLayout(base,2); IERROR_ASSERT_NULL_POINTER(l);
+	QGridLayout *l = iqtAssistant::NewLayout(base,2); IERROR_ASSERT(l);
 #ifdef IQT_3
 	l->expand(2,2);
 	l->setColStretch(0,10);
@@ -261,7 +261,7 @@ void iqtMainWindowSubject::PlaceWindowsInDockedPositions()
 
 	QGridLayout *fl = iqtAssistant::NewLayout(fw,1);
 
-    Workspace *ws = new Workspace(fw); IERROR_ASSERT_NULL_POINTER(ws);
+    Workspace *ws = new Workspace(fw); IERROR_ASSERT(ws);
 	fl->addWidget(ws,0,0);
 
 	l->addWidget(fw,0,0);
@@ -305,7 +305,7 @@ void iqtMainWindowSubject::RestoreWindowsFromDockedPositions()
 {
 	if(mMainFrame == 0)
 	{
-		IERROR_REPORT_FATAL_ERROR("Invalid call to iqtMainWindowSubject::RestoreWindowsFromDockedPositions.");
+		IERROR_FINISH("Invalid call to iqtMainWindowSubject::RestoreWindowsFromDockedPositions.");
 	}
 
 	this->hide();
