@@ -67,7 +67,7 @@ iqtRenderWindowSubject::iqtRenderWindowSubject(iggRenderWindow *owner, QWidget*
 #endif
 	ibgRenderWindowSubject(owner)
 {
-	mWindowHelper = new iqtWindowHelper(this,iImageFactory::FindIcon("genie1vtk.png"),""); IERROR_ASSERT_NULL_POINTER(mWindowHelper);
+	mWindowHelper = new iqtWindowHelper(this,iImageFactory::FindIcon("genie1vtk.png"),""); IERROR_ASSERT(mWindowHelper);
 
 	this->setFocusPolicy(QFocus::StrongFocus);
 
@@ -76,7 +76,7 @@ iqtRenderWindowSubject::iqtRenderWindowSubject(iggRenderWindow *owner, QWidget*
 	//
 	if(!this->doubleBuffer())
 	{
-		IERROR_REPORT_FATAL_ERROR("IFrIT only works in double buffering mode.");
+		IERROR_FINISH("IFrIT only works in double buffering mode.");
 	}
 	this->setMinimumWidth(120);
 	this->setMinimumHeight(120);
@@ -86,8 +86,8 @@ iqtRenderWindowSubject::iqtRenderWindowSubject(iggRenderWindow *owner, QWidget*
 
 	if(parent!=0 && parent->layout()!=0) iPointerCast<QGridLayout,QLayout>(parent->layout())->addWidget(this,0,0);
 
-	mTimer = new QTimer(this); IERROR_ASSERT_NULL_POINTER(mTimer);
-	if(!connect(mTimer,SIGNAL(timeout()),this,SLOT(OnTimer()))) IERROR_REPORT_FATAL_ERROR("Missed connection.");
+	mTimer = new QTimer(this); IERROR_ASSERT(mTimer);
+	if(!connect(mTimer,SIGNAL(timeout()),this,SLOT(OnTimer()))) IERROR_FINISH("Missed connection.");
 }
 
 
@@ -117,7 +117,7 @@ void iqtRenderWindowSubject::AttachToParent(QWidget *parent)
 #ifdef I_DEBUG
 	if(!this->context()->isValid())
 	{
-		IERROR_REPORT_FATAL_ERROR("Invalid context in iqtRenderWindowSubject.");
+		IERROR_FINISH("Invalid context in iqtRenderWindowSubject.");
 	}
 #endif
 }
@@ -272,7 +272,7 @@ void iqtRenderWindowSubject::paintGL()
 	//
 	if(this->autoBufferSwap())
 	{
-		IERROR_REPORT_ERROR("iqtRenderWindowSubject only works with AutoBufferSwap turned off.");
+		IERROR_REPORT("iqtRenderWindowSubject only works with AutoBufferSwap turned off.");
 		return;
 	}
 
