@@ -67,7 +67,7 @@ using namespace iggParameter;
 //
 iqtWidgetDisplayAreaSubject::iqtWidgetDisplayAreaSubject(iggWidget *owner, const iString &text) : QLabel(iqtAssistant::Convert(owner->GetParent())), ibgWidgetDisplayAreaSubject(owner,text)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT_NULL_POINTER(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
 	this->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
@@ -114,14 +114,14 @@ void iqtWidgetDisplayAreaSubject::SetImage(const iImage *image, bool withMask, b
 //
 iqtWidgetMultiImageDisplayAreaSubject::iqtWidgetMultiImageDisplayAreaSubject(iggWidget *owner) : QLabel(iqtAssistant::Convert(owner->GetParent())), ibgWidgetMultiImageDisplayAreaSubject(owner)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT_NULL_POINTER(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
 	this->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
 	this->setScaledContents(false);
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
 
-	mTimer = new QTimer(this); IERROR_ASSERT_NULL_POINTER(mTimer);
-	if(!connect(mTimer,SIGNAL(timeout()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid1()))) IERROR_REPORT_ERROR("Missed connection.");
+	mTimer = new QTimer(this); IERROR_ASSERT(mTimer);
+	if(!connect(mTimer,SIGNAL(timeout()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid1()))) IERROR_REPORT("Missed connection.");
 };
 
 
@@ -143,7 +143,7 @@ ibgWidgetMultiImageDisplayAreaSubject::Image* iqtWidgetMultiImageDisplayAreaSubj
 		QPixmap &base = iPointerCast<qtImage,Image>(mImages[0])->Pixmap;
 		if(tmp.size() != base.size())
 		{
-			IERROR_REPORT_ERROR("Incompatible size of iqtWidgetMultiImageDisplayAreaSubject images.");
+			IERROR_REPORT("Incompatible size of iqtWidgetMultiImageDisplayAreaSubject images.");
 			tmp = QPixmap(base.size());
 		}
 	}
@@ -187,7 +187,7 @@ iqtWidgetDrawAreaSubject::iqtWidgetDrawAreaSubject(iggWidgetDrawArea *owner, boo
 	this->setAttribute(Qt::WA_PaintOnScreen);
 #endif
 
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT_NULL_POINTER(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
 	mPainter = new QPainter();
 	mBackgroundColor = iColor(255,255,255);
@@ -276,7 +276,7 @@ void iqtWidgetDrawAreaSubject::Begin(Mode m, bool clear)
 		}
 	default:
 		{
-			IERROR_REPORT_ERROR("Incorrect iqtWidgetDrawArea mode.");
+			IERROR_REPORT("Incorrect iqtWidgetDrawArea mode.");
 		}
 	}
 	mOffsetY = this->Height() - 1;
@@ -295,7 +295,7 @@ void iqtWidgetDrawAreaSubject::End()
 		}
 	default:
 		{
-			IERROR_REPORT_ERROR("Incorrect iqtWidgetDrawArea mode.");
+			IERROR_REPORT("Incorrect iqtWidgetDrawArea mode.");
 		}
 	}
 }
