@@ -174,7 +174,7 @@ namespace iqtWidgetEntrySubject_Private
 
 iqtWidgetEntrySubject::iqtWidgetEntrySubject(iggWidget *owner, bool slider, int numdig, const iString &label, iggWidgetRenderModeButton* rmb) : QWidget(iqtAssistant::Convert(owner->GetParent())), ibgWidgetEntrySubject(owner,slider,numdig,label,rmb)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT_NULL_POINTER(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
 	//
 	//  Create a layout
@@ -204,16 +204,16 @@ iqtWidgetEntrySubject::iqtWidgetEntrySubject(iggWidget *owner, bool slider, int
 	mSlider->setPageStep(1);
 	mSlider->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Minimum));
 	w->addWidget(mSlider,0,1);
-	if(!this->connect(mSlider,SIGNAL(valueChanged(int)),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnInt1(int)))) IERROR_REPORT_ERROR("Missed connection.");
-	if(!this->connect(mSlider,SIGNAL(sliderReleased()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid1()))) IERROR_REPORT_ERROR("Missed connection.");
+	if(!this->connect(mSlider,SIGNAL(valueChanged(int)),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnInt1(int)))) IERROR_REPORT("Missed connection.");
+	if(!this->connect(mSlider,SIGNAL(sliderReleased()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid1()))) IERROR_REPORT("Missed connection.");
 	if(!slider) mSlider->hide();
 
 	mEdit = new iqtWidgetEntrySubject_Private::LineEdit(slider,this);
 	if(slider || numdig>0) mEdit->setValidator(new QDoubleValidator(mEdit));
 	if(slider) mEdit->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum)); else mEdit->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Minimum));
 	w->addWidget(mEdit,0,2);
-	if(!this->connect(mEdit,SIGNAL(textChanged(const QString&)),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnString1(const QString &)))) IERROR_REPORT_ERROR("Missed connection.");
-	if(!this->connect(mEdit,SIGNAL(returnPressed()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid1()))) IERROR_REPORT_ERROR("Missed connection.");
+	if(!this->connect(mEdit,SIGNAL(textChanged(const QString&)),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnString1(const QString &)))) IERROR_REPORT("Missed connection.");
+	if(!this->connect(mEdit,SIGNAL(returnPressed()),iPointerCast<iqtWidgetHelper,ibgWidgetHelper>(mWidgetHelper),SLOT(OnVoid1()))) IERROR_REPORT("Missed connection.");
 	if(slider && numdig<=0) mEdit->hide();
 
 	mView = new QLCDNumber(this);
