@@ -116,7 +116,7 @@ protected:
 //
 iqtWidgetHelper::iqtWidgetHelper(QWidget *widget, iggWidget *owner) : ibgWidgetHelper(owner)
 {
-	IERROR_ASSERT_NULL_POINTER(widget);
+	IERROR_ASSERT(widget);
 	mWidget = widget;
 	mBaloonHelp = 0;
 }
