@@ -281,7 +281,7 @@ private:
 //
 iqtWidgetTextEditorSubject::iqtWidgetTextEditorSubject(iggWidgetTextEditor *owner, unsigned int mode) : QTextEdit(iqtAssistant::Convert(owner->GetParent())), ibgWidgetTextEditorSubject(owner,mode), mMode(mode)
 {
-	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT_NULL_POINTER(mWidgetHelper);
+	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
 	this->setFocusPolicy(QFocus::StrongFocus);
@@ -316,7 +316,7 @@ iqtWidgetTextEditorSubject::iqtWidgetTextEditorSubject(iggWidgetTextEditor *owne
 
 #ifndef I_NO_SYNTAX_HIGHLIGHTING
 #if defined(IQT_3) || defined(IQT_3SUPPORT)
-	mSyntaxHighlighter = new iqtSyntaxHighlighter; IERROR_ASSERT_NULL_POINTER(mSyntaxHighlighter);
+	mSyntaxHighlighter = new iqtSyntaxHighlighter; IERROR_ASSERT(mSyntaxHighlighter);
 	this->document()->setPreProcessor(mSyntaxHighlighter);
 #else
 	mSyntaxHighlighter = 0;
@@ -325,10 +325,10 @@ iqtWidgetTextEditorSubject::iqtWidgetTextEditorSubject(iggWidgetTextEditor *owne
 	mSyntaxHighlighter = 0;
 #endif
 
-	if(!connect(this,SIGNAL(textChanged()),this,SLOT(OnTextChanged()))) IERROR_REPORT_ERROR("Missed connection.");
-	if(!connect(this,SIGNAL(selectionChanged()),this,SLOT(OnSelectionChanged()))) IERROR_REPORT_ERROR("Missed connection.");
-	if(!connect(this,SIGNAL(cursorPositionChanged(int,int)),this,SLOT(OnCursorPositionChanged(int,int)))) IERROR_REPORT_ERROR("Missed connection.");
-	if(!connect(this,SIGNAL(returnPressed()),this,SLOT(OnReturnPressed()))) IERROR_REPORT_ERROR("Missed connection.");
+	if(!connect(this,SIGNAL(textChanged()),this,SLOT(OnTextChanged()))) IERROR_REPORT("Missed connection.");
+	if(!connect(this,SIGNAL(selectionChanged()),this,SLOT(OnSelectionChanged()))) IERROR_REPORT("Missed connection.");
+	if(!connect(this,SIGNAL(cursorPositionChanged(int,int)),this,SLOT(OnCursorPositionChanged(int,int)))) IERROR_REPORT("Missed connection.");
+	if(!connect(this,SIGNAL(returnPressed()),this,SLOT(OnReturnPressed()))) IERROR_REPORT("Missed connection.");
 }
 
 
@@ -414,10 +414,9 @@ void iqtWidgetTextEditorSubject::AppendText(const iString &text, bool scroll)
 {
 	this->blockSignals(true);
 	//
-	//  A work-around for a bug in some versions
+	//  A work-around for a bug in some versions - needed on idunn, for example
 	//
-	//if(false && this->GetText().IsEmpty()) this->SetText(text); else 
-	this->append(iqtAssistant::Convert(text));
+	if(this->GetText().IsEmpty()) this->SetText(text); else this->append(iqtAssistant::Convert(text));
 #if defined(IQT_3) || defined(IQT_3SUPPORT)
 	if(scroll) this->scrollToBottom();
 #endif
